<?php
/**
 * Application level Controller
 *
 * This file is application-wide controller file. You can put all
 * application-wide controller-related methods here.
 *
 * CakePHP(tm) : Rapid Development Framework (http://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 * @link          http://cakephp.org CakePHP(tm) Project
 * @package       app.Controller
 * @since         CakePHP(tm) v 0.2.9
 * @license       http://www.opensource.org/licenses/mit-license.php MIT License
 */

App::uses('Controller', 'Controller');

/**
 * Application Controller
 *
 * Add your application-wide methods in the class below, your controllers
 * will inherit them.
 *
 * @package		app.Controller
 * @link		http://book.cakephp.org/2.0/en/controllers.html#the-app-controller
 */
class AppController extends Controller {
	const SPL_LEAVE_CLASSIFICATION_CODE = 'LVC-3';
	
	public $uses = array(
		'EmployeeLeaveCard',
		'LeaveClassification',
	);
	
	public $components = array(
        'Session',
        'Auth' => array(
			'loginAction' => array('controller' => 'login', 'action' => 'index', 'prefix' => 'hris'),
            'logoutRedirect' => array('controller' => 'login', 'action' => 'index', 'prefix' => 'hris'),			
			'authorize' => array('Controller'),
        ),
		'Alert',
		'Paginator',
		'DaiPaginator',
		'DaiSecurity',
		'Integration',
		'DaiFpdf'
    );
	
	public function afterFilter() {
			$this->Session->delete('Alert');
	}
	public function beforeRender() {
		// $this->response->compress();
		$this->response->disableCache();
		// auto pull test3
		//auto pull test4
	}

	public function get_approver_setting($module = null) {
		$approver_order = array();
		if($module){
			if(isset($_SESSION['Auth']['User']['PositionDetail']['section_code'])){
				$section_code = $_SESSION['Auth']['User']['PositionDetail']['section_code'];
				$employee_code = $_SESSION['Auth']['User']['employee_code'];
				$this->loadModel('ApproverPerModules');
				$approver_setting = $this->ApproverPerModules->find('first', array(
					'conditions'=>array(
						'ApproverPerModules.section_code' => $section_code,
						'ApproverPerModules.module_code' => $module,
						
					)
				));
				if($approver_setting){
					if($approver_setting['ApproverPerModules']['first_approver']!=''){
						$approver_order[]=$approver_setting['ApproverPerModules']['first_approver'];
					}
					if($approver_setting['ApproverPerModules']['second_approver']!=''){
						$approver_order[]=$approver_setting['ApproverPerModules']['second_approver'];
					}
					if($approver_setting['ApproverPerModules']['third_approver']!=''){
						$approver_order[]=$approver_setting['ApproverPerModules']['third_approver'];
					}
					if($approver_setting['ApproverPerModules']['fourth_approver']!=''){
						$approver_order[]=$approver_setting['ApproverPerModules']['fourth_approver'];
					}
				}
			}
		}
		return $approver_order;
	}
	public function system_approver() {
		// debug($_SESSION['Auth']['User']['PositionDetail']['section_code']);
		// exit();
		
		
		$this->loadModel('SystemApprover');
		$system_approver = $this->SystemApprover->find('first', array(
			'conditions' => array(
				'SystemApprover.status' => 'Active'
			),
			'recursive' => -1
		));
		return $system_approver;
	}
	
		
	protected function app_get_dropdowns($requested_dropdowns = array()) {
		
		if (in_array('EmploymentStatus', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('EmploymentStatus');
			
			$employment_status_list = $this->EmploymentStatus->find('list', array(
				'fields' => array(
					'EmploymentStatus.code', 
					'EmploymentStatus.name'
				),
				'conditions' => array(
					'EmploymentStatus.status' => 'Active',
				),
				'order' => array(
					'EmploymentStatus.name' => 'ASC'
				)
			));			
			$this->set('app_employment_status_list', $employment_status_list);			
		}
		
		if (in_array('Section', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Section');
			
			$app_sections = $this->Section->find('list', array(
				'conditions' => array(
					'Section.status' => 'Active'
				),
				'order' => array(
					'Section.name' => 'ASC'
				)
			));
			
			$this->set('app_sections', $app_sections);
		}
		if (in_array('JobTitle', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('JobTitle');
			
			$app_jobtitle = $this->JobTitle->find('list', array(
				'conditions' => array(
					'JobTitle.status' => 'Active'
				),
				'order' => array(
					'JobTitle.name' => 'ASC'
				)
			));
			
			$this->set('app_jobtitle', $app_jobtitle);
		}
		if (in_array('Division', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Division');
			
			$app_divisions = $this->Division->find('list', array(
				'conditions' => array(
					'Division.status' => 'Active'
				),
				'order' => array(
					'Division.name' => 'ASC'
				)
			));
			
			$this->set('app_divisions', $app_divisions);
		}
		if (in_array('Unit', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Unit');
			
			$app_units = $this->Unit->find('list', array(
				'conditions' => array(
					'Unit.status' => 'Active'
				),
				'order' => array(
					'Unit.name' => 'ASC'
				)
			));
			
			$this->set('app_units', $app_units);
		}
		
		if (in_array('SubUnit', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('SubUnit');
			
			$app_sub_units = $this->SubUnit->find('list', array(
				'conditions' => array(
					'SubUnit.status' => 'Active'
				),
				'order' => array(
					'SubUnit.name' => 'ASC'
				)
			));
			
			$this->set('app_sub_units', $app_sub_units);
		}
		
		
		if (in_array('PersonnelType', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('PersonnelType');
			
			$app_personnel_types = $this->PersonnelType->find('list', array(
				'conditions' => array(
					'PersonnelType.status' => 'Active'
				),
				'order' => array(
					'PersonnelType.name' => 'ASC'
				)
			));
			
			$this->set('app_personnel_types', $app_personnel_types);
		}
		
		if (in_array('Signatory', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Signatory');
			
			$app_signatory_list = $this->Signatory->find('list', array(
				'conditions' => array(
					'Signatory.status' => 'Active'
				),
				'order' => array(
					'Signatory.name' => 'ASC'
				)
			));
			
			$this->set('app_signatory_list', $app_signatory_list);
		}
		
		if (in_array('Employee', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Employee');
			
			$app_employee_list= $this->Employee->find('all', array(
				'fields' => array(
					'Employee.employee_code',
					'Employee.first_name',
					'Employee.middle_name',
					'Employee.last_name',
				),
				'conditions' => array(
			
					'Employee.status' => 'Active'
				),
				'order' => 'last_name asc'
			));

			$app_employee_list = Set::combine($app_employee_list, '{n}.Employee.employee_code', array('{0} {1}', '{n}.Employee.last_name', '{n}.Employee.first_name','{n}.Employee.middle_name'));
			$this->set('app_employee_list', $app_employee_list);
			 
		}
		if (in_array('month_list', $requested_dropdowns) || count($requested_dropdowns) == 0) {
						
			$month_list = array(
				1  => 'January',
				2  => 'February',
				3  => 'March',
				4  => 'April',
				5  => 'May',
				6  => 'June',
				7  =>' July ',
				8  => 'August',
				9  => 'September',
				10 => 'October',
				11 => 'November',
				12 => 'December',
			);
			$this->set('month_list', $month_list);
		}
		
		
	}
	// public function head_approvers() {
		// $this->loadModel('SubUnit');
		// $sub_unit_approver = $this->SubUnit->find('first', array(
			// 'conditions' => array(
				// 'SubUnit.status' => 'Active',
				// 'OR' => array(
					// array('SubUnit.sub_unit_head' => $_SESSION['Auth']['User']['employee_code']),
					// array('SubUnit.sub_unit_head_assistant' => $_SESSION['Auth']['User']['employee_code']),
				// )
			// ),
		// ));

		// $this->loadModel('Unit');
		// $unit_approver = $this->Unit->find('first', array(
			// 'conditions' => array(
				// 'Unit.status' => 'Active',
				// 'OR' => array(
					// array('Unit.unit_head' => $_SESSION['Auth']['User']['employee_code']),
					// array('Unit.unit_head_assistant' => $_SESSION['Auth']['User']['employee_code']),
				// )
			// ),
		// ));
		
		// $this->loadModel('Section');
		// $section_approver = $this->Section->find('first', array(
			// 'conditions' => array(
				// 'Section.status' => 'Active',
				// 'OR' => array(
					// array('Section.section_head' => $_SESSION['Auth']['User']['employee_code']),
					// array('Section.assistant_section_head' => $_SESSION['Auth']['User']['employee_code']),
				// )
			// ),
		// ));
		
		// return array('sub_unit_approver' => $sub_unit_approver, 'unit_approver' => $unit_approver, 'section_approver' => $section_approver);
	// }
	function beforeFilter() {
		// phpinfo();
		$this->loadModel('SystemApprover');
		$find_approvers = $this->SystemApprover->find('first');
		$this->set('find_approvers', $find_approvers);

		$this->loadModel('Employee');
		
		$this->Auth->allow('display');
		if($this->Session->read('Auth.User.status') == 'Active') {
			
			$this->get_profile_image_link();
			// $this->get_leave_earned();
			
			if(isset($_SESSION['Kiosk']['kiosk']) && $_SESSION['Kiosk']['kiosk'] == 'kiosk'){
				$this->layout = 'kiosk-layout';
			}
			else if($_SESSION['Auth']['User']['role'] == 'Administrator'){
				$this->layout = 'dai.dai.administrator.default';  
			}
			else if($_SESSION['Auth']['User']['role'] == 'Accounting'){
				$this->layout = 'dai.dai.accounting.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'Medical Director'){
				$this->layout = 'dai.dai.medical_director.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'HR User'){
				$this->layout = 'dai.dai.hr_user.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'HR Section Head'){
				$this->layout = 'dai.dai.hr_user_section_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'HR Division Head'){
				$this->layout = 'dai.dai.hr_user_division_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'HR Sub Unit Head'){
				$this->layout = 'dai.dai.hr_user_sub_unit_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'HR Unit Head'){
				$this->layout = 'dai.dai.hr_user_unit_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'Non HR Section Head'){
				$this->layout = 'dai.dai.non_hr_section_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'Non HR Division Head'){
				$this->layout = 'dai.dai.non_hr_division_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'Non HR Unit Head'){
				$this->layout = 'dai.dai.non_hr_unit_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'Non HR Sub Unit Head'){
				$this->layout = 'dai.dai.non_hr_sub_unit_head.default';
			}
			else if($_SESSION['Auth']['User']['role'] == 'Non HR User'){
				$this->layout = 'dai.dai.non_hr_user.default';
			}
			else{
				$this->layout = 'dai.dai.employee.default';
			}
			
			// For AdvanceSearch incorporated in BootstrapComponent is_advanced_search 
			if(isset($_GET['is_advanced_search'])){
				if ($_GET['is_advanced_search'] != 1 ){
					unset($this->params->query['is_advanced_search']);
					$link_params = array_merge($this->request->params['pass'], $this->params['named'], array('?' => $this->params->query));
					unset($link_params['page']);
					return $this->redirect($link_params);
				}
			}
		
			
		}
		else {
			$url = $this->here;
			if (strpos($url, 'kiosk_login') !== false) {
				$this->layout = 'dai.kiosk_login.default';
			}else{
				$this->layout = 'dai.login.default';
			}
			
		}
		
		
    }
	
	protected function get_my_notifications($employee_code = null){
		
		$this->loadModel('LeaveEntry');
		
		$my_notifications = $this->LeaveEntry->query(
				'SELECT 
					LeaveEntry.id,
					LeaveClassification.name,
					LeaveEntry.filing_date as filing_date,
					LeaveEntry.employee_code,
					LeaveEntry.modified,
					LeaveEntry.filing_status,
					"view_leave_entry" as "action",
					"leave_entries" as "controller"
				FROM filing_leave_entries LeaveEntry
				LEFT JOIN setting_leave_classifications LeaveClassification 
					on LeaveClassification.code = LeaveEntry.leave_classification_code
				WHERE  LeaveEntry.employee_code = "'.$employee_code.'"
					AND LeaveEntry.status = "Active"
					AND LeaveEntry.notification_message_status = "Active"
					AND LeaveEntry.notification_read_status != 1
                    AND (LeaveEntry.filing_status = "Approved" 
					OR LeaveEntry.filing_status = "Disapproved" 
					OR LeaveEntry.filing_status = "Void")

					UNION

				SELECT 
					Compensatory.id,
					"COMPENSATORY" as name,
					CONCAT(Compensatory.date_from, " - ", Compensatory.date_to) as filing_date,
					Compensatory.employee_code,
					Compensatory.modified,
					Compensatory.filing_status,
					"view_compensatory" as "action",
					"compensatories" as "controller"
				FROM filing_compensatories Compensatory
				WHERE  Compensatory.employee_code = "'.$employee_code.'"
					AND Compensatory.status = "Active"
					AND Compensatory.notification_message_status = "Active"
					AND Compensatory.notification_read_status != 1
                    AND (Compensatory.filing_status = "Approved" 
					OR Compensatory.filing_status = "Disapproved" 
					OR Compensatory.filing_status = "Void")

					UNION

				SELECT 
					PermissionToLeave.id,
					PermissionToLeave.activity_title as name,
					CONCAT(PermissionToLeave.date_from, " - ", PermissionToLeave.date_to) as filing_date,
					PermissionToLeave.employee_code,
					PermissionToLeave.modified,
					PermissionToLeave.filing_status,
					"view_permission_to_leave" as "module",
					"permission_to_leaves" as "controller"
				FROM filing_permission_to_leaves PermissionToLeave
				LEFT JOIN employees Employee 
					on Employee.employee_code = "'.$employee_code.'"
				WHERE  PermissionToLeave.employee_code = "'.$employee_code.'"
					AND PermissionToLeave.status = "Active"
					AND PermissionToLeave.notification_message_status = "Active"
					AND PermissionToLeave.notification_read_status != 1
                    AND (PermissionToLeave.filing_status = "Approved" 
					OR PermissionToLeave.filing_status = "Disapproved" 
					OR PermissionToLeave.filing_status = "Void")

					UNION

				SELECT 
					UnderTimeEntry.id,
					"UNDER TIME ENTRY" as name,
					UnderTimeEntry.under_time_entry_date as filing_date,
					UnderTimeEntry.employee_code,
					UnderTimeEntry.modified,
					UnderTimeEntry.filing_status,
					"view_under_time_entry" as "module",
					"under_time_entries" as "controller"
				FROM filing_under_time_entries UnderTimeEntry
				WHERE  UnderTimeEntry.employee_code = "'.$employee_code.'"
					AND UnderTimeEntry.status = "Active"
					AND UnderTimeEntry.notification_message_status = "Active"
					AND UnderTimeEntry.notification_read_status != 1
                    AND (UnderTimeEntry.filing_status = "Approved" 
					OR UnderTimeEntry.filing_status = "Disapproved" 
					OR UnderTimeEntry.filing_status = "Void")

					UNION

				SELECT 
					Overtime.id,
					"OVERTIME" as name,
					Overtime.date_from as filing_date,
					Overtime.employee_code,
					Overtime.modified,
					Overtime.filing_status,
					"view_overtime" as "module",
					"overtimes" as "controller"
				FROM filing_overtimes Overtime
				WHERE  Overtime.employee_code = "'.$employee_code.'"
					AND Overtime.status = "Active"
					AND Overtime.notification_message_status = "Active"
					AND Overtime.notification_read_status != 1
                    AND (Overtime.filing_status = "Approved" 
					OR Overtime.filing_status = "Disapproved" 
					OR Overtime.filing_status = "Void")

					UNION

				SELECT 
					RequestChangeShift.id,
					"REQUEST CHANGE SHIFT" as name,
					RequestChangeShift.schedule_date as filing_date,
					RequestChangeShift.employee_code,
					RequestChangeShift.modified,
					RequestChangeShift.filing_status,
					"view_request_change_shift" as "module",
					"request_change_shifts" as "controller"
				FROM filing_request_change_shifts RequestChangeShift
				WHERE  RequestChangeShift.employee_code = "'.$employee_code.'"
					AND RequestChangeShift.status = "Active"
					AND RequestChangeShift.notification_message_status = "Active"
					AND RequestChangeShift.notification_read_status != 1
                    AND (RequestChangeShift.filing_status = "Approved" 
					OR RequestChangeShift.filing_status = "Disapproved" 
					OR RequestChangeShift.filing_status = "Void")
					
					UNION
					
				SELECT 
					Retirement.id,
					"RETIREMENT" as name,
					Retirement.filing_date as filing_date,
					Retirement.employee_code,
					Retirement.modified,
					Retirement.filing_status,
					"view_retirement" as "module",
					"retirements" as "controller"
				FROM separation_retirements Retirement
				WHERE  Retirement.employee_code = "'.$employee_code.'"
					AND Retirement.status = "Active"
					AND Retirement.notification_message_status = "Active"
					AND Retirement.notification_read_status != 1
                    AND (Retirement.filing_status = "Approved" 
					OR Retirement.filing_status = "Disapproved" 
					OR Retirement.filing_status = "Void")
					
					UNION
					
				SELECT 
					TimeDispute.id,
					"TIME DISPUTE" as name,
					TimeDispute.filing_date as filing_date,
					TimeDispute.employee_code,
					TimeDispute.modified,
					TimeDispute.filing_status,
					"view_temp_time_dispute" as "module",
					"temp_time_disputes" as "controller"
				FROM employee_temp_time_disputes TimeDispute
				WHERE  TimeDispute.employee_code = "'.$employee_code.'"
					AND TimeDispute.status = "Active"
					AND TimeDispute.notification_message_status = "Active"
					AND TimeDispute.notification_read_status != 1
                    AND (TimeDispute.filing_status = "Approved" 
					OR TimeDispute.filing_status = "Disapproved" 
					OR TimeDispute.filing_status = "Void")
					
				ORDER BY modified DESC'
			);
		
		$this->set('my_system_notification_navigations', $my_notifications);
	}
	
	private function get_count_hr_approval_multiple_overtime(){
		$this->loadModel('MultipleOvertime');
		$count_multiple_overtime = $this->MultipleOvertime->find('count', array(
			'fields' => 'MultipleOvertime.id',
			'conditions' => array(
				'MultipleOvertime.hr_filing_status' => 'Pending',
				'MultipleOvertime.filing_status'=>'Approved',
				'MultipleOvertime.status' => 'Active',
			),
			'recursive'=>-1
		));
		$this->set('count_multiple_overtime', $count_multiple_overtime);
	}
	
	public function add_system_trail($event_name=null, $model_name=null, $description=null, $id=null){
		
		$this->loadModel('Audit');
		if($id==null){
			$action_description = ' ' . $description . '.'; // has viewed PDS.
		}
		else{
			$action_description = ' ' . $description . ' ' . $id . '.'; // has viewed PDS.
		}
		$event = $event_name;  // VIEW | CREATE | DELETE | EDIT | LOGIN | LOGOUT
		$model = $model_name; // model name
		// $action_description = ' '.$description.' '.$id.''; // has viewed PDS.

		$standard_name = $_SESSION['Auth']['User']['Employee']['standard_name'];
		$audit_data['Audit']['event'] = $event;
		$audit_data['Audit']['entity_id'] = '-1';
		$audit_data['Audit']['request_id'] = '-1';
		$audit_data['Audit']['source_id'] = $this->Auth->user('id');
		$audit_data['Audit']['json_object'] = '';
		$audit_data['Audit']['model'] = $model;
		$audit_data['Audit']['description'] = $standard_name . ' ' . $action_description;
		$this->Audit->save($audit_data);
		
		return true;
	}
	
	public function save_employee_system_notifications($employee_code=null,$title=null,$message=null, $model=null, $controller=null, $view = null, $system_id_or_code=null){
		
		$this->loadModel('EmployeeSystemNotification');
		
		$data = array();
		
		$data['EmployeeSystemNotification']['employee_code'] = $employee_code;
		$data['EmployeeSystemNotification']['title'] = $title;
		$data['EmployeeSystemNotification']['message'] = $message;
		$data['EmployeeSystemNotification']['model'] = $model;
		$data['EmployeeSystemNotification']['controller'] = $controller;
		$data['EmployeeSystemNotification']['view'] = $view;
		$data['EmployeeSystemNotification']['system_id_or_code'] = $system_id_or_code;
		
		$this->EmployeeSystemNotification->save($data);
		
		// return true;
	}
	
	public function system_trail($event_name=null, $model_name=null, $description=null, $id=null){
		
		$this->loadModel('Audit');
		if($id==null){
			$action_description = ' ' . $description . '.'; // has viewed PDS.
		}
		else{
			$action_description = ' ' . $description . ' ' . $id . '.'; // has viewed PDS.
		}
		$event = $event_name;  // VIEW | CREATE | DELETE | EDIT | LOGIN | LOGOUT
		$model = $model_name; // model name
		// $action_description = ' '.$description.' '.$id.''; // has viewed PDS.

		$standard_name = $_SESSION['Auth']['User']['Employee']['standard_name'];
		$audit_data['Audit']['event'] = $event;
		$audit_data['Audit']['entity_id'] = '-1';
		$audit_data['Audit']['request_id'] = '-1';
		$audit_data['Audit']['source_id'] = $this->Auth->user('id');
		$audit_data['Audit']['json_object'] = '';
		$audit_data['Audit']['model'] = $model;
		$audit_data['Audit']['description'] = $standard_name . ' ' . $action_description;
		$this->Audit->save($audit_data);
		
		return true;
	}
	
	public function get_employee_remining_leave_balance($leave_classification_code = null, $employee_code) {
		if($leave_classification_code == 'LM'){
			$leave_classification_code = 'VL';
		}
		$this->loadModel('EmployeeLeaveCard');
		$this->EmployeeLeaveCard->virtualFields = array(
				'leave_balance' => "SUM((CASE EmployeeLeaveCard.operation WHEN '+' THEN EmployeeLeaveCard.leave_quantity ELSE 0 END)) - 
				SUM((CASE EmployeeLeaveCard.operation WHEN '-' THEN EmployeeLeaveCard.leave_quantity ELSE 0 END))",
			);

			$this->Paginator->settings = array(
				'fields' => array(
					'EmployeeLeaveCard.id',
					'EmployeeLeaveCard.date',
					'EmployeeLeaveCard.code',
					'EmployeeLeaveCard.generated_payroll_code',
					'EmployeeLeaveCard.employee_code',
					'EmployeeLeaveCard.operation',
					'leave_balance',
					'EmployeeLeaveCard.leave_classification_code',
					'EmployeeLeaveCard.remarks',
				),
				'conditions' => array(
					'EmployeeLeaveCard.status' => 'Active',
					'EmployeeLeaveCard.employee_code' => $employee_code,
					'EmployeeLeaveCard.leave_classification_code' => $leave_classification_code
					
				),
				'order' => array(
					'EmployeeLeaveCard.date' => 'ASC',
					// 'EmployeeLeaveCard.employee_leave_type_2' => 'ASC', 
					'EmployeeLeaveCard.code' => 'ASC',
					'EmployeeLeaveCard.id' => 'ASC',
				),
				'group' => 'EmployeeLeaveCard.leave_classification_code',
			);
			
			$employee_leave_card_balances = $this->Paginator->paginate('EmployeeLeaveCard');
			if(isset($employee_leave_card_balances) && count($employee_leave_card_balances) >0){
				$current_balance_before_adjustment = $employee_leave_card_balances[0]['EmployeeLeaveCard']['leave_balance'];	
			}
			else{
				$current_balance_before_adjustment = '0.000';
			}
			// debug($current_balance_before_adjustment);
		return $current_balance_before_adjustment;
	}
	
	public function get_my_employees($params = array()) {
		// $this->autoRender=false;
		
		$default_params = array(
			'is_employee_codes_only' => true, 
			'include_self' => true
		);
		
		$default_params = array_merge($default_params, $params);
		
		$default_conditions = array(
			'Employee.status' => 'Active'
		);
		
		
		if(isset($default_params['additional_conditions'])) {
			$default_conditions = array_merge($default_conditions, $default_params['additional_conditions']);
		}
		
		if(isset($default_params['include_self']) && !$default_params['include_self']) {
			$default_conditions = array_merge($default_conditions, array(
				'Employee.employee_code NOT' => $_SESSION['Auth']['User']['Employee']['employee_code']
			));
		}
		
		
		if($_SESSION['Auth']['User']['role'] == 'Administrator') { 
			
		}
		else if($_SESSION['Auth']['User']['role'] == 'Accounting') { 
		
		}
		else if($_SESSION['Auth']['User']['role'] == 'Medical Director') { 
		
		}
		//HR
		else if($_SESSION['Auth']['User']['role'] == 'HR User') { 
		
		}
		else if($_SESSION['Auth']['User']['role'] == 'HR Unit Head') { 
		
		}
		else if($_SESSION['Auth']['User']['role'] == 'HR Sub Unit Head') { 
		
		}
		else if($_SESSION['Auth']['User']['role'] == 'HR Division Head') { 
		
		}
		else if($_SESSION['Auth']['User']['role'] == 'HR Section Head') { 
		
		}
		//NON HR
		else if($_SESSION['Auth']['User']['role'] == 'Non HR Division Head') { 
			if (isset($_SESSION['Auth']['User']['PositionDetail'])) {
				$default_conditions = array_merge($default_conditions, array(
					'PositionDetail.division_code' => $_SESSION['Auth']['User']['PositionDetail']['division_code']
				));
			}			
		}
		else if($_SESSION['Auth']['User']['role'] == 'Non HR Section Head') { 
			if (isset($_SESSION['Auth']['User']['PositionDetail'])) {
				$default_conditions = array_merge($default_conditions, array(
					'PositionDetail.section_code' => $_SESSION['Auth']['User']['PositionDetail']['section_code'],
					'PositionDetail.is_division_head' => 0
				));	
			}
		}
		else if($_SESSION['Auth']['User']['role'] == 'Non HR Unit Head') { 
			if (isset($_SESSION['Auth']['User']['PositionDetail'])) {
				$default_conditions = array_merge($default_conditions, array(
					'PositionDetail.unit_code' => $_SESSION['Auth']['User']['PositionDetail']['unit_code'],
					'PositionDetail.is_division_head' => 0,
					'PositionDetail.is_section_head' => 0
				));	
			}
		}
		else if($_SESSION['Auth']['User']['role'] == 'Non HR Sub Unit Head') { 
			if (isset($_SESSION['Auth']['User']['PositionDetail'])) {
				$default_conditions = array_merge($default_conditions, array(
					'PositionDetail.sub_unit_code' => $_SESSION['Auth']['User']['PositionDetail']['sub_unit_code'],
					'PositionDetail.is_division_head' => 0,
					'PositionDetail.is_section_head' => 0,
					'PositionDetail.is_unit_head' => 0
				));	
			}
		}
		else if($_SESSION['Auth']['User']['role'] == 'Non HR User') {
			if (isset($_SESSION['Auth']['User']['PositionDetail'])) {
				$default_conditions = array_merge($default_conditions, array(
					'PositionDetail.sub_unit_code' => $_SESSION['Auth']['User']['PositionDetail']['sub_unit_code']
				));	
			}
		}
		
		// debug($default_conditions);
		// exit();
		
		$employees = $this->Employee->find('all', array(
			'fields' => array(
				'Employee.employee_code',
				'Employee.combination_whole_name',
			),
			'contain' => array(
				'PositionDetail'
			),
			'conditions' => $default_conditions, 
			'recursive' => -1
		));
		
		
		if(isset($default_params['is_employee_codes_only']) && $default_params['is_employee_codes_only']) {
			$employees = $this->get_employee_codes_from_employee_list($employees);
		}
		
		return $employees;
	}
	
	public function get_employee_codes_from_employee_list($employees = array()) {
		$employee_codes = array();
		
		foreach($employees as $employee_key => $employee_key_value_pair) {
			$employee_codes[] = $employee_key_value_pair['Employee']['employee_code'];
		}
		
		return $employee_codes;
	}
	
	public function get_position_details($employee_code = null) {
		$this->loadModel('PositionDetail');
		
		$position_detail = $this->PositionDetail->find('first', array(
			'contain'=>array(
				'Employee',
				'JobTitle',
				'Section',
				'Division',
				'Unit',
				'SubUnit',
				'EmploymentStatus',
			),
			'conditions' => array(
				'PositionDetail.employee_code' => $employee_code,
				'PositionDetail.status' => 'Active',
			),
			'order' => array(
				'Section.name' => 'ASC'
			)
		));			

		return $position_detail;
		
	}
	
	public function get_available_division(){
		$this->loadModel('Division');
		$division_list = $this->Division->find('list', array(
			'fields' => array(
				'Division.code', 
				'Division.name'
			),
			'conditions' => array(
				'Division.status' => 'Active',
			),
			'order' => array(
				'Division.name' => 'ASC'
			)
		));			
		
		return $division_list;
	}
	
	public function get_available_section(){
		$this->loadModel('Section');
		$section_list = $this->Section->find('list', array(
			'fields' => array(
				'Section.code', 
				'Section.name'
			),
			'conditions' => array(
				'Section.status' => 'Active',
			),
			'order' => array(
				'Section.name' => 'ASC'
			)
		));			
		
		return $section_list;
	}
	
	public function get_available_unit(){
		$this->loadModel('Unit');
		$unit_list = $this->Unit->find('list', array(
			'fields' => array(
				'Unit.code', 
				'Unit.name'
			),
			'conditions' =>array(
				'Unit.status' => 'Active',
			),
			'order' => array(
				'Unit.name' => 'ASC'
			)
		));			
		
		return $unit_list;
	}
	
	public function get_available_sub_unit(){
		$this->loadModel('SubUnit');
		$sub_unit_list = $this->SubUnit->find('list', array(
			'fields' => array(
				'SubUnit.code', 
				'SubUnit.name'
			),
			'conditions' => array(
				'SubUnit.status' => 'Active',
			),
			'order' => array(
				'SubUnit.name' => 'ASC'
			)
		));			
		
		return $sub_unit_list;
	}
	
	public function get_available_employees($division_code = null, $section_code = null, $unit_code = null, $sub_unit_code = null){
		$this->loadModel('Employee');
		$employees = $this->Employee->find('all', array(
			'fields' => array(
				'Employee.employee_code',
				'Employee.last_name',
				'Employee.first_name',
				'Employee.middle_initial',
			),
			'conditions' => array(
				'Employee.status' => 'Active',
			),
			'order' => array(
				'Employee.last_name' => 'ASC'
			)
		));
		$employee_list = Set::combine($employees, '{n}.Employee.employee_code', array('{0}, {1} {2}', '{n}.Employee.last_name', '{n}.Employee.first_name', '{n}.Employee.middle_initial'));

		// debug($employee_list);
		// exit();
		
		return $employee_list;
	}
	
	protected function get_count_absent(){
		
		$this->loadModel('EmployeeSchedule');
			$count_absent = $this->EmployeeSchedule->find('count', array(
				'fields' => array(
					'TimeEntry.employee_code',
					'TimeEntry.time_in',
					'TimeEntry.time_out',
					'TimeEntry.schedule_code as time_entry_schedule',
					'EmployeeSchedule.schedule_code as employee_schedule',
					'EmployeeSchedule.schedule_date',
				),
				'joins' => array(
					array(
						'table' => 'setting_shifts',
						'alias' => 'Shift',
						'type' => 'LEFT',
						'conditions' => array(
							'Shift.code = EmployeeSchedule.shift_code',
						)
					),
					array(
						'table' => 'employee_time_entries',
						'alias' => 'TimeEntry',
						'type' => 'LEFT',
						'conditions' => array(
							'TimeEntry.employee_code = EmployeeSchedule.employee_code',
							'DATE(TimeEntry.time_in) = EmployeeSchedule.schedule_date',
						)
					),
				),
				'conditions' => array(
					'EmployeeSchedule.schedule_date < CAST(NOW() AS DATE)',
					'EmployeeSchedule.employee_code' => $_SESSION['Auth']['User']['Employee']['employee_code'],
					'EmployeeSchedule.status' => 'Active',
					'EmployeeSchedule.has_attendance' => '0',
					'EmployeeSchedule.has_approved_leave_with_pay' => '0',
					'EmployeeSchedule.has_approved_leave_without_pay' => '0',
					// 'TimeEntry.time_in' => null,
					
					// 'EmployeeSchedule.schedule_date < CAST(NOW() AS DATE)',
					// 'TimeEntry.time_in' => null,
					// 'EmployeeSchedule.status' => 'Active',
					
				),
				'recursive'=>-1
			));
		$this->set('count_absent', $count_absent);
		
		// debug($count_absent);exit();
		
	}
	
	protected function get_profile_image_link() {
		
		$this->loadModel('Employee');
		
		$employee_profile = $this->Employee->find('first', array(
			'contain' => array(
				'PositionDetail' => array(
					'JobTitle',
					'Section',
					'Unit',
					'SubUnit',
					'Division',
				),
				'BankAccountDetail'
			),
			'conditions' => array(
				'Employee.id' => $_SESSION['Auth']['User']['Employee']['id']
			)
		));
		
		$this->set('employee_profile', $employee_profile);
	}
	
	public function check_sync_data_exist($biometric_id=null,$date_time=null){
		$this->loadModel('BiometricTimeEntry');
		$data = $this->BiometricTimeEntry->find('first',array(
			'conditions'=>array(
				'BiometricTimeEntry.biometric_id'=>$biometric_id,
			    'BiometricTimeEntry.entry_date'=>$date_time,
			)
		));
		return $data;
	}
	
	
	
	private function set_total_leave_params($employee_code = null, $operation = null, $field = null, $spl_leave_classification_code = null) {
		if (isset($spl_leave_classification_code)) {
			return $params = array(
				'fields' => array(
					'SUM(IFNULL(EmployeeLeaveCard.' . $field . ', 0)) AS ' . $field, 
				),
				'conditions' => array(
					'EmployeeLeaveCard.status' => 'Active',
					'EmployeeLeaveCard.employee_code' => $employee_code,
					'EmployeeLeaveCard.operation' => $operation,
					'EmployeeLeaveCard.current_year' => date('Y'),
					'EmployeeLeaveCard.leave_classification_code' => $spl_leave_classification_code,
				),
			);
		}
		else { 
			return $params = array(
				'fields' => array(
					'SUM(IFNULL(EmployeeLeaveCard.' . $field . ', 0)) AS ' . $field, 
				),
				'conditions' => array(
					'EmployeeLeaveCard.status' => 'Active',
					'EmployeeLeaveCard.employee_code' => $employee_code,
					'EmployeeLeaveCard.operation' => $operation,
					'EmployeeLeaveCard.current_year' => date('Y'),
				),
			);
		}
	}
	
	private function get_total_vacation_leave_earned($employee_code = null) {
		$params = $this->set_total_leave_params($employee_code, '+', 'vacation_leave_earned');		
		return isset($this->EmployeeLeaveCard->find('all', $params)[0][0]['vacation_leave_earned']) ? $this->EmployeeLeaveCard->find('all', $params)[0][0]['vacation_leave_earned'] : '0';
	}
	
	private function get_total_vacation_absence_with_pay($employee_code = null) {
		$params = $this->set_total_leave_params($employee_code, '-', 'vacation_absence_with_pay');		
		return isset($this->EmployeeLeaveCard->find('all', $params)[0][0]['vacation_absence_with_pay']) ? $this->EmployeeLeaveCard->find('all', $params)[0][0]['vacation_absence_with_pay'] : '0';
	}
	
	public function get_remaining_vacation_leave($employee_code = null) {
		$total_vacation_leave_earned = $this->get_total_vacation_leave_earned($employee_code);
		$total_vacation_absence_with_pay = $this->get_total_vacation_absence_with_pay($employee_code);
		
		return $total_vacation_leave_earned - $total_vacation_absence_with_pay;
	}
	
	
	private function get_total_sick_leave_earned($employee_code = null) {
		$params = $this->set_total_leave_params($employee_code, '+', 'sick_leave_earned');		
		return isset($this->EmployeeLeaveCard->find('all', $params)[0][0]['sick_leave_earned']) ? $this->EmployeeLeaveCard->find('all', $params)[0][0]['sick_leave_earned'] : '0';
	}
	
	private function get_total_sick_absence_with_pay($employee_code = null) {
		$params = $this->set_total_leave_params($employee_code, '-', 'sick_absence_with_pay');		
		return isset($this->EmployeeLeaveCard->find('all', $params)[0][0]['sick_absence_with_pay']) ? $this->EmployeeLeaveCard->find('all', $params)[0][0]['sick_absence_with_pay'] : '0';
	}
	
	public function get_remaining_sick_leave($employee_code = null) {
		$total_sick_leave_earned = $this->get_total_sick_leave_earned($employee_code);
		$total_sick_absence_with_pay = $this->get_total_sick_absence_with_pay($employee_code);
		
		return $total_sick_leave_earned - $total_sick_absence_with_pay;
	}
	
	
	public function get_spl_leave_per_year() {
		$params = array(
			'fields' => array(
				'LeaveClassification.leave_per_year', 
			),
			'conditions' => array(
				'LeaveClassification.status' => 'Active',
				'LeaveClassification.code' => self::SPL_LEAVE_CLASSIFICATION_CODE,
			),
		);
		return isset($this->LeaveClassification->find('first', $params)['LeaveClassification']['leave_per_year']) ? $this->LeaveClassification->find('first', $params)['LeaveClassification']['leave_per_year'] : false;
	}
	
	private function get_total_other_leave_absence_with_pay_spl($employee_code = null) {
		$params = $this->set_total_leave_params($employee_code, '-', 'other_leave_absence_with_pay', self::SPL_LEAVE_CLASSIFICATION_CODE);		
		return isset($this->EmployeeLeaveCard->find('all', $params)[0][0]['other_leave_absence_with_pay']) ? $this->EmployeeLeaveCard->find('all', $params)[0][0]['other_leave_absence_with_pay'] : '0';
	}
	
	public function get_remaining_spl_leave($employee_code = null) {
		$spl_leave_per_year = $this->get_spl_leave_per_year();
		$total_other_leave_absence_with_pay_spl = $this->get_total_other_leave_absence_with_pay_spl($employee_code);
		
		if ($spl_leave_per_year) {
			return $spl_leave_per_year - $total_other_leave_absence_with_pay_spl;
		}
		else {
			die('Class constant error: Invalid SPL Leave Classification Code!');
		}
	}
	
	public function checkbox($fpdf, $checked = null,$border,$l=1,$w=1)
	{
		if($checked == "1")
		{
			$check = "3";	
		}
		else
		{
			$check = "";
		}

		$fpdf->SetFont('ZapfDingbats','', 9);
		$fpdf->Cell($l, $w, $check  , $border, '', 'C');
		$fpdf->SetFont('Courier', '', 7);
	}
	
	public function get_time_entry_status_definition($time_entry_status = null) {
		if ($time_entry_status == "C") {
			$time_entry_status = "Perfect Time Entry";
		}
		else if ($time_entry_status == "LWP") {
			$time_entry_status = "Leave with Pay";
		}
		else if ($time_entry_status == "I") {
			$time_entry_status = "Incomplete Time Entry";
		}
		else if ($time_entry_status == "P") {
			$time_entry_status = "Problematic Time Entry";
		}
		else if ($time_entry_status == "H") {
			$time_entry_status = "Holiday";
		}
		else if ($time_entry_status == "U") {
			$time_entry_status = "Undertime";
		}
		else if ($time_entry_status == "N") {
			$time_entry_status = "No Schedule Time Entry";
		}
		else if ($time_entry_status == "R") {
			$time_entry_status = "Resolved";
		}
		else {
			$time_entry_status = "";
		}
		
		return $time_entry_status;
	}
	
	public function get_holiday_by_date_employee($date = null,$employee_code=null) {
		$this->loadModel('HolidayAllowedEmployee');
		$holiday = $this->HolidayAllowedEmployee->find('first',array(
			'conditions'=>array(
				'Holiday.status'=>'Active',
				'Holiday.holiday_date'=>$date,
				'HolidayAllowedEmployee.employee_code'=>$employee_code
			),
			'contain'=>array(
				'Holiday'
			),
			'recursive'=>-1
		));
		// debug($holiday);
		return $holiday;
	}
	public function get_holiday_by_date($date = null) {
		$this->loadModel('Holiday');
		$holiday = $this->Holiday->find('first',array(
			'conditions'=>array(
				'Holiday.status'=>'Active',
				'Holiday.holiday_date'=>$date,
			),
			'recursive'=>-1
		));
		return $holiday;
	}
	
	public function app_validate_not_assigned_field($data=null) {
	
		if (isset($data)) {
			$status = $data;
		}
		else {
			$status = 'N/A';
		}
		return $status;
	}
}
?>