<?php
App::uses('Component', 'Controller');

class ExportComponent extends Component {
	
	public $controller;

	public function startup(Controller $controller) {
		$this->controller = $controller;
	}
	
	public function export_csv($params = array()) {
		if(isset($params['export_title'])){
			
			$file_name =  $params['export_title'].'List_';
		}
		else{
			$file_name = 'export_csv_';
		}
		
		
		$default_params = array(
			'title' => '', 
			'data' => array(), 
			'header_data' => array(), 
			'file_name' => $file_name. date("mdYHis") . '.csv', 
			'max_execution_time' => null, 
			'delimiter' => ',', 
			'enclosure' => '"'
		);
		
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		$this->controller->autoRender = false;
		$csv_file = fopen('php://output', 'w');
		header('Content-type: application/csv');
		header('Content-Disposition: attachment; filename="' . $default_params['file_name'] . '"');
		print "\xEF\xBB\xBF"; // UTF-8 BOM fix for enye
		fputcsv($csv_file, array($default_params['title']), $default_params['delimiter'], $default_params['enclosure']);
		
		if(count($default_params['data']) > 0) {
			if(count($default_params['header_data']) > 0) {
				fputcsv($csv_file, $default_params['header_data'], $default_params['delimiter'], $default_params['enclosure']);
			}
			else {
				foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
					$default_params['header_data'][] = Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1));
				}
				
				fputcsv($csv_file, $default_params['header_data'], $default_params['delimiter'], $default_params['enclosure']);
			}
			
			foreach ($default_params['data'] as $key => $value) {			
				fputcsv($csv_file, $value, $default_params['delimiter'], $default_params['enclosure']);
			}
		}
		else {
			if(isset($default_params['header_data']) && count($default_params['header_data']) > 0) {
				fputcsv($csv_file, $default_params['header_data'], $default_params['delimiter'], $default_params['enclosure']);
			}
			fputcsv($csv_file, array('No records found.'), $default_params['delimiter'], $default_params['enclosure']);
		}
		
		fclose($csv_file);
	}
	
	public function export_excel($params = array()) {
		$default_params = array(
			'title' => '', 
			'data' => array(), 
			'header_data' => array(), 
			'file_name' => 'export_' . date("Y-m-d") . '.xlsx', 
			'max_execution_time' => null
		);
		
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		$this->controller->autoRender = false;
		App::import('Vendor', 'PHPExcel');

		$cache_method = PHPExcel_CachedObjectStorageFactory::cache_in_memory_gzip;
		if (!PHPExcel_Settings::setCacheStorageMethod($cache_method)) {
			die($cache_method . " caching method is not available" . EOL);
		}

		$objPHPExcel = new PHPExcel();
		$objPHPExcel->getProperties()->setCreator("Dona Alejandra Inc.");
		
		$row_count = 1;
		
		$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row_count, $default_params['title']);
		
		$row_count++;
		$column_count = 0;
		$max_page_width = 98;
		if(count($default_params['data']) > 0) {
			if(count($default_params['header_data']) > 0) {
				foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
					$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
					$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth(25);
					$column_count++;
				}
			}
			else {
				foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
					$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1)));
					$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth(25);
					$column_count++;
				}
			}
			
			$objPHPExcel->getActiveSheet()->mergeCells('A1:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . '1')->getStyle()->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
			
			$row_count++;
			
			foreach ($default_params['data'] as $flat_data_item) {
				$column_count = 0;
				foreach ($flat_data_item as $flat_data_key => $flat_data_value) {
					$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $flat_data_value);
					$column_count++;
				}
				$row_count++;
			}
			
			
			$objPHPExcel->getActiveSheet()->freezePane('A3');
			
			$style_array_header = array(
				'borders' => array(
					'allborders' => array(
						'style' => PHPExcel_Style_Border::BORDER_THIN
					),
				),
				'alignment' => array(
					'vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP
				),
				'font' => array(
					'name' => 'Tahoma',
					'bold' => true
				)
			);
			
			$style_array_data = array(
				'borders' => array(
					'allborders' => array(
						'style' => PHPExcel_Style_Border::BORDER_THIN
					)
				),
				'alignment' => array(
					'vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP
				),
				'font' => array(
					'name' => 'Tahoma'
				)
			);
			
			$objPHPExcel->getActiveSheet()->getStyle('A1:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . '1')->applyFromArray($style_array_header);
			$objPHPExcel->getActiveSheet()->getStyle('A2:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . ($row_count - 1))->applyFromArray($style_array_data);
			$objPHPExcel->getActiveSheet()->getStyle('A2:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . ($row_count - 1))->getAlignment()->setWrapText(true); 
		}
		else {
			if(isset($default_params['header_data']) && count($default_params['header_data']) > 0) {
				$column_width = $max_page_width / count($default_params['header_data']);
				if(isset($default_params['column_widths']) && count($default_params['column_widths']) > 0) {
					for($column_width_counter = 0; $column_width_counter < count($default_params['column_widths']); $column_width_counter++) {
						$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_width_counter)->setWidth($default_params['column_widths'][$column_width_counter]);
					}
					if(count($default_params['header_data']) > 0) {
						foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
							$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
							$column_count++;
						}
					}
				}
				else {
					if(count($default_params['header_data']) > 0) {
						foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
							$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
							$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth($column_width);
							$column_count++;
						}
					}
				}
				$row_count++;
			}
			
			$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row_count, 'No records found.');
		}
		header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
		header('Content-Disposition: attachment;filename="' . $default_params['file_name'] . '"');
		header('Cache-Control: max-age=0');

		$objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel2007');
		$objWriter->save('php://output');
	}
	
	public function export_excel_with_template($params = array()) {
		if(isset($params['export_title'])){
			
			$file_name =  $params['export_title'].'List_';
		}
		else{
			$file_name = 'export_excel_';
		}
		
		$default_params = array(
			'title' => '', 
			'template_path' => 'templates/excel/basic_template.xlsx', 
			'data' => array(), 
			'column_widths' => array(),
			'header_data' => array(), 
			'put_pages' => true,
			'file_name' => $file_name . date("mdYHis") . '.xlsx', 
			'max_execution_time' => null
		);
		
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		$this->controller->autoRender = false;
		App::import('Vendor', 'PHPExcel');
		
		if (!file_exists($default_params['template_path'])) {
			exit("Employee Schedule Form Template not found.");
		}
		
		$objPHPExcel = PHPExcel_IOFactory::load($default_params['template_path']);
		

		$cache_method = PHPExcel_CachedObjectStorageFactory::cache_in_memory_gzip;
		if (!PHPExcel_Settings::setCacheStorageMethod($cache_method)) {
			die($cache_method . " caching method is not available" . EOL);
		}

		$objPHPExcel->getProperties()->setCreator("Dona Alejandra Inc.");
		
		$row_count = 1;
		
		
		$column_count = 0;
		$max_page_width = 98;
		
		if(count($default_params['data']) > 0) {
			$objPHPExcel->getActiveSheet()->mergeCells('A1:' . PHPExcel_Cell::stringFromColumnIndex(count($default_params['data'][0]) - 1) . '1');
			$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row_count, $default_params['title']);
			$row_count++;
			$row_count++;
			$column_width = $max_page_width / count($default_params['data'][0]);
			if(isset($default_params['column_widths']) && count($default_params['column_widths']) > 0) {
				for($column_width_counter = 0; $column_width_counter < count($default_params['column_widths']); $column_width_counter++) {
					$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_width_counter)->setWidth($default_params['column_widths'][$column_width_counter]);
				}
				if(count($default_params['header_data']) > 0) {
					foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
						$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
						$column_count++;
					}
				}
				else {
					foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
						$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1)));
						$column_count++;
					}
				}
			}
			else {
				if(count($default_params['header_data']) > 0) {
					foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
						$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
						$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth($column_width);
						$column_count++;
					}
				}
				else {
					foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
						$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1)));
						$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth($column_width);
						$column_count++;
					}
				}
			}
			
			
			$row_count++;
			
			foreach ($default_params['data'] as $flat_data_item) {
				$column_count = 0;
				foreach ($flat_data_item as $flat_data_key => $flat_data_value) {
					$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $flat_data_value);
					$column_count++;
				}
				$row_count++;
			}
			
			
			$objPHPExcel->getActiveSheet()->freezePane('A4');
			
			$style_array_title = array(

				'alignment' => array(
					'vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP,
					'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_CENTER
				),
				'font' => array(
					'name' => 'Tahoma',
					'bold' => true
				)
			);
			
			$style_array_header = array(
				'borders' => array(
					'allborders' => array(
						'style' => PHPExcel_Style_Border::BORDER_THIN
					),
				),
				'alignment' => array(
					'vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP,
					'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_CENTER,
				),
				'font' => array(
					'name' => 'Tahoma',
					'bold' => true
				)
			);
			
			$style_array_data = array(
				'borders' => array(
					'allborders' => array(
						'style' => PHPExcel_Style_Border::BORDER_THIN
					)
				),
				'alignment' => array(
					'vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP
				),
				'font' => array(
					'name' => 'Tahoma'
				)
			);
			
			$objPHPExcel->getActiveSheet()->getStyle('A1')->applyFromArray($style_array_title);
			$objPHPExcel->getActiveSheet()->getStyle('A3:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . '3')->applyFromArray($style_array_header);
			$objPHPExcel->getActiveSheet()->getStyle('A4:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . ($row_count - 1))->applyFromArray($style_array_data);
			$objPHPExcel->getActiveSheet()->getStyle('A3:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . ($row_count - 1))->getAlignment()->setWrapText(true); 
			if($default_params['put_pages']) {
				$objPHPExcel->getActiveSheet()->getHeaderFooter()->setDifferentOddEven(false);
				$objPHPExcel->getActiveSheet()->getHeaderFooter()->setOddFooter('&R Page &P / &N');
			}
		}
		else {
			if(isset($default_params['header_data']) && count($default_params['header_data']) > 0) {
				$objPHPExcel->getActiveSheet()->mergeCells('A1:' . PHPExcel_Cell::stringFromColumnIndex(count($default_params['header_data']) - 1) . '1');
				$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row_count, $default_params['title']);
				$row_count++;
				$column_width = $max_page_width / count($default_params['header_data']);
				if(isset($default_params['column_widths']) && count($default_params['column_widths']) > 0) {
					for($column_width_counter = 0; $column_width_counter < count($default_params['column_widths']); $column_width_counter++) {
						$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_width_counter)->setWidth($default_params['column_widths'][$column_width_counter]);
					}
					if(count($default_params['header_data']) > 0) {
						foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
							$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
							$column_count++;
						}
					}
				}
				else {
					if(count($default_params['header_data']) > 0) {
						foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
							$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
							$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth($column_width);
							$column_count++;
						}
					}
				}
				$row_count++;
			}
			
			$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row_count, 'No records found.');
		}
		header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
		header('Content-Disposition: attachment;filename="' . $default_params['file_name'] . '"');
		header('Cache-Control: max-age=0');

		$objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel2007');
		$objWriter->save('php://output');
	}
	
	public function export_pdf($params = array()) {
		$default_params = array(
			'title' => '', 
			'data' => array(), 
			'header_data' => array(), 
			'file_name' => 'export_' . date("Y-m-d") . '.pdf', 
			'max_execution_time' => null,
			'paper_size' => 'A4',
			'unit_of_measurement' => 'mm',
			'orientation' => 'P',
			'max_page_width' => 190,
			'widths'=>array(),
			'alignments'=>array(),
		);
		
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		
		
		$auto_generate_header = true;
		$this->controller->autoRender = false;
		$this->controller->response->type('pdf');
		$max_page_width = $default_params['max_page_width'];
		
		App::import('Vendor', 'Fpdf', array('file' => 'fpdf' . DS . 'mc_table.php'));
		
		$fpdf = new PDF_MC_Table($default_params['orientation'],$default_params['unit_of_measurement'],$default_params['paper_size']);
		$fpdf->SetAutoPageBreak(true, 10);
		$fpdf->AddPage();
		
		$fpdf->SetFont('Courier', 'B', 14);
		
		$fpdf->MultiCell($max_page_width, 10, $default_params['title'], 0, 'C');
		
		if(count($default_params['data']) > 0) {
			if(isset($default_params['header_aligns'])) {
				$header_aligns = $default_params['header_aligns'];
			}
			
			if(isset($default_params['data_aligns'])) {
				$data_aligns = $default_params['data_aligns'];
			}
			$remaining_width = $max_page_width - array_sum($default_params['widths']);
			$remaining_no_width = count($default_params['data'][0]) - count($default_params['widths']);
			
			for($no_of_columns = 0; $no_of_columns < count($default_params['data'][0]); $no_of_columns++) {
				if(isset($default_params['widths'][$no_of_columns])){
					$column_widths[]=$default_params['widths'][$no_of_columns];
				}else{
					$column_widths[] = $remaining_width  / $remaining_no_width;
				}
				if(!isset($default_params['header_aligns'])) {
					$header_aligns[] = 'C';
				}
					
				if(!isset($default_params['data_aligns'])) {
					if(isset($default_params['alignments'][$no_of_columns])){
						$data_aligns[]=$default_params['alignments'][$no_of_columns];
					}else{
						$data_aligns[] = 'L';
					}
				}
			}
			
			if($default_params['alignments']){
				$data_aligns=$default_params['alignments'];
			}
			$fpdf->SetWidths($column_widths);
			$no_of_records = count($default_params['data']);
			$fpdf->SetFont('Courier', 'B', 10);
			
			$fpdf->SetAligns($header_aligns);
			
			if(count($default_params['header_data']) == 0) {
				foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
					$default_params['header_data'][] = Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1));
				}
			}
			$fpdf->RowWithBorder($default_params['header_data']);
			
			$fpdf->SetFont('Courier', '', 10);
			if($no_of_records > 0) {
				$fpdf->SetAligns($data_aligns);
				foreach ($default_params['data'] as $key => $value) {			
					$fpdf->RowWithBorder(array_values($value));
				}
			}
		}
		else {
			if(isset($default_params['header_data']) && count($default_params['header_data']) > 0) {
				$fpdf->setX(10);
			
				if(isset($default_params['header_aligns'])) {
					$header_aligns = $default_params['header_aligns'];
				}
				
				for($no_of_columns = 0; $no_of_columns < count($default_params['header_data']); $no_of_columns++) {
					$column_widths[] = $max_page_width / count($default_params['header_data']);
					if(!isset($default_params['header_aligns'])) {
						$header_aligns[] = 'C';
					}
					
					if(!isset($default_params['data_aligns'])) {
						$data_aligns[] = 'L';
					}
				}
				
				$fpdf->SetWidths($column_widths);
				$fpdf->SetFont('Courier', 'B', 10);
				$fpdf->SetAligns($header_aligns);
				
				$fpdf->RowWithBorder($default_params['header_data']);
			}
			
			$fpdf->setX(10);
			$fpdf->MultiCell($max_page_width, 20, 'No records found.', 0, 'C');
		}

		$fpdf->AliasNbPages();
		$fpdf->Output($default_params['file_name'], 'I');
	}
	
	public function export_pdf_with_template($params = array()) {
		if(isset($params['export_title'])){
			
			$file_name =  $params['export_title'].'List_';
		}
		else{
			$file_name = 'export_pdf_';
		}
	
		$default_params = array(
			'title' => '', 
			'template_path' => 'templates/pdf/basic_template.pdf', 
			'data' => array(), 
			'header_data' => array(), 
			'file_name' => $file_name . date("mdYHis") . '.pdf', 
			'max_execution_time' => null,
			'paper_size' => 'A4',
			'unit_of_measurement' => 'mm',
			'orientation' => 'P',
			'put_pages' => true,
			'title_y_position' => 38,
			'max_page_width' => 190
		);
		if(isset($params['orientation']) && ($params['orientation']=='L') ){
			$default_params['template_path']='templates/pdf/basic_template_a4_landscape.pdf';
			
		}
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		
		
		$auto_generate_header = true;
		$this->controller->autoRender = false;
		$this->controller->response->type('pdf');
		$max_page_width = $default_params['max_page_width'];

		App::import('Vendor', 'Fpdf', array('file' => 'fpdf' . DS . 'mc_table.php'));
		App::import('Vendor', 'Fpdi', array('file' => 'fpdf' . DS . 'fpdi.php'));
		
		// $fpdf = new FPDI();
		$fpdf = new FPDI($default_params['orientation'],$default_params['unit_of_measurement'],$default_params['paper_size']);
		$pageCount = $fpdf->setSourceFile($default_params['template_path']);
		$template_page_1 = $fpdf->importPage(1);
		
		$fpdf->template_page_1 = $template_page_1;
		$fpdf->title = $default_params['title'];
		$fpdf->title_y_position = $default_params['title_y_position'];
		$fpdf->max_page_width = $max_page_width;
		$fpdf->put_pages = $default_params['put_pages'];
		
		$fpdf->SetAutoPageBreak(true, 10);
		
		if(count($default_params['data']) > 0) {
			
			if(isset($default_params['header_aligns'])) {
				$header_aligns = $default_params['header_aligns'];
			}
			
			if(isset($default_params['data_aligns'])) {
				$data_aligns = $default_params['data_aligns'];
			}
			
			$column_width_total = 0;
			
			if(isset($default_params['data_size']) && count($default_params['data_size']) > 0) {

				foreach ($default_params['data_size'] as  $flat_data_value) {
					$column_widths[] = $flat_data_value;
					$column_width_total += $flat_data_value;

					if(!isset($default_params['header_aligns'])) {
						$header_aligns[] = 'C';
					}
					
					if(!isset($default_params['data_aligns'])) {
						$data_aligns[] = 'L';
					}
					
				}
			}
			else{
				if(isset($default_params['column_widths'])) {
					$column_widths = $default_params['column_widths'];
					
					for($no_of_columns = 0; $no_of_columns < count($default_params['column_widths']); $no_of_columns++) {
						$column_width_total += $default_params['column_widths'][$no_of_columns];
						if(!isset($default_params['header_aligns'])) {
							$header_aligns[] = 'C';
						}
						
						if(!isset($default_params['data_aligns'])) {
							$data_aligns[] = 'L';
						}
					}
				}
				else {
					for($no_of_columns = 0; $no_of_columns < count($default_params['data'][0]); $no_of_columns++) {
						$column_widths[] = $max_page_width / count($default_params['data'][0]);
						$column_width_total += $column_widths[$no_of_columns];
						if(!isset($default_params['header_aligns'])) {
							$header_aligns[] = 'C';
						}
						
						if(!isset($default_params['data_aligns'])) {
							$data_aligns[] = 'L';
						}
					}
				}
			}
			
			
			
			
			if(count($default_params['header_data']) == 0) {

				foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
					$default_params['header_data'][] = Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1));
				}
				
				
			}
			
			$fpdf->header_data = $default_params['header_data'];
			$fpdf->header_aligns = $header_aligns;
			$fpdf->column_widths = $column_widths;
			$fpdf->data_aligns = $data_aligns;
			$fpdf->column_widths = $column_widths;
			$fpdf->column_width_total = $column_width_total;
			
			$no_of_records = count($default_params['data']);
			
			$fpdf->addPage();
			
			$fpdf->SetFont('Arial', '', 8);
			if($no_of_records > 0) {
				foreach ($default_params['data'] as $key => $value) {			
					$fpdf->RowWithBorder(array_values($value));
				}
			}
		}
		else {
			$fpdf->AddPage();
			
			if(isset($default_params['header_data']) && count($default_params['header_data']) > 0) {
				$fpdf->setX(10);
			
				if(isset($default_params['header_aligns'])) {
					$header_aligns = $default_params['header_aligns'];
				}
				
				for($no_of_columns = 0; $no_of_columns < count($default_params['header_data']); $no_of_columns++) {
					$column_widths[] = $max_page_width / count($default_params['header_data']);
					if(!isset($default_params['header_aligns'])) {
						$header_aligns[] = 'C';
					}
					
					if(!isset($default_params['data_aligns'])) {
						$data_aligns[] = 'L';
					}
				}
				
				$fpdf->SetWidths($column_widths);
				$fpdf->SetFont('Courier', 'B', 10);
				$fpdf->SetAligns($header_aligns);
				
				$fpdf->RowWithBorder($default_params['header_data']);
			}
			
			$fpdf->setX(10);
			$fpdf->MultiCell($max_page_width, 20, 'No records found.', 0, 'C');
		}

		$fpdf->AliasNbPages();
		$fpdf->Output($default_params['file_name'], 'I');
	}
}