<?php
App::uses('Component', 'Controller');

class ExportInventoryVersionComponent extends Component {
	
	public $controller;

	public function startup(Controller $controller) {
		$this->controller = $controller;
	}
	
	public function export_csv($params = array()) {
		$default_params = array(
			'title' => '', 
			'data' => array(), 
			'header_data' => array(), 
			'file_name' => 'export_' . date("Y-m-d") . '.csv', 
			'max_execution_time' => null, 
			'delimiter' => ',', 
			'enclosure' => '"'
		);
		
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		$this->controller->autoRender = false;
		$csv_file = fopen('php://output', 'w');
		header('Content-type: application/csv');
		header('Content-Disposition: attachment; filename="' . $default_params['file_name'] . '"');
		fputcsv($csv_file, array($default_params['title']), $default_params['delimiter'], $default_params['enclosure']);
		
		if(count($default_params['data']) > 0) {
			if(count($default_params['header_data']) > 0) {
				fputcsv($csv_file, $default_params['header_data'], $default_params['delimiter'], $default_params['enclosure']);
			}
			else {
				foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
					$default_params['header_data'][] = Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1));
				}
				
				fputcsv($csv_file, $default_params['header_data'], $default_params['delimiter'], $default_params['enclosure']);
			}
			
			foreach ($default_params['data'] as $key => $value) {			
				fputcsv($csv_file, $value, $default_params['delimiter'], $default_params['enclosure']);
			}
		}
		else {
			fputcsv($csv_file, array('No records found.'), $default_params['delimiter'], $default_params['enclosure']);
		}
		
		fclose($csv_file);
	}
	
	public function export_excel($params = array()) {
		$default_params = array(
			'title' => '', 
			'data' => array(), 
			'header_data' => array(), 
			'file_name' => 'export_' . date("Y-m-d") . '.xlsx', 
			'max_execution_time' => null
		);
		
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		$this->controller->autoRender = false;
		App::import('Vendor', 'PHPExcel');

		$cache_method = PHPExcel_CachedObjectStorageFactory::cache_in_memory_gzip;
		if (!PHPExcel_Settings::setCacheStorageMethod($cache_method)) {
			die($cache_method . " caching method is not available" . EOL);
		}

		$objPHPExcel = new PHPExcel();
		$objPHPExcel->getProperties()->setCreator("Dona Alejandra Inc.");
		
		$row_count = 1;
		
		$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row_count, $default_params['title']);
		
		$row_count++;
		$column_count = 0;
		if(count($default_params['data']) > 0) {
			if(count($default_params['header_data']) > 0) {
				foreach ($default_params['header_data'] as $header_data_key => $header_data_value) {
					$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $header_data_value);
					$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth(25);
					$column_count++;
				}
			}
			else {
				foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
					$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1)));
					$objPHPExcel->getActiveSheet()->getColumnDimensionByColumn($column_count)->setWidth(25);
					$column_count++;
				}
			}
			
			$objPHPExcel->getActiveSheet()->mergeCells('A1:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . '1')->getStyle()->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
			
			$row_count++;
			
			foreach ($default_params['data'] as $flat_data_item) {
				$column_count = 0;
				foreach ($flat_data_item as $flat_data_key => $flat_data_value) {
					$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($column_count, $row_count, $flat_data_value);
					$column_count++;
				}
				$row_count++;
			}
			
			
			$objPHPExcel->getActiveSheet()->freezePane('A3');
			
			$style_array_header = array(
				'borders' => array(
					'allborders' => array(
						'style' => PHPExcel_Style_Border::BORDER_THIN
					),
				),
				'alignment' => array(
					'vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP
				),
				'font' => array(
					'name' => 'Tahoma',
					'bold' => true
				)
			);
			
			$style_array_data = array(
				'borders' => array(
					'allborders' => array(
						'style' => PHPExcel_Style_Border::BORDER_THIN
					)
				),
				'alignment' => array(
					'vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP
				),
				'font' => array(
					'name' => 'Tahoma'
				)
			);
			
			$objPHPExcel->getActiveSheet()->getStyle('A1:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . '1')->applyFromArray($style_array_header);
			$objPHPExcel->getActiveSheet()->getStyle('A2:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . ($row_count - 1))->applyFromArray($style_array_data);
			$objPHPExcel->getActiveSheet()->getStyle('A2:' . PHPExcel_Cell::stringFromColumnIndex($column_count - 1) . ($row_count - 1))->getAlignment()->setWrapText(true); 
		}
		else {
			$objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row_count, 'No records found.');
		}
		header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
		header('Content-Disposition: attachment;filename="' . $default_params['file_name'] . '"');
		header('Cache-Control: max-age=0');

		$objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel2007');
		$objWriter->save('php://output');
	}
	
	public function export_pdf($params = array()) {
		$default_params = array(
			'title' => '', 
			'data' => array(), 
			'header_data' => array(), 
			'file_name' => 'export_' . date("Y-m-d") . '.pdf', 
			'max_execution_time' => null,
			'paper_size' => 'A4',
			'unit_of_measurement' => 'mm',
			'orientation' => 'P',
			'max_page_width' => 190
		);
		
		foreach($params as $param_key => $param_content) {
			$default_params[$param_key] = $param_content;
		}
		
		if(!empty($default_params['max_execution_time'])){
			ini_set('max_execution_time', $default_params['max_execution_time']);
		}
		
		
		
		$auto_generate_header = true;
		$this->controller->autoRender = false;
		$this->controller->response->type('pdf');
		$max_page_width = $default_params['max_page_width'];
		
		App::import('Vendor', 'Fpdf', array('file' => 'fpdf' . DS . 'mc_table.php'));
		
		$fpdf = new PDF_MC_Table($default_params['orientation'],$default_params['unit_of_measurement'],$default_params['paper_size']);
		$fpdf->SetAutoPageBreak(true, 10);
		$fpdf->AddPage();
		
		$fpdf->SetFont('Courier', 'B', 14);
		
		$fpdf->MultiCell($max_page_width, 10, $default_params['title'], 0, 'C');
		
		if(count($default_params['data']) > 0) {
			if(isset($default_params['header_aligns'])) {
				$header_aligns = $default_params['header_aligns'];
			}
			
			if(isset($default_params['data_aligns'])) {
				$data_aligns = $default_params['data_aligns'];
			}
			
			for($no_of_columns = 0; $no_of_columns < count($default_params['data'][0]); $no_of_columns++) {
				$column_widths[] = $max_page_width / count($default_params['data'][0]);
				if(!isset($default_params['header_aligns'])) {
					$header_aligns[] = 'C';
				}
				
				if(!isset($default_params['data_aligns'])) {
					$data_aligns[] = 'L';
				}
			}
			
			$fpdf->SetWidths($column_widths);
			$no_of_records = count($default_params['data']);
			$fpdf->SetFont('Courier', 'B', 10);
			
			$fpdf->SetAligns($header_aligns);
			
			if(count($default_params['header_data']) == 0) {
				foreach ($default_params['data'][0] as $flat_data_key => $flat_data_value) {
					$default_params['header_data'][] = Inflector::humanize(substr($flat_data_key, strrpos($flat_data_key, '.') + 1));
				}
			}
			$fpdf->RowWithBorder($default_params['header_data']);
			
			$fpdf->SetFont('Courier', '', 10);
			if($no_of_records > 0) {
				$fpdf->SetAligns($data_aligns);
				foreach ($default_params['data'] as $key => $value) {			
					$fpdf->RowWithBorder(array_values($value));
				}
			}
		}
		else {
			$fpdf->MultiCell($max_page_width, 20, 'No records found.', 0, 'C');
		}

		$fpdf->AliasNbPages();
		$fpdf->Output($default_params['file_name'], 'I');
	}
}