<?php
class InitialApplicantsController extends AppController {
	
	private $default_params = array(
		'fields' => array(
			'Applicant.id',
			'Applicant.color',
			'CONCAT((CASE WHEN Applicant.prefix_code = "" THEN "" WHEN Applicant.prefix_code IS NULL THEN "" ELSE PrefixList.name END), " ", Applicant.last_name, ", ", Applicant.first_name, " ", Applicant.middle_name, (CASE WHEN Applicant.suffix_code = "" THEN "" WHEN Applicant.suffix_code IS NULL THEN "" ELSE CONCAT(", ", Suffix.name) END)) as applicant_name',
			'Gender.name',
			'Applicant.date_of_birth',
			'ApplicationStatus.name',
			'Applicant.applicant_type',
		), 
		'conditions' => array(
			'Applicant.status' => 'Active'
		), 
		'order' => 'Applicant.last_name ASC', 
		'limit' => 20, 
		'recursive' => 0
	);
		
	public $components = array('ExportInventoryVersion','Export');
	public function hris_index() {
		$this->search_applicants();
	}
	private function search_applicants($submitted_conditions = array(), $report_type = '', $report_format = ''){
		$this->get_dropdowns();
		$default_conditions = array(
			'Applicant.status' => 'Active'
		);
		$default_order = 'Applicant.last_name ASC';

		if(isset($this->request['url']['sort']) && $this->request['url']['direction']) {
			$default_order = $this->request['url']['sort'] . ' ' . $this->request['url']['direction'];
		}
		
		if(isset($this->request->query['applicant_name']) && trim($this->request->query['applicant_name']) != '') {
			$applicant_name = $this->request->query['applicant_name'];
			$this->request->data['SearchApplicant']['applicant_name'] = $applicant_name;
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'OR' => array(
						'Applicant.first_name LIKE \'%'. $applicant_name .'%\'',
						'Applicant.middle_name LIKE \'%'. $applicant_name .'%\'',
						'Applicant.last_name LIKE \'%'. $applicant_name .'%\''
					)
						
				)
			);
		}

		if(isset($this->request->query['application_status']) && trim($this->request->query['application_status']) != '') {
			$application_status = $this->request->query['application_status'];
			$this->request->data['SearchApplicant']['application_status'] = $application_status;
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'Applicant.application_status_code = "'. $application_status .'"' 
				)
			);
		}
		
		if(isset($this->request->query['gender']) && trim($this->request->query['gender']) != '') {
			$gender = $this->request->query['gender'];
			$this->request->data['SearchApplicant']['gender'] = $gender;
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'Applicant.gender_code = "'. $gender .'"' 
				)
			);
		}
		
		if(isset($this->request->query['date_of_birth_from']) && trim($this->request->query['date_of_birth_from']) != '') {
			$date_of_birth_from = $this->request->query['date_of_birth_from'];
			$date_of_birth_from = convert_datetime($date_of_birth_from, 'Y-m-d');
			$this->request->data['SearchApplicant']['date_of_birth_from'] =  convert_datetime($date_of_birth_from, 'm/d/Y');
		}
		if(isset($this->request->query['date_of_birth_to']) && trim($this->request->query['date_of_birth_to']) != '') {
			$date_of_birth_to = $this->request->query['date_of_birth_to'];
			$date_of_birth_to = convert_datetime($date_of_birth_to, 'Y-m-d');
			$this->request->data['SearchApplicant']['date_of_birth_to'] =  convert_datetime($date_of_birth_to, 'm/d/Y');
		}

		if(isset($date_of_birth_from) && isset($date_of_birth_to)) {
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'Applicant.date_of_birth >=' => $date_of_birth_from,
					'Applicant.date_of_birth <=' => $date_of_birth_to
				)
			);
		}
		else if(isset($date_of_birth_from)) {
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'Applicant.date_of_birth >=' => $date_of_birth_from,
				)
			);
		}
		else if(isset($date_of_birth_to)) {
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'Applicant.date_of_birth <=' => $date_of_birth_to
				)
			);
		}
		
		if(isset($this->request->query['applicant_type']) && trim($this->request->query['applicant_type']) != '') {
			$applicant_type= $this->request->query['applicant_type'];
			$this->request->data['SearchApplicant']['applicant_type'] = $applicant_type;

			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'Applicant.applicant_type = "'. $applicant_type .'"' 
				)
			);
		}
		
		if(isset($report_type) && $report_type == 'Basic Reports') {
			$applicants = $this->Applicant->find('all',array(
				// 'fields' => array(
					// 'Applicant.id',
					// 'Applicant.color',
					// 'Applicant.date_applied',
					// 'Applicant.standard_name',
					// 'Gender.name',
					// 'Applicant.date_of_birth',
					// 'ApplicationStatus.name',
					// 'Applicant.outsider_or_insider',
				// ),
				'contain' => array(
					'ApplicantAppliedPosition' => array(
						'JobTitle' => array(
							'Section'
						),
					
					),
					'Gender',
					'ApplicationStatus',
					'Employee'
				),
				'conditions' => $default_conditions,
				'order' => $default_order,
				'recursive' => 1
			));
			
			
			$applicants = reorder(array(
				'fields' => array(

					// 'Applicant.color',
					'Applicant.date_applied',
					'Applicant.standard_name',
					'ApplicantAppliedPosition.0.JobTitle.name',
					'ApplicantAppliedPosition.0.JobTitle.Section.name',
					'Gender.name',
					'Applicant.date_of_birth',
					'ApplicationStatus.name',
					'Applicant.applicant_type',
						),
				'data' => $applicants
			));
			
			

			if(isset($report_format) && $report_format == 'csv') {
				$this->Export->export_csv(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Date Applied',
						'Name',
						'Position Applied',
						'Section',
						'Gender',
						'Date of Birth',
						'Application Status',
						'Applicant Type',
						
					),
					'data' => $applicants
				));
			}
			else if(isset($report_format) && $report_format == 'excel') {
				$this->Export->export_excel_with_template(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Date Applied',
						'Name',
						'Position Applied',
						'Section',
						'Gender',
						'Date of Birth',
						'Application Status',
						'Applicant Type',
					),
					'data' => $applicants
				));
			}
			else if(isset($report_format) && $report_format == 'pdf') {
				$this->Export->export_pdf_with_template(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Date Applied',
						'Name',
						'Position Applied',
						'Section',
						'Gender',
						'Date of Birth',
						'Application Status',
						'Applicant Type',
					),
					'data' => $applicants
				));
			}
		}
		else {
			$this->Paginator->settings=array(
				'contain' => array(
					'ApplicantAppliedPosition' => array(
						'JobTitle' => array(
							'Section'
						),
					),
					'Gender',
					'ApplicationStatus',
					'Employee'
				),
				'conditions' => $default_conditions,
				'order' => $default_order,
				'recursive' => 0
			);
			
			$applicants = $this->Paginator->paginate('Applicant');
			
			$applicants = reorder(array(
				'fields' => array(
					'Applicant.id',
					'Applicant.color',
					'Applicant.date_applied',
					'Applicant.standard_name',
					'ApplicantAppliedPosition.0.JobTitle.name',
					'ApplicantAppliedPosition.0.JobTitle.Section.name',
					'Gender.name',
					'Applicant.date_of_birth',
					'ApplicationStatus.name',
					'Applicant.applicant_type',
					'Applicant.remarks',
						),
				'data' => $applicants
			));
			
		foreach($applicants as $k=>$applicant) $applicants[$k]['Applicant.color']= '<div style="background-color: '. $applicants[$k]['Applicant.color'].';"> &nbsp;</div>';
		$this->set('applicants', $applicants);
		
		if (count($applicants) == 0) {
			$this->Alert->display('no_records_found');
		}
		
		
		}
	
	}
	
	
	
	
	
	public function hris_add_initial_applicant($id=null,$job_title_code=null,$job_title_item_number=null) {
		$this->get_dropdowns();
		
		$this->layout = 'dai.dai.applicant.default';
		$data_save = array();
				$datasource  = array();
		if ($this->request->is('post') || $this->request->is('put')) {
			$this->loadModel('Applicant');
			
			## ADDED BASED ON MAIN FIELDS
			$this->request->data['Applicant']['outsider_or_insider'] = 'Outsider';
			$this->request->data['Applicant']['date_created'] = date('m/d/Y');
			$this->request->data['Applicant']['color'] = 'red';
			$this->request->data['ApplicantAppliedPosition'][0]['job_title_code'] = $job_title_code;
			$this->request->data['ApplicantAppliedPosition'][0]['job_title_item_number_code'] = $job_title_item_number;
			$this->request->data['ApplicantAppliedPosition'][0]['date_applied'] = date('m/d/Y');
			## ADDED BASED ON MAIN FIELDS
			
			$attachment_content_rows = array();
			if (isset($this->request->data['Applicant']['RecruitmentApplicantLearningAndDevelopment'])) {
					
					foreach($this->request->data['Applicant']['RecruitmentApplicantLearningAndDevelopment'] as $attachment_content_item_no => $content) {
						$new_image=$this->request->data['Applicant']['RecruitmentApplicantLearningAndDevelopment'];
					
						$file_path = "files". "/" ."attachment/Applicant";
						if($new_image[$attachment_content_item_no]['attachment']['size']>0) {
							
							$temp = explode(".", $new_image[$attachment_content_item_no]["attachment"]["name"]);
							$newfilename = uniqid().rand(0,99) . '.' . end($temp);
							if (!file_exists($file_path)) {
								mkdir($file_path, 0777, true);
							}
							move_uploaded_file( $new_image[$attachment_content_item_no]["attachment"]["tmp_name"],$file_path. "/" . $newfilename );
							$new_image[$attachment_content_item_no]['attachment']= "/" .$file_path. "/" . $newfilename;

							array_push($attachment_content_rows, $attachment_content_item_no);
							$this->request->data['Applicant']['RecruitmentApplicantLearningAndDevelopment']=$new_image;
							
							
							## ADDED TO COPY FILES UPLOADED HERE TO HRIS DESTINATION
							$learning_and_development_original_path = WWW_ROOT . $file_path . "/" . $newfilename;
							$learning_and_development_destination_path = Configure::read('HRIS_MAIN_PATH_WEBROOT') . '\\' . $file_path . "/" . $newfilename;
							// debug($learning_and_development_destination_path);
							debug($this->hris_location_path_webroot . $file_path);
							if(!file_exists(Configure::read('HRIS_MAIN_PATH_WEBROOT') . '/' . $file_path)) {
								mkdir(Configure::read('HRIS_MAIN_PATH_WEBROOT') . '/' . $file_path, 0777, true);
							}
							
							copy($learning_and_development_original_path, $learning_and_development_destination_path);
							## ADDED TO COPY FILES UPLOADED HERE TO HRIS DESTINATION
						}
						else {
							unset($this->request->data['Applicant']['RecruitmentApplicantLearningAndDevelopment'][$attachment_content_item_no]);
						}
					}
			}
			$attachment_content_rows1 = array();
			if (isset($this->request->data['Applicant']['RecruitmentApplicantAttachment'])) {
					
					foreach($this->request->data['Applicant']['RecruitmentApplicantAttachment'] as $attachment_content_item_no_attachment => $content_attachment) {
						$new_image=$this->request->data['Applicant']['RecruitmentApplicantAttachment'];
					
						$file_path = "files". "/" ."attachment/Applicant";
						if($new_image[$attachment_content_item_no_attachment]['attachment']['size']>0) {
							
							$temp = explode(".", $new_image[$attachment_content_item_no_attachment]["attachment"]["name"]);
							$newfilename = uniqid().rand(0,99) . '.' . end($temp);
							if (!file_exists($file_path)) {
								mkdir($file_path, 0777, true);
							}
							move_uploaded_file( $new_image[$attachment_content_item_no_attachment]["attachment"]["tmp_name"],$file_path. "/" . $newfilename );
							$new_image[$attachment_content_item_no_attachment]['attachment']= "/" .$file_path. "/" . $newfilename;

							array_push($attachment_content_rows1, $attachment_content_item_no_attachment);
							$this->request->data['Applicant']['RecruitmentApplicantAttachment']=$new_image;
							// debug($this->request->data['Applicant']['ApplicantLearningAndDevelopment']);
							
							
							## ADDED TO COPY FILES UPLOADED HERE TO HRIS DESTINATION
							$attachment_original_path = WWW_ROOT . $file_path . "/" . $newfilename;
							$attachment_destination_path = Configure::read('HRIS_MAIN_PATH_WEBROOT') . '\\' . $file_path . "/" . $newfilename;
							
							if(!file_exists(Configure::read('HRIS_MAIN_PATH_WEBROOT') . '/' . $file_path)) {
								mkdir(Configure::read('HRIS_MAIN_PATH_WEBROOT') . '/' . $file_path, 0777, true);
							}
							
							copy($attachment_original_path, $attachment_destination_path);
							## ADDED TO COPY FILES UPLOADED HERE TO HRIS DESTINATION
						}
						else {
							unset($this->request->data['Applicant']['RecruitmentApplicantAttachment'][$attachment_content_item_no_attachment]);
						}
					}
			}
			$datasource = $this->Applicant->getDataSource();
			$datasource->begin();
			$data_save = $this->request->data;
			
			if ($this->Applicant->saveAssociated($data_save, array('deep' => true))) {
			
				$datasource->commit();
	
				$this->Session->setFlash('Applicant has been saved.', 'global-notice-success-full');
				return $this->redirect(array('controller' => 'initial_applicants', 'action' => 'select_job_type_vacancy', 'prefix' => 'hris', 'hris' => true));
			}
			else {

				$this->Alert->display('failed_applicant_save');
			}
		}
		
		$this->set('job_title_code',$job_title_code);
		$this->set('job_title_item_number',$job_title_item_number);
		$this->set('roles', $this->DaiSecurity->roles);
 	}
	
	public function hris_edit_initial_applicant($applicant_id = null) { 
		$this->loadModel('Applicant');
		$applicant = $this->Applicant->find('first',array(
			
			'contain' => array(
				'Gender',
				'PrefixList',
				'Suffix',
				'ApplicantAppliedPosition' => array(
					'JobTitle',
					'JobTitleItemNumber'
				),
				'RecruitmentApplicantAttachment',
				'RecruitmentApplicantWorkHistory' => array(
					'StatusOfAppointment'
				),
				'RecruitmentApplicantEducation' => array(
					'Level'
				),
				'RecruitmentApplicantLearningAndDevelopment' => array(
					'LearningAndDevelopmentType'
				),
				'RecruitmentApplicantEligibility'
			),
			'conditions' => array(
				'Applicant.id' => $applicant_id,
			),
			'recursive' => 1
		));
		
		// debug($applicant);
		// exit();
		$this->get_dropdowns();
		$attachment_content_rows = array();
		if(count($applicant) > 0) {
			if ($this->request->is('post') || $this->request->is('put')) {	
			 
				$selected_education_ids = array();
				$selected_work_history_ids = array();
				$learning_and_development_ids = array();
				
				$education_content_item_no     = 0;
				
				if ($this->request->data['Applicant']['applicant_type'] == 'Promotion' || $this->request->data['Applicant']['applicant_type'] == 'Demotion') {
					$edit_applicant= $this->Employee->find('first',array(
						'fields' => array(
							'PrefixList.code',
							'Employee.last_name',
							'Employee.first_name',
							'Employee.middle_name',
							'Employee.birth_date',
							'Suffix.code',
							'Gender.code',
							'Employee.birth_date',
						),
						
						'contain' => array(
							'Gender',
							'PrefixList',
							'Suffix'
						),
						'conditions' => array(
							'Employee.employee_code' =>$this->request->data['Applicant']['employee_code'],
						),
						'recursive' => -1
					));
					
					$this->request->data['Applicant']['last_name'] = $edit_applicant['Employee']['last_name'];
					$this->request->data['Applicant']['first_name'] = $edit_applicant['Employee']['first_name'];
					$this->request->data['Applicant']['middle_name'] = $edit_applicant['Employee']['middle_name'];
					$this->request->data['Applicant']['suffix_code'] = $edit_applicant['Suffix']['code'];
					$this->request->data['Applicant']['prefix_code'] = $edit_applicant['PrefixList']['code'];
					$this->request->data['Applicant']['date_of_birth'] = $edit_applicant['Employee']['birth_date'];
					$this->request->data['Applicant']['gender_code'] = $edit_applicant['Gender']['code'];
					$this->request->data['Applicant']['color'] = 'green';
					
				}
				else{
					$this->request->data['Applicant']['color'] = 'red';
				}
				
				
				if (isset($this->request->data['RecruitmentApplicantEducation'])) {
					
					foreach ($this->request->data['RecruitmentApplicantEducation'] as $education_content_item_no => $content) {
							
						if ($content['id'] != null) {
							array_push($selected_education_ids, $content['id']);
						}
					
					}
					
					if (isset($applicant['RecruitmentApplicantEducation'][$education_content_item_no]['applicant_code']) && count($applicant['RecruitmentApplicantEducation']) > 0) {
						
						$this->loadModel('RecruitmentApplicantEducation');
						$this->RecruitmentApplicantEducation->deleteAll(
							array(
								'NOT' => array(
									'RecruitmentApplicantEducation.id' => $selected_education_ids
								),
								'AND' => array(
									'RecruitmentApplicantEducation.applicant_code' => $applicant['RecruitmentApplicantEducation'][$education_content_item_no]['applicant_code'],
								)
							), 
							false
						);
					}
					
				}
				else {
					$original_attachment_ids = array();
					
					if (isset($applicant['RecruitmentApplicantEducation'][$education_content_item_no]['applicant_code'])) {
					
						foreach($applicant['RecruitmentApplicantEducation'] as $education_content_item_no => $content) {
							
							array_push($original_attachment_ids, $content['id']);
							
						}
						$this->loadModel('RecruitmentApplicantEducation');
						
						$this->RecruitmentApplicantEducation->deleteAll(
							array(
								'RecruitmentApplicantEducation.applicant_code' => $applicant['RecruitmentApplicantEducation'][$education_content_item_no]['applicant_code'],
							), 
							false
						);
						
					}
					
				}
					
				if (isset($this->request->data['RecruitmentApplicantWorkHistory'])) {
					
					foreach($this->request->data['RecruitmentApplicantWorkHistory'] as $work_history_content_item_no => $content) {
							
						if ($content['id'] != null) {
							array_push($selected_work_history_ids, $content['id']);
						}
					
					}
					
					if (isset($applicant['RecruitmentApplicantWorkHistory'][$work_history_content_item_no]['applicant_code']) && count($applicant['RecruitmentApplicantWorkHistory']) > 0) {
						
						$this->loadModel('RecruitmentApplicantWorkHistory');
						$this->RecruitmentApplicantWorkHistory->deleteAll(
							array(
								'NOT' => array(
									'RecruitmentApplicantWorkHistory.id' => $selected_work_history_ids
								),
								'AND' => array(
									'RecruitmentApplicantWorkHistory.applicant_code' => $applicant['RecruitmentApplicantWorkHistory'][$work_history_content_item_no]['applicant_code'],
								)
							), 
							false
						);
					}
					
					
				}
				else {
					
					$original_attachment_ids = array();
					// debug($applicant); exit();
					
					// foreach($applicant['RecruitmentApplicantWorkHistory'] as $work_history_content_item_no =>$content) {
						
						// array_push($original_attachment_ids, $content['id']);
						
					// }

					// $this->loadModel('RecruitmentApplicantWorkHistory');
					
					// $this->RecruitmentApplicantWorkHistory->deleteAll(
						// array(
							// 'RecruitmentApplicantWorkHistory.applicant_code' => $applicant['RecruitmentApplicantWorkHistory'][$work_history_content_item_no]['applicant_code'],
						// ), 
						// false
					// );

				}
				
				if (isset($this->request->data['RecruitmentApplicantLearningAndDevelopment'])) {
					
					foreach($this->request->data['RecruitmentApplicantLearningAndDevelopment'] as $learning_and_development_content_item_no => $content) {
							
						if($content['id']!=null) {
							array_push($learning_and_development_ids, $content['id']);
						}
						
						$new_image=$this->request->data;
						$file_path = "files". "/" ."RecruitmentApplicantLearningAndDevelopment";
						

						if (isset($new_image['RecruitmentApplicantLearningAndDevelopment'])) {
							
							if ($new_image['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['attachment']['size'] > 0) {
								
								$temp = explode(".", $new_image['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]["attachment"]["name"]);
								$newfilename = uniqid().rand(0,99) . '.' . end($temp);
								
								if (!file_exists($file_path)) {
									mkdir($file_path, 0777, true);
								}
								
								move_uploaded_file( $new_image['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]["attachment"]["tmp_name"],$file_path. "/" . $newfilename );
								$new_image['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['attachment']= "/" .$file_path. "/" . $newfilename;
								
							}
							else {
								
							if (isset($applicant['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['attachment']) != '') {
									
									$new_image['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['attachment'] = $applicant['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['attachment'];
									
								}
								else {
									
									$new_image['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['attachment'] = '';
									
								}
							}
							$this->request->data = $new_image;
						}			
	
					}
			
					if (isset($applicant['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['applicant_code']) && count($applicant['RecruitmentApplicantLearningAndDevelopment']) > 0) {
						
						$this->loadModel('RecruitmentApplicantLearningAndDevelopment');
						$this->RecruitmentApplicantLearningAndDevelopment->deleteAll(
							array(
								'NOT' => array(
									'RecruitmentApplicantLearningAndDevelopment.id' => $learning_and_development_ids
								),
								'AND' => array(
									'RecruitmentApplicantLearningAndDevelopment.applicant_code' => $applicant['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['applicant_code'],
								)
							), 
							false
						);
						
					}
				}
				else {
					$original_attachment_ids=array();
					
					if (isset($this->request->data['RecruitmentApplicantLearningAndDevelopment'])) {
			
						foreach($applicant['RecruitmentApplicantLearningAndDevelopment'] as $learning_and_development_content_item_no => $content) {
							
							array_push($original_attachment_ids, $content['id']);
							
						}
						
						$this->loadModel('RecruitmentApplicantLearningAndDevelopment');
						
						$this->RecruitmentApplicantLearningAndDevelopment->deleteAll(
							array(
								'RecruitmentApplicantLearningAndDevelopment.applicant_code' => $applicant['RecruitmentApplicantLearningAndDevelopment'][$learning_and_development_content_item_no]['applicant_code'],
							), 
							
							false
						);
					
					}
					else {
						unset($this->request->data['RecruitmentApplicantLearningAndDevelopment']);
					}
				}
				
				if (isset($this->request->data['RecruitmentApplicantEligibility'])) {
					$selected_eligibity_ids = array();
					foreach($this->request->data['RecruitmentApplicantEligibility'] as $eligibility_content_item_no => $content) {
							
						if ($content['id'] != null) {
							array_push($selected_eligibity_ids, $content['id']);
						}
					
					}
					
					if (isset($applicant['RecruitmentApplicantEligibility'][$eligibility_content_item_no]['applicant_code']) && count($applicant['RecruitmentApplicantEligibility']) > 0) {
						
						$this->loadModel('RecruitmentApplicantEligibility');
						$this->RecruitmentApplicantEligibility->deleteAll(
							array(
								'NOT' => array(
									'RecruitmentApplicantEligibility.id' => $selected_eligibity_ids
								),
								'AND' => array(
									'RecruitmentApplicantEligibility.applicant_code' => $applicant['RecruitmentApplicantEligibility'][$eligibility_content_item_no]['applicant_code'],
								)
							), 
							false
						);
					}
					
					
				}
				else {
					
					$original_attachment_ids = array();

					foreach($applicant['RecruitmentApplicantEligibility'] as $eligibility_content_item_no =>$content) {
						
						array_push($original_attachment_ids, $content['id']);
						
					}
					
					if (isset($this->request->data['RecruitmentApplicantEligibility'])) {
						$this->loadModel('RecruitmentApplicantEligibility');
						
						$this->RecruitmentApplicantEligibility->deleteAll(
							array(
								'RecruitmentApplicantEligibility.applicant_code' => $applicant['RecruitmentApplicantEligibility'][$eligibility_content_item_no]['applicant_code'],
							), 
							false
						);
					}

				}

				if (isset($this->request->data['RecruitmentApplicantAttachment'])) {
					
					foreach($this->request->data['RecruitmentApplicantAttachment'] as $attachment_content_item_no => $content) {

						$new_image=$this->request->data['RecruitmentApplicantAttachment'];
					
						$file_path = "files". "/" ."attachment/Applicant";
						if($new_image[$attachment_content_item_no]['attachment']['size']>0) {
							
							$temp = explode(".", $new_image[$attachment_content_item_no]["attachment"]["name"]);
							$newfilename = uniqid().rand(0,99) . '.' . end($temp);
							if (!file_exists($file_path)) {
								mkdir($file_path, 0777, true);
							}
							move_uploaded_file( $new_image[$attachment_content_item_no]["attachment"]["tmp_name"],$file_path. "/" . $newfilename );
							$new_image[$attachment_content_item_no]['attachment']= "/" .$file_path. "/" . $newfilename;

							array_push($attachment_content_rows, $attachment_content_item_no);
							$this->request->data['RecruitmentApplicantAttachment']=$new_image;
						}
						else {
							unset($this->request->data['RecruitmentApplicantAttachment'][$attachment_content_item_no]);
						}
						
					}
					
				}
				
				
				$selected_ids = array();
				
				$applied_position_data = array();
				$this->loadModel('ApplicantAppliedPosition');
				/* 
				if(!isset($this->request->data['ApplicantAppliedPosition'])){
					$this->Alert->display('failed_no_applicant_selected');
					return $this->redirect(array('controller' => 'applicants', 'action' => 'edit_applicant', $applicant['Applicant']['id'],'prefix' => 'hris', 'hris' => true));
				}

				foreach($this->request->data['ApplicantAppliedPosition'] as $application_applied_position_key => $application_applied_position_value){
					
					if($application_applied_position_value['id'] == "undefined"){
						unset($this->request->data['ApplicantAppliedPosition'][$application_applied_position_key]['id']);
						$applied_position_data['ApplicantAppliedPosition'][$application_applied_position_key]['job_title_code'] = $application_applied_position_value['job_title_code'];
						$applied_position_data['ApplicantAppliedPosition'][$application_applied_position_key]['job_title_code'] = $application_applied_position_value['date_applied'];
					}
					else{
						// debug($application_applied_position_value);
						$selected_ids[$application_applied_position_value['id']] = $application_applied_position_value['id'];
						
						unset($this->request->data['ApplicantAppliedPosition'][$application_applied_position_key]['id']);
						$applied_position_data['ApplicantAppliedPosition'][$application_applied_position_key]['job_title_code'] = $application_applied_position_value['job_title_code'];
						$applied_position_data['ApplicantAppliedPosition'][$application_applied_position_key]['job_title_code'] = $application_applied_position_value['date_applied'];
						
					}
				}
				
				// exit();
				$unselected_data_ids = $this->ApplicantAppliedPosition->find('all', array(
					'fields'=>array('ApplicantAppliedPosition.id'),
					'conditions' => array(
						'ApplicantAppliedPosition.status'=>'Active',	
						'ApplicantAppliedPosition.applicant_code'=>$applicant['Applicant']['code'],	
						"NOT" => array( "ApplicantAppliedPosition.id" => $selected_ids)
					),
					'recursive' => -1
				));
				
				$unselected_ids = array();
				foreach($unselected_data_ids as $unselected_data_ids){
					$unselected_ids[$unselected_data_ids['ApplicantAppliedPosition']['id']] = $unselected_data_ids['ApplicantAppliedPosition']['id'];
				}
				 */
				$datasource = $this->Applicant->getDataSource();
				$datasource->begin();
				
				if ($this->Applicant->saveAssociated($this->request->data, array('deep' => true))) {
					
					$datasource->commit();
					/* 
					$this->ApplicantAppliedPosition->updateAll(
						array('ApplicantAppliedPosition.status'=>"'Disabled'"),
						array('ApplicantAppliedPosition.id'=>$unselected_ids)
						
					);
					 */
					$this->Alert->display('success_applicant_update');
					
					
					
					return $this->redirect(array('controller' => 'initial_applicants', 'action' => 'view_initial_applicant', $applicant['Applicant']['code'],'prefix' => 'hris', 'hris' => true));
				}
				else {
					
					$datasource->rollback();
					$datasource->commit();
					
					$this->Alert->display('failed_applicant_update');
				}
			}
			else {
				$this->request->data = $applicant;
				$selected_job_title = array();
				// debug($applicant['ApplicantAppliedPosition']);
				// exit();
				/* 
				if(isset($applicant['ApplicantAppliedPosition']) && count($applicant['ApplicantAppliedPosition'])>0){		
					foreach($applicant['ApplicantAppliedPosition'] as $key => $applicant_applied_position_value){
						
						$selected_job_title[$applicant_applied_position_value['job_title_item_number_code']]['id'] = $applicant_applied_position_value['id'];
						$selected_job_title[$applicant_applied_position_value['job_title_item_number_code']]['item_number'] = isset($applicant_applied_position_value['JobTitleItemNumber']['item_number']) ? $applicant_applied_position_value['JobTitleItemNumber']['item_number'] : '';
						$selected_job_title[$applicant_applied_position_value['job_title_item_number_code']]['code'] = $applicant_applied_position_value['job_title_item_number_code'];
						$selected_job_title[$applicant_applied_position_value['job_title_item_number_code']]['name'] = isset($applicant_applied_position_value['JobTitle']['name']) ? $applicant_applied_position_value['JobTitle']['name'] : 'N/A';
						$selected_job_title[$applicant_applied_position_value['job_title_item_number_code']]['job_title_code'] = $applicant_applied_position_value['job_title_code'];
						$selected_job_title[$applicant_applied_position_value['job_title_item_number_code']]['date_applied'] = $applicant_applied_position_value['date_applied'] == null? '' : $applicant_applied_position_value['date_applied'];
						
					}
				}
				 */
				// debug($selected_job_title);
				// exit();
				$this->set('selected_job_title', $selected_job_title);
				$this->set('applicant', $applicant);
			}
		}
		else {
			$this->Alert->display('no_records_found');
			return $this->redirect(array('controller' => 'initial_applicants', 'action' => 'add_initial_applicants', 'prefix' => 'hris', 'hris' => true));
		}		
 	}
	
	
	
	
	public function hris_view_initial_applicant($applicant_code = null) {
		$this->layout = 'dai.dai.applicant.default';
		$this->loadModel('Applicant');
		// $this->add_system_trail('VIEW', 'Applicant','has viewed applicant.');
		
		$applicant = $this->Applicant->find('first',array(
			'contain' => array(
				'ApplicantAppliedPosition' => array(
					// 'JobTitleItemNumber' => array(
					'JobTitle' => array(
						'Section',
						'SalaryGrade'
					),
					// ),
					'TakeExam' => array(
						'Exam' => array(
							'ExamType',
								'ExamQuestionnaire',
						),
						'TakeExamApplicantAnswer'
					),
					'ApplicationStatus',
				),
				'ApplicationStatus',
				'Gender',
				'PrefixList',
				'Suffix',
				'Employee' => array(
					'Education'=>array(
						'fields'=>array('Education.*'),
						'Level',	
					),
					'WorkHistory'=>array(
						'fields'=>array('WorkHistory.*'),
						'StatusOfAppointment',	
					),
					'LearningAndDevelopment'=>array(
						'fields'=>array('LearningAndDevelopment.*'),
						'LearningAndDevelopmentType'
					)
				),
				'RecruitmentApplicantAttachment' ,
				'RecruitmentApplicantWorkHistory' => array(
					'StatusOfAppointment'
				),
				'RecruitmentApplicantEducation' => array(
					'Level'
				),
				'RecruitmentApplicantLearningAndDevelopment' => array(
					'LearningAndDevelopmentType'
				),
				'RecruitmentApplicantEligibility'
			),
			'conditions'=>array(
				'Applicant.code' => $applicant_code
			),
			'recursive' => 1
		));
		
		// debug($applicant);
		// exit();

		if(count($applicant) > 0) {	
			$applicant['Applicant']['applicant_name'] = $applicant['PrefixList']['name'] . ' ' . $applicant['Applicant']['last_name'] . ', ' . $applicant['Applicant']['first_name'] . ' ' . $applicant['Applicant']['middle_name'];
			$this->set('applicant', $applicant);
		}
		else {
			$this->Alert->display('no_records_found');
			return $this->redirect(array('controller' => 'applicants', 'action' => 'index', 'prefix' => 'hris', 'hris' => true));
		}		
		
 	}
	
	public function hris_delete_applicant($applicant_id = null) {
		$this->loadModel('Applicant');

		$this->Applicant->recursive=-1;
		if($this->Applicant->updateAll(
					array('Applicant.status'=>"'Disabled'"),
					array('Applicant.id'=>$applicant_id))){
			$this->add_system_trail('DELETE', 'Applicant','has deleted applicant', $applicant_id);
			$this->Alert->display('success_applicant_delete');
			return $this->redirect(array('controller' => 'applicants', 'action' => 'index', 'prefix' => 'hris', 'hris' => true));
		}
		else{
			$this->Alert->display('failed_applicant_delete');
		}
	}
	
	
	
	protected function get_dropdowns($requested_dropdowns = array()) {
		
		if (in_array('LearningAndDevelopmentType', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('LearningAndDevelopmentType');
			
			$type_of_ld_list = $this->LearningAndDevelopmentType->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'LearningAndDevelopmentType.status' => 'Active',
				),
				'order' => array(
					'LearningAndDevelopmentType.created' => 'ASC'
				)
			));			
			$this->set('type_of_ld_list', $type_of_ld_list);			
		}
		
		if (in_array('StatusOfAppointment', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('StatusOfAppointment');
			
			$status_of_appointment_list = $this->StatusOfAppointment->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'StatusOfAppointment.status' => 'Active',
				),
				'order' => array(
					'StatusOfAppointment.name' => 'ASC'
				)
			));			
			$this->set('status_of_appointment_list', $status_of_appointment_list);			
		}
		
		if (in_array('PrefixList', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('PrefixList');
			
			$prefix_list = $this->PrefixList->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'PrefixList.status' => 'Active',
				),
				'order' => array(
					'PrefixList.name' => 'ASC'
				)
			));			
			$this->set('prefix_list', $prefix_list);			
		}
		
		if (in_array('Suffix', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Suffix');
			
			$suffix_list = $this->Suffix->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'Suffix.status' => 'Active',
				),
				'order' => array(
					'Suffix.name' => 'ASC'
				)
			));			
			$this->set('suffix_list', $suffix_list);			
		}
		
		if (in_array('ApplicationStatus', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('ApplicationStatus');
			
			$application_status_list = $this->ApplicationStatus->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'ApplicationStatus.status' => 'Active',
				),
				'order' => array(
					'ApplicationStatus.name' => 'ASC'
				)
			));			
			$this->set('application_status_list', $application_status_list);			
		}
		if (in_array('Level', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Level');
			
			$level_list = $this->Level->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'Level.status' => 'Active',
				),
				'order' => array(
					'Level.id' => 'ASC'
				)
			));			
			$this->set('level_list', $level_list);			
		}
		
		if (in_array('Vacancy', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Vacancy');
			
			$vacancy_lists = $this->Vacancy->find('list', array(
				'fields' => array(
					'reference_number', 
					// 'job_title'
				),
				'conditions' => array(
					'Vacancy.status' => 'Active',
				),
				'order' => array(
					// 'Vacancy.job_title' => 'ASC'
				)
			));			
			$this->set('vacancy_lists', $vacancy_lists);			
		}
		
		if (in_array('VacancyPlantilla', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('JobTitle');
			$this->loadModel('VacancyPlantilla');
			$this->loadModel('VacancyJobOrder');
			$job_title_list = array();
			$this->VacancyPlantilla->virtualFields = array(
				'name' => 'JobTitle.name'
			);
			$vacancy_plantilla_list = $this->VacancyPlantilla->find('list', array(
				'fields' => array(
					'job_title_code', 
					'name'
				),
				'contain' => array(
					'JobTitle'
				),
				'conditions' => array(
					'VacancyPlantilla.status' => 'Active',
				),
				'order' => array(
					'VacancyPlantilla.name' => 'ASC'
				)
			));			
			$this->VacancyJobOrder->virtualFields = array(
				'name' => 'JobTitle.name'
			);
			$vacancy_job_order_list = $this->VacancyJobOrder->find('list', array(
				'fields' => array(
					'job_title_code', 
					'name'
				),
				'contain' => array(
					'JobTitle'
				),
				'conditions' => array(
					'VacancyJobOrder.status' => 'Active',
				),
				'order' => array(
					'VacancyJobOrder.name' => 'ASC'
				)
			));			
			
			
			
			$job_title_list = array_merge(
				array(
					'Plantilla' => $vacancy_plantilla_list, 
					'Job Order' => $vacancy_job_order_list, 
				)
			);
			$this->set('job_title_list', $job_title_list);
		}
		// debug($job_title_list);
		// exit();
		
		$this->loadModel('Exam');
		
		$exams = $this->Exam->find('all', array(
			'fields' => array(
				'Exam.reference_number',
				'ExamType.name',
			), 
			'conditions' => array(
				'Exam.status' => 'Active'
			), 
			'order' => 'Exam.reference_number ASC', 
			'limit' => 20, 
			'recursive' => 0
		));		
		
		$exam_list=array();
		
		foreach($exams as $e => $exam_items){
			$exam_list[$exam_items['Exam']['reference_number']] = $exam_items['ExamType']['name'];
		}
		
		$this->set('exam_list', $exam_list);
		
		
		
		
		if (in_array('Gender', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Gender');
			
			$gender_list = $this->Gender->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'Gender.status' => 'Active',
				),
				'order' => array(
					'Gender.name' => 'ASC'
				)
			));			
			$this->set('gender_list', $gender_list);			
		}
		if (in_array('Section', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('Section');
			
			$section_list = $this->Section->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'Section.status' => 'Active',
				),
				'order' => array(
					'Section.name' => 'ASC'
				)
			));			
			$this->set('section_list', $section_list);			
		}
		if (in_array('JobTitleItemNumber', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('JobTitleItemNumber');
			
			$job_title_item_number_list = $this->JobTitleItemNumber->find('list', array(
				'fields' => array(
					'code', 
					'item_number'
				),
				'conditions' => array(
					'JobTitleItemNumber.status' => 'Active',
				),
				'order' => array(
					'JobTitleItemNumber.item_number' => 'ASC'
				)
			));			
			$this->set('job_title_item_number_list', $job_title_item_number_list);			
		}
		$this->loadModel('Employee');
		$employee_list = $this->Employee->find('list', array(
			'fields' => array(
				'employee_code', 
				'combination_whole_name'
			),
			'conditions' => array(
				'Employee.status' => 'Active',
			),
			'order' => array(
				'Employee.combination_whole_name' => 'ASC'
			)
		));		
		$this->set('employee_list', $employee_list);
		
		if (in_array('CivilStatus', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('CivilStatus');
			
			$civil_status_list = $this->CivilStatus->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'CivilStatus.status' => 'Active',
				),
				'order' => array(
					'CivilStatus.name' => 'ASC'
				)
			));			
			$this->set('civil_status_list', $civil_status_list);			
		}
		
		if (in_array('BloodType', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('BloodType');
			
			$blood_type_list = $this->BloodType->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'BloodType.status' => 'Active',
				),
				'order' => array(
					'BloodType.name' => 'ASC'
				)
			));			
			$this->set('blood_type_list', $blood_type_list);			
		}
		
		if (in_array('CountryList', $requested_dropdowns) || count($requested_dropdowns) == 0) {
			$this->loadModel('CountryList');
			
			$country_list = $this->CountryList->find('list', array(
				'fields' => array(
					'code', 
					'name'
				),
				'conditions' => array(
					'CountryList.status' => 'Active',
				),
				'order' => array(
					'CountryList.name' => 'ASC'
				)
			));			
			$this->set('country_list', $country_list);			
		}

	}
	public function hris_get_vacancy() {
		$this->loadModel('JobTitle');
		$this->loadModel('JobTitleItemNumber');
		$this->autoRender=false;
		
		if ($this->request->is('post') || $this->request->is('put')) {
			
			$conditions=array();
			$conditions['JobTitleItemNumber.status'] = "Active";
			$conditions['JobTitleItemNumber.is_filled'] = "NO";
			
			if(isset($this->request->data['SearchVacancy']['search_keyword']) && $this->request->data['SearchVacancy']['search_keyword']!="") {
				$conditions[] = '(
					JobTitle.name like "%'.$this->request->data['SearchVacancy']['search_keyword'].'%"
					OR JobTitleItemNumber.item_number like "%'.$this->request->data['SearchVacancy']['search_keyword'].'%"
				)';
			}
			
			$job_title_item_number_list = $this->JobTitleItemNumber->find('all',array(
				'conditions'=>$conditions,
				'contain'=>array(
					'JobTitle'
				),
				'recursive'=>-1
			));
			
			// $data=array();
			foreach($job_title_item_number_list as $k => $val){
				$data[$val['JobTitleItemNumber']['code']]['code'] = $val['JobTitleItemNumber']['code'];
				$data[$val['JobTitleItemNumber']['code']]['job_title_code'] = $val['JobTitle']['code'];
				$data[$val['JobTitleItemNumber']['code']]['item_number'] = $val['JobTitleItemNumber']['item_number'];
				$data[$val['JobTitleItemNumber']['code']]['date_applied'] = '';
				$data[$val['JobTitleItemNumber']['code']]['name'] = $val['JobTitle']['name'];
				##// $data[$val['JobTitle']['code']]['created_by']=$val['JobTitl	eItemNumber']['created_by'];
			}
			// debug($data);
			// debug($job_title_item_number_list);
			// exit();
			// debug($job_title);exit();
			// echo json_encode($data);
			echo json_encode($data);
		}
		
	}
	
	
	
	public function hris_export_csv_applicant() {
		$this->add_system_trail('VIEW', 'Applicant','has has exported applicant  list to csv');
		$this->search_applicants(
			array(),
			'Basic Reports',
			'csv'
		);
	}
	
	public function hris_export_excel_applicant() {
		$this->add_system_trail('VIEW', 'Applicant','has has exported applicant  list to csv');
		$this->search_applicants(
			array(),
			'Basic Reports',
			'excel'
		);
	}
	
	public function hris_export_pdf_applicant() {
		$this->add_system_trail('VIEW', 'Applicant','has has exported applicant  list to csv');
		$this->search_applicants(
			array(),
			'Basic Reports',
			'pdf'
		);
	}
	
	public function hris_get_employee_information($employee_code = null){
		$this->loadModel('Employee');
		$this->autoRender=false;
		$applicant= $this->Employee->find('first',array(
			'fields' => array(
				'PrefixList.code',
				'Employee.last_name',
				'Employee.first_name',
				'Employee.middle_name',
				'Employee.birth_date',
				'Suffix.code',
				'Gender.code',
				'Employee.birth_date',
			),
			
			'contain' => array(
				'Gender',
				'PrefixList',
				'Suffix'
				),
			'conditions' => array(
				'Employee.employee_code' => $employee_code,
			),
			'recursive' => -1
		));
		return json_encode($applicant);
	}
	
	public function hris_get_item_number($job_title_code = null){
		$this->autoRender = false;		
		$this->loadModel('VacancyPlantilla');
		$this->VacancyPlantilla->virtualFields = array(
				'item_number' => 'JobTitleItemNumber.item_number'
			);
		$job_title_item_number = $this->VacancyPlantilla->find('list', array(
			'fields' => array(
				// 'JobTitleItemNumber.code',
				'VacancyPlantilla.job_title_item_number_code',
				'VacancyPlantilla.item_number'
			),
			'contain' => array(
				'JobTitleItemNumber' => array(
					'fields' => array(
						'JobTitleItemNumber.code',
						'JobTitleItemNumber.item_number',
					),
				),
			),
			'conditions' => array(
				'VacancyPlantilla.job_title_code' => $job_title_code,
				'VacancyPlantilla.status' => 'Active',
				'JobTitleItemNumber.is_filled' => 'NO',
				'VacancyPlantilla.open_for_vacancy' => 'YES'
			),
			'order' => array(
				'VacancyPlantilla.item_number ASC'
			)
		));
		
		// debug($job_title_item_number);
		// exit();
		
		echo json_encode($job_title_item_number);
	}
	
	public function hris_submitted_to_hr($initial_applicant_id = null){
		
   		$this->loadModel('Applicant');
		
		$applicant = $this->Applicant->find('first',array(
   				'conditions'=>array(
   					'Applicant.id' => $initial_applicant_id,
   				),
   				'recursive'=> -1
   		));
		// debug($applicant);
		// exit();
   		$this->Applicant->recursive=-1;
   		if($this->Applicant->updateAll(
   					array('Applicant.is_from_initial_applicant' => "'0'"),
   					array('Applicant.id' => $initial_applicant_id))){
   
			$this->add_system_trail('EDIT', $this->modelClass, 'has submitted training effectiveness evaluation form one', $initial_applicant_id);
   
   			$this->Alert->display('success_applicant_submitted_to_hr');
			
   			return $this->redirect(array(
				'controller' => 'initial_applicants', 
				'action' => 'add_initial_applicant' ,
				'prefix' => 'hris', 
				'hris' => true
			));
   		}
   		else{
   			$this->Alert->display('failed_applicant_submitted_to_hr');
   		}
	
   	}
	public function hris_view_vacancy_job_order($vacancy_job_order_id=null) {
		$this->loadModel('VacancyJobOrder');
		$vacancy_job_order = $this->VacancyJobOrder->find('first', array(
			'contain' => array(
				'JobTitle',
				'Section',
				'SuggestedSchedule',
				'ActualSchedule',
			),
			'conditions' => array(
				'VacancyJobOrder.id' => $vacancy_job_order_id,
			),
			// 'recursive' => -1
		));
		
		if (isset($vacancy_job_order) && count($vacancy_job_order) > 0) {		 
			// $this->add_system_trail('VIEW', 'VacancyJobOrder','has viewed vacancy_job_order:'. ' '. $vacancy_job_order_id);
			$this->set('vacancy_job_order', $vacancy_job_order);
		}
		else {
			$this->Alert->display('no_records_found');
			return $this->redirect(array('controller' => 'vacancy_job_orders', 'action' => 'index', 'prefix' => 'hris', 'hris' => true));
		}		
 	}
	public function hris_select_job_type_vacancy() {
		// debug($this->layout);
		// exit();
	}
	public function hris_vacancy_contractual_index() {
		$this->get_dropdowns();
		$this->search_vacancy_job_orders();
	}
	public function hris_vacancy_plantilla_index() {
		$this->get_dropdowns();
		$this->search_vacancy_plantillas();
	}
	private function search_vacancy_job_orders($submitted_conditions = array(), $report_type = '', $report_format = ''){
		// $this->get_dropdowns();
		// debug($vacancy_job_order);
			// exit();
		$this->loadModel('VacancyJobOrder');
		$default_conditions = array(
			'VacancyJobOrder.status' => 'Active'
		);
		$default_order = 'VacancyJobOrder.id ASC';

		if(isset($this->request['url']['sort']) && $this->request['url']['direction']) {
			$default_order = $this->request['url']['sort'] . ' ' . $this->request['url']['direction'];
		}
		
		
		// START SEARCH
		if(isset($this->request->query['position_title']) && trim($this->request->query['position_title']) != '') {
			$position_title = $this->request->query['position_title'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.job_title_code' => $position_title,
				)
			);
		}
		
		if(isset($this->request->query['section']) && trim($this->request->query['section']) != '') {
			$section = $this->request->query['section'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.section_code' => $section,
				)
			);
		}
		
		if((isset($this->request->query['valid_from']) && trim($this->request->query['valid_from']) != '') && (isset($this->request->query['valid_until']) && trim($this->request->query['valid_until']) != '')) {
			$valid_from = date("Y-m-d", strtotime($this->request->query['valid_from']));
			$valid_until = date("Y-m-d", strtotime($this->request->query['valid_until']));
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'OR' => array(
						'AND' => array(
							'VacancyJobOrder.valid_from_date >= "' . $valid_from . '"',
							'VacancyJobOrder.valid_from_date <= "' . $valid_until . '"',
						),
						'AND' => array(
							'VacancyJobOrder.valid_to_date >= "' . $valid_from . '"',
							'VacancyJobOrder.valid_to_date <= "' . $valid_until . '"',
						)
					)	
				)
			);
		}
		else if((isset($this->request->query['valid_from']) && trim($this->request->query['valid_from']) != '') && (!isset($this->request->query['valid_until']) || trim($this->request->query['valid_until']) == '')) {
			$valid_from = date("Y-m-d", strtotime($this->request->query['valid_from']));
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.valid_from_date >= "' . $valid_from . '"',
				)
			);
		}
		else if((isset($this->request->query['valid_until']) && trim($this->request->query['valid_until']) != '') && (!isset($this->request->query['valid_from']) || trim($this->request->query['valid_from']) == '')) {
			$valid_until = date("Y-m-d", strtotime($this->request->query['valid_until']));
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.valid_to_date <= "' . $valid_until . '"',
				)
			);
		}
		
		if(isset($this->request->query['number_of_vacancy']) && trim($this->request->query['number_of_vacancy']) != '') {
			$number_of_vacancy = $this->request->query['number_of_vacancy'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.number_of_vacancy' => $number_of_vacancy,
				)
			);
		}
		
		if(isset($this->request->query['years_of_experience']) && trim($this->request->query['years_of_experience']) != '') {
			$years_of_experience = $this->request->query['years_of_experience'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.years_of_experience LIKE \'%'. $years_of_experience .'%\''
				)
			);
		}
		
		if(isset($this->request->query['hours_of_relevant_training']) && trim($this->request->query['hours_of_relevant_training']) != '') {
			$hours_of_relevant_training = $this->request->query['hours_of_relevant_training'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.hours_of_relevant_training LIKE \'%'. $hours_of_relevant_training .'%\''
				)
			);
		}
		
		if(isset($this->request->query['eligibility']) && trim($this->request->query['eligibility']) != '') {
			$eligibility = $this->request->query['eligibility'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyJobOrder.eligibility LIKE \'%'. $eligibility .'%\''
				)
			);
		}
		
		// if(isset($this->request->query['education']) && trim($this->request->query['education']) != '') {
			// $education = $this->request->query['education'];
			
			// $default_conditions = array_merge(
				// $default_conditions, 
				// array(
					// 'VacancyJobOrder.education LIKE \'%'. $education .'%\''
				// )
			// );
		// }
		
		// END SEARCH
		
		if(isset($report_type) && $report_type == 'Basic Reports') {
			$vacancy_job_order = $this->VacancyJobOrder->find('all',array(
				'contain' => array(
					'JobTitle',
					'Section'
				),
				'conditions' => $default_conditions,
				'order' => $default_order,
			));
			
			
			$vacancy_job_order = reorder(array(
				'fields' => array(
					'JobTitle.name',
					// 'Section.name',
					'VacancyJobOrder.valid_from_date',
					'VacancyJobOrder.valid_to_date',
					'VacancyJobOrder.number_of_vacancy',
					'VacancyJobOrder.years_of_experience',
					'VacancyJobOrder.hours_of_relevant_training',
					'VacancyJobOrder.eligibility',
					// 'VacancyJobOrder.education',
				),
				'data' => $vacancy_job_order
			));
			
			

			if(isset($report_format) && $report_format == 'csv') {
				$this->Export->export_csv(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Position Title',
						// 'Section',
						'Valid From',
						'Valid Until',
						'Number of Vacancy',
						'Years of Experience',
						'Hours of Relevant Training',
						'Eligibility'
						// 'Education'
					),
					'data' => $vacancy_job_order
				));
			}
			else if(isset($report_format) && $report_format == 'excel') {
				$this->Export->export_excel_with_template(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Position Title',
						// 'Section',
						'Valid From',
						'Valid Until',
						'Number of Vacancy',
						'Years of Experience',
						'Hours of Relevant Training',
						'Eligibility'
						// 'Education'
					),
					'data' => $vacancy_job_order
				));
			}
			else if(isset($report_format) && $report_format == 'pdf') {
				$this->Export->export_pdf_with_template(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Position Title',
						// 'Section',
						'Valid From',
						'Valid Until',
						'Number of Vacancy',
						'Years of Experience',
						'Hours of Relevant Training',
						'Eligibility'
						// 'Education'
					),
					'data' => $vacancy_job_order
				));
			}
		}
		else {
			$this->Paginator->settings = array(
				'contain' => array(
					'JobTitle',
					'Section'
				),
				'conditions' => $default_conditions,
				'order' => $default_order,
				// 'recursive' => -1
			);
			
			$vacancy_job_order = $this->Paginator->paginate('VacancyJobOrder');
			// debug($default_conditions);
			// debug($vacancy_job_order);
			// exit();
			$vacancy_job_order = reorder(array(
				'fields' => array(
					'VacancyJobOrder.id',
					'JobTitle.name',
					// 'Section.name',
					'VacancyJobOrder.valid_from_date',
					'VacancyJobOrder.valid_to_date',
					'VacancyJobOrder.number_of_vacancy',
					'VacancyJobOrder.years_of_experience',
					'VacancyJobOrder.hours_of_relevant_training',
					'VacancyJobOrder.eligibility',
					// 'VacancyJobOrder.education',
				),
				'data' => $vacancy_job_order
			));
			
		}
		
		if(!$vacancy_job_order){
			$this->Alert->display('no_records_found');
		}
		$this->set('vacancy_job_order', $vacancy_job_order);
		
	}
	private function search_vacancy_plantillas($submitted_conditions = array(), $report_type = '', $report_format = ''){
		$this->loadModel('VacancyPlantilla');
		// $this->get_dropdowns();
		$default_conditions = array(
			'VacancyPlantilla.status' => 'Active',
			'VacancyPlantilla.open_for_vacancy' => 'YES'
		);
		$default_order = 'VacancyPlantilla.id ASC';

		if(isset($this->request['url']['sort']) && $this->request['url']['direction']) {
			$default_order = $this->request['url']['sort'] . ' ' . $this->request['url']['direction'];
		}
		
		
		// START SEARCH
		if(isset($this->request->query['position_title']) && trim($this->request->query['position_title']) != '') {
			$position_title = $this->request->query['position_title'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.job_title_code' => $position_title,
				)
			);
		}
				
		if(isset($this->request->query['item_number']) && trim($this->request->query['item_number']) != '') {
			$item_number = $this->request->query['item_number'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.job_title_item_number_code' => $item_number,
				)
			);
		}
		
		if(isset($this->request->query['section']) && trim($this->request->query['section']) != '') {
			$section = $this->request->query['section'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.section_code' => $section,
				)
			);
		}
		
		if((isset($this->request->query['valid_from']) && trim($this->request->query['valid_from']) != '') && (isset($this->request->query['valid_until']) && trim($this->request->query['valid_until']) != '')) {
			$valid_from = date("Y-m-d", strtotime($this->request->query['valid_from']));
			$valid_until = date("Y-m-d", strtotime($this->request->query['valid_until']));
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'OR' => array(
						'AND' => array(
							'VacancyPlantilla.valid_from_date >= "' . $valid_from . '"',
							'VacancyPlantilla.valid_from_date <= "' . $valid_until . '"',
						),
						'AND' => array(
							'VacancyPlantilla.valid_to_date >= "' . $valid_from . '"',
							'VacancyPlantilla.valid_to_date <= "' . $valid_until . '"',
						)
					)	
				)
			);
		}
		else if((isset($this->request->query['valid_from']) && trim($this->request->query['valid_from']) != '') && (!isset($this->request->query['valid_until']) || trim($this->request->query['valid_until']) == '')) {
			$valid_from = date("Y-m-d", strtotime($this->request->query['valid_from']));
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.valid_from_date >= "' . $valid_from . '"',
				)
			);
		}
		else if((isset($this->request->query['valid_until']) && trim($this->request->query['valid_until']) != '') && (!isset($this->request->query['valid_from']) || trim($this->request->query['valid_from']) == '')) {
			$valid_until = date("Y-m-d", strtotime($this->request->query['valid_until']));
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.valid_to_date <= "' . $valid_until . '"',
				)
			);
		}
		
		if(isset($this->request->query['years_of_experience']) && trim($this->request->query['years_of_experience']) != '') {
			$years_of_experience = $this->request->query['years_of_experience'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.years_of_experience LIKE \'%'. $years_of_experience .'%\''
				)
			);
		}
		
		if(isset($this->request->query['hours_of_relevant_training']) && trim($this->request->query['hours_of_relevant_training']) != '') {
			$hours_of_relevant_training = $this->request->query['hours_of_relevant_training'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.hours_of_relevant_training LIKE \'%'. $hours_of_relevant_training .'%\''
				)
			);
		}
		
		if(isset($this->request->query['eligibility']) && trim($this->request->query['eligibility']) != '') {
			$eligibility = $this->request->query['eligibility'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.eligibility LIKE \'%'. $eligibility .'%\''
				)
			);
		}
		
		if(isset($this->request->query['education']) && trim($this->request->query['education']) != '') {
			$education = $this->request->query['education'];
			
			$default_conditions = array_merge(
				$default_conditions, 
				array(
					'VacancyPlantilla.education LIKE \'%'. $education .'%\''
				)
			);
		}
		
		// END SEARCH
		
		if(isset($report_type) && $report_type == 'Basic Reports') {
			$vacancy_plantilla = $this->VacancyPlantilla->find('all',array(
				'contain' => array(
					'JobTitle',
					'JobTitleItemNumber',
					'Section'
				),
				'conditions' => $default_conditions,
				'order' => $default_order,
			));
			
			
			$vacancy_plantilla = reorder(array(
				'fields' => array(
					'JobTitle.name',
					'JobTitleItemNumber.item_number',
					// 'Section.name',
					'VacancyPlantilla.valid_from_date',
					'VacancyPlantilla.valid_to_date',
					'VacancyPlantilla.years_of_experience',
					'VacancyPlantilla.hours_of_relevant_training',
					'VacancyPlantilla.eligibility',
					'VacancyPlantilla.education',
				),
				'data' => $vacancy_plantilla
			));
			
			

			if(isset($report_format) && $report_format == 'csv') {
				$this->Export->export_csv(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Position Title',
						'Item Number',
						// 'Section',
						'Valid From',
						'Valid Until',
						'Years of Experience',
						'Hours of Relevant Training',
						'Eligibility',
						'Education'
					),
					'data' => $vacancy_plantilla
				));
			}
			else if(isset($report_format) && $report_format == 'excel') {
				$this->Export->export_excel_with_template(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Position Title',
						'Item Number',
						// 'Section',
						'Valid From',
						'Valid Until',
						'Years of Experience',
						'Hours of Relevant Training',
						'Eligibility',
						'Education'
					),
					'data' => $vacancy_plantilla
				));
			}
			else if(isset($report_format) && $report_format == 'pdf') {
				$this->Export->export_pdf_with_template(array(
					'title' => 'Applicant',
					'header_data' => array(
						'Position Title',
						'Item Number',
						// 'Section',
						'Valid From',
						'Valid Until',
						'Years of Experience',
						'Hours of Relevant Training',
						'Eligibility',
						'Education'
					),
					'data' => $vacancy_plantilla
				));
			}
		}
		else {
			$this->Paginator->settings = array(
				'contain' => array(
					'JobTitle',
					'JobTitleItemNumber',
					'Section'
				),
				'conditions' => $default_conditions,
				'order' => $default_order,
				// 'recursive' => -1
			);
			
			$vacancy_plantilla = $this->Paginator->paginate('VacancyPlantilla');
			
			// debug($vacancy_plantilla);
			// exit();
			
			$vacancy_plantilla = reorder(array(
				'fields' => array(
					'VacancyPlantilla.id',
					'JobTitle.name',
					'JobTitleItemNumber.item_number',
				),
				'data' => $vacancy_plantilla
			));
			
		}
		if(!$vacancy_plantilla){
			$this->Alert->display('no_records_found');
		}
		$this->set('vacancy_plantilla', $vacancy_plantilla);
		
	}
	private function get_find_params($default_find_params = array(), $find_name = 'Pagination') {		
		$default_fields = $this->default_params['fields'];
		$default_condition = $this->default_params['conditions'];
		$default_order = $this->default_params['order'];
		$default_limit = $this->default_params['limit'];
		$default_recursive = $this->default_params['recursive'];
		
		if(isset($default_find_params['fields'])) {
			$default_fields = $default_find_params['fields'];
		}
		
		if(isset($default_find_params['order'])) {
			$default_order = $default_find_params['order'];
		}
		
		if(isset($this->request['url']['sort']) && $this->request['url']['direction']) {
			$default_order = $this->request['url']['sort'] . ' ' . $this->request['url']['direction'];
		}
		
		if(isset($default_find_params['limit'])) {
			$default_limit = $default_find_params['limit'];
		}
		
		if(isset($default_find_params['recursive'])) {
			$default_recursive = $default_find_params['recursive'];
		}
		
		if(isset($default_find_params['conditions'])) {
			$default_condition = array_merge($default_condition, $default_find_params['conditions']);
		}
		
		if(isset($this->request['url']['keyword'])){
			$default_condition = array_merge(
				$default_condition, 
				array(
					'OR'=> array(
						'Applicant.first_name LIKE \'%'. $this->request['url']['keyword'] .'%\' ',
						'Applicant.middle_name LIKE \'%'. $this->request['url']['keyword'] .'%\' ',
						'Applicant.last_name LIKE \'%'. $this->request['url']['keyword'] .'%\' ',
					)
				)
			);
		}
		
		if($find_name == 'Basic Reports') {
			unset($default_fields[0]);
			
			$find_params_result = array(
				'fields' => $default_fields,
				'conditions' => $default_condition,
				'order' => $default_order,
				'recursive' => $default_recursive
			);
		}
		else {
			$find_params_result = array(
				'fields' => $default_fields,
				'conditions' => $default_condition,
				'order' => $default_order,
				'limit' => $default_limit,
				'recursive' => $default_recursive
			);
		}
		
		return $find_params_result;
	}
	// private function process_records($params = array()) {
		// if(isset($params['search-type']) && $params['search-type'] == 'Basic Reports') {
			// $find_params = $this->get_find_params(
				// $params['find_params'],
				// $params['search-type']
			// );
			
			// $records = $this->Applicant->find('all', $find_params);
		// }
		// else {
			
			// $find_params = $this->get_find_params(
				// $params['find_params']
			// );
			
			// $this->Paginator->settings = $find_params;
		
			// $records = $this->Paginator->paginate('Applicant');
		// }
		
		// $records = flatten_data($records);
		// return $records;
	// }
	public function hris_view_vacancy_plantilla($vacancy_plantilla_id=null) {
		$this->loadModel('VacancyPlantilla');
		
		// $this->set('job_title_code', $job_title_code);
		// $this->set('job_title_item_number', $job_title_item_number);
		$vacancy_plantilla = $this->VacancyPlantilla->find('first', array(
			'contain' => array(
				'JobTitle',
				'JobTitleItemNumber',
				'Section',
				'SuggestedSchedule',
				'ActualSchedule',
			),
			'conditions' => array(
				'VacancyPlantilla.id' => $vacancy_plantilla_id,
			),
			'recursive' => -1
		));
		// debug($vacancy_plantilla);
		// exit();
		if (isset($vacancy_plantilla) && count($vacancy_plantilla) > 0) {		 
			// $this->add_system_trail('VIEW', 'VacancyPlantilla','has viewed vacancy_plantilla:'. ' '. $vacancy_plantilla_id);
			$this->set('vacancy_plantilla', $vacancy_plantilla);
			
		}
		else {
			$this->Alert->display('no_records_found');
			return $this->redirect(array('controller' => 'vacancy_plantillas', 'action' => 'index', 'prefix' => 'hris', 'hris' => true));
		}		
 	}

	private function process_records($params = array()) {
		if(isset($params['search-type']) && $params['search-type'] == 'Basic Reports') {
			$find_params = $this->get_find_params(
				$params['find_params'],
				$params['search-type']
			);
			
			$records = $this->Applicant->find('all', $find_params);
		}
		else {
			
			$find_params = $this->get_find_params(
				$params['find_params']
			);
			
			$this->Paginator->settings = $find_params;
		
			$records = $this->Paginator->paginate('Applicant');
		}
		
		$records = reorder(array(
			'fields' => $find_params['fields'], 
			'data' => $records
		));
		
		$records = convert_array(array(
			'fields' => array(
				'Applicant.date_applied' => 'F j, Y',
				'Applicant.scheduled_date' => 'F j, Y',
			),
			'data' => $records
		));
		$records = flatten_data($records);
		return $records;
	}
	
	function beforeFilter(){
		parent::beforeFilter();
		$this->Auth->allow('hris_view_vacancy_plantilla','hris_view_plantilla_vacancy','hris_vacancy_plantilla_index','hris_add_initial_applicant','hris_get_item_number','hris_submitted_to_hr', 'hris_view_initial_applicant','hris_edit_initial_applicant','hris_select_job_type_vacancy','hris_vacancy_contractual_index','hris_view_vacancy_job_order');
	}	
	public function isAuthorized($user) {
		
		if(isset($user['id'])){
			// debug($user);
			// exit();
			return $this->DaiSecurity->check_user_privileges($user, $this->params['controller'], $this->params['action']);
			
		}
		else {
			return false;
		}
	}
	
	
	

	// public function isAuthorized($user) {
		// if(isset($user['id'])){
			// return $this->DaiSecurity->check_user_privileges($user, $this->params['controller'], $this->params['action']);
		// }
		// else {
			// return false;
		// }
	// }
}
?>