<?php
App::uses('AppModel', 'Model');

class AdministrativeCase extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	// public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
	);
	
	public $hasMany = array(
		'EmployeeAdministrativeOffense' => array(
			'className' => 'EmployeeAdministrativeOffense',
			'foreignKey' => 'administrative_case_code',
		),
	);
	
	public function add_administrative_case($data = array()) {		
		$existing_administrative_case = $this->find_existing_administrative_case_by_name($data['AdministrativeCase']['name']);
		
		if(isset($existing_administrative_case) && count($existing_administrative_case) > 0) {
			$existing_administrative_case['AdministrativeCase']['status'] = 'Active';
			$data = $existing_administrative_case;
			
		}

		return $this->save($data);
	}
	
	public function update_administrative_case($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($administrative_case_id = null, $administrative_case = null) {
		$existing_administrative_case = $this->find_existing_administrative_case_by_id_or_code($administrative_case_id);
		
		if(isset($existing_administrative_case) && count($existing_administrative_case) > 0) {
			$existing_administrative_case['AdministrativeCase']['status'] = $administrative_case;
			$data = $existing_administrative_case;
		}

		return $this->save($data);
	}
	
	public function find_existing_administrative_case_by_name($administrative_case_name = null) {
		if(isset($administrative_case_name)) {
			$default_conditions = array(
				'UPPER(AdministrativeCase.name)' => strtoupper($administrative_case_name)
			);
		}
		
		$administrative_case = $this->find('first', array(
			'fields' => array(
				'AdministrativeCase.id',
				'AdministrativeCase.code',
				'AdministrativeCase.name',
				'AdministrativeCase.status',
				'AdministrativeCase.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $administrative_case;
	}
	
	public function find_existing_administrative_case_by_id_or_code($administrative_case_id = null) {
		if(is_numeric($administrative_case_id)) {
			$default_conditions = array(
				'AdministrativeCase.id' => $administrative_case_id
			);
		}
		else {
			$default_conditions = array(
				'AdministrativeCase.code' => $administrative_case_id
			);
		}
		
		$administrative_case = $this->find('first', array(
			'fields' => array(
				'AdministrativeCase.id',
				'AdministrativeCase.code',
				'AdministrativeCase.name',
				'AdministrativeCase.status',
				'AdministrativeCase.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $administrative_case;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['AdministrativeCase']['id'])) {
			$this->data['AdministrativeCase']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['AdministrativeCase']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['AdministrativeCase']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'ADVCS';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['AdministrativeCase']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['AdministrativeCase']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>