<?php
App::uses('AppModel', 'Model');

class AnniversaryIncentive extends AppModel {
	
	public $tablePrefix = 'payroll_';
	public $primaryKey = 'code';
	
	public $validate = array(
	
        'anniversary_incentive_name' => array(
			'anniversary_incentive_name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Anniversary incentive name is already used.',
			),
			'anniversary_incentive_name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Anniversary incentive name is required.'
			)
        ),
		
		'assumption_date' => array(
			'assumption_date logic 1' => array(
				'rule' => array('notEmpty'),
				'assumption_date' => 'Assumption date is required.'
			),
			'assumption_date logic 2' => array(
				'rule' => array('date'),
				'message' => 'Enter a valid date in MM/DD/YY format.',
			),

		),
		
		'incentive_amount' => array(
			'incentive_amount logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Incentive amount is required.',
			),
			'incentive_amount logic 2' => array(
				'rule' => 'numeric',
				'message'	=> 'Incentive amount is numbers only.'
			)
        ),	
		
	);
	
	public $hasMany = array(
		'AnniversaryIncentiveEmploymentStatus' => array(
			'className' => 'AnniversaryIncentiveEmploymentStatus',
			'foreignKey' => 'payroll_anniversary_incentive_code',
			'conditions' => array(
				'AnniversaryIncentiveEmploymentStatus.status' => 'Active'
			),
		),
		'AnniversaryIncentiveDetail' => array(
			'className' => 'AnniversaryIncentiveDetail',
			'foreignKey' => 'payroll_anniversary_incentive_code',
			'conditions' => array(
				'AnniversaryIncentiveDetail.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		
		if(isset($this->data['AnniversaryIncentive']['anniversary_incentive_date']) && validate_datetime($this->data['AnniversaryIncentive']['anniversary_incentive_date'], 'm/d/Y')) {
			$this->data['AnniversaryIncentive']['anniversary_incentive_date'] = convert_datetime($this->data['AnniversaryIncentive']['anniversary_incentive_date'], 'Y-m-d');
		}
		if(isset($this->data['AnniversaryIncentive']['assumption_date']) && validate_datetime($this->data['AnniversaryIncentive']['assumption_date'], 'm/d/Y')) {
			$this->data['AnniversaryIncentive']['assumption_date'] = convert_datetime($this->data['AnniversaryIncentive']['assumption_date'], 'Y-m-d');
		}

		return true;
		
	}

	public function beforeSave($options = array()) { 
		
		if(!isset($this->data['AnniversaryIncentive']['id'])) {
			$this->data['AnniversaryIncentive']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['AnniversaryIncentive']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['AnniversaryIncentive']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'AI';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];

			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			
			$this->data['AnniversaryIncentive']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['AnniversaryIncentive']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false) {
		foreach($results as $x => $result) {
			
			if (isset($result['AnniversaryIncentive']['anniversary_incentive_date'])) {
				$results[$x]['AnniversaryIncentive']['anniversary_incentive_date'] = date('m/d/Y',strtotime($results[$x]['AnniversaryIncentive']['anniversary_incentive_date']));
			}
			
			if (isset($result['AnniversaryIncentive']['assumption_date'])) {
				$results[$x]['AnniversaryIncentive']['assumption_date'] = date('m/d/Y',strtotime($results[$x]['AnniversaryIncentive']['assumption_date']));
			}
			
		}

		return $results;
	}
	
}
?>