<?php
App::uses('AppModel', 'Model');

class Applicant extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'recruitment_';
	public $primaryKey = 'code';
	// public $displayField = 'employee_code';
	
	public function __construct($id = false, $table = null, $ds = null) {
		parent::__construct($id, $table, $ds);
		$this->virtualFields['combination_whole_name'] = sprintf(
			'CONCAT(%s.last_name, ", ", %s.first_name, " ", %s.middle_name)', $this->alias, $this->alias, $this->alias
		);
		
		$this->virtualFields['standard_name'] = sprintf(
			'CONCAT(%s.first_name, " ", SUBSTR(%s.middle_name, 1, 1), ". ", %s.last_name)', $this->alias, $this->alias, $this->alias
		);
	}
	
	public $hasMany = array(
		
		'ApplicantAppliedPosition' => array(
			'className' => 'ApplicantAppliedPosition',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				// 'ApplicantAppliedPosition.status' => 'Active'
			)
		),
		'RecruitmentApplicantAttachment' => array(
			'className' => 'RecruitmentApplicantAttachment',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				// 'RecruitmentApplicantAttachment.status' => 'Active'
			)
		),
		'RecruitmentApplicantOtherInformation' => array(
			'className' => 'RecruitmentApplicantOtherInformation',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				// 'RecruitmentApplicantOtherInformation.status' => 'Active'
			)
		),
		'RecruitmentApplicantEducation' => array(
			'className' => 'RecruitmentApplicantEducation',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				// 'RecruitmentApplicantEducation.status' => 'Active'
			)
		),
		'RecruitmentApplicantWorkhistory' => array(
			'className' => 'RecruitmentApplicantWorkhistory',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				// 'RecruitmentApplicantWorkHistory.status' => 'Active'
			)
		),
		'RecruitmentApplicantLearningAndDevelopment' => array(
			'className' => 'RecruitmentApplicantLearningAndDevelopment',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				// 'RecruitmentApplicantLearningAndDevelopment.status' => 'Active'
			)
		),
		
		'RecruitmentApplicantEligibility' => array(
			'className' => 'RecruitmentApplicantEligibility',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				// 'RecruitmentApplicantEligibility.status' => 'Active'
			)
		),
		
		'RecruitmentUploadManualExam' => array(
			'className' => 'RecruitmentUploadManualExam',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				'RecruitmentUploadManualExam.status' => 'Active'
			)
		),
		'TakeExamApplicantAnswer' => array(
			'className' => 'TakeExamApplicantAnswer',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				'TakeExamApplicantAnswer.status' => 'Active'
			)
		),
	);
		
	public $hasOne = array(
		// 'Employee' => array(
			// 'className' => 'Employee',
			// 'foreignKey' => false,
			// 'conditions' => array(
				// 'Employee.status' => 'Active',
				// 'Applicant.employee_code=Employee.employee_code'
			// ),
		// ),
	);
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active',
				// 'Applicant.employee_code=Employee.employee_code'
			),
		),
		'Gender' => array(
			'className' => 'Gender',
			'foreignKey' => 'gender_code',
			'conditions' => array(
				'Gender.status' => 'Active'
			),
		),
		'PrefixList' => array(
			'className' => 'PrefixList',
			'foreignKey' => 'prefix_code',
			'conditions' => array(
				'PrefixList.status' => 'Active'
			),
		),
		'Suffix' => array(
			'className' => 'Suffix',
			'foreignKey' => 'suffix_code',
			'conditions' => array(
				'Suffix.status' => 'Active'
			),
		),
		'ApplicationStatus' => array(
			'className' => 'ApplicationStatus',
			'foreignKey' => 'application_status_code',
			'conditions' => array(
				'ApplicationStatus.status' => 'Active'
			),
		),
		'Vacancy' => array(
			'className' => 'Vacancy',
			'foreignKey' => 'vacancy_reference_number',
			'conditions' => array(
				'Vacancy.status' => 'Active'
			),
		),
		// 'JobTitle' => array(
			// 'className' => 'JobTitle',
			// 'foreignKey' => 'JobTitle',
			// 'conditions' => array(
				// 'JobTitle.status' => 'Active'
			// ),
		// ),
	);

	public $validate = array(
		 
        'last_name' => array(
            'last_name logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Last name is required.'
            ),
        ),
        'first_name' => array(
            'first_name logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Fist name is required.'
            ),
        ),
        'gender_code' => array(
            'gender_code logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Gender is required.'
            ),
        ),
        'outsider_or_insider' => array(
            'outsider_or_insider logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Outsider or insider is required.'
            ),
        ),
        // 'job_title' => array(
            // 'job_title logic 1' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'Position title is required.'
            // ),
        // ),
        

    );
	
	public function beforeValidate($options = array()) {


		if(isset($this->data['Applicant']['date_applied']) && validate_datetime($this->data['Applicant']['date_applied'], 'm/d/Y')) {
			$this->data['Applicant']['date_applied'] = convert_datetime($this->data['Applicant']['date_applied'], 'Y-m-d');
		}	
		if(isset($this->data['Applicant']['scheduled_date']) && validate_datetime($this->data['Applicant']['scheduled_date'], 'm/d/Y')) {
			$this->data['Applicant']['scheduled_date'] = convert_datetime($this->data['Applicant']['scheduled_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['Applicant']['date_of_birth']) && validate_datetime($this->data['Applicant']['date_of_birth'], 'm/d/Y')) {
			$this->data['Applicant']['date_of_birth'] = convert_datetime($this->data['Applicant']['date_of_birth'], 'Y-m-d');
		}
		
		if(isset($this->data['Applicant']['date_created']) && validate_datetime($this->data['Applicant']['date_created'], 'm/d/Y')) {
			$this->data['Applicant']['date_created'] = convert_datetime($this->data['Applicant']['date_created'], 'Y-m-d');
		}
		
		if(isset($this->data['Applicant']['application_deadline']) && validate_datetime($this->data['Applicant']['application_deadline'], 'm/d/Y')) {
			$this->data['Applicant']['application_deadline'] = convert_datetime($this->data['Applicant']['application_deadline'], 'Y-m-d');
		}
		
		if(isset($this->data['Applicant']['application_deadline']) && validate_datetime($this->data['Applicant']['application_deadline'], 'm/d/Y')) {
			$this->data['Applicant']['application_deadline'] = convert_datetime($this->data['Applicant']['application_deadline'], 'Y-m-d');
		}

		return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Applicant']['id'])) {
			$this->data['Applicant']['created_by'] = isset($_SESSION['Auth']['User']['id'])?$_SESSION['Auth']['User']['id']:0;
			$this->data['Applicant']['modified_by'] = isset($_SESSION['Auth']['User']['id'])?$_SESSION['Auth']['User']['id']:0;
			$this->data['Applicant']['status'] = 'Active';
			$this->data['Applicant']['application_status_code'] = 'APPTAT-1';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'RAPP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Applicant']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Applicant']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Applicant']['date_applied'])){
				$results[$x]['Applicant']['date_applied'] = date('m/d/Y',strtotime($results[$x]['Applicant']['date_applied']));
			}
			
			if(isset($result['Applicant']['scheduled_date'])){
				$results[$x]['Applicant']['scheduled_date'] = date('m/d/Y',strtotime($results[$x]['Applicant']['scheduled_date']));
			}
			
			if(isset($result['Applicant']['date_of_birth'])){
				$results[$x]['Applicant']['date_of_birth'] = date('m/d/Y',strtotime($results[$x]['Applicant']['date_of_birth']));
			}
		}

		return $results;
	}
}
?>