<?php
App::uses('AppModel', 'Model');

class ApplicantAppliedPosition extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'recruitment_';
	// public $primaryKey = 'applicant_code';
	// public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Applicant' => array(
			'className' => 'Applicant',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				'Applicant.status' => 'Active'
			),
		),
		'JobTitleItemNumber' => array(
			'className' => 'JobTitleItemNumber',
			'foreignKey' => 'job_title_item_number_code',
			'conditions' => array(
				'JobTitleItemNumber.status' => 'Active'
			),
		),
		'ApplicationStatus' => array(
			'className' => 'ApplicationStatus',
			'foreignKey' => 'application_status_code',
			'conditions' => array(
				'ApplicationStatus.status' => 'Active'
			),
		),
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		),
		'ApplicantRateCard' => array(
			'className' => 'ApplicantRateCard',
			'foreignKey' => false,
			'conditions' => array(
				'ApplicantRateCard.status' => 'Active',
				'ApplicantRateCard.job_title_code = ApplicantAppliedPosition.job_title_code',
			),
		),
		// 'Section' => array(
			// 'className' => 'Section',
			// 'foreignKey' => 'section_code',
			// 'conditions' => array(
				// 'Section.status' => 'Active'
			// ),
		// ),
	);
	
	public $hasMany = array(
		'TakeExam' => array(
			'className' => 'TakeExam',
			'foreignKey' => 'applicant_applied_position_id',
			'conditions' => array(
				'TakeExam.status' => 'Active'
			)
		),
		'RecruitmentUploadManualExam' => array(
			'className' => 'RecruitmentUploadManualExam',
			'foreignKey' => 'applicant_applied_position_id',
			'conditions' => array(
				'RecruitmentUploadManualExam.status' => 'Active'
			)
		),
		'ApplicantAppliedPositionHistoryLog' => array(
			'className' => 'ApplicantAppliedPositionHistoryLog',
			'foreignKey' => 'applicant_applied_position_id',
			'conditions' => array(
				'ApplicantAppliedPositionHistoryLog.status' => 'Active'
			),
		),
		'TakeExamApplicantAnswer' => array(
			'className' => 'TakeExamApplicantAnswer',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				'TakeExamApplicantAnswer.status' => 'Active'
			)
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['ApplicantAppliedPosition']['appointment_date']) && validate_datetime($this->data['ApplicantAppliedPosition']['appointment_date'], 'm/d/Y')) {
			$this->data['ApplicantAppliedPosition']['appointment_date'] = convert_datetime($this->data['ApplicantAppliedPosition']['appointment_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['ApplicantAppliedPosition']['date_applied']) && validate_datetime($this->data['ApplicantAppliedPosition']['date_applied'], 'm/d/Y')) {
			$this->data['ApplicantAppliedPosition']['date_applied'] = convert_datetime($this->data['ApplicantAppliedPosition']['date_applied'], 'Y-m-d');
		}	
		
		return true;
	}
	
	public function beforeSave($options = array()) {
	
		if(!isset($this->data['ApplicantAppliedPosition']['id'])) {
				$this->data['ApplicantAppliedPosition']['created_by'] = 0;
				$this->data['ApplicantAppliedPosition']['created_by'] = 0;
				$this->data['ApplicantAppliedPosition']['modified_by'] = 0;
				$this->data['ApplicantAppliedPosition']['status'] = 'Active';
				$this->data['ApplicantAppliedPosition']['application_status_code'] = 'APPTAT-1';
		}
		else {
			$this->data['ApplicantAppliedPosition']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
	
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['ApplicantAppliedPosition']['appointment_date'])){
				$results[$x]['ApplicantAppliedPosition']['appointment_date'] = date('m/d/Y',strtotime($results[$x]['ApplicantAppliedPosition']['appointment_date']));
			}
			
			if(isset($result['ApplicantAppliedPosition']['date_applied'])){
				$results[$x]['ApplicantAppliedPosition']['date_applied'] = date('m/d/Y',strtotime($results[$x]['ApplicantAppliedPosition']['date_applied']));
			}
		}

		return $results;
	}
}
?>