<?php
App::uses('AppModel', 'Model');

class ApplicantAppliedPositionHistoryLog extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'recruitment_';
	// public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Applicant' => array(
			'className' => 'Applicant',
			'foreignKey' => 'applicant_code',
			'conditions' => array(
				'Applicant.status' => 'Active'
			),
		),
		'JobTitleItemNumber' => array(
			'className' => 'JobTitleItemNumber',
			'foreignKey' => 'job_title_item_number_code',
			'conditions' => array(
				'JobTitleItemNumber.status' => 'Active'
			),
		),
		'ApplicationStatus' => array(
			'className' => 'ApplicationStatus',
			'foreignKey' => 'application_status_code',
			'conditions' => array(
				'ApplicationStatus.status' => 'Active'
			),
		),
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		),
		'ApplicantAppliedPosition' => array(
			'className' => 'ApplicantAppliedPosition',
			'foreignKey' => 'applicant_applied_position_id',
			'conditions' => array(
				'ApplicantAppliedPosition.status' => 'Active'
			),
		),
	);
	
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['ApplicantAppliedPositionHistoryLog']['appointment_date']) && validate_datetime($this->data['ApplicantAppliedPositionHistoryLog']['appointment_date'], 'm/d/Y')) {
			$this->data['ApplicantAppliedPositionHistoryLog']['appointment_date'] = convert_datetime($this->data['ApplicantAppliedPositionHistoryLog']['appointment_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['ApplicantAppliedPositionHistoryLog']['date_applied']) && validate_datetime($this->data['ApplicantAppliedPositionHistoryLog']['date_applied'], 'm/d/Y')) {
			$this->data['ApplicantAppliedPositionHistoryLog']['date_applied'] = convert_datetime($this->data['ApplicantAppliedPositionHistoryLog']['date_applied'], 'Y-m-d');
		}	
		
		if(isset($this->data['ApplicantAppliedPositionHistoryLog']['etd_uad']) && validate_datetime($this->data['ApplicantAppliedPositionHistoryLog']['etd_uad'], 'm/d/Y')) {
			$this->data['ApplicantAppliedPositionHistoryLog']['etd_uad'] = convert_datetime($this->data['ApplicantAppliedPositionHistoryLog']['etd_uad'], 'Y-m-d');
		}	
		
		if(isset($this->data['ApplicantAppliedPositionHistoryLog']['interview_date']) && validate_datetime($this->data['ApplicantAppliedPositionHistoryLog']['interview_date'], 'm/d/Y')) {
			$this->data['ApplicantAppliedPositionHistoryLog']['interview_date'] = convert_datetime($this->data['ApplicantAppliedPositionHistoryLog']['interview_date'], 'Y-m-d');
		}	
		
		return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ApplicantAppliedPositionHistoryLog']['id'])) {
			$this->data['ApplicantAppliedPositionHistoryLog']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApplicantAppliedPositionHistoryLog']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApplicantAppliedPositionHistoryLog']['status'] = 'Active';
			// $this->data['ApplicantAppliedPositionHistoryLog']['application_status_code'] = 'APPTAT-1';
		}
		else {
			$this->data['ApplicantAppliedPositionHistoryLog']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['ApplicantAppliedPositionHistoryLog']['appointment_date'])){
				$results[$x]['ApplicantAppliedPositionHistoryLog']['appointment_date'] = date('m/d/Y',strtotime($results[$x]['ApplicantAppliedPositionHistoryLog']['appointment_date']));
			}
			
			if(isset($result['ApplicantAppliedPositionHistoryLog']['date_applied'])){
				$results[$x]['ApplicantAppliedPositionHistoryLog']['date_applied'] = date('m/d/Y',strtotime($results[$x]['ApplicantAppliedPositionHistoryLog']['date_applied']));
			}
			
			if(isset($result['ApplicantAppliedPosition']['etd_uad'])){
				$results[$x]['ApplicantAppliedPosition']['etd_uad'] = date('m/d/Y',strtotime($results[$x]['ApplicantAppliedPosition']['etd_uad']));
			}
			
			if(isset($result['ApplicantAppliedPosition']['interview_date'])){
				$results[$x]['ApplicantAppliedPosition']['interview_date'] = date('m/d/Y',strtotime($results[$x]['ApplicantAppliedPosition']['interview_date']));
			}
		}

		return $results;
	}
}
?>