<?php
App::uses('AppModel', 'Model');

class ApplicationRemark extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
	);
	
	public function add_application_remark($data = array()) {		
		$existing_application_remark = $this->find_existing_application_remark_by_name($data['ApplicationRemark']['name']);
		
		if(isset($existing_application_remark) && count($existing_application_remark) > 0) {
			$existing_application_remark['ApplicationRemark']['status'] = 'Active';
			$data = $existing_application_remark;
			
		}

		return $this->save($data);
	}
	
	public function update_application_remark($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($application_remark_id = null, $application_remark = null) {
		$existing_application_remark = $this->find_existing_application_remark_by_id_or_code($application_remark_id);
		
		if(isset($existing_application_remark) && count($existing_application_remark) > 0) {
			$existing_application_remark['ApplicationRemark']['status'] = $application_remark;
			$data = $existing_application_remark;
		}

		return $this->save($data);
	}
	
	public function find_existing_application_remark_by_name($application_remark_name = null) {
		if(isset($application_remark_name)) {
			$default_conditions = array(
				'ApplicationRemark.name' => $application_remark_name
			);
		}
		
		$application_remark = $this->find('first', array(
			'fields' => array(
				'ApplicationRemark.id',
				'ApplicationRemark.code',
				'ApplicationRemark.name',
				'ApplicationRemark.status',
				'ApplicationRemark.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $application_remark;
	}
	
	public function find_existing_application_remark_by_id_or_code($application_remark_id = null) {
		if(is_numeric($application_remark_id)) {
			$default_conditions = array(
				'ApplicationRemark.id' => $application_remark_id
			);
		}
		else {
			$default_conditions = array(
				'ApplicationRemark.code' => $application_remark_id
			);
		}
		
		$application_remark = $this->find('first', array(
			'fields' => array(
				'ApplicationRemark.id',
				'ApplicationRemark.code',
				'ApplicationRemark.name',
				'ApplicationRemark.status',
				'ApplicationRemark.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $application_remark;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ApplicationRemark']['id'])) {
			$this->data['ApplicationRemark']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApplicationRemark']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApplicationRemark']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'APPRMK';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ApplicationRemark']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ApplicationRemark']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>