<?php
App::uses('AppModel', 'Model');

class ApplicationStatus extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
	);
	
	public function add_application_status($data = array()) {		
		$existing_application_status = $this->find_existing_application_status_by_name($data['ApplicationStatus']['name']);
		
		if(isset($existing_application_status) && count($existing_application_status) > 0) {
			$existing_application_status['ApplicationStatus']['status'] = 'Active';
			$data = $existing_application_status;
			
		}

		return $this->save($data);
	}
	
	public function update_application_status($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($application_status_id = null, $application_status = null) {
		$existing_application_status = $this->find_existing_application_status_by_id_or_code($application_status_id);
		
		if(isset($existing_application_status) && count($existing_application_status) > 0) {
			$existing_application_status['ApplicationStatus']['status'] = $application_status;
			$data = $existing_application_status;
		}

		return $this->save($data);
	}
	
	public function find_existing_application_status_by_name($application_status_name = null) {
		if(isset($application_status_name)) {
			$default_conditions = array(
				'ApplicationStatus.name' => $application_status_name
			);
		}
		
		$application_status = $this->find('first', array(
			'fields' => array(
				'ApplicationStatus.id',
				'ApplicationStatus.code',
				'ApplicationStatus.name',
				'ApplicationStatus.status',
				'ApplicationStatus.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $application_status;
	}
	
	public function find_existing_application_status_by_id_or_code($application_status_id = null) {
		if(is_numeric($application_status_id)) {
			$default_conditions = array(
				'ApplicationStatus.id' => $application_status_id
			);
		}
		else {
			$default_conditions = array(
				'ApplicationStatus.code' => $application_status_id
			);
		}
		
		$application_status = $this->find('first', array(
			'fields' => array(
				'ApplicationStatus.id',
				'ApplicationStatus.code',
				'ApplicationStatus.name',
				'ApplicationStatus.status',
				'ApplicationStatus.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $application_status;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ApplicationStatus']['id'])) {
			$this->data['ApplicationStatus']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApplicationStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApplicationStatus']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'APPTAT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ApplicationStatus']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ApplicationStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>