<?php
App::uses('AppModel', 'Model');

class AppointmentEntry extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'employee_';
	// public $primaryKey = 'code';
	// public $displayField = 'name';
	
	public $validate = array(
        'employee_code' => array(
			'employee_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		'appointment_type' => array(
			'appointment_type logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Insider/Outsider is required.'
			),
        ),
	);

	public $belongsTo = array(
		'NatureOfAppointment' => array(
			'className' => 'NatureOfAppointment',
			'foreignKey' => 'nature_of_appointment_code',
			'fields'=>array(
				'code',
				'name'
			),
			'conditions' => array(
				'NatureOfAppointment.status' => 'Active'
			),
		),
		'EmploymentStatus' => array(
			'className' => 'EmploymentStatus',
			'foreignKey' => 'status_of_appointment_code',
			'fields'=>array(
				'code',
				'name',
			),
			'conditions' => array(
				'EmploymentStatus.status' => 'Active'
			),
		),
		'SeparationStatus' => array(
			'className' => 'SeparationStatus',
			'foreignKey' => 'reason_of_separation',
			'fields'=>array(
				'code',
				'name',
			),
			'conditions' => array(
				'SeparationStatus.status' => 'Active'
			),
		),
		'Chairperson' => array(
			'className' => 'Employee',
			'foreignKey' => 'name_of_chairperson',
			'fields'=>array(
				'employee_code',
				'combination_whole_name',
			)
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['AppointmentEntry']['date_of_signing']) && validate_datetime($this->data['AppointmentEntry']['date_of_signing'], 'm/d/Y')) {
			$this->data['AppointmentEntry']['date_of_signing'] = convert_datetime($this->data['AppointmentEntry']['date_of_signing'], 'Y-m-d');
		}	
		
		if(isset($this->data['AppointmentEntry']['from_1']) && validate_datetime($this->data['AppointmentEntry']['from_1'], 'm/d/Y')) {
			$this->data['AppointmentEntry']['from_1'] = convert_datetime($this->data['AppointmentEntry']['from_1'], 'Y-m-d');
		}

		if(isset($this->data['AppointmentEntry']['to_1']) && validate_datetime($this->data['AppointmentEntry']['to_1'], 'm/d/Y')) {
			$this->data['AppointmentEntry']['to_1'] = convert_datetime($this->data['AppointmentEntry']['to_1'], 'Y-m-d');
		}	
		
		if(isset($this->data['AppointmentEntry']['from_2']) && validate_datetime($this->data['AppointmentEntry']['from_2'], 'm/d/Y')) {
			$this->data['AppointmentEntry']['from_2'] = convert_datetime($this->data['AppointmentEntry']['from_2'], 'Y-m-d');
		}
		
		if(isset($this->data['AppointmentEntry']['to_2']) && validate_datetime($this->data['AppointmentEntry']['to_2'], 'm/d/Y')) {
			$this->data['AppointmentEntry']['to_2'] = convert_datetime($this->data['AppointmentEntry']['to_2'], 'Y-m-d');
		}	
		
		if(isset($this->data['AppointmentEntry']['date_of_assessment']) && validate_datetime($this->data['AppointmentEntry']['date_of_assessment'], 'm/d/Y')) {
			$this->data['AppointmentEntry']['date_of_assessment'] = convert_datetime($this->data['AppointmentEntry']['date_of_assessment'], 'Y-m-d');
		}	
		
		if(isset($this->data['AppointmentEntry']['date_of_deliberation_of_hrmpsb']) && validate_datetime($this->data['AppointmentEntry']['date_of_deliberation_of_hrmpsb'], 'm/d/Y')) {
			$this->data['AppointmentEntry']['date_of_deliberation_of_hrmpsb'] = convert_datetime($this->data['AppointmentEntry']['date_of_deliberation_of_hrmpsb'], 'Y-m-d');
		}	
		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['AppointmentEntry']['id']) || empty($this->data['AppointmentEntry']['id'])) {
			$this->data['AppointmentEntry']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['AppointmentEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['AppointmentEntry']['status'] = 'Active';
		}
		else {
			$this->data['AppointmentEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['AppointmentEntry']['date_of_signing'])){
				$results[$x]['AppointmentEntry']['date_of_signing'] = date('m/d/Y',strtotime($results[$x]['AppointmentEntry']['date_of_signing']));
			}
			
			if(isset($result['AppointmentEntry']['from_1'])){
				$results[$x]['AppointmentEntry']['from_1'] = date('m/d/Y',strtotime($results[$x]['AppointmentEntry']['from_1']));
			}
			
			if(isset($result['AppointmentEntry']['to_1'])){
				$results[$x]['AppointmentEntry']['to_1'] = date('m/d/Y',strtotime($results[$x]['AppointmentEntry']['to_1']));
			}
			
			
			if(isset($result['AppointmentEntry']['from_2'])){
				$results[$x]['AppointmentEntry']['from_2'] = date('m/d/Y',strtotime($results[$x]['AppointmentEntry']['from_2']));
			}
			
			if(isset($result['AppointmentEntry']['to_2'])){
				$results[$x]['AppointmentEntry']['to_2'] = date('m/d/Y',strtotime($results[$x]['AppointmentEntry']['to_2']));
			}
			
			if(isset($result['AppointmentEntry']['date_of_assessment'])){
				$results[$x]['AppointmentEntry']['date_of_assessment'] = date('m/d/Y',strtotime($results[$x]['AppointmentEntry']['date_of_assessment']));
			}
			
			if(isset($result['AppointmentEntry']['date_of_deliberation_of_hrmpsb'])){
				$results[$x]['AppointmentEntry']['date_of_deliberation_of_hrmpsb'] = date('m/d/Y',strtotime($results[$x]['AppointmentEntry']['date_of_deliberation_of_hrmpsb']));
			}
		}

		return $results;
	}
	
	
	
}
?>