<?php
App::uses('AppModel', 'Model');

class ApproverPerModule extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	
	public $validate = array(
        'section_code' => array(
			'section_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Section is required.'
			),
        ),
		'module_code' => array(
			'module_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Module is required.'
			),
        ),
	);
	public $belongsTo = array(
		'ModuleWithApprover' => array(
			'className' => 'ModuleWithApprover',
			'foreignKey' => 'module_code'
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'fields'=>array(
				'Section.code',
				'Section.name',
			)

		),
		'FirstApprover' => array(
			'className' => 'Employee',
			'foreignKey' => 'first_approver',
			'fields'=>array(
				'FirstApprover.employee_code',
				'FirstApprover.first_name',
				'FirstApprover.middle_name',
				'FirstApprover.last_name',
				'CONCAT(FirstApprover.last_name, ", ", FirstApprover.first_name, " ", FirstApprover.middle_name) as first_approver_name',
	
			)

		),
		'SecondApprover' => array(
			'className' => 'Employee',
			'foreignKey' => 'second_approver',
			'fields'=>array(
				'SecondApprover.employee_code',
				'SecondApprover.first_name',
				'SecondApprover.middle_name',
				'SecondApprover.last_name',
				'CONCAT(SecondApprover.last_name, ", ", SecondApprover.first_name, " ", SecondApprover.middle_name) as second_approver_name',
			)

		),
		'ThirdApprover' => array(
			'className' => 'Employee',
			'foreignKey' => 'third_approver',
			'fields'=>array(
				'ThirdApprover.employee_code',
				'ThirdApprover.first_name',
				'ThirdApprover.middle_name',
				'ThirdApprover.last_name',
				'CONCAT(ThirdApprover.last_name, ", ", ThirdApprover.first_name, " ", ThirdApprover.middle_name) as third_approver_name',
			
			)

		),
		'FourthApprover' => array(
			'className' => 'Employee',
			'foreignKey' => 'fourth_approver',
			'fields'=>array(
				'FourthApprover.employee_code',
				'FourthApprover.first_name',
				'FourthApprover.middle_name',
				'FourthApprover.last_name',
				'CONCAT(FourthApprover.last_name, ", ", FourthApprover.first_name, " ", FourthApprover.middle_name) as fourth_approver_name',
		
			)

		),
	);
	public function add_approver_per_module($data = array()) {		
		$existing_approver_per_modules = $this->find_existing_approver_per_module_by_name($data['ApproverPerModule']['name']);
		
		if(isset($existing_approver_per_modules) && count($existing_approver_per_modules) > 0) {
			$existing_approver_per_modules['ApproverPerModule']['status'] = 'Active';
			$data = $existing_approver_per_modules;
		}

		return $this->save($data);
	}
	public function update_approver_per_module($data = array()) {
		return $this->save($data);
	}
	public function update_status($approver_per_module_id = null, $approver_per_module = null) {
		$existing_approver_per_module = $this->find_existing_approver_per_module_by_id_or_code($approver_per_module_id);
		
		if(isset($existing_approver_per_module) && count($existing_approver_per_module) > 0) {
			$existing_approver_per_module['ApproverPerModule']['status'] = $approver_per_module;
			$data = $existing_approver_per_module;
		}

		return $this->save($data);
	}
	
	public function find_existing_approver_per_module_by_id_or_code($approver_per_modules_id = null) {
		if(is_numeric($approver_per_modules_id)) {
			$default_conditions = array(
				'ApproverPerModule.id' => $approver_per_modules_id
			);
		}
		else {
			$default_conditions = array(
				'ApproverPerModule.code' => $approver_per_modules_id
			);
		}
		
		$approver_per_module = $this->find('first', array(
			'fields' => array(
				
				'ApproverPerModule.id',
				'ApproverPerModule.code',
				'ApproverPerModule.module_code',
				'ApproverPerModule.section_code',
				'ApproverPerModule.has_final_approver',
				'ApproverPerModule.first_approver',
				'ApproverPerModule.second_approver',
				'ApproverPerModule.third_approver',
				'ApproverPerModule.fourth_approver',
				'ApproverPerModule.final_approver',
				'ApproverPerModule.status',
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $approver_per_module;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ApproverPerModule']['code'])) {
			$this->data['ApproverPerModule']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApproverPerModule']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ApproverPerModule']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'APM';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ApproverPerModule']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ApproverPerModule']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>