<?php
App::uses('AppModel', 'Model');

class Bank extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public function add_bank($data = array()) {		
		$existing_banks = $this->find_existing_bank_by_name($data['Bank']['name']);
		
		if(isset($existing_banks) && count($existing_banks) > 0) {
			$existing_banks['Bank']['status'] = 'Active';
			$data = $existing_banks;
		}

		return $this->save($data);
	}
	public function update_bank($data = array()) {
		return $this->save($data);
	}
	public function update_status($bank_id = null, $bank = null) {
		$existing_bank = $this->find_existing_bank_by_id_or_code($bank_id);
		
		if(isset($existing_bank) && count($existing_bank) > 0) {
			$existing_bank['Bank']['status'] = $bank;
			$data = $existing_bank;
		}

		return $this->save($data);
	}
	public function find_existing_bank_by_name($bank_name = null) {
		if(isset($bank_name)) {
			$default_conditions = array(
				'Bank.name' => $bank_name
			);
		}
		
		$banks = $this->find('first', array(
			'fields' => array(
				'Bank.id',
				'Bank.code',
				'Bank.name',
				'Bank.status',
				'Bank.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $banks;
	}
	
	public function find_existing_bank_by_id_or_code($banks_id = null) {
		if(is_numeric($banks_id)) {
			$default_conditions = array(
				'Bank.id' => $banks_id
			);
		}
		else {
			$default_conditions = array(
				'Bank.code' => $banks_id
			);
		}
		
		$bank = $this->find('first', array(
			'fields' => array(
				'Bank.id',
				'Bank.code',
				'Bank.name',
				'Bank.status',
				'Bank.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $bank;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Bank']['code'])) {
			$this->data['Bank']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Bank']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Bank']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'BNK';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Bank']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Bank']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>