<?php
App::uses('AppModel', 'Model');

class Barangay extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
			'name logic 2' => array(
				'rule'		=> array('validate_city_by_id_and_name_and_region_code_and_province_code_and_city_code'),
				'message'	=> 'The data that you inserted is already exist.'
			),
			// 'name logic 3' => array(
				// 'rule'		=> 'isUnique',
				// 'message'	=> 'Name must be unique.'
			// ),
        ),
	);
	public $hasMany = array(
		'Address' => array(
			'className' => 'Address',
			'foreignKey' => 'barangay_code'
		)
	);
	public $belongsTo = array(
		'Province' => array(
			'className' => 'Province',
			'foreignKey' => 'nso_province_code'
		),
		'Region' => array(
			'className' => 'Region',
			'foreignKey' => 'nso_region_code'

		),
		'City' => array(
			'className' => 'City',
			'foreignKey' => 'combined_nso_code'

		)
	);
	public function validate_city_by_id_and_name_and_region_code_and_province_code_and_city_code($validation_fields = array()) {
		
		$id = null;
		$region_code = $this->data['Barangay']['nso_region_code'];
		$province_code = $this->data['Barangay']['nso_province_code'];
		$barangay_name = $this->data['Barangay']['name'];
		$city_code = $this->data['Barangay']['combined_nso_code'];
		
		if(isset($this->data['Barangay']['id'])) {
			$id = $this->data['Barangay']['id'];
		}
		// debug($this->data);
		// exit();
		$existing_barangay = $this->find_existing_city_by_id_and_name_and_region_code_province_code_and_city_code($id, $barangay_name, $region_code,$province_code, $city_code);
		
		if(isset($existing_barangay) && count($existing_barangay) > 0) {
			return false;
		}
		else {
			return true;
		}
	}
	
	public function find_existing_city_by_id_and_name_and_region_code_province_code_and_city_code($id = null, $barangay_name = null, $region_code = null, $province_code = null, $city_code = null) {
		if(isset($barangay_name)) {
			$default_conditions = array(
				'Barangay.name' => $barangay_name
			);
		}
		
		if(isset($id)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'Barangay.id NOT' => $id
				)
			);
		}
		
		if(isset($region_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'Barangay.nso_region_code' => $region_code
				)
			);
		}
		if(isset($province_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'Barangay.nso_province_code' => $province_code
				)
			);
		}
		if(isset($city_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'Barangay.combined_nso_code' => $city_code
				)
			);
		}
		
		$barangay = $this->find('first', array(
			'fields' => array(
				'Barangay.id',
				'Barangay.code',
				'Barangay.name',
				'Barangay.nso_region_code',
				'Barangay.nso_province_code',
				'Barangay.combined_nso_code',
				'Barangay.status',
				'Barangay.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $barangay;
	}
	public function add_barangay($data = array(), $barangay_id = null, $barangay = null) {
		// $existing_barangay = $this->find_existing_barangay_by_id_or_code($barangay_id);
		
		// if(isset($existing_barangay) && count($existing_barangay) > 0) {
			// $existing_barangay['Barangay']['status'] = $barangay;
			// $data = $existing_barangay;
		// }
		return $this->save($data);
	}
	
	public function update_barangay($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($barangay_id = null, $barangay = null) {
		$existing_barangay = $this->find_existing_barangay_by_id_or_code($barangay_id);
		
		if(isset($existing_barangay) && count($existing_barangay) > 0) {
			$existing_barangay['Barangay']['status'] = $barangay;
			$data = $existing_barangay;
		}

		return $this->save($data);
	}
	
	public function find_existing_barangay_by_name($barangay_name = null) {
		if(isset($barangay_name)) {
			$default_conditions = array(
				'Barangay.name' => $barangay_name
			);
		}
		
		$barangay = $this->find('first', array(
			'fields' => array(
				'Barangay.id',
				'Barangay.code',
				'Barangay.name',
				'City.name',
				'Province.name',
				'Region.name',
				'Barangay.nso_region_code',
				'Barangay.nso_province_code',
				'Barangay.combined_nso_code',
				'Barangay.combined_nso_code',
				'Barangay.status'
			), 
			'contain'=>array(
				'City'=>array(
					'fields'=>array(
						'City.code',
						'City.name',
					)
				),
				'Province'=>array(
					'fields'=>array(
						'Province.code',
						'Province.name',
					)
				),
				'Region'=>array(
					'fields'=>array(
						'Region.code',
						'Region.name',
					)
				),
			),
			'conditions' => $default_conditions
		));
		
		return $barangay;
	}
	
	public function find_existing_barangay_by_id_or_code($barangay_id = null) {
		if(is_numeric($barangay_id)) {
			$default_conditions = array(
				'Barangay.id' => $barangay_id
			);
		}
		else {
			$default_conditions = array(
				'Barangay.code' => $barangay_id
			);
		}
		
		$barangay = $this->find('first', array(
			'fields' => array(
				'Barangay.id',
				'Barangay.code',
				'Barangay.name',
				'City.name',
				'Province.name',
				'Region.name',
				'Barangay.combined_nso_code',
				'Barangay.nso_region_code',
				'Barangay.nso_province_code',
				'Barangay.combined_nso_code',
				'Barangay.status'
			), 
			'contain'=>array(
				'City'=>array(
					'fields'=>array(
						'City.code',
						'City.name',
					)
				),
				'Province'=>array(
					'fields'=>array(
						'Province.code',
						'Province.name',
					)
				),
				'Region'=>array(
					'fields'=>array(
						'Region.code',
						'Region.name',
					)
				),
			),
			'conditions' => $default_conditions
		));
		
		return $barangay;
	}
	public function beforeSave($options = array()) {
		if(!isset($this->data['Barangay']['id'])) {
			$this->data['Barangay']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Barangay']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Barangay']['status'] = 'Active';
			$this->data['Barangay']['barangay_status'] = 'A';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'BRGY';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Barangay']['nso_barangay_code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
			
		$this->data['Barangay']['code']=$this->data['Barangay']['nso_barangay_code'];
		}
		else {
			$this->data['Barangay']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		return true;
	}
}
?>