<?php

/**
 * Records changes made to an object during save operations.
 */
class DaiCacheBehavior extends ModelBehavior {
	public $cacheQueries=true;
	public function get_query_signature(&$model, $find_type, $find_params) {
		$query_signature = Security::hash($model->name . '-' . $find_type . '-' . serialize($find_params), 'sha1', true);
		
		return $query_signature;
	}
	
	public function get_cache_from_query_signature(&$model, $query_signature) {
		$cached_results = Cache::read($query_signature, $model->name . 'Cache');

        return $cached_results;
	}
	
	public function cachedFind(&$model, $find_type, $find_params = array()) {
		$query_signature = $this->get_query_signature($model, $find_type, $find_params);
		
		$cached_results = $this->get_cache_from_query_signature($model, $query_signature);
		
		if(!$cached_results) {
			$cached_results = $model->find($find_type, $find_params);
            Cache::write($query_signature, $cached_results, $model->name . 'Cache');
		}
		
		return $cached_results;
	}
	
	public function afterSave(model $model, $created, $options = array()) {
		$model_mapping = $this->get_model_cache_mapping();
		
		if(isset($model_mapping[$model->name])) {
			foreach($model_mapping[$model->name] as $model_for_clearing) {
				Cache::clearGroup($model_for_clearing, $model_for_clearing . 'Cache');
			}
		}
		
		Cache::clearGroup($model->name, $model->name . 'Cache');
	}
	
	public function clearCacheGroup(model $model) {
		Cache::clearGroup('ModelMapping', 'ModelMapping');

		$system_models = App::objects('Model');

		foreach($system_models as $system_model) {
			Cache::clearGroup($system_model, $system_model. 'Cache');
		}
	}
	
	public function get_model_cache_mapping() {
		$model_mapping = Cache::read('default', 'ModelMappingCache');
		
		if(!$model_mapping) {
			$model_mapping = array();
			
			$system_models = App::objects('Model');
			foreach($system_models as $system_model) {
				$this->get_model_mapping($system_model, $model_mapping);
			}
			
			foreach($model_mapping as $model_mapping_key => $model_mapping_value) {
				foreach($model_mapping_value as $model_mapping_value_key) {
					$this->get_model_mapping_recursive($model_mapping_value_key, $model_mapping_key, $model_mapping);
				}
			}
			
			Cache::write('default', $model_mapping, 'ModelMappingCache');
		}
		
		return $model_mapping;
	}
	
	private function get_model_mapping($system_model, &$model_mapping) {
		$selected_model = ClassRegistry::init($system_model);
		
		foreach($selected_model->belongsTo as $model_key => $model_value) {
			if(isset($model_value['className'])) {
				$model_mapping_key = $model_value['className'];
			}
			else {
				$model_mapping_key = $model_key;
			}
			
			if(!isset($model_mapping[$model_mapping_key]) || !in_array($system_model, $model_mapping[$model_mapping_key])) {
				$model_mapping[$model_mapping_key][] = $system_model;
			}
		}
		
		foreach($selected_model->hasOne as $model_key => $model_value) {
			if(isset($model_value['className'])) {
				$model_mapping_key = $model_value['className'];
			}
			else {
				$model_mapping_key = $model_key;
			}
			
			if(!isset($model_mapping[$model_mapping_key]) || !in_array($system_model, $model_mapping[$model_mapping_key])) {
				$model_mapping[$model_mapping_key][] = $system_model;
			}
		}
		
		foreach($selected_model->hasMany as $model_key => $model_value) {
			if(isset($model_value['className'])) {
				$model_mapping_key = $model_value['className'];
			}
			else {
				$model_mapping_key = $model_key;
			}
			
			if(!isset($model_mapping[$model_mapping_key]) || !in_array($system_model, $model_mapping[$model_mapping_key])) {
				$model_mapping[$model_mapping_key][] = $system_model;
			}
		}
		
		return $model_mapping;
	}
	
	private function get_model_mapping_recursive($system_model, $origin_model_mapping_key, &$model_mapping) {
		$selected_model = ClassRegistry::init($system_model);
		
		foreach($selected_model->belongsTo as $model_key => $model_value) {
			if(isset($model_value['className'])) {
				$model_mapping_key = $model_value['className'];
			}
			else {
				$model_mapping_key = $model_key;
			}

			if(!isset($model_mapping[$origin_model_mapping_key]) || !in_array($model_mapping_key, $model_mapping[$origin_model_mapping_key])) {
				$model_mapping[$origin_model_mapping_key][] = $model_mapping_key;
			}
		}
		
		foreach($selected_model->hasOne as $model_key => $model_value) {
			if(isset($model_value['className'])) {
				$model_mapping_key = $model_value['className'];
			}
			else {
				$model_mapping_key = $model_key;
			}

			if(!isset($model_mapping[$origin_model_mapping_key]) || !in_array($model_mapping_key, $model_mapping[$origin_model_mapping_key])) {
				$model_mapping[$origin_model_mapping_key][] = $model_mapping_key;
			}
		}
		
		foreach($selected_model->hasMany as $model_key => $model_value) {
			if(isset($model_value['className'])) {
				$model_mapping_key = $model_value['className'];
			}
			else {
				$model_mapping_key = $model_key;
			}

			if(!isset($model_mapping[$origin_model_mapping_key]) || !in_array($model_mapping_key, $model_mapping[$origin_model_mapping_key])) {
				$model_mapping[$origin_model_mapping_key][] = $model_mapping_key;
			}
		}
		
		return $model_mapping;
	}
  /*
	public function beforeFind( model $model, $query = array() ) {
		 // return $query;
		if(isset($query['fields']) && !is_array($query['fields'])){
				if (strpos($query['fields'], 'COUNT(*)') !== false) {
						$query['fields']=' COUNT('. $model->name . '.id) AS `count`';
				}
				elseif(!(isset($query['callbacks'])))
				{	
					$query['fields']= " SQL_CACHE " . $query['fields'];
					
				}
				
		}
		elseif(isset($query['fields'][0]))
		{	
			if (strpos($query['fields'][0], ' as ') !== false || strpos($query['fields'][0], ' ') !== false) 
			{
				$query['fields'][0]= "SQL_CACHE " .$query['fields'][0];
			}
			else
			{	
				$field = explode('.',$query['fields'][0]);
				if(isset($field[1]) && !in_array($field[1],array_keys($model->virtualFields)))
				{
					$query['fields'][0]= "SQL_CACHE (" .$query['fields'][0].")";
				}
			}
		}
		
				// debug($query);
		return $query;
	}
  */
}
