<?php
App::uses('AppModel', 'Model');

class BloodType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';

		public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.'
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),
		
	);
	
	public function add_blood_type($data = array()) {		
		$existing_blood_type = $this->find_existing_blood_type_by_name($data['BloodType']['name']);
		
		if(isset($existing_blood_type) && count($existing_blood_type) > 0) {
			$existing_blood_type['BloodType']['status'] = 'Active';
			$data = $existing_blood_type;
		}

		return $this->save($data);
	}
	
	public function update_blood_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($blood_type_id = null, $blood_type = null) {
		$existing_blood_type = $this->find_existing_blood_type_by_id_or_code($blood_type_id);
		
		if(isset($existing_blood_type) && count($existing_blood_type) > 0) {
			$existing_blood_type['BloodType']['status'] = $blood_type;
			$data = $existing_blood_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_blood_type_by_name($blood_type_name = null) {
		if(isset($blood_type_name)) {
			$default_conditions = array(
				'UPPER(BloodType.name)' => strtoupper($blood_type_name)
			);
		}
		
		$blood_type = $this->find('first', array(
			'fields' => array(
				'BloodType.id',
				'BloodType.code',
				'BloodType.name',
				'BloodType.status',
				'BloodType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $blood_type;
	}
	
	public function find_existing_blood_type_by_id_or_code($blood_type_id = null) {
		if(is_numeric($blood_type_id)) {
			$default_conditions = array(
				'BloodType.id' => $blood_type_id
			);
		}
		else {
			$default_conditions = array(
				'BloodType.code' => $blood_type_id
			);
		}
		
		$blood_type = $this->find('first', array(
			'fields' => array(
				'BloodType.id',
				'BloodType.code',
				'BloodType.name',
				'BloodType.status',
				'BloodType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $blood_type;
	}

	public function beforeSave($options = array()) {
		if(!isset($this->data['BloodType']['id'])) {
			$this->data['BloodType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['BloodType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['BloodType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'BLDTYPE';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['BloodType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['BloodType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>