<?php
App::uses('AppModel', 'Model');

class CareerServiceType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.'
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),
		
	);
	
	public function add_career_service_type($data = array()) {		
		$existing_career_service_type = $this->find_existing_career_service_type_by_name($data['CareerServiceType']['name']);
		
		if(isset($existing_career_service_type) && count($existing_career_service_type) > 0) {
			$existing_career_service_type['CareerServiceType']['status'] = 'Active';
			$data = $existing_career_service_type;
		
		}

		return $this->save($data);
	}
	
	public function update_career_service_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($career_service_type_id = null, $career_service_type = null) {
		$existing_career_service_type = $this->find_existing_career_service_type_by_id_or_code($career_service_type_id);
		
		if(isset($existing_career_service_type) && count($existing_career_service_type) > 0) {
			$existing_career_service_type['CareerServiceType']['status'] = $career_service_type;
			$data = $existing_career_service_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_career_service_type_by_name($career_service_type_name = null) {
		if(isset($career_service_type_name)) {
			$default_conditions = array(
				'CareerServiceType.name' => $career_service_type_name
			);
		}
		
		$career_service_type = $this->find('first', array(
			'fields' => array(
				'CareerServiceType.id',
				'CareerServiceType.code',
				'CareerServiceType.name',
				'CareerServiceType.status',
				'CareerServiceType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $career_service_type;
	}
	
	public function find_existing_career_service_type_by_id_or_code($career_service_type_id = null) {
		if(is_numeric($career_service_type_id)) {
			$default_conditions = array(
				'CareerServiceType.id' => $career_service_type_id
			);
		}
		else {
			$default_conditions = array(
				'CareerServiceType.code' => $career_service_type_id
			);
		}
		
		$career_service_type = $this->find('first', array(
			'fields' => array(
				'CareerServiceType.id',
				'CareerServiceType.code',
				'CareerServiceType.name',
				'CareerServiceType.status',
				'CareerServiceType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $career_service_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['CareerServiceType']['id'])) {
			$this->data['CareerServiceType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CareerServiceType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CareerServiceType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'CST';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['CareerServiceType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['CareerServiceType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>