<?php
App::uses('AppModel', 'Model');

class ChangeOfStatus extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	public $primaryKey = 'code';
	public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
	);

	public $hasMany = array(
		'ChangeOfStatusHistoryLog' => array(
			'className' => 'ChangeOfStatusHistoryLog',
			'foreignKey' => 'change_of_status_code',
			'fields' => array(
				'ChangeOfStatusHistoryLog.change_of_status_code',
				'ChangeOfStatusHistoryLog.employee_code',
				'ChangeOfStatusHistoryLog.change_of_status_date',
				'ChangeOfStatusHistoryLog.remarks',
				'ChangeOfStatusHistoryLog.change_of_status',
			),
			'conditions' => array(
				'ChangeOfStatusHistoryLog.status' => 'Active'
			)
		),
	);



	public function beforeValidate($options = array()) {		
		if(isset($this->data['ChangeOfStatus']['change_of_status_date']) && validate_datetime($this->data['ChangeOfStatus']['change_of_status_date'], 'm/d/Y')) {
			$this->data['ChangeOfStatus']['change_of_status_date'] = convert_datetime($this->data['ChangeOfStatus']['change_of_status_date'], 'Y-m-d');
		}
			return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ChangeOfStatus']['id'])) {
			$this->data['ChangeOfStatus']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ChangeOfStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ChangeOfStatus']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'CHASTAT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ChangeOfStatus']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ChangeOfStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['ChangeOfStatus']['change_of_status_date'])){
				$results[$x]['ChangeOfStatus']['change_of_status_date'] = date('m/d/Y',strtotime($results[$x]['ChangeOfStatus']['change_of_status_date']));
			}
		}

		return $results;
	}
}
?>