<?php
App::uses('AppModel', 'Model');

class City extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
			'name logic 2' => array(
				'rule'		=> array('validate_city_by_id_and_name_and_region_code_and_province_code_and_zip_code'),
				'message'	=> 'The data that you inserted is already exist.'
			),
			'name logic 3' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name already exist.'
			),
        ),
	);
	public $hasMany = array(
		'Barangay' => array(
			'targetForeignKey' => 'code',
            'foreignKey' => 'combined_nso_code',
            'joinTable' => 'setting_barangays',
			'fields' => array(
				'code',
				'name'
			)
		),
		'Address' => array(
			'className' => 'Address',
			'foreignKey' => 'city_code'
		)
	);
	public $belongsTo = array(
		'Region' => array(
			'className' => 'Region',
			'foreignKey' => 'region_code',
			'fields' => array(
				'code',
				'name'
			)
		),
		'Province' => array(
			'className' => 'Province',
			'foreignKey' => 'province_code',
			'fields' => array(
				'code',
				'name'
			)
		)
	
	);
	public function validate_city_by_id_and_name_and_region_code_and_province_code_and_zip_code($validation_fields = array()) {
		$id = null;
		$region_code = $this->data['City']['region_code'];
		$province_code = $this->data['City']['province_code'];
		$city_name = $this->data['City']['name'];
		$zip_code = $this->data['City']['zip_code'];
		
		if(isset($this->data['City']['id'])) {
			$id = $this->data['City']['id'];
		}
		
		$existing_city = $this->find_existing_city_by_id_and_name_and_region_code_province_code_and_zip_code($id, $city_name, $region_code,$province_code,$zip_code);
		
		if(isset($existing_city) && count($existing_city) > 0) {
			return false;
		}
		else {
			return true;
		}
	}
	
	public function find_existing_city_by_id_and_name_and_region_code_province_code_and_zip_code($id = null, $city_name = null, $region_code = null, $province_code = null, $zip_code = null) {
		if(isset($city_name)) {
			$default_conditions = array(
				'City.name' => $city_name
			);
		}
		
		if(isset($id)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'City.id NOT' => $id
				)
			);
		}
		
		if(isset($region_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'City.region_code' => $region_code
				)
			);
		}
		if(isset($province_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'City.province_code' => $province_code
				)
			);
		}
		if(isset($zip_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'City.zip_code' => $zip_code
				)
			);
		}
		
		$city = $this->find('first', array(
			'fields' => array(
				'City.id',
				'City.code',
				'City.name',
				'City.region_code',
				'City.province_code',
				'City.zip_code',
				'City.status',
				'City.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $city;
	}
	
	public function add_city($data = array()) {		
		return $this->save($data);
	}
	
	public function update_city($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($city_id = null, $city = null) {
		$existing_city = $this->find_existing_city_by_id_or_code($city_id);
		
		if(isset($existing_city) && count($existing_city) > 0) {
			$existing_city['City']['status'] = $city;
			$data = $existing_city;
		}
		
		// debug($data);
		// exit();
		return $this->save($data);
	}
	
	public function find_existing_city_by_name($city_name = null) {
		if(isset($city_name)) {
			$default_conditions = array(
				'City.name' => $city_name
			);
		}
		
		$city = $this->find('first', array(
			'fields' => array(
				'City.id',
				'City.code',
				'City.name',
				'City.status',
				'City.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $city;
	}
	
	public function find_existing_city_by_id_or_code($city_id = null) {
		if(is_numeric($city_id)) {
			$default_conditions = array(
				'City.id' => $city_id
			);
		}
		else {
			$default_conditions = array(
				'City.code' => $city_id
			);
		}
		 
		$city = $this->find('first', array(
			'fields' => array(
				'City.id',
				'City.code',
				'City.name',
				'City.zip_code',
				'City.status',
				'City.lock_flag',
				'City.region_code',
				'City.province_code',
				'Region.code',
				'Region.name',
				'Province.code',
				'Province.name'
			),
			'contain'=>array(
				'Region'=>array(
					'fields'=>array(
						'Region.code',
						'Region.name'
					)
				),
				'Province'=>array(
					'fields'=>array(
						'Province.code',
						'Province.name'
					)
				)
			),
			'conditions' => $default_conditions
		));
		
		return $city;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['City']['id'])) {
			$this->data['City']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['City']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['City']['status'] = 'Active';
		
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'CITY';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['City']['nso_city'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
			$this->data['City']['code']=$this->data['City']['province_code'].''.$this->data['City']['nso_city'];
			
		}
		else {
			$this->data['City']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}

		return true;
	}
}
?>