<?php
App::uses('AppModel', 'Model');

class CivilStatus extends AppModel {
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	// public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.'
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),
		
	);
	
	public function add_civil_status($data = array()) {		
		$existing_civil_status = $this->find_existing_civil_status_by_name($data['CivilStatus']['name']);
		
		if(isset($existing_civil_status) && count($existing_civil_status) > 0) {
			$existing_civil_status['CivilStatus']['status'] = 'Active';
			$data = $existing_civil_status;
		}

		return $this->save($data);
	}
	
	public function update_civil_status($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($civil_status_id = null, $civil_status = null) {
		$existing_civil_status = $this->find_existing_civil_status_by_id_or_code($civil_status_id);
		
		if(isset($existing_civil_status) && count($existing_civil_status) > 0) {
			$existing_civil_status['CivilStatus']['status'] = $civil_status;
			$data = $existing_civil_status;
		}
		
		// debug($data);exit();

		return $this->save($data);
	}
	
	public function find_existing_civil_status_by_name($civil_name = null) {
		if(isset($civil_name)) {
			$default_conditions = array(
				'CivilStatus.name' => $civil_name
			);
		}
		
		$civil_status = $this->find('first', array(
			'fields' => array(
				'CivilStatus.id',
				'CivilStatus.code',
				'CivilStatus.name',
				'CivilStatus.status',
				'CivilStatus.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $civil_status;
	}
	
	public function find_existing_civil_status_by_id_or_code($civil_status_id = null) {
		if(is_numeric($civil_status_id)) {
			$default_conditions = array(
				'CivilStatus.id' => $civil_status_id
			);
		}
		else {
			$default_conditions = array(
				'CivilStatus.code' => $civil_status_id
			);
		}
		
		$civil_status = $this->find('first', array(
			'fields' => array(
				'CivilStatus.id',
				'CivilStatus.code',
				'CivilStatus.name',
				'CivilStatus.status',
				'CivilStatus.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $civil_status;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['CivilStatus']['id'])) {
			$this->data['CivilStatus']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CivilStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CivilStatus']['status'] = 'Active';

			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'CVLSTAT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['CivilStatus']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['CivilStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>