<?php
App::uses('AppModel', 'Model');

class Compensatory extends AppModel {
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'filing_';
	public $primaryKey = 'reference_number';

	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
		'ApprovedByUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_unit',
			'conditions' => array(
				'ApprovedByUnit.status' => 'Active'
			)
		),
		'ApprovedBySubUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_sub_unit',
			'conditions' => array(
				'ApprovedBySubUnit.status' => 'Active'
			)
		),
		'ApprovedBySection' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_section',
			'conditions' => array(
				'ApprovedBySection.status' => 'Active'
			)
		),
		'ApprovedByDivision' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_division',
			'conditions' => array(
				'ApprovedByDivision.status' => 'Active'
			)
		),
		'ApprovedByAdminOfficer' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_admin_officer',
			'conditions' => array(
				'ApprovedByAdminOfficer.status' => 'Active'
			)
		),
		'ApprovedByHRAdmin' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_hr_admin',
			'conditions' => array(
				'ApprovedByHRAdmin.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
	);
	public $hasMany = array (
		'FilingCompensatoryAttachment' => array(
			'className' => 'FilingCompensatoryAttachment',
			'foreignKey' => 'compensatory_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
		'CompensatoryAttachment' => array(
			'className' => 'CompensatoryAttachment',
			'foreignKey' => 'compensatory_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
	);
	public function beforeValidate($options = array()) {
		if(isset($this->data['Compensatory']['date_from']) && validate_datetime($this->data['Compensatory']['date_from'], 'm/d/Y')) {
			$this->data['Compensatory']['date_from'] = convert_datetime($this->data['Compensatory']['date_from'], 'Y-m-d');
		}	
		
		if(isset($this->data['Compensatory']['date_to']) && validate_datetime($this->data['Compensatory']['date_to'], 'm/d/Y')) {
			$this->data['Compensatory']['date_to'] = convert_datetime($this->data['Compensatory']['date_to'], 'Y-m-d');
		}	
		
		if(isset($this->data['Compensatory']['date_of_overtime']) && validate_datetime($this->data['Compensatory']['date_of_overtime'], 'm/d/Y')) {
			$this->data['Compensatory']['date_of_overtime'] = convert_datetime($this->data['Compensatory']['date_of_overtime'], 'Y-m-d');
		}	
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Compensatory']['reference_number'])) {
			$this->data['Compensatory']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Compensatory']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Compensatory']['status'] = 'Active';
		
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'CMPSTRY';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['Compensatory']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Compensatory']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Compensatory']['date_from'])){
				$results[$x]['Compensatory']['date_from'] = date('m/d/Y',strtotime($results[$x]['Compensatory']['date_from']));
			}
			
			if(isset($result['Compensatory']['date_to'])){
				$results[$x]['Compensatory']['date_to'] = date('m/d/Y',strtotime($results[$x]['Compensatory']['date_to']));
			}
			
			if(isset($result['Compensatory']['date_of_overtime'])){
				$results[$x]['Compensatory']['date_of_overtime'] = date('m/d/Y',strtotime($results[$x]['Compensatory']['date_of_overtime']));
			}
			
		}

		return $results;
	}
}
?>