<?php
App::uses('AppModel', 'Model');

class CoopRemittanceEntry extends AppModel {
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'payroll_';
	
	
	public $hasMany = array(
		'CoopRemittanceEntryDetail' => array(
			'className' => 'CoopRemittanceEntryDetail',
			'foreignKey' => 'payroll_coop_remittance_entry_id',
			'conditions' => array(
				'CoopRemittanceEntryDetail.status' => 'Active'
			)
		),
	);
	
	public $belongsTo = array(
		'PayrollPeriod' => array(
			'className' => 'PayrollPeriod',
			'foreignKey' => false,
			'conditions' => array(
				// 'PayrollPeriod.status' => 'Active',
				'PayrollPeriod.id = CoopRemittanceEntry.payroll_period_id',
			),
		)
	);
	public $validate = array(
        'payroll_period_id' => array(
			'payroll_period_id logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Payroll Period is required.'
			),
        ),	
	);

	
	public function beforeValidate($options = array()) {
		if(isset($this->data['CoopRemittanceEntry']['payroll_period']) && validate_datetime($this->data['CoopRemittanceEntry']['payroll_period'], 'm/d/Y')) {
			$this->data['CoopRemittanceEntry']['payroll_period'] = convert_datetime($this->data['CoopRemittanceEntry']['payroll_period'], 'Y-m-d');
		}		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['CoopRemittanceEntry']['id'])) {
			$this->data['CoopRemittanceEntry']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CoopRemittanceEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CoopRemittanceEntry']['status'] = 'Active';
			
		}
		else {
			$this->data['CoopRemittanceEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['CoopRemittanceEntry']['payroll_period'])){
				$results[$x]['CoopRemittanceEntry']['payroll_period'] = date('m/d/Y',strtotime($results[$x]['CoopRemittanceEntry']['payroll_period']));
			}
			
			if(isset($result['CoopRemittanceEntry']['date_filed'])){
				$results[$x]['CoopRemittanceEntry']['date_filed'] = date('m/d/Y',strtotime($results[$x]['CoopRemittanceEntry']['date_filed']));
			}
			
		}

		return $results;
	}
}
?>