<?php
App::uses('AppModel', 'Model');

class CountryList extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public $hasMany = array(
		'Address' => array(
			'className' => 'Address',
			'foreignKey' => 'country_code'
		),
	);
	
		public function add_country_list($data = array()) {		
		$existing_country_list = $this->find_existing_country_list_by_name($data['CountryList']['name']);
		
		if(isset($existing_country_list) && count($existing_country_list) > 0) {
			$existing_country_list['CountryList']['status'] = 'Active';
			$data = $existing_country_list;
			
		}

		return $this->save($data);
	}
	
	public function update_country_list($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($country_list_id = null, $country_list = null) {
		$existing_country_list = $this->find_existing_country_list_by_id_or_code($country_list_id);
		
		if(isset($existing_country_list) && count($existing_country_list) > 0) {
			$existing_country_list['CountryList']['status'] = $country_list;
			$data = $existing_country_list;
		}

		return $this->save($data);
	}
	
	public function find_existing_country_list_by_name($country_list_name = null) {
		if(isset($country_list_name)) {
			$default_conditions = array(
				'CountryList.name' => $country_list_name
			);
		}
		
		$country_list = $this->find('first', array(
			'fields' => array(
				'CountryList.id',
				'CountryList.code',
				'CountryList.name',
				'CountryList.status',
				'CountryList.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $country_list;
	}
	
	public function find_existing_country_list_by_id_or_code($country_list_id = null) {
		if(is_numeric($country_list_id)) {
			$default_conditions = array(
				'CountryList.id' => $country_list_id
			);
		}
		else {
			$default_conditions = array(
				'CountryList.code' => $country_list_id
			);
		}
		
		$country_list = $this->find('first', array(
			'fields' => array(
				'CountryList.id',
				'CountryList.code',
				'CountryList.name',
				'CountryList.status',
				'CountryList.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $country_list;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['CountryList']['id'])) {
			$this->data['CountryList']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CountryList']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['CountryList']['status'] = 'Active';
			
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'CNTRY';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['CountryList']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['CountryList']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>