<?php
App::uses('AppModel', 'Model');

class Death extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'separation_';
	public $primaryKey = 'reference_number';
	public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'Employee.first_name',
				'Employee.middle_name',
				'Employee.last_name',
				'Employee.combination_whole_name',
				'Employee.standard_name',
			),
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),	
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['Death']['filing_date']) && validate_datetime($this->data['Death']['filing_date'], 'm/d/Y')) {
			$this->data['Death']['filing_date'] = convert_datetime($this->data['Death']['filing_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['Death']['death_date']) && validate_datetime($this->data['Death']['death_date'], 'm/d/Y')) {
			$this->data['Death']['death_date'] = convert_datetime($this->data['Death']['death_date'], 'Y-m-d');
		}
		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Death']['id'])) {
			$this->data['Death']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Death']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Death']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DTH';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			
			$this->data['Death']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Death']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>