<?php
App::uses('AppModel', 'Model');

class DeductionType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $displayField = 'name';
	public $primaryKey = 'code';
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
				'on'=>'create'
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		// 'institution' => array(
			// 'institution logic 1' => array(
				// 'rule'		=> 'notEmpty',
				// 'message'	=> 'Institution is required.'
			// ),
        // ),
		'accounting_code' => array(
			'accounting_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Accounting Code is required.'
			),
        ),
	);
	
	public function add_deduction_type($data = array()) {		
		$existing_deduction_type = $this->find_existing_deduction_type_by_name($data['DeductionType']['name']);
		
		if(isset($existing_deduction_type) && count($existing_deduction_type) > 0) {
			$existing_deduction_type['DeductionType']['status'] = 'Active';
			$data = $existing_deduction_type;
		}

		return $this->save($data);
	}
	
	public function update_deduction_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($deduction_type_id = null, $deduction_type = null) {
		$existing_deduction_type = $this->find_existing_deduction_type_by_id_or_code($deduction_type_id);
		
		if(isset($existing_deduction_type) && count($existing_deduction_type) > 0) {
			$existing_deduction_type['DeductionType']['status'] = $deduction_type;
			$data = $existing_deduction_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_deduction_type_by_name($deduction_type_name = null) {
		if(isset($deduction_type_name)) {
			$default_conditions = array(
				'DeductionType.name' => $deduction_type_name
			);
		}
		
		$deduction_type = $this->find('first', array(
			'fields' => array(
				'DeductionType.id',
				'DeductionType.code',
				'DeductionType.name',
				'DeductionType.institution',
				'DeductionType.accounting_code',
				'DeductionType.status',
				'DeductionType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $deduction_type;
	}
	
	public function find_existing_deduction_type_by_id_or_code($deduction_type_id = null) {
		if(is_numeric($deduction_type_id)) {
			$default_conditions = array(
				'DeductionType.id' => $deduction_type_id
			);
		}
		else {
			$default_conditions = array(
				'DeductionType.code' => $deduction_type_id
			);
		}
		
		$deduction_type = $this->find('first', array(
			'fields' => array(
				'DeductionType.id',
				'DeductionType.code',
				'DeductionType.name',
				'DeductionType.institution',
				'DeductionType.accounting_code',
				'DeductionType.category',
				'DeductionType.status',
				'DeductionType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $deduction_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['DeductionType']['code'])) {
			$this->data['DeductionType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DeductionType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DeductionType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['DeductionType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['DeductionType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>