<?php
App::uses('AppModel', 'Model');

class Demotion extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	public $primaryKey = 'code';
	public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		)
	);

	public $hasMany = array(
		'DemotionHistoryLog' => array(
			'className' => 'DemotionHistoryLog',
			'foreignKey' => 'demotion_code',
			'fields' => array(
				'DemotionHistoryLog.demotion_code',
				'DemotionHistoryLog.employee_code',
				'DemotionHistoryLog.demotion_date',
				'DemotionHistoryLog.remarks',
			),
			'conditions' => array(
				'DemotionHistoryLog.status' => 'Active'
			)
		),
	);
	public $validate = array(
		 
        'employee_code' => array(
            'employee_code logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Employee is required.'
            ),
			
        ), 
	);
	public function beforeValidate($options = array()) {		
		if(isset($this->data['Demotion']['demotion_date']) && validate_datetime($this->data['Demotion']['demotion_date'], 'm/d/Y')) {
			$this->data['Demotion']['demotion_date'] = convert_datetime($this->data['Demotion']['demotion_date'], 'Y-m-d');
		}
			return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Demotion']['id'])) {
			$this->data['Demotion']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Demotion']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Demotion']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DEMTION';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Demotion']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Demotion']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Demotion']['demotion_date'])){
				$results[$x]['Demotion']['demotion_date'] = date('m/d/Y',strtotime($results[$x]['Demotion']['demotion_date']));
			}
		}

		return $results;
	}
}
?>