<?php
App::uses('AppModel', 'Model');

class Dependent extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	// public $primaryKey = 'code';
	// public $displayField = 'name';
	
	public $virtualFields = array(
		'automated_age' => "DATE_FORMAT(NOW(), '%Y') - DATE_FORMAT(Dependent.birth_date, '%Y') - (DATE_FORMAT(NOW(), '00-%m-%d') < DATE_FORMAT(Dependent.birth_date, '00-%m-%d'))"
	);
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'Gender' => array(
			'className' => 'Gender',
			'foreignKey' => 'gender_code',
			'fields' => array(
				'code',
				'name',
			),
			'conditions' => array(
				'Gender.status' => 'Active'
			),
		),
		'Relation' => array(
			'className' => 'Relation',
			'foreignKey' => 'relation_code',
			'fields' => array(
				'code',
				'name',
			),
			'conditions' => array(
				'Relation.status' => 'Active'
			),
		),
		// 'PersonWithDisability' => array(
			// 'className' => 'PersonWithDisability',
			// 'foreignKey' => 'person_with_disability_code',
			// 'fields' => array(
				// 'code',
				// 'name',
			// ),
			// 'conditions' => array(
				// 'PersonWithDisability.status' => 'Active'
			// ),
		// ),
		'Disability' => array(
			'className' => 'Disability',
			'foreignKey' => 'disability_code',
			'fields' => array(
				'code',
				'name',
			),
			'conditions' => array(
				'Disability.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['Dependent']['birth_date']) && validate_datetime($this->data['Dependent']['birth_date'], 'm/d/Y')) {
			$this->data['Dependent']['birth_date'] = convert_datetime($this->data['Dependent']['birth_date'], 'Y-m-d');
		}	
		if(isset($this->data['Dependent']['date_hired']) && validate_datetime($this->data['Dependent']['date_hired'], 'm/d/Y')) {
			$this->data['Dependent']['date_hired'] = convert_datetime($this->data['Dependent']['date_hired'], 'Y-m-d');
		}	
		return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Dependent']['id'])) {
			$this->data['Dependent']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Dependent']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Dependent']['status'] = 'Active';
			
			// $ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			// $code_char = 'BNK';
			// $reference = $ReferenceCode->findByPrefixCode($code_char);
			// $code_number = $reference['ReferenceCode']['number'] + 1;
			// $this->data['Dependent']['code'] = $code_char . '-' . $code_number;
		
			// $ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Dependent']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Dependent']['birth_date'])){
				$results[$x]['Dependent']['birth_date'] = date('m/d/Y',strtotime($results[$x]['Dependent']['birth_date']));
			}
		}

		return $results;
	}
}
?>