<?php
App::uses('AppModel', 'Model');

class Disability extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_disability($data = array()) {		
		$existing_disability = $this->find_existing_disability_by_name($data['Disability']['name']);
		
		if(isset($existing_disability) && count($existing_disability) > 0) {
			$existing_disability['Disability']['status'] = 'Active';
			$data = $existing_disability;
		}
		return $this->save($data);
	}
	
	public function find_existing_disability_by_name($disability_name = null) {
		if(isset($disability_name)) {
			$default_conditions = array(
				'UPPER(Disability.name)' => strtoupper($disability_name)
			);
		}
		
		$disability = $this->find('first', array(
			'fields' => array(
				'Disability.id',
				'Disability.code',
				'Disability.name',
				'Disability.status',
				'Disability.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $disability;
	}
	
	public function update_disability($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($disability_id = null, $disability = null) {
		$existing_disability = $this->find_existing_disability_by_id_or_code($disability_id);
		
		if(isset($existing_disability) && count($existing_disability) > 0) {
			$existing_disability['Disability']['status'] = $disability;
			$data = $existing_disability;
		}

		return $this->save($data);
	}
	
	public function find_existing_disability_by_id_or_code($disability_id = null) {
		if(is_numeric($disability_id)) {
			$default_conditions = array(
				'Disability.id' => $disability_id
			);
		}
		else {
			$default_conditions = array(
				'Disability.code' => $disability_id
			);
		}
		
		$disability = $this->find('first', array(
			'fields' => array(
				'Disability.id',
				'Disability.code',
				'Disability.name',
				'Disability.status',
				'Disability.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $disability;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Disability']['id'])) {
			$this->data['Disability']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Disability']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Disability']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DSBL';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Disability']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Disability']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>