<?php
App::uses('AppModel', 'Model');
class DisbursementVoucher extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'setting_';

	public $validate = array(
		'fund_cluster' => array(
			'required' => array(
				'rule' => array('notEmpty'),
				'message' => 'Fund Cluster is required.'
			)
		),
		'payee' => array(
			'required' => array(
				'rule' => array('notEmpty'),
				'message' => 'Payee is required.'
			)
		),
		'disbursement_date' => array(
			'required' => array(
				'rule' => array('notEmpty'),
				'message' => 'Disbursement date is required.'
			)
		)
	);
	
	public $belongsTo = array(
		'ModeOfPayment' => array(
			'className' => 'ModeOfPayment',
			'foreignKey' => 'mode_of_payment_code',
			'fields' => array(
				'ModeOfPayment.code',
				'ModeOfPayment.name',
			),
			'conditions' => array(
				'ModeOfPayment.status' => 'Active'
			)
		),
	);
	public $hasMany = array(
		'DisbursementVoucherParticular' => array(
			'className' => 'DisbursementVoucherParticular',
			'foreignKey' => 'disbursement_voucher_id',
			'conditions' => array(
				'DisbursementVoucherParticular.status' => 'Active'
			)
		),
		'DisbursementVoucherAccountingEntry' => array(
			'className' => 'DisbursementVoucherAccountingEntry',
			'foreignKey' => 'disbursement_voucher_id',
			'conditions' => array(
				'DisbursementVoucherAccountingEntry.status' => 'Active'
			)
		),
		// 'DisbursementVoucherModeOfPayment' => array(
			// 'className' => 'DisbursementVoucherModeOfPayment',
			// 'foreignKey' => 'disbursement_voucher_id',
			// 'conditions' => array(
				// 'DisbursementVoucherModeOfPayment.status' => 'Active'
			// )
		// ),
		'DisbursementVoucherCertifiedMethod' => array(
			'className' => 'DisbursementVoucherCertifiedMethod',
			'foreignKey' => 'disbursement_voucher_id',
			'conditions' => array(
				'DisbursementVoucherCertifiedMethod.status' => 'Active'
			)
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['DisbursementVoucher']['disbursement_date']) && validate_datetime($this->data['DisbursementVoucher']['disbursement_date'], 'm/d/Y')) {
			$this->data['DisbursementVoucher']['disbursement_date'] = convert_datetime($this->data['DisbursementVoucher']['disbursement_date'], 'Y-m-d');
		}	
		if(isset($this->data['DisbursementVoucher']['check_ada_no_date']) && validate_datetime($this->data['DisbursementVoucher']['check_ada_no_date'], 'm/d/Y')) {
			$this->data['DisbursementVoucher']['check_ada_no_date'] = convert_datetime($this->data['DisbursementVoucher']['check_ada_no_date'], 'Y-m-d');
		}	
		if(isset($this->data['DisbursementVoucher']['jev_no_date']) && validate_datetime($this->data['DisbursementVoucher']['jev_no_date'], 'm/d/Y')) {
			$this->data['DisbursementVoucher']['jev_no_date'] = convert_datetime($this->data['DisbursementVoucher']['jev_no_date'], 'Y-m-d');
		}
		return true;
	}		
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['DisbursementVoucher']['id'])) {
			$this->data['DisbursementVoucher']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DisbursementVoucher']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DisbursementVoucher']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DISVOU';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['DisbursementVoucher']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['DisbursementVoucher']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['DisbursementVoucher']['disbursement_date'])){
				$results[$x]['DisbursementVoucher']['disbursement_date'] = date('m/d/Y',strtotime($results[$x]['DisbursementVoucher']['disbursement_date']));
			}
			
			if(isset($result['DisbursementVoucher']['check_ada_no_date'])){
				$results[$x]['DisbursementVoucher']['check_ada_no_date'] = date('m/d/Y',strtotime($results[$x]['DisbursementVoucher']['check_ada_no_date']));
			}
			
			if(isset($result['DisbursementVoucher']['jev_no_date'])){
				$results[$x]['DisbursementVoucher']['jev_no_date'] = date('m/d/Y',strtotime($results[$x]['DisbursementVoucher']['jev_no_date']));
			}
		}

		return $results;
	}
}
?>