<?php
App::uses('AppModel', 'Model');

class Division extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public $belongsTo= array(
		'DivisionHead' => array(
			'className' => 'Employee',
			'foreignKey' => 'division_head',
			'fields' => array(
				'DivisionHead.combination_whole_name',
				
			),
			'conditions' => array(
				'DivisionHead.status' => 'Active'
			)
		),
		'DivisionAssistantHead' => array(
			'className' => 'Employee',
			'foreignKey' => 'assistant_division_head',
			'fields' => array(
				'DivisionAssistantHead.combination_whole_name',
				
			),
			'conditions' => array(
				'DivisionAssistantHead.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array(
		'DivisionHistoryLog' => array(
			'className' => 'DivisionHistoryLog',
			'foreignKey' => 'division_code',
			'fields' => array(
				'DivisionHistoryLog.division_code',
				'DivisionHistoryLog.name',
				'DivisionHistoryLog.division_head',
				'DivisionHistoryLog.assistant_division_head',
			),
			'conditions' => array(
				'DivisionHistoryLog.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'division_code',
			'fields' => array(
				'Section.code',
				'Section.name',
				'Section.section_head',
				'Section.assistant_section_head',
			),
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'division_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
	);
	
	public function add_division($data = array()) {		
		$existing_division = $this->find_existing_division_by_name($data['Division']['name']);
		
		if(isset($existing_division) && count($existing_division) > 0) {
			$existing_division['Division']['status'] = 'Active';
			$data = $existing_division;
			
		}
		return $this->saveAssociated($data);
	}
	
	public function update_division($data = array()) {
		return $this->saveAssociated($data);
	}
	
	public function update_status($division_id = null, $division = null) {
		$existing_division = $this->find_existing_division_by_id_or_code($division_id);
		
		if(isset($existing_division) && count($existing_division) > 0) {
			$existing_division['Division']['status'] = $division;
			$data = $existing_division;
		}

		return $this->save($data);
	}
	
	public function find_existing_division_by_name($division_name = null) {
		if(isset($division_name)) {
			$default_conditions = array(
				'Division.name' => $division_name
			);
		}
		
		$division = $this->find('first', array(
			'fields' => array(
				'Division.id',
				'Division.code',
				'Division.name',
				'Division.status',
				'Division.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $division;
	}
	
	public function find_existing_division_by_id_or_code($division_id = null) {
		if(is_numeric($division_id)) {
			$default_conditions = array(
				'Division.id' => $division_id
			);
		}
		else {
			$default_conditions = array(
				'Division.code' => $division_id
			);
		}
		
		$division = $this->find('first', array(
			// 'fields' => array(
				// 'Division.id',
				// 'Division.code',
				// 'Division.name',
				// 'Division.status',
				// 'Division.lock_flag',
				// 'DivisionHead.combination_whole_name',
				// 'DivisionAssistantHead.combination_whole_name',
			// ),
			'contain' => array(
				'DivisionHead',
				'DivisionAssistantHead',
				'DivisionHistoryLog',
			),
			'recursive'=>1,
			'conditions' => $default_conditions
		));
		
		return $division;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Division']['id'])) {
			$this->data['Division']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Division']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Division']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DIV';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Division']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Division']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>