<?php
App::uses('AppModel', 'Model');

class DivisionType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public $belongsTo= array(
	
		// 'DivisionAssistantHead' => array(
			// 'className' => 'Employee',
			// 'foreignKey' => 'assistant_division_type_head',
			// 'fields' => array(
				// 'DivisionAssistantHead.combination_whole_name',
				
			// ),
			// 'conditions' => array(
				// 'DivisionAssistantHead.status' => 'Active'
			// )
		// ),

	);
	
	public $hasMany = array(
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_type_code',
			'fields' => array(
				'Division.code',
				'Division.division_type_code',
				'Division.name',
				
			),
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		// 'DivisionHistoryLog' => array(
			// 'className' => 'DivisionHistoryLog',
			// 'foreignKey' => 'division_type_code',
			// 'fields' => array(
				// 'DivisionHistoryLog.division_type_code',
				// 'DivisionHistoryLog.name',
				// 'DivisionHistoryLog.division_type_head',
				// 'DivisionHistoryLog.assistant_division_type_head',
			// ),
			// 'conditions' => array(
				// 'DivisionHistoryLog.status' => 'Active'
			// )
		// ),
	);
	
	public function add_division_type($data = array()) {		
		$existing_division_type = $this->find_existing_division_type_by_name($data['DivisionType']['name']);
		
		if(isset($existing_division_type) && count($existing_division_type) > 0) {
			$existing_division_type['DivisionType']['status'] = 'Active';
			$data = $existing_division_type;
			
		}
		return $this->saveAssociated($data);
	}
	
	public function update_division_type($data = array()) {
		return $this->saveAssociated($data);
	}
	
	public function update_status($division_type_id = null, $division_type = null) {
		$existing_division_type = $this->find_existing_division_type_by_id_or_code($division_type_id);
		
		if(isset($existing_division_type) && count($existing_division_type) > 0) {
			$existing_division_type['DivisionType']['status'] = $division_type;
			$data = $existing_division_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_division_type_by_name($division_type_name = null) {
		if(isset($division_type_name)) {
			$default_conditions = array(
				'DivisionType.name' => $division_type_name
			);
		}
		
		$division_type = $this->find('first', array(
			'fields' => array(
				'DivisionType.id',
				'DivisionType.code',
				'DivisionType.name',
				'DivisionType.status',
				'DivisionType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $division_type;
	}
	
	public function find_existing_division_type_by_id_or_code($division_type_id = null) {
		if(is_numeric($division_type_id)) {
			$default_conditions = array(
				'DivisionType.id' => $division_type_id
			);
		}
		else {
			$default_conditions = array(
				'DivisionType.code' => $division_type_id
			);
		}
		
		$division_type = $this->find('first', array(
			// 'fields' => array(
				// 'Division.id',
				// 'Division.code',
				// 'Division.name',
				// 'Division.status',
				// 'Division.lock_flag',
				// 'DivisionHead.combination_whole_name',
				// 'DivisionAssistantHead.combination_whole_name',
			// ),
			// 'contain' => array(
				// 'DivisionHead',
				// 'DivisionAssistantHead',
				// 'DivisionHistoryLog',
			// ),
			'recursive'=>1,
			'conditions' => $default_conditions
		));
		
		return $division_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['DivisionType']['id'])) {
			$this->data['DivisionType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DivisionType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DivisionType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DVTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['DivisionType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['DivisionType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>