<?php
App::uses('AppModel', 'Model');

class Document extends AppModel {
	
	public $tablePrefix = 'employee_';
	// public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'employee_code' => array(
			'employee_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		'document_type_code' => array(
			'document_type_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		// 'file_path' => array(
			// 'file_path logic 1' => array(
				// 'rule'		=> 'notEmpty',
				// 'message'	=> 'Please attach a document.',
				// 'on' => 'create',
			// ),
        // ),
	);

	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'DocumentType' => array(
			'className' => 'DocumentType',
			'foreignKey' => 'document_type_code',
			'conditions' => array(
				'DocumentType.status' => 'Active'
			),
		),
		'StatementOfAssetsLiabilityAndNetworth' => array(
			'className' => 'StatementOfAssetsLiabilityAndNetworth',
			'foreignKey' => 'statement_of_assets_liability_and_networth_code',
			'conditions' => array(
				'StatementOfAssetsLiabilityAndNetworth.status' => 'Active'
			),
		),
		'EmployeeFormalCharge' => array(
			'className' => 'EmployeeFormalCharge',
			'foreignKey' => 'employee_formal_charge_code',
			'conditions' => array(
				'EmployeeFormalCharge.status' => 'Active'
			),
		),
		'OtherInformationQuestion' => array(
			'className' => 'OtherInformationQuestion',
			'foreignKey' => 'other_information_question_id',
			'conditions' => array(
				'OtherInformationQuestion.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['Document']['filing_date']) && validate_datetime($this->data['Document']['filing_date'], 'm/d/Y')) {
			$this->data['Document']['filing_date'] = convert_datetime($this->data['Document']['filing_date'], 'Y-m-d');
		}	
			
		return true;
	}
	
	public function beforeSave($options = array()) {
		// debug($this->data['Document']);
		// exit();
		if(!isset($this->data['Document']['code']) || empty($this->data['Document']['code'])) {
			$this->data['Document']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Document']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Document']['status'] = 'Active';
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = '201';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['Document']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		// debug($this->data);
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Document']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Document']['filing_date'])){
				$results[$x]['Document']['filing_date'] = date('m/d/Y',strtotime($results[$x]['Document']['filing_date']));
			}
		}

		return $results;
	}
}
?>