<?php
App::uses('AppModel', 'Model');

class DocumentType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
           'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public function add_document_type($data = array()) {		
		$existing_document_type = $this->find_existing_document_type_by_name($data['DocumentType']['name']);
		
		if(isset($existing_document_type) && count($existing_document_type) > 0) {
			$existing_document_type['DocumentType']['status'] = 'Active';
			$data = $existing_document_type;
			
		}

		return $this->save($data);
	}
	public function update_document_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($document_type_id = null, $document_type = null) {
		$existing_document_type = $this->find_existing_document_type_by_id_or_code($document_type_id);
		
		if(isset($existing_document_type) && count($existing_document_type) > 0) {
			$existing_document_type['DocumentType']['status'] = $document_type;
			$data = $existing_document_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_document_type_by_name($document_type_name = null) {
		if(isset($document_type_name)) {
			$default_conditions = array(
				'DocumentType.name' => $document_type_name
			);
		}
		
		$document_type = $this->find('first', array(
			'fields' => array(
				'DocumentType.id',
				'DocumentType.code',
				'DocumentType.name',
				'DocumentType.status',
				'DocumentType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $document_type;
	}
	
	public function find_existing_document_type_by_id_or_code($document_type_id = null) {
		if(is_numeric($document_type_id)) {
			$default_conditions = array(
				'DocumentType.id' => $document_type_id
			);
		}
		else {
			$default_conditions = array(
				'DocumentType.code' => $document_type_id
			);
		}
		
		$document_type = $this->find('first', array(
			'fields' => array(
				'DocumentType.id',
				'DocumentType.code',
				'DocumentType.name',
				'DocumentType.status',
				'DocumentType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $document_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['DocumentType']['id'])) {
			$this->data['DocumentType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DocumentType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['DocumentType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'DTYPE';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['DocumentType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['DocumentType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>