<?php
App::uses('AppModel', 'Model');

class Employee extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $primaryKey = "employee_code";
	public $displayField = 'employee_number';

	public $virtualFields=array(
		// 'vl_earn' => "PERIOD_DIFF( DATE_FORMAT(CURDATE(), '%Y%m') , DATE_FORMAT(Employee.date_hired, '%Y%m') ) * 1.25",
		// 'sl_earn' => "PERIOD_DIFF( DATE_FORMAT(CURDATE(), '%Y%m') , DATE_FORMAT(Employee.date_hired, '%Y%m') ) * 1.25" ,
		// 'spl_earn' => 5, //special privelege leave
		// 'fl_earn' => 5, //force leave
		'age' => "TIMESTAMPDIFF(YEAR,Employee.birth_date, CURDATE())",
		'years_of_service' => "TIMESTAMPDIFF(YEAR,Employee.date_hired, CURDATE())",
	);
	
	public function __construct($id = false, $table = null, $ds = null) {
		parent::__construct($id, $table, $ds);
		$this->virtualFields['combination_whole_name'] = sprintf(
			'CONCAT(%s.last_name, ", ", %s.first_name, " ", %s.middle_name)', $this->alias, $this->alias, $this->alias
		);
		
		$this->virtualFields['standard_name'] = sprintf(
			'CONCAT(%s.first_name, " ", %s.middle_initial, ". ", %s.last_name)', $this->alias, $this->alias, $this->alias
		);
	}
	
	public $belongsTo = array(
		'Suffix' => array(
			'className' => 'Suffix',
			'foreignKey' => 'suffix_code',
			'fields' => array(
				'Suffix.code',
				'Suffix.name',
			),
			'conditions' => array(
				'Suffix.status' => 'Active'
			)
		),
		
		'PrefixList' => array(
			'className' => 'PrefixList',
			'foreignKey' => 'prefix_code',
			'fields' => array(
				'PrefixList.code',
				'PrefixList.name',
			),
			'conditions' => array(
				'PrefixList.status' => 'Active'
			)
		),
		'Gender' => array(
			'className' => 'Gender',
			'foreignKey' => 'gender_code',
			'fields' => array(
				'Gender.code',
				'Gender.name',
			),
			'conditions' => array(
				'Gender.status' => 'Active'
			)
		),
		'CivilStatus' => array(
			'className' => 'CivilStatus',
			'foreignKey' => 'civil_status_code',
			'fields' => array(
				'CivilStatus.code',
				'CivilStatus.name',
			),
			'conditions' => array(
				'CivilStatus.status' => 'Active'
			)
		),
		'Nationality' => array(
			'className' => 'Nationality',
			'foreignKey' => 'nationality_code',
			'fields' => array(
				'Nationality.code',
				'Nationality.name',
			),
			'conditions' => array(
				'Nationality.status' => 'Active'
			)
		),
		'SeparationStatus' => array(
			'className' => 'SeparationStatus',
			'foreignKey' => 'separation_status_code',
			'fields' => array(
				'SeparationStatus.code',
				'SeparationStatus.name',
			),
			'conditions' => array(
				'SeparationStatus.status' => 'Active'
			)
		),
		'DocumentType' => array(
			'className' => 'DocumentType',
			'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'SeparationStatus.code',
				// 'SeparationStatus.name',
			// ),
			'conditions' => array(
				'DocumentType.status' => 'Active'
			)
		),
		'BloodType' => array(
			'className' => 'BloodType',
			'foreignKey' => 'blood_type_code',
			'fields' => array(
				'BloodType.code',
				'BloodType.name',
			),
			'conditions' => array(
				'BloodType.status' => 'Active'
			)
		),
		'IndigenousGroup' => array(
			'className' => 'IndigenousGroup',
			'foreignKey' => 'indigenous_group_code',
			'fields' => array(
				'IndigenousGroup.code',
				'IndigenousGroup.name',
			),
			'conditions' => array(
				'IndigenousGroup.status' => 'Active'
			)
		),
		'Disability' => array(
			'className' => 'Disability',
			'foreignKey' => 'disability_code',
			'fields' => array(
				'Disability.code',
				'Disability.name',
			),
			'conditions' => array(
				'Disability.status' => 'Active'
			)
		),
		'OtherPersonnelActionType' => array(
			'className' => 'OtherPersonnelActionType',
			'foreignKey' => 'other_personnel_action_type_code',
			'fields' => array(
				'OtherPersonnelActionType.code',
				'OtherPersonnelActionType.name'
			),
			'conditions' => array(
				'OtherPersonnelActionType.status' => 'Active'
			)
		),
		'CitizenshipCountry' => array(
			'className' => 'CountryList',
			'foreignKey' => 'citizenship_country_code',
			'conditions' => array(
				'CitizenshipCountry.status' => 'Active'
			)
		),
	
		
	);

	public $hasMany = array(
		// 'PermissionToLeave' => array(
			// 'className' => 'PermissionToLeave',
			// 'foreignKey' => false,
			// 'conditions' => array(
				// 'PermissionToLeave.employee_code = EmployeeSchedule.employee_code'
				
			// ),
		// ),
		'Applicant' => array(
			'className' => 'Applicant',
			'foreignKey' =>'employee_code',
			'conditions' => array(
				'Applicant.status' => 'Active',
				// 'Applicant.employee_code=Employee.employee_code'
			)
		),
		
		'LeaveEntry' => array(
			'className' => 'LeaveEntry',
			'foreignKey' =>'employee_code',
			'fields' => array(
				'LeaveEntry.id',
				'LeaveEntry.reference_number',
				'LeaveEntry.employee_code',
				'LeaveEntry.no_of_days',
				'LeaveEntry.from_date',
				'LeaveEntry.to_date',
				'LeaveEntry.leave_with_pay',
				'LeaveEntry.no_of_days_with_pay',
				'LeaveEntry.no_of_days_without_pay',
				'LeaveEntry.is_insufficient',
				'LeaveEntry.leave_classification_code',
				'LeaveEntry.filing_status',
			),
			'conditions' => array(
				'LeaveEntry.status' => 'Active',
			)
		),
		'EmployeeSmokingCessationProgram' => array(
			'className' => 'EmployeeSmokingCessationProgram',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeSmokingCessationProgram.status' => 'Active'
			),
		),
		'EmployeeLoanEntry' => array(
			'className' => 'EmployeeLoanEntry',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'EmployeeLoanEntry.id',
				'EmployeeLoanEntry.code',
				'EmployeeLoanEntry.employee_code',
				'EmployeeLoanEntry.loan_type_code',
				'EmployeeLoanEntry.date_filed',
				'EmployeeLoanEntry.reference_no',
				'EmployeeLoanEntry.loan_amount',
				'EmployeeLoanEntry.loan_with_interest',
				'EmployeeLoanEntry.monthly_amortization',
				'EmployeeLoanEntry.payment_start',
				'EmployeeLoanEntry.payment_end',
				'EmployeeLoanEntry.remarks',
				'EmployeeLoanEntry.pnno',
				'EmployeeLoanEntry.pn_date',
				'EmployeeLoanEntry.payroll_cycle',
				'EmployeeLoanEntry.deduct_loan',
			),
			'conditions' => array(
				'EmployeeLoanEntry.status' => 'Active'
			),
			 'order' => 'EmployeeLoanEntry.created ASC',
		),
		'EmployeeLeaveCard' => array(
			'className' => 'EmployeeLeaveCard',
			'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'EmployeeLeaveCard.id',
				// 'EmployeeLeaveCard.code',
				// 'EmployeeLeaveCard.employee_code',
				// 'EmployeeLeaveCard.particulars',
				// 'EmployeeLeaveCard.period',
				// 'EmployeeLeaveCard.vacation_leave_earned',
				// 'EmployeeLeaveCard.vacation_absence_with_pay',
				// 'EmployeeLeaveCard.vacation_balance_incl',
				// 'EmployeeLeaveCard.vacation_balance_excl',
				// 'EmployeeLeaveCard.vacation_absence_without_pay',
				// 'EmployeeLeaveCard.sick_leave_earned',
				// 'EmployeeLeaveCard.sick_absence_with_pay',
				// 'EmployeeLeaveCard.sick_balance_incl',
				// 'EmployeeLeaveCard.sick_balance_excl',
				// 'EmployeeLeaveCard.sick_absence_without_pay',
				// 'EmployeeLeaveCard.excess_vacation',
				// 'EmployeeLeaveCard.excess_sick',
				// 'EmployeeLeaveCard.remarks',
				
			// ),
			'conditions' => array(
				'EmployeeLeaveCard.status' => 'Active'
			)
		),
		// 'EmployeeServiceRecord' =>array(
			// 'className' => 'EmployeeServiceRecord',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'EmployeeServiceRecord.id',
				// 'EmployeeServiceRecord.employee_code',
				// 'EmployeeServiceRecord.date_from',
				// 'EmployeeServiceRecord.date_to',
				// 'EmployeeServiceRecord.designation',
				// 'EmployeeServiceRecord.service_status',
				// 'EmployeeServiceRecord.salary',
				// 'EmployeeServiceRecord.place_of_assignment',
				// 'EmployeeServiceRecord.branch',
				// 'EmployeeServiceRecord.wop',
				// 'EmployeeServiceRecord.cause_remarks',
			// ),
			// 'conditions' => array(
				// 'EmployeeServiceRecord.status' => 'Active'
			// )			
		// ),
		// 'ServiceRecord' =>array(
			// 'className' => 'ServiceRecord',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'ServiceRecord.id',
				// 'ServiceRecord.employee_code',
				// 'ServiceRecord.date_from',
				// 'ServiceRecord.date_to',
				// 'ServiceRecord.designation',
				// 'ServiceRecord.service_status',
				// 'ServiceRecord.salary',
				// 'ServiceRecord.place_of_assignment',
				// 'ServiceRecord.branch',
				// 'ServiceRecord.wop',
				// 'ServiceRecord.cause_remarks',
				// 'ServiceRecord.employment_status_code',
				// 'ServiceRecord.employment_status_name',
			// ),
			// 'conditions' => array(
				// 'ServiceRecord.status' => 'Active'
			// )			
		// ),
		'EmployeeHistoryLog' =>array(
			'className' => 'EmployeeHistoryLog',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeHistoryLog.status' => 'Active'
			)
		),
		'AddressHistoryLog' =>array(
			'className' => 'AddressHistoryLog',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'AddressHistoryLog.status' => 'Active'
			)
		),
		'HolidayAllowedEmployee' =>array(
			'className' => 'HolidayAllowedEmployee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'HolidayAllowedEmployee.status' => 'Active'
			)
		),
		'UnderTimeEntry' => array(
			'className' => 'UnderTimeEntry',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'UnderTimeEntry.status' => 'Active'
			)
		),
		'Overtime' => array(
			'className' => 'Overtime',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Overtime.status' => 'Active'
			)
		),
		'MultipleOvertimeEmployee' => array(
			'className' => 'MultipleOvertimeEmployee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'MultipleOvertimeEmployee.status' => 'Active'
			)
		),
		// 'EmployeeDeduction' => array(
			// 'className' => 'EmployeeDeduction',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeDeduction.status' => 'Active'
			// )
		// ),
		
		'EmployeeLoanEntry' => array(
			'className' => 'EmployeeLoanEntry',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeLoanEntry.status' => 'Active'
			)
		),
		'Education' => array(
			'className' => 'Education',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'Education.id',
				'Education.employee_code',
				'Education.degree_level',
				'Education.from',
				'Education.to',
				'Education.highest_level_units_earned',
				'Education.year_graduated',
				'Education.scholarship',
				'Education.remarks',
				'Education.school',
				'Education.course_degree ',
			),
			'conditions' => array(
				'Education.status' => 'Active'
			),
		),
		
		'EmployeeSchedule' =>array(
			'className' => 'EmployeeSchedule',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeSchedule.status' => 'Active'
			)
		),
		'ServiceRecord' => array(
			'className' => 'ServiceRecord',
			'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'ServiceRecord.id',
				// 'ServiceRecord.employee_code',
				// 'ServiceRecord.designation',
				// 'ServiceRecord.date_from',
				// 'ServiceRecord.date_to',
				// 'ServiceRecord.salary',
				// 'ServiceRecord.service_status',
				// 'ServiceRecord.place_of_assignment',
				// 'ServiceRecord.branch',
				// 'ServiceRecord.wop',
				// 'ServiceRecord.cause_remarks',
			// ),
			'conditions' => array(
				'ServiceRecord.status' => 'Active'
			),
		),		
		'TrainingsSeminar' => array(
			'className' => 'TrainingsSeminar',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'TrainingsSeminar.id',
				'TrainingsSeminar.employee_code',
				'TrainingsSeminar.date_from',
				'TrainingsSeminar.date_to',
				'TrainingsSeminar.activity_title',
				'TrainingsSeminar.provider',
				'TrainingsSeminar.remarks',
			),
			'conditions' => array(
				'TrainingsSeminar.status' => 'Active'
			),
		),
		'WorkHistory' => array(
			'className' => 'WorkHistory',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'WorkHistory.id',
				'WorkHistory.employee_code',
				'WorkHistory.from',
				'WorkHistory.to',
				'WorkHistory.present',
				'WorkHistory.position_title',
				'WorkHistory.department_office_company',
				'WorkHistory.monthly_salary',
				'WorkHistory.salary_job_grade',
				'WorkHistory.status_of_appointment_code',
				'WorkHistory.gov_service',
			),
			'conditions' => array(
				'WorkHistory.status' => 'Active'
			),
		),
		'TimeEntry' => array(
			'className' => 'TimeEntry',
			'foreignKey' => 'employee_code',
		),

		'EmployeeMobileNumber' => array(
			'className' => 'EmployeeMobileNumber',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeMobileNumber.status' => 'Active'
			),
		),
		
		'EmployeeEmailAddress' => array(
			'className' => 'EmployeeEmailAddress',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeEmailAddress.status' => 'Active'
			),
		),
		
		'TempEmployeeEmailAddress' => array(
			'className' => 'TempEmployeeEmailAddress',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'TempEmployeeEmailAddress.status' => 'Active'
			),
		),		
		
		'EmployeeFormalCharge' => array(
			'className' => 'EmployeeFormalCharge',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeFormalCharge.status' => 'Active'
			),
		),
		'EmployeeAdministrativeOffense' => array(
			'className' => 'EmployeeAdministrativeOffense',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeAdministrativeOffense.status' => 'Active'
			),
		),
		'EmployeeRanForPublicOffice' => array(
			'className' => 'EmployeeRanForPublicOffice',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeRanForPublicOffice.status' => 'Active'
			),
		),
		
		// 'EmployeeIncomeAndBenefit' => array(
			// 'className' => 'EmployeeIncomeAndBenefit',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeIncomeAndBenefit.status' => 'Active'
			// ),
		// ),
		'CivilService' => array(
			'className' => 'CivilService',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'CivilService.id',
				'CivilService.employee_code',
				'CivilService.career_service_code',
				'CivilService.career_service_others',
				'CivilService.rating',
				'CivilService.date_of_examination',
				'CivilService.place_of_examination',
				'CivilService.number',
				'CivilService.date_of_validity',
				'CivilService.date_passed',
				'CivilService.title',
				'CivilService.remarks',
				'CivilService.attachment',
				'CivilService.status',
				'CivilService.career_type',
				
			),
			'conditions' => array(
				'CivilService.status' => 'Active'
			),
		),
		'VoluntaryWork' => array(
			'className' => 'VoluntaryWork',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'VoluntaryWork.id',
				'VoluntaryWork.employee_code',
				'VoluntaryWork.name_address_of_organization',
				'VoluntaryWork.from',
				'VoluntaryWork.to',
				'VoluntaryWork.present',

				'VoluntaryWork.number_of_hours',
				'VoluntaryWork.position_nature_of_work',
				'VoluntaryWork.status',
				
			),
			'conditions' => array(
				'VoluntaryWork.status' => 'Active'
			),
		),
		
		'LearningAndDevelopment' => array(
			'className' => 'LearningAndDevelopment',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'LearningAndDevelopment.id',
				'LearningAndDevelopment.employee_code',
				'LearningAndDevelopment.title_of_learning_and_development',
				'LearningAndDevelopment.from',
				'LearningAndDevelopment.to',
				'LearningAndDevelopment.number_of_hours',
				'LearningAndDevelopment.type_of_ld',
				'LearningAndDevelopment.conducted_sponsored_by',
				'LearningAndDevelopment.status',
				
			),
			'conditions' => array(
				'LearningAndDevelopment.status' => 'Active'
			),
		),
		
		'OtherInformation' => array(
			'className' => 'OtherInformation',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'OtherInformation.id',
				'OtherInformation.employee_code',
				'OtherInformation.special_skill_and_hobby',
				'OtherInformation.non_academic_distinction_or_recognition',
				'OtherInformation.membership_in_association_or_organization',
				'OtherInformation.status',
				
			),
			'conditions' => array(
				'OtherInformation.status' => 'Active'
			),
		),
		
		'Reference' => array(
			'className' => 'Reference',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'Reference.id',
				'Reference.employee_code',
				'Reference.name',
				'Reference.address',
				'Reference.telephone_no',
				'Reference.status',
				
			),
			'conditions' => array(
				'Reference.status' => 'Active'
			),
		),
		
		'Dependent' => array(
			'className' => 'Dependent',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Dependent.status' => 'Active'
			),
		),
		
		'Contact' => array(
			'className' => 'Contact',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Contact.status' => 'Active'
			),
		),
		
		'RelativesInGovernment' => array(
			'className' => 'RelativesInGovernment',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'RelativesInGovernment.status' => 'Active'
			),
		),
		
		'Document' => array(
			'className' => 'Document',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Document.status' => 'Active'
			),
		),
		
		'EmployeeAdministrativeOffense' => array(
			'className' => 'EmployeeAdministrativeOffense',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeAdministrativeOffense.status' => 'Active'
			),
		),
		'EmployeeRanForPublicOffice' => array(
			'className' => 'EmployeeRanForPublicOffice',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeRanForPublicOffice.status' => 'Active'
			),
		),
		'EmployeeFormalCharge' => array(
			'className' => 'EmployeeFormalCharge',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeFormalCharge.status' => 'Active'
			),
		),
		'EmployeeFormalCharge' => array(
			'className' => 'EmployeeFormalCharge',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeFormalCharge.status' => 'Active'
			),
		),
		'StepIncrement' => array(
			'className' => 'StepIncrement',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'StepIncrement.status' => 'Active'
			),
		),
		'LeaveEarned' => array(
			'className' => 'LeaveEarned',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'LeaveEarned.status' => 'Active'
			),
		),
		
		'TempEducation' => array(
			'className' => 'TempEducation',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'TempEducation.status' => 'Active'
			),
		),
		
		'TempCivilService' => array(
			'className' => 'TempCivilService',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'TempCivilService.status' => 'Active'
			),
		),
		
		'HospitalPersonnelOrderSubmissionForDtr' => array(
			'className' => 'HospitalPersonnelOrderSubmissionForDtr',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'HospitalPersonnelOrderSubmissionForDtr.status' => 'Active'
			),
		),
		
		'HospitalPersonnelOrderSubmissionForDtrDate' => array(
			'className' => 'HospitalPersonnelOrderSubmissionForDtrDate',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'HospitalPersonnelOrderSubmissionForDtrDate.status' => 'Active'
			),
		),
		
		'LeaveClassificationEligibleEmployee' => array(
			'className' => 'LeaveClassificationEligibleEmployee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'LeaveClassificationEligibleEmployee.status' => 'Active'
			),
		),
		// 'TimeEntry' => array(
			// 'className' => 'TimeEntry',
			// 'foreignKey' => 'employee_code',
		// ),
		'LearningAndDevelopmentAssessmentTool' => array(
			'className' => 'LearningAndDevelopmentAssessmentTool',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'LearningAndDevelopmentAssessmentTool.status' => 'Active'
			)
		),
		'IndividualLearningAndDevelopmentMonitoring' => array(
			'className' => 'IndividualLearningAndDevelopmentMonitoring',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'IndividualLearningAndDevelopmentMonitoring.status' => 'Active'
			)
		),
		
	);
	
	public $hasOne = array(
		'User' => array(
			'className' => 'User',
			'foreignKey' => 'employee_code',
			'dependent' => true
		),
		'LongevityPay' => array(
			'className' => 'LongevityPay',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'LongevityPay.status' => 'Active'
			)
		),
		'LeaveUsedAndRemaining' => array(
			'className' => 'LeaveUsedAndRemaining',
			'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'LeaveUsedAndRemaining.employee_code' => 'Employee.employee_code'
			// )
		),
		'EmployeeRanForPublicOfficeForSearch' => array(
			'className' => 'EmployeeRanForPublicOffice',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeRanForPublicOfficeForSearch.status' => 'Active'
			),
		),
		'EmployeeAdministrativeOffenseForSearch' => array(
			'className' => 'EmployeeAdministrativeOffense',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeAdministrativeOffenseForSearch.status' => 'Active'
			),
		),
		'EmployeeFormalChargeForSearch' => array(
			'className' => 'EmployeeFormalCharge',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeFormalChargeForSearch.status' => 'Active'
			),
		),
		'RelativesInGovernmentForSearch' => array(
			'className' => 'RelativesInGovernment',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'RelativesInGovernmentForSearch.status' => 'Active'
			),
		),
		'EmployeeAdressForSearch' => array(
			'className' => 'EmployeeAddress',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeAdressForSearch.status' => 'Active'
			),
		),
		'EmployeeTrainingsSeminarForSearch' => array(
			'className' => 'TrainingsSeminar',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeTrainingsSeminarForSearch.status' => 'Active'
				
			),
		),
		'EmployeeTrainingsSeminarForSearch' => array(
			'className' => 'TrainingsSeminar',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeTrainingsSeminarForSearch.status' => 'Active'
				
			),
		),
		'EmployeeWorkHistoryForSearch' => array(
			'className' => 'WorkHistory',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeWorkHistoryForSearch.status' => 'Active'
				
			),
		),
		// 'EmployeeCityForSearch' => array(
			// 'className' => 'City',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeCityForSearch.status' => 'Active'
			// ),
		// ),
		
		'Address' => array(
			'className' => 'Address',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'Address.id',
				'Address.house_block_lot_no',
				'Address.street',
				'Address.subdivision_village',
				'Address.barangay_code',
				'Address.city_code',
				'Address.province_code',
				'Address.region_code',
				'Address.postal_zip_code',
				'Address.country_code',
				'Address.duplicate_address',
				'Address.pa_house_block_lot_no',
				'Address.pa_street',
				'Address.pa_subdivision_village',
				'Address.pa_barangay_code',
				'Address.pa_city_code',
				'Address.pa_province_code',
				'Address.pa_region_code',
				'Address.pa_postal_zip_code',
				'Address.pa_country_code',
			),
			'conditions' => array(
				'Address.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
		'PayrollDetail' => array(
			'className' => 'PayrollDetail',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'PayrollDetail.status' => 'Active'
			)
		),
		'BankAccountDetail' => array(
			'className' => 'BankAccountDetail',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'BankAccountDetail.id',
				'BankAccountDetail.bank_code',
				'BankAccountDetail.account_number',
			),
			'conditions' => array(
				'BankAccountDetail.status' => 'Active'
			)
		),
		// 'SectionHead' => array(
			// 'className' => 'Section',
			// 'foreignKey' => 'section_head',
			// 'conditions' => array(
				// 'SectionHead.status' => 'Active'
			// )
		// ),
		// 'SectionAssistantHead' => array(
			// 'className' => 'Section',
			// 'foreignKey' => 'assistant_section_head',
			// 'conditions' => array(
				// 'SectionAssistantHead.status' => 'Active'
			// )
		// ),
		// 'UnitHead' => array(
			// 'className' => 'Unit',
			// 'foreignKey' => 'unit_head',
			// 'conditions' => array(
				// 'UnitHead.status' => 'Active'
			// )
		// ),
		// 'UnitHeadAssistant' => array(
			// 'className' => 'Unit',
			// 'foreignKey' => 'unit_head_assistant',
			// 'conditions' => array(
				// 'UnitHeadAssistant.status' => 'Active'
			// )
		// ),
		// 'SubUnitHead' => array(
			// 'className' => 'SubUnit',
			// 'foreignKey' => 'sub_unit_head',
			// 'conditions' => array(
				// 'SubUnitHead.status' => 'Active'
			// )
		// ),
		// 'SubUnitHeadAssistant' => array(
			// 'className' => 'SubUnit',
			// 'foreignKey' => 'sub_unit_head_assistant',
			// 'conditions' => array(
				// 'SubUnitHeadAssistant.status' => 'Active'
			// )
		// ),
		// 'EmployeePayrollDetail' => array(
			// 'className' => 'EmployeePayrollDetail',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
					// 'EmployeePayrollDetail.id',
					// 'EmployeePayrollDetail.reference_code',
					// 'EmployeePayrollDetail.employee_code',
					// 'EmployeePayrollDetail.monthly_rate',
					// 'EmployeePayrollDetail.semi_monthly_rate',
					// 'EmployeePayrollDetail.daily_rate',
					// 'EmployeePayrollDetail.hourly_rate',
					// 'EmployeePayrollDetail.food_allowance',
					// 'EmployeePayrollDetail.cola',
					// 'EmployeePayrollDetail.tax_shield',
					// 'EmployeePayrollDetail.transportation_allowance',
					// 'EmployeePayrollDetail.payroll_type_code',
					// 'EmployeePayrollDetail.has_holiday_pay',
					// 'EmployeePayrollDetail.has_night_differential_pay',
					// 'EmployeePayrollDetail.pagibig_employee_share',
					// 'EmployeePayrollDetail.pagibig_employer_share',
					// 'EmployeePayrollDetail.gsis_employee_share',
					// 'EmployeePayrollDetail.gsis_employer_share',
			// ),
			// 'conditions' => array(
				// 'EmployeePayrollDetail.status' => 'Active'
			// )
		// )
		
		'OtherInformationQuestion' => array(
			'className' => 'OtherInformationQuestion',
			'foreignKey' => 'employee_code',
			
			'conditions' => array(
				'OtherInformationQuestion.status' => 'Active'
			),
		),
		
		'FamilyMember' => array(
			'className' => 'FamilyMember',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'FamilyMember.id',
				'FamilyMember.employee_code',
				'FamilyMember.spouse_surname',
				'FamilyMember.spouse_first_name',
				'FamilyMember.spouse_middle_name',
				'FamilyMember.spouse_name_extension',
				'FamilyMember.spouse_maiden_middle_name',
				'FamilyMember.spouse_occupation',
				'FamilyMember.spouse_employeer_business_name',
				'FamilyMember.spouse_employment_status',
				'FamilyMember.spouse_tin',
				'FamilyMember.spouse_business_address',
				'FamilyMember.spouse_telephone',
				'FamilyMember.spouse_combination_whole_name',
				'FamilyMember.spouse_standard_name',
				'FamilyMember.father_surname',
				'FamilyMember.father_first_name',
				'FamilyMember.father_middle_name',
				'FamilyMember.father_name_extension',
				'FamilyMember.mother_maiden_name',
				'FamilyMember.mother_surname',
				'FamilyMember.mother_first_name',
				'FamilyMember.mother_middle_name',
				'FamilyMember.status',
			),
			'conditions' => array(
				'FamilyMember.status' => 'Active'
			),
		),
		
		'GovernmentIssuedId' => array(
			'className' => 'GovernmentIssuedId',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'GovernmentIssuedId.id',
				'GovernmentIssuedId.employee_code',
				'GovernmentIssuedId.government_issued_id_no',
				'GovernmentIssuedId.id_license_passport_no',
				'GovernmentIssuedId.date_place_of_issuance',
				'GovernmentIssuedId.status',
				
			),
			'conditions' => array(
				'GovernmentIssuedId.status' => 'Active'
			),
		),
		
		'StatementOfAssetsLiabilityAndNetworth' => array(
			'className' => 'StatementOfAssetsLiabilityAndNetworth',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'StatementOfAssetsLiabilityAndNetworth.status' => 'Active'
			),
		),
		
		'LoyaltyIncentivePay' => array(
			'className' => 'LoyaltyIncentivePay',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'LoyaltyIncentivePay.status' => 'Active'
			),
		),
		
		'TempSeparationStatus' => array(
			'className' => 'TempSeparationStatus',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'TempSeparationStatus.status' => 'Active'
			),
		),
		
		'TempEmployee' => array(
			'className' => 'TempEmployee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'TempEmployee.approval_status' => 'Pending'
			),
		),		
		'TempFamilyMember' => array(
			'className' => 'TempFamilyMember',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'TempFamilyMember.approval_status' => 'Pending'
			),
		),		
		'EmployeeIncomeAndBenefit' => array(
			'className' => 'EmployeeIncomeAndBenefit',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeIncomeAndBenefit.status' => 'Active'
			),
		),
		'EmployeeDeduction' => array(
			'className' => 'EmployeeDeduction',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'EmployeeDeduction.status' => 'Active'
			)
		),
		'GeneratedPayroll' => array(
			'className' => 'GeneratedPayroll',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'GeneratedPayroll.status' => 'Active'
			)
		),
		'LatestEmployeeSmokingCessationProgram' => array(
			'className' => 'EmployeeSmokingCessationProgram',
			'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeSmokingCessationProgram.status' => 'Active'
			// ),
			// 'order'=> 'EmployeeSmokingCessationProgram.smoking_cessation_program_date DESC'
		),
		
		
	);
	
	public function update_status($employee_code = null, $employee = null, $deactivate_employee_type_code = null, $date_of_effectivity = null ) {
		
		$existing_employee = $this->find_existing_employee_by_id_or_code($employee_code);
 
		if (isset($existing_employee) && count($existing_employee) > 0) {
			$existing_employee['Employee']['employee_code'] = $employee_code;
			$existing_employee['Employee']['status'] = $employee;
			$existing_employee['Employee']['deactivate_employee_type_code']	= $deactivate_employee_type_code;
			$existing_employee['Employee']['date_of_effectivity'] = $date_of_effectivity;
			$data = $existing_employee;
		}
 
		return $this->save($data);
	}
	
	public function find_existing_employee_by_id_or_code($employee_code = null) {
		if(is_numeric($employee_code)) {
			$default_conditions = array(
				'Employee.id' => $employee_code
			);
		}
		else {
			$default_conditions = array(
				'Employee.employee_code' => $employee_code
			);
		} 
		
		$employee = $this->find('first', array(
			'fields' => array(
				'Employee.id',
				'Employee.employee_code',
				'Employee.status',
				'Employee.deactivate_employee_type_code',
			),
			'recursive'=> -1,
			'conditions' => $default_conditions
		));

		return $employee;
	}
	public $validate = array(
		 
        // 'employee_id_number' => array(
            // 'employee_id_number logic 1' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'Employee ID Number is required.'
            // ),
			// 'employee_id_number logic 2' => array(
                // 'rule' => array('isUnique',array('employee_id_number'),false),
                // 'message' => 'Employee ID Number is already exist.'
            // ),
        // ), 

        // 'employee_number' => array(
            // 'employee_number logic 1' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'Employee Number is required.'
            // ),
            // 'employee_number logic 2' => array(
                // 'rule' => array('isUnique'),
                // 'message' => 'Employee Number is already used.'
            // ),
        // ), 

        'first_name' => array(
            'first_name logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'First Name is required.'
            ),
			// 'first_name logic 2' => array(
                // 'rule' => array('isUnique',array('first_name', 'last_name'),false),
                // 'message' => 'This Name is already exist.',
				// 'on'=>'create'
            // ),
        ),
		// 'employee_number' => array(
            // 'employee_number logic 1' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'Employee Number is required.'
            // ),
			
        // ),
		'employee_number' => array(
            'employee_number logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Employee Number is required.'
            ),
			'employee_number logic 2' => array(
                'rule' => array('isUnique',array('employee_number'),false),
                'message' => 'Employee Number is already Exist',
				'on'=>'create'
            ),
        ),
		'last_name' => array(
            'last_name logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'First name is required.'
            ),
			'last_name logic 2' => array(
                'rule'    => array('maxLength', 50),
                'message' => 'Last name must be no longer than 100 characters.'
            ),
			// 'last_name logic 2' => array(
                // 'rule' => array('isUnique',array('last_name', 'first_name'),false),
                // 'message' => 'This Name is already exist.',
				// 'on'=>'create'
            // ),
        ),   
		
		'plantilla_number' => array(
			'plantilla_number logic 1' => array(
                'rule' => array('isUnique',array('plantilla_number'),false),
				'allowEmpty' => true,
                'message' => 'This Plantilla No. is already exist.',
				'on'=>'create'
				
            )
        ),  
		
		'biometric_id' => array(
			'biometric_id logic 1' => array(
                'rule' => array('isUnique',array('biometric_id'),false),
				'allowEmpty' => true,
                'message' => 'This Biometric is already exist.',
				
            )
        ),    		
        'philhealth' => array(
            'philhealth logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'PHILHEALTH is required.'
            ), 
        ),
        'tin' => array(
            'tin logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'TIN is required.'
            ), 
        ),
		// 'birth_date' => array(
		    // 'birth_date logic 1' => array(
		        // 'rule' => array('notEmpty'),
		        // 'message' => 'Birth Date is required.'
		    // ),
		    // 'birth_date logic 2' => array(
		        // 'rule' => array('date'),
		        // 'message' => 'Enter a valid date'
		    // ),

		// ),

		// 'civil_status_code' => array(
		    // 'civil_status_code logic 1' => array(
		        // 'rule' => array('notEmpty'),
		        // 'message' => 'Civil Status is required.'
		    // )
		// ),
		
		// 'biometric_id' => array(
            // 'biometric_id logic 1' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'Biometric ID Number is required.'
            // ),
        // ), 
		
        // 'biometric_id' => array(
            // 'biometric_id logic 1' => array(
                // 'rule' => array('isUnique'),
                // 'message' => 'Biometric ID is already used.'
            // ),
			// 'biometric_id logic 2' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'Biometric ID is required.'
            // ),
        // ),
		
		// 'gsis' => array(
            // 'gsis logic 1' => array(
                // 'rule' => array('isUnique'),
				// 'allowEmpty' => true,
                // 'message' => 'GSIS No. is already used.'
            // ),
			// 'gsis logic 2' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'GSIS No. is required.'
            // ),
        // ),
		
		// 'pagibig' => array(
            // 'pagibig logic 1' => array(
                // 'rule' => array('isUnique'),
				// 'allowEmpty' => true,
                // 'message' => 'PAGIBIG No. is already used.'
            // ),
			// 'pagibig logic 2' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'PAGIBIG No. is required.'
            // ),
        // ),
		
		// 'philhealth' => array(
            // 'philhealth logic 1' => array(
                // 'rule' => array('isUnique'),
				// 'allowEmpty' => true,
                // 'message' => 'PHIC No. is already used.'
            // ),
			// 'philhealth logic 2' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'PHIC No. is required.'
            // ),
        // ),
		
		// 'sss' => array(
            // 'sss logic 1' => array(
                // 'rule' => array('isUnique'),
                // 'message' => 'SSS No. is already used.'
            // ),
			// 'sss logic 2' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'SSS No. is required.'
            // ),
        // ),
		
		// 'tin' => array(
            // 'tin logic 1' => array(
                // 'rule' => array('isUnique'),
				// 'allowEmpty' => true,
                // 'message' => 'TIN No. is already used.'
            // ),
			// 'tin logic 2' => array(
                // 'rule' => array('notEmpty'),
                // 'message' => 'TIN No. is required.'
            // ),
        // ),
		
		 
        'status' => array(
            'status logic 1' => array(
                'rule' => array('inList', array('Active', 'Disabled','Inactive')),
                'message' => 'Please select a status.',
                'allowEmpty' => false
            )
        ),
		
		
		
		
    );	
	
	public function beforeValidate($options = array()) {

		if(isset($this->data['Employee']['birth_date']) && validate_datetime($this->data['Employee']['birth_date'], 'm/d/Y')) {
			$this->data['Employee']['birth_date'] = convert_datetime($this->data['Employee']['birth_date'], 'Y-m-d');
		}		
		if(isset($this->data['Employee']['assumption_date']) && validate_datetime($this->data['Employee']['assumption_date'], 'm/d/Y')) {
			$this->data['Employee']['assumption_date'] = convert_datetime($this->data['Employee']['assumption_date'], 'Y-m-d');
		}		
		if(isset($this->data['Employee']['renewal_date']) && validate_datetime($this->data['Employee']['renewal_date'], 'm/d/Y')) {
			$this->data['Employee']['renewal_date'] = convert_datetime($this->data['Employee']['renewal_date'], 'Y-m-d');
		}	
		if(isset($this->data['Employee']['date_hired']) && validate_datetime($this->data['Employee']['date_hired'], 'm/d/Y')) {
			$this->data['Employee']['date_hired'] = convert_datetime($this->data['Employee']['date_hired'], 'Y-m-d');
		}
		if(isset($this->data['Employee']['step_increment_date']) && validate_datetime($this->data['Employee']['step_increment_date'], 'm/d/Y')) {
			$this->data['Employee']['step_increment_date'] = convert_datetime($this->data['Employee']['step_increment_date'], 'Y-m-d');
		}
		
		if(isset($this->data['Employee']['effectivity_date']) && validate_datetime($this->data['Employee']['effectivity_date'], 'm/d/Y')) {
			$this->data['Employee']['effectivity_date'] = convert_datetime($this->data['Employee']['effectivity_date'], 'Y-m-d');
		}
		
		if(isset($this->data['Employee']['since_date']) && validate_datetime($this->data['Employee']['since_date'], 'm/d/Y')) {
			$this->data['Employee']['since_date'] = convert_datetime($this->data['Employee']['since_date'], 'Y-m-d');
		}
		
		if(isset($this->data['Employee']['date_of_effectivity']) && validate_datetime($this->data['Employee']['date_of_effectivity'], 'm/d/Y')) {
			$this->data['Employee']['date_of_effectivity'] = convert_datetime($this->data['Employee']['date_of_effectivity'], 'Y-m-d');
		}
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Employee']['employee_code'])) {
			$this->data['Employee']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Employee']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Employee']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'EMP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Employee']['employee_code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			// $this->data['Employee']['status'] = 'Active';
			$this->data['Employee']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Employee']['date_last_modified'] = date("Y-m-d");
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Employee']['birth_date'])){
				$results[$x]['Employee']['birth_date'] = date('m/d/Y',strtotime($results[$x]['Employee']['birth_date']));
			}
			if(isset($result['Employee']['date_hired'])){
				$results[$x]['Employee']['date_hired'] = date('m/d/Y',strtotime($results[$x]['Employee']['date_hired']));
			}
			if(isset($result['Employee']['assumption_date'])){
				$results[$x]['Employee']['assumption_date'] = date('m/d/Y',strtotime($results[$x]['Employee']['assumption_date']));
			}
			if(isset($result['Employee']['renewal_date'])){
				$results[$x]['Employee']['renewal_date'] = date('m/d/Y',strtotime($results[$x]['Employee']['renewal_date']));
			}
			if(isset($result['Employee']['step_increment_date'])){
				$results[$x]['Employee']['step_increment_date'] = date('m/d/Y',strtotime($results[$x]['Employee']['step_increment_date']));
			}
			
			if(isset($result['Employee']['effectivity_date'])){
				$results[$x]['Employee']['effectivity_date'] = date('m/d/Y',strtotime($results[$x]['Employee']['effectivity_date']));
			}
			
			if(isset($result['Employee']['since_date'])){
				$results[$x]['Employee']['since_date'] = date('m/d/Y',strtotime($results[$x]['Employee']['since_date']));
			}
			
			if(isset($result['Employee']['date_of_effectivity'])){
				$results[$x]['Employee']['date_of_effectivity'] = date('m/d/Y',strtotime($results[$x]['Employee']['date_of_effectivity']));
			}
			// if(isset($result['FamilyMember']['FamilyMemberChildren'])){
				// $results[$x]['Employee']['since_date'] = date('m/d/Y',strtotime($results[$x]['Employee']['since_date']));
			// }
		}
		 // debug($results);		
		// exit();
		return $results;
	}
}
?>