<?php
App::uses('AppModel', 'Model');

class EmployeeCodeGenerator extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'code';
	
	public $validate = array(
        'reference' => array(
			'reference logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Reference is already used.',
			),
			'reference logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Reference is required.'
			),
        ),
	);
	public $belongsTo = array(
		'EmploymentStatus' => array(
			'className' => 'EmploymentStatus',
			'foreignKey' => 'employment_status_code',
			
			// 'conditions' => array(
				// 'Suffix.status' => 'Active'
			// )
		),
	);	
	
	
	public function add_employee_code_generator($data = array()) {		
		$existing_employee_code_generator = $this->find_existing_employee_code_generator_by_name($data['EmployeeCodeGenerator']['name']);
		
		if(isset($existing_employee_code_generator) && count($existing_employee_code_generator) > 0) {
			$existing_employee_code_generator['EmployeeCodeGenerator']['status'] = 'Active';
			$data = $existing_employee_code_generator;
			
		}

		return $this->save($data);
	}
	
	public function update_employee_code_generator($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($employee_code_generator_id = null, $employee_code_generator = null) {
		$existing_employee_code_generator = $this->find_existing_employee_code_generator_by_id_or_code($employee_code_generator_id);

		if(isset($existing_employee_code_generator) && count($existing_employee_code_generator) > 0) {
			$existing_employee_code_generator['EmployeeCodeGenerator']['status'] = $employee_code_generator;
			$data = $existing_employee_code_generator;
		}
		return $this->save($data);
	}
	
	public function find_existing_employee_code_generator_by_name($employee_code_generator_name = null) {
		if(isset($employee_code_generator_name)) {
			$default_conditions = array(
				'EmployeeCodeGenerator.employment_status_code' => $employee_code_generator_name
			);
		}
		
		$employee_code_generator = $this->find('first', array(
			'fields' => array(
				'EmployeeCodeGenerator.id',
				'EmployeeCodeGenerator.code',
				'EmployeeCodeGenerator.employment_status_code',
				'EmployeeCodeGenerator.status',
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $employee_code_generator;
	}
	public function find_existing_employee_code_generator_by_id_or_code($employee_code_generator_id = null) {
		if(is_numeric($employee_code_generator_id)) {
			$default_conditions = array(
				'EmployeeCodeGenerator.id' => $employee_code_generator_id
			);
		}
		else {
			$default_conditions = array(
				'EmployeeCodeGenerator.code' => $employee_code_generator_id
			);
		}
		
		$employee_code_generator = $this->find('first', array(
			'fields' => array(
				'EmployeeCodeGenerator.id',
				'EmployeeCodeGenerator.code',
				'EmployeeCodeGenerator.employment_status_code',
				'EmployeeCodeGenerator.status',
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $employee_code_generator;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['EmployeeCodeGenerator']['id'])) {
			$this->data['EmployeeCodeGenerator']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeCodeGenerator']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeCodeGenerator']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SECG';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['EmployeeCodeGenerator']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['EmployeeCodeGenerator']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>