<?php
App::uses('AppModel', 'Model');

class EmployeeHistoryLog extends AppModel {
	
	public $belongsTo = array(
		'Suffix' => array(
			'className' => 'Suffix',
			'foreignKey' => 'suffix_code',
			'fields' => array(
				'Suffix.code',
				'Suffix.name',
			),
			'conditions' => array(
				'Suffix.status' => 'Active'
			)
		),
		'PrefixList' => array(
			'className' => 'PrefixList',
			'foreignKey' => 'prefix_code',
			'fields' => array(
				'PrefixList.code',
				'PrefixList.name',
			),
			'conditions' => array(
				'PrefixList.status' => 'Active'
			)
		),
		'Gender' => array(
			'className' => 'Gender',
			'foreignKey' => 'gender_code',
			'fields' => array(
				'Gender.code',
				'Gender.name',
			),
			'conditions' => array(
				'Gender.status' => 'Active'
			)
		),
		'CivilStatus' => array(
			'className' => 'CivilStatus',
			'foreignKey' => 'civil_status_code',
			'fields' => array(
				'CivilStatus.code',
				'CivilStatus.name',
			),
			'conditions' => array(
				'CivilStatus.status' => 'Active'
			)
		),
		'BloodType' => array(
			'className' => 'BloodType',
			'foreignKey' => 'blood_type_code',
			'fields' => array(
				'BloodType.code',
				'BloodType.name',
			),
			'conditions' => array(
				'BloodType.status' => 'Active'
			)
		),
		'Nationality' => array(
			'className' => 'Nationality',
			'foreignKey' => 'nationality_code',
			'fields' => array(
				'Nationality.code',
				'Nationality.name',
			),
			'conditions' => array(
				'Nationality.status' => 'Active'
			)
		),
		'SeparationStatus' => array(
			'className' => 'SeparationStatus',
			'foreignKey' => 'separation_status_code',
			'fields' => array(
				'SeparationStatus.code',
				'SeparationStatus.name',
			),
			'conditions' => array(
				'SeparationStatus.status' => 'Active'
			)
		),
		'CountryList' => array(
			'className' => 'CountryList',
			'foreignKey' => 'citizenship_country_code',
			'fields' => array(
				'CountryList.code',
				'CountryList.name',
			),
			'conditions' => array(
				'CountryList.status' => 'Active'
			)
		),
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			)
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['EmployeeHistoryLog']['birth_date']) && validate_datetime($this->data['EmployeeHistoryLog']['birth_date'], 'm/d/Y')) {
			$this->data['EmployeeHistoryLog']['birth_date'] = convert_datetime($this->data['EmployeeHistoryLog']['birth_date'], 'Y-m-d');
		}
		if(isset($this->data['EmployeeHistoryLog']['date_hired']) && validate_datetime($this->data['EmployeeHistoryLog']['date_hired'], 'm/d/Y')) {
			$this->data['EmployeeHistoryLog']['date_hired'] = convert_datetime($this->data['EmployeeHistoryLog']['date_hired'], 'Y-m-d');
		}	
		if(isset($this->data['EmployeeHistoryLog']['step_increment_date']) && validate_datetime($this->data['EmployeeHistoryLog']['step_increment_date'], 'm/d/Y')) {
			$this->data['EmployeeHistoryLog']['step_increment_date'] = convert_datetime($this->data['EmployeeHistoryLog']['step_increment_date'], 'Y-m-d');
		}		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['EmployeeHistoryLog']['id'])) {
			$this->data['EmployeeHistoryLog']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeHistoryLog']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeHistoryLog']['status'] = 'Active';
		}
		else {
			$this->data['EmployeeHistoryLog']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeHistoryLog']['date_last_modified'] = date("Y-m-d");
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['EmployeeHistoryLog']['birth_date'])){
				$results[$x]['EmployeeHistoryLog']['birth_date'] = date('m/d/Y',strtotime($results[$x]['EmployeeHistoryLog']['birth_date']));
			}
			
			if(isset($result['EmployeeHistoryLog']['date_hired'])){
				$results[$x]['EmployeeHistoryLog']['date_hired'] = date('m/d/Y',strtotime($results[$x]['EmployeeHistoryLog']['date_hired']));
			}
			
			if(isset($result['EmployeeHistoryLog']['step_increment_date'])){
				$results[$x]['EmployeeHistoryLog']['step_increment_date'] = date('m/d/Y',strtotime($results[$x]['EmployeeHistoryLog']['step_increment_date']));
			}
		}

		return $results;
	}
}
?>