<?php
App::uses('AppModel', 'Model');

class EmployeeLeaveCard extends AppModel {
	
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	// public $displayField = 'name';
	
	public $validate = array(
		'leave_quantity' => array(
			'leave_quantity logic 2' => array(
				'rule'		=> array('validate_leave_quantity'),
				'message'	=> 'Remaining Leave Balance after adjustment should not be less than 0'
			),
        ),
		'leave_with_out_pay_quantity' => array(
			'leave_with_out_pay_quantity logic 2' => array(
				'rule'		=> array('validate_leave_with_out_pay_quantity'),
				'message'	=> 'Remaining Leave Balance after adjustment should not be less than 0'
			),
        ),
	);
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
		),
		'GeneratedPayroll' => array(
			'className' => 'GeneratedPayroll',
			'foreignKey' => 'generated_payroll_code',
		),
		'LeaveEntry' => array(
			'className' => 'LeaveEntry',
			// 'foreignKey' => 'leave_entry_code',
            'foreignKey' => 'leave_entry_reference_number',
			'fields' => array(
				'LeaveEntry.*',
			),
		),
		'LeaveClassification' => array(
			'className' => 'LeaveClassification',
			'foreignKey' => 'leave_classification_code',
			'fields' => array(
				'LeaveClassification.*',
			),
		),
	);
	public function validate_leave_with_out_pay_quantity($validation_fields = array()) {
		
		if(isset($this->data['EmployeeLeaveCard']['leave_with_out_pay_quantity'])){
			$leave_with_out_pay_quantity = number_format($this->data['EmployeeLeaveCard']['leave_with_out_pay_quantity'] , 2 , '.' , '');
		}
		else{
			$leave_with_out_pay_quantity = 0;
		}
			
		if($leave_with_out_pay_quantity < 0){
			
			return false;
		}
		else{
			return true;
		}
		return true;
	
	}
	public function validate_leave_quantity($validation_fields = array()) {
	
		$leave_quantity = number_format($this->data['EmployeeLeaveCard']['leave_quantity'] , 2 , '.' , '');

		if(isset($this->data['EmployeeLeaveCard']['current_leave_credit'])){
			$current_leave_credit = number_format($this->data['EmployeeLeaveCard']['current_leave_credit'] , 2 , '.', '');
		}
		else{
			$current_leave_credit = null;
		}
		$x = $this->validate_leave_quantity_and_current_leave_balance($leave_quantity , $current_leave_credit );
		
		
		if($x == 1){
			
			return false;
		}
		else{
			
			return true;
		}
	}
	
	public function validate_leave_quantity_and_current_leave_balance($leave_quantity = null , $current_leave_credit = null) {

	
		if($current_leave_credit != null){
			
			if($leave_quantity > $current_leave_credit){
				$x = 1;
			}
			else{
				$x = 0;
			}
			
		}
		else{
			$x = 0;
		}
		
		return $x;
	
	}


	public function beforeSave($options = array()) {
		// exit();
		if(!isset($this->data['EmployeeLeaveCard']['id'])) {
			$this->data['EmployeeLeaveCard']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeLeaveCard']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeLeaveCard']['status'] = 'Active';


			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'ELC';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			
			$this->data['EmployeeLeaveCard']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");

		}
		else {
			$this->data['EmployeeLeaveCard']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		if(isset($this->data['EmployeeLeaveCard']['month'])) {
			$this->data['EmployeeLeaveCard']['month'] =  (str_pad($this->data['EmployeeLeaveCard']['month'],2,"0",STR_PAD_LEFT));
		}
		// debug($this->data);
		// exit();
		
		return true;
	}
	
	public function afterFind($results, $primary = false) {
		foreach($results as $x => $result){
			if (isset($result['EmployeeLeaveCard']['leave_balance'])) {
				$results[$x]['EmployeeLeaveCard']['leave_balance'] = convert_to_formatted_number_dec_3($results[$x]['EmployeeLeaveCard']['leave_balance']);
			}
			
				
		}

		return $results;
	}
}
?>