<?php
App::uses('AppModel', 'Model');

class EmployeeLoanEntry extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'loan_type_code';
	
	public $validate = array(
        'loan_term' => array(
			'loan_term logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Loan Term is required.',
			),
        ),
		'monthly_amortization' => array(
			'monthly_amortization logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Monthly Amortization is required.',
			),
        ),
		'payment_start' => array(
			'payment_start logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Payment Start is required.',
			),
        ),
		'payment_end' => array(
			'payment_end logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Payment End is required.',
			),
        ),
		'remarks' => array(
			'remarks logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Remarks is required.',
			),
        ),
	);
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
		),
		'LoanType' => array(
			'className' => 'LoanType',
			'foreignKey' => 'loan_type_code',
		),
	);

	public $hasMany = array(
		'EmployeeLoanPayment' => array(
			'className' => 'EmployeeLoanPayment',
			'foreignKey' => 'loan_entry_code',
			'fields' => array(
				'EmployeeLoanPayment.id',
				'EmployeeLoanPayment.code',
				'EmployeeLoanPayment.loan_entry_code',
				'EmployeeLoanPayment.employee_code',
				'EmployeeLoanPayment.paid_amount',
				'EmployeeLoanPayment.payment_date',
				'EmployeeLoanPayment.remarks',
			),
			'conditions' => array(
				'EmployeeLoanPayment.status' => 'Active'
			)
		),
		'EmployeeLoanPaymentSchedule' => array(
			'className' => 'EmployeeLoanPaymentSchedule',
			'foreignKey' => 'employee_loan_entry_code',
		),
		'EmployeeLoanEntryAttachment' => array(
			'className' => 'EmployeeLoanEntryAttachment',
			'foreignKey' => 'employee_loan_entry_code',
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['EmployeeLoanEntry']['date_filed']) && validate_datetime($this->data['EmployeeLoanEntry']['date_filed'], 'm/d/Y')) {
			$this->data['EmployeeLoanEntry']['date_filed'] = convert_datetime($this->data['EmployeeLoanEntry']['date_filed'], 'Y-m-d');
		}		
		
		if(isset($this->data['EmployeeLoanEntry']['pn_date']) && validate_datetime($this->data['EmployeeLoanEntry']['pn_date'], 'm/d/Y')) {
			$this->data['EmployeeLoanEntry']['pn_date'] = convert_datetime($this->data['EmployeeLoanEntry']['pn_date'], 'Y-m-d');
		}else{
			$this->data['EmployeeLoanEntry']['pn_date'] = null;
		}	
		
		return true;
	}

	public function beforeSave($options = array()) {
		// debug($this->data);
		// exit();
		if(!isset($this->data['EmployeeLoanEntry']['id'])) {
			$this->data['EmployeeLoanEntry']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeLoanEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeLoanEntry']['status'] = 'Active';


			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'ELEN';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			$this->data['EmployeeLoanEntry']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
			
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char1 = 'LERN';
			$reference = $ReferenceCode->findByPrefixCode($code_char1);
			$code_number1 = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char1'");
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char2 = 'LRNO';
			$reference = $ReferenceCode->findByPrefixCode($code_char2);
			$code_number2 = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number2' WHERE prefix_code = '$code_char2'");
			
			// debug($year);
			// debug(date('Y'));
			// exit();
			
			
			if($year != date('Y')){
				$year = date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number = 1;
			}
			
			

		}
		else {
			$this->data['EmployeeLoanEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['EmployeeLoanEntry']['date_filed'])){
				$results[$x]['EmployeeLoanEntry']['date_filed'] = date('m/d/Y',strtotime($results[$x]['EmployeeLoanEntry']['date_filed']));
			}
			
			if(isset($result['EmployeeLoanEntry']['pn_date'])){
				
				$results[$x]['EmployeeLoanEntry']['pn_date'] = date('m/d/Y',strtotime($results[$x]['EmployeeLoanEntry']['pn_date']));
			}
		}

		return $results;
	}
}
?>
