<?php
App::uses('AppModel', 'Model');

class EmployeePerformanceAppraisal extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'employee_';
	// public $primaryKey = 'code';
	public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				// 'Employee.status' => 'Active'
			),
		),
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'fields' => array(
				'Section.code',
				'Section.name',
			),
			'conditions' => array(
				'Section.status' => 'Active'
			),
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'fields' => array(
				'Division.code',
				'Division.name',
			),
			'conditions' => array(
				'Division.status' => 'Active'
			),
		),
		// 'Division' => array(
		// 	'className' => 'Division',
		// 	'foreignKey' => 'division_code',
			// 'fields' => array(
			// 	'Division.code',
			// 	'Division.name',
			// ),
		// 	'conditions' => array(
		// 		'Division.status' => 'Active'
		// 	)
		// ),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'fields' => array(
				'Unit.code',
				'Unit.name',
			),
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'fields' => array(
				'SubUnit.code',
				'SubUnit.name',
			),
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
	);

	public $hasMany = array(
		'EmployeePerformanceAppraisalAttribute' => array(
			'className' => 'EmployeePerformanceAppraisalAttribute',
			'foreignKey' => 'performance_appraisal_id',
			'fields' => array(
				'EmployeePerformanceAppraisalAttribute.id',
				'EmployeePerformanceAppraisalAttribute.performance_appraisal_id',
				'EmployeePerformanceAppraisalAttribute.attribute_id',
				'EmployeePerformanceAppraisalAttribute.self_rating',
				'EmployeePerformanceAppraisalAttribute.head_rating',
			),
			'conditions' => array(
				'EmployeePerformanceAppraisalAttribute.status' => 'Active'
			)
		),
		'Document' => array(
			'className' => 'Document',
			'foreignKey' => 'performance_appraisal_id',

			'conditions' => array(
				'Document.status' => 'Active'
			)
		),
	);
	
	public $hasOne = array(
		// 'Document' => array(
			// 'className' => 'Document',
			// 'foreignKey' => 'performance_appraisal_id',
			// 'fields' => array(
				// 'Document.id',
				// 'Document.code',
				// 'Document.employee_code',
				// 'Document.performance_appraisal_id',
				// 'Document.document_type_code',
				// 'Document.document_name',
				// 'Document.file_path',
				// 'Document.filing_date',
			// ),
			// 'conditions' => array(
				// 'Document.status' => 'Active'
			// )
		// ),
	);

	public function beforeValidate($options = array()) {
		if(isset($this->data['EmployeePerformanceAppraisal']['date']) && validate_datetime($this->data['EmployeePerformanceAppraisal']['date'], 'm/d/Y')) {
			$this->data['EmployeePerformanceAppraisal']['date'] = convert_datetime($this->data['EmployeePerformanceAppraisal']['date'], 'Y-m-d');
		}
	
		if(isset($this->data['EmployeePerformanceAppraisal']['appraisal_from']) && validate_datetime($this->data['EmployeePerformanceAppraisal']['appraisal_from'], 'm/d/Y')) {
			$this->data['EmployeePerformanceAppraisal']['appraisal_from'] = convert_datetime($this->data['EmployeePerformanceAppraisal']['appraisal_from'], 'Y-m-d');
		}

		if(isset($this->data['EmployeePerformanceAppraisal']['appraisal_to']) && validate_datetime($this->data['EmployeePerformanceAppraisal']['appraisal_to'], 'm/d/Y')) {
			$this->data['EmployeePerformanceAppraisal']['appraisal_to'] = convert_datetime($this->data['EmployeePerformanceAppraisal']['appraisal_to'], 'Y-m-d');
		}

		if(isset($this->data['EmployeePerformanceAppraisal']['date_hired']) && validate_datetime($this->data['EmployeePerformanceAppraisal']['date_hired'], 'm/d/Y')) {
			$this->data['EmployeePerformanceAppraisal']['date_hired'] = convert_datetime($this->data['EmployeePerformanceAppraisal']['date_hired'], 'Y-m-d');
		}
		return true;
	}


	public function beforeSave($options = array()) {
		if(!isset($this->data['EmployeePerformanceAppraisal']['id'])) {
			$this->data['EmployeePerformanceAppraisal']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeePerformanceAppraisal']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeePerformanceAppraisal']['status'] = 'Active';
		}
		else {
			$this->data['EmployeePerformanceAppraisal']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['EmployeePerformanceAppraisal']['date'])){
				$results[$x]['EmployeePerformanceAppraisal']['date'] = date('m/d/Y',strtotime($results[$x]['EmployeePerformanceAppraisal']['date']));
			}
			if(isset($result['EmployeePerformanceAppraisal']['appraisal_from'])){
				$results[$x]['EmployeePerformanceAppraisal']['appraisal_from'] = date('m/d/Y',strtotime($results[$x]['EmployeePerformanceAppraisal']['appraisal_from']));
			}
			if(isset($result['EmployeePerformanceAppraisal']['appraisal_to'])){
				$results[$x]['EmployeePerformanceAppraisal']['appraisal_to'] = date('m/d/Y',strtotime($results[$x]['EmployeePerformanceAppraisal']['appraisal_to']));
			}
			if(isset($result['EmployeePerformanceAppraisal']['date_hired'])){
				$results[$x]['EmployeePerformanceAppraisal']['date_hired'] = date('m/d/Y',strtotime($results[$x]['EmployeePerformanceAppraisal']['date_hired']));
			}
		}
		return $results;
	}
	
	
}
?>