<?php
App::uses('AppModel', 'Model');

class EmployeeRanForPublicOffice extends AppModel {
	
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	public $belongsTo = array(
		'GovernmentOfficialPosition' => array(
			'className' => 'GovernmentOfficialPosition',
			'foreignKey' => 'government_official_position_code',
		),
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
		),
	);
	
	public $validate = array(
        'election_year' => array(
			'election_year logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Election Year is required.'
			),
			'election_year logic 2' => array(
				'rule'		=> array('validate_election_year_for_negative_number'),
				'message'	=> 'Election Year should be not a negative value.'
			),
			'election_year logic 2' => array(
				'rule'		=> array('validate_election_year_for_greater_than_current_year', 0),
				'message'	=> 'Election Year should not be greater than current year.'
			),
			
        ),
		  'government_official_position_code' => array(
			'government_official_position_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Government Official Position is required.'
			),
		)
	);
	
	public function validate_election_year_for_negative_number($validation_fields = array()) {
		$election_year = $this->data['EmployeeRanForPublicOffice']['election_year'];
		
		if ($election_year <= 0){
			return false;
		}
		else{
			return true;
		}
		
	}
	
	public function validate_election_year_for_greater_than_current_year($validation_fields = array()) {
		$election_year = $this->data['EmployeeRanForPublicOffice']['election_year'];
		$current_year = date('Y');
		if ($election_year > $current_year){
			return false;
		}
		else{
			return true;
		}
		
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['EmployeeRanForPublicOffice']['id'])) {
			$this->data['EmployeeRanForPublicOffice']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeRanForPublicOffice']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeRanForPublicOffice']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'RFPO';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['EmployeeRanForPublicOffice']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['EmployeeRanForPublicOffice']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>