<?php
App::uses('AppModel', 'Model');

class EmployeeSchedule extends AppModel {
	
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'Employee.employee_number',
				// 'Employee.employee_code',
				// 'Employee.combination_whole_name'
			// )
		),'ScheduleType' => array(
			'className' => 'ScheduleType',
			'foreignKey' => 'schedule_type_code',
		),'Schedule' => array(
			'className' => 'Schedule',
			'foreignKey' => 'schedule_code',
		),
		'Shift' => array(
			'className' => 'Shift',
			'foreignKey' => 'shift_code',
			'fields' => array(
				'Shift.id',
				'Shift.code',
				'Shift.name',
				'Shift.shift_type_code',
				'Shift.time_in',
				'Shift.break_in',
				'Shift.break_out',
				'Shift.time_out',
				'Shift.no_of_hours',
				'Shift.color',
			),
			'conditions'=>array(
				'Shift.status'=>'Active'
			)
		),
		'PreviousShift' => array(
			'className' => 'Shift',
			'foreignKey' => 'previous_shift_code',
			'fields' => array(
				'PreviousShift.id',
				'PreviousShift.code',
				'PreviousShift.name',
				'PreviousShift.shift_type_code',
				'PreviousShift.time_in',
				'PreviousShift.break_in',
				'PreviousShift.break_out',
				'PreviousShift.time_out',
				'PreviousShift.no_of_hours',
				'PreviousShift.color',
			),
			'conditions'=>array(
				'PreviousShift.status'=>'Active'
			)
		),
		// 'TimeEntry' => array(
			// 'className' => 'TimeEntry',
			// 'foreignKey' => false,
			// 'conditions' => array(
				// 'TimeEntry.schedule_code = EmployeeSchedule.code'
				
			// ),
		// ),
		'Holiday' => array(
			'className' => 'Holiday',
			'foreignKey' => false,
			'conditions'=>array(
				'Holiday.holiday_date=EmployeeSchedule.schedule_date',
				'Holiday.status'=>'Active'
			)
		)
		// 'PermissionToLeave' => array(
			// 'className' => 'PermissionToLeave',
			// 'foreignKey' => false,
			// 'conditions' => array(
				// 'PermissionToLeave.employee_code = EmployeeSchedule.employee_code'
				
			// ),
		// ),
		
	);
	// public $hasMany = array(
		// 'PermissionToLeave' => array(
			// 'className' => 'PermissionToLeave',
			// 'foreignKey' => false,
			// 'conditions' => array(
				// 'PermissionToLeave.employee_code = EmployeeSchedule.employee_code'
				
			// ),
		// ),
	// );
	public $hasOne = array(
		'TimeEntry' => array(
			'className' => 'TimeEntry',
			'foreignKey' => 'schedule_code',
			'conditions' => array(
				// 'TimeEntry.schedule_code = EmployeeSchedule.code',
				'TimeEntry.status' => 'Active',
				
			),
		),
	);
	public $validate = array(
		'shift_code' => array(
			'shift_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Schedule is required.'
			),
        ),
	);	
	public function beforeSave($options = array()) {
		
		if(!isset($this->data['EmployeeSchedule']['code'])) {
			$this->data['EmployeeSchedule']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeSchedule']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeSchedule']['created_by_user'] = $_SESSION['Auth']['User']['Employee']['combination_whole_name'];
			// debug($this->data);
			// exit();
			$this->data['EmployeeSchedule']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'ESCHED';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['EmployeeSchedule']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,9,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			// debug($this->data);
		// exit();
			$this->data['EmployeeSchedule']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		// debug($this->data);
		// exit();
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['EmployeeSchedule']['schedule_date'])){
				$results[$x]['EmployeeSchedule']['schedule_date'] = date('m/d/Y',strtotime($results[$x]['EmployeeSchedule']['schedule_date']));
			}
		}

		return $results;
	}
	
	public function afterSave($created, $options = array()) {
		$schedule_date = isset($this->data['EmployeeSchedule']['schedule_date']) ? $this->data['EmployeeSchedule']['schedule_date'] : null;
		$employee_code = isset($this->data['EmployeeSchedule']['employee_code']) ? $this->data['EmployeeSchedule']['employee_code'] : '';
		$Employee = ClassRegistry::init('Employee');
		$employee_data = $Employee->find('first',array(
			'conditions'=>array(
				'Employee.employee_code'=>$employee_code,
				'Employee.status'=>'Active'
			),
			'recursive'=>-1
		));
		if(count($employee_data)>=1){
			$biometric_id = $employee_data['Employee']['biometric_id'];
			if(!empty($biometric_id)){
				$TimeEntry = ClassRegistry::init('TimeEntry');
				$BiometricTimeEntry = ClassRegistry::init('BiometricTimeEntry');
				$BiometricTimeEntry->query("UPDATE biometric_time_entries SET is_retrieved = '0',is_priority='1' WHERE biometric_id = '$biometric_id' AND DATE(entry_date)=DATE('$schedule_date')");
				$TimeEntry->query("DELETE FROM employee_time_entries WHERE biometric_id = '$biometric_id' AND DATE(time_entry_date)=DATE('$schedule_date')");
			}
		}
		// debug($employee_code);
		// debug($employee_data);
		// debug($this->data);
		// exit();
		return true;
	}
	
	public function find_existing_schedule_by_id_or_code($employee_schedule_id = null) {
		if(is_numeric($employee_schedule_id)) {
			$default_conditions = array(
				'EmployeeSchedule.id' => $employee_schedule_id
			);
		}
		else {
			$default_conditions = array(
				'EmployeeSchedule.code' => $employee_schedule_id
			);
		}
		
		$employee_schedule = $this->find('first', array(
			'fields' => array(
				'EmployeeSchedule.id',
				'EmployeeSchedule.code',
				'EmployeeSchedule.employee_code',
				'EmployeeSchedule.schedule_date',
				'EmployeeSchedule.status',
				'EmployeeSchedule.shift_code'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $employee_schedule;
	}
	
	public function update_status($employee_schedule_id = null, $employee_schedule = null) {
		$existing_employee_schedule = $this->find_existing_schedule_by_id_or_code($employee_schedule_id);
		
		if(isset($existing_employee_schedule) && count($existing_employee_schedule) > 0) {
			$existing_employee_schedule['EmployeeSchedule']['status'] = $employee_schedule;
			$data = $existing_employee_schedule;
		}
	// debug($existing_employee_schedule);
	// exit();
		return $this->save($data);
	}
}
?>