<?php
App::uses('AppModel', 'Model');

class EmployeeType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	
	public $hasOne = array(
		'EmployeeCodeGenerator' => array(
			'className' => 'EmployeeCodeGenerator',
			'foreignKey' => 'employee_type_code',
			// 'dependent' => true
		),
	);
	public function add_employee_type($data = array()) {		
		$existing_employee_type = $this->find_existing_employee_type_by_name($data['EmployeeType']['name']);
		
		if(isset($existing_employee_type) && count($existing_employee_type) > 0) {
			$existing_employee_type['EmployeeType']['status'] = 'Active';
			$data = $existing_employee_type;
			
		}

		return $this->save($data);
	}
	
	public function update_employee_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($employee_type_id = null, $employee_type = null) {
		$existing_employee_type = $this->find_existing_employee_type_by_id_or_code($employee_type_id);
		
		if(isset($existing_employee_type) && count($existing_employee_type) > 0) {
			$existing_employee_type['EmployeeType']['status'] = $employee_type;
			$data = $existing_employee_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_employee_type_by_name($employee_type_name = null) {
		if(isset($employee_type_name)) {
			$default_conditions = array(
				'EmployeeType.name' => $employee_type_name
			);
		}
		
		$employee_type = $this->find('first', array(
			'fields' => array(
				'EmployeeType.id',
				'EmployeeType.code',
				'EmployeeType.name',
				'EmployeeType.status',
				'EmployeeType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $employee_type;
	}
	public function find_existing_employee_type_by_id_or_code($employee_type_id = null) {
		if(is_numeric($employee_type_id)) {
			$default_conditions = array(
				'EmployeeType.id' => $employee_type_id
			);
		}
		else {
			$default_conditions = array(
				'EmployeeType.code' => $employee_type_id
			);
		}
		
		$employee_type = $this->find('first', array(
			'fields' => array(
				'EmployeeType.id',
				'EmployeeType.code',
				'EmployeeType.name',
				'EmployeeType.status',
				'EmployeeType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $employee_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['EmployeeType']['id'])) {
			$this->data['EmployeeType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmployeeType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'EMPTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['EmployeeType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['EmployeeType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>