<?php
App::uses('AppModel', 'Model');

class EmploymentStatus extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	
	public $hasOne = array(
		'EmployeeCodeGenerator' => array(
			'className' => 'EmployeeCodeGenerator',
			'foreignKey' => 'employment_status_code',
			// 'dependent' => true
		),
	);
	public function add_employment_status($data = array()) {		
		$existing_employment_status = $this->find_existing_employment_status_by_name($data['EmploymentStatus']['name']);
		
		if(isset($existing_employment_status) && count($existing_employment_status) > 0) {
			$existing_employment_status['EmploymentStatus']['status'] = 'Active';
			$data = $existing_employment_status;
			
		}

		return $this->save($data);
	}
	
	public function update_employment_status($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($employment_status_id = null, $employment_status = null) {
		$existing_employment_status = $this->find_existing_employment_status_by_id_or_code($employment_status_id);
		
		if(isset($existing_employment_status) && count($existing_employment_status) > 0) {
			$existing_employment_status['EmploymentStatus']['status'] = $employment_status;
			$data = $existing_employment_status;
		}

		return $this->save($data);
	}
	
	public function find_existing_employment_status_by_name($employment_status_name = null) {
		if(isset($employment_status_name)) {
			$default_conditions = array(
				'EmploymentStatus.name' => $employment_status_name
			);
		}
		
		$employment_status = $this->find('first', array(
			'fields' => array(
				'EmploymentStatus.id',
				'EmploymentStatus.code',
				'EmploymentStatus.name',
				'EmploymentStatus.status',
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $employment_status;
	}
	
	public function find_existing_employment_status_by_id_or_code($employment_status_id = null) {
		if(is_numeric($employment_status_id)) {
			$default_conditions = array(
				'EmploymentStatus.id' => $employment_status_id
			);
		}
		else {
			$default_conditions = array(
				'EmploymentStatus.code' => $employment_status_id
			);
		}
		
		$employment_status = $this->find('first', array(
			'fields' => array(
				'EmploymentStatus.id',
				'EmploymentStatus.code',
				'EmploymentStatus.name',
				'EmploymentStatus.status',
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $employment_status;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['EmploymentStatus']['id'])) {
			$this->data['EmploymentStatus']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmploymentStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['EmploymentStatus']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'ESTAT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['EmploymentStatus']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['EmploymentStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>