<?php
App::uses('AppModel', 'Model');

class ExamType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_exam_type($data = array()) {		
		$existing_exam_type = $this->find_existing_exam_type_by_name($data['ExamType']['name']);
		
		if(isset($existing_exam_type) && count($existing_exam_type) > 0) {
			$existing_exam_type['ExamType']['status'] = 'Active';
			$data = $existing_exam_type;
			
		}

		return $this->save($data);
	}
	
	public function update_exam_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($exam_type_id = null, $exam_type = null) {
		$existing_exam_type = $this->find_existing_exam_type_by_id_or_code($exam_type_id);
		
		if(isset($existing_exam_type) && count($existing_exam_type) > 0) {
			$existing_exam_type['ExamType']['status'] = $exam_type;
			$data = $existing_exam_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_exam_type_by_name($application_name = null) {
		if(isset($application_name)) {
			$default_conditions = array(
				'ExamType.name' => $application_name
			);
		}
		
		$exam_type = $this->find('first', array(
			'fields' => array(
				'ExamType.id',
				'ExamType.code',
				'ExamType.name',
				'ExamType.status',
				'ExamType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $exam_type;
	}
	
	public function find_existing_exam_type_by_id_or_code($exam_type_id = null) {
		if(is_numeric($exam_type_id)) {
			$default_conditions = array(
				'ExamType.id' => $exam_type_id
			);
		}
		else {
			$default_conditions = array(
				'ExamType.code' => $exam_type_id
			);
		}
		
		$exam_type = $this->find('first', array(
			'fields' => array(
				'ExamType.id',
				'ExamType.code',
				'ExamType.name',
				'ExamType.status',
				'ExamType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $exam_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ExamType']['id'])) {
			$this->data['ExamType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ExamType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ExamType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'EXTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ExamType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ExamType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>