<?php
App::uses('AppModel', 'Model');

class FormalCharge extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $hasMany = array(
		'EmployeeFormalCharge' => array(
			'className' => 'EmployeeFormalCharge',
			'foreignKey' => 'formal_charge_code',
			)
		);

	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
				
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public function add_formal_charge($data = array()) {		
		$existing_formal_charge = $this->find_existing_formal_charge_by_name($data['FormalCharge']['name']);
		
		if(isset($existing_formal_charge) && count($existing_formal_charge) > 0) {
			$existing_formal_charge['FormalCharge']['status'] = 'Active';
			$data = $existing_formal_charge;
			
		}

		return $this->save($data);
	}
	
	public function update_formal_charge($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($formal_charge_id = null, $formal_charge = null) {
		$existing_formal_charge = $this->find_existing_formal_charge_by_id_or_code($formal_charge_id);
		
		if(isset($existing_formal_charge) && count($existing_formal_charge) > 0) {
			$existing_formal_charge['FormalCharge']['status'] = $formal_charge;
			$data = $existing_formal_charge;
		}

		return $this->save($data);
	}
	
	public function find_existing_formal_charge_by_name($formal_charge_name = null) {
		if(isset($formal_charge_name)) {
			$default_conditions = array(
				'UPPER(FormalCharge.name)' => strtoupper($formal_charge_name)
			);
		}
		
		$formal_charge = $this->find('first', array(
			'fields' => array(
				'FormalCharge.id',
				'FormalCharge.code',
				'FormalCharge.name',
				'FormalCharge.status',
				'FormalCharge.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $formal_charge;
	}
	
	public function find_existing_formal_charge_by_id_or_code($formal_charge_id = null) {
		if(is_numeric($formal_charge_id)) {
			$default_conditions = array(
				'FormalCharge.id' => $formal_charge_id
			);
		}
		else {
			$default_conditions = array(
				'FormalCharge.code' => $formal_charge_id
			);
		}
		
		$formal_charge = $this->find('first', array(
			'fields' => array(
				'FormalCharge.id',
				'FormalCharge.code',
				'FormalCharge.name',
				'FormalCharge.status',
				'FormalCharge.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $formal_charge;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['FormalCharge']['id'])) {
			$this->data['FormalCharge']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['FormalCharge']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['FormalCharge']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'FMLCHG';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['FormalCharge']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['FormalCharge']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>