<?php
App::uses('AppModel', 'Model');

class GeneratedPayroll extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'payroll_';
	public $primaryKey = 'reference_number';
	// public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.'
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public $hasOne = array(
		'EmployeeLeaveCard' => array(
			'className' => 'EmployeeLeaveCard',
			'foreignKey' => 'generated_payroll_code',
		)
	);
	
	public $hasMany = array(
		'GeneratedPayrollIncomeAndBenefit' => array(
			'className' => 'GeneratedPayrollIncomeAndBenefit',
			'foreignKey' => 'generated_payroll_code',
		),
		'GeneratedPayrollDeduction' => array(
			'className' => 'GeneratedPayrollDeduction',
			'foreignKey' => 'generated_payroll_code',
		),
		'GeneratedPayrollLoanAndPayment' => array(
			'className' => 'GeneratedPayrollLoanAndPayment',
			'foreignKey' => 'generated_payroll_code',
		),
		'GeneratedPayrollDeductionAndLoanPayment' => array(
			'className' => 'GeneratedPayrollDeductionAndLoanPayment',
			'foreignKey' => 'generated_payroll_code',
		),
	);
	
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'Employee.status' => 'Active'
			// )
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => false,
			'conditions' => array(
				'PositionDetail.employee_code = GeneratedPayroll.employee_code'
			)
		),
		'PayrollPeriod' => array(
			'className' => 'PayrollPeriod',
			'foreignKey' => 'payroll_period_code',
			'conditions' => array(
				'PayrollPeriod.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
		
		
	);
	public function update_multiple($data = array()) {
		foreach($data as $k=>$val){
			$code= $val['code'];
			unset($val['code']);
			// debug($val);
		// exit();
			$this->updateAll(
					$val,
				array(
					'GeneratedPayroll.reference_number'=>$code
				)
			);
			
		}
		
		
		return true;
	}
	
	public function update_status($generated_payroll_id = null, $generated_payroll = null) {
		$existing_generated_payroll = $this->find_existing_review_and_finalize_by_id_or_code($generated_payroll_id);
		$data=array();
		if(isset($existing_generated_payroll) && count($existing_generated_payroll) > 0) {
			$existing_generated_payroll['GeneratedPayroll']['status'] = $generated_payroll;
			$data = $existing_generated_payroll;
		}

		return $this->save($data);
	}
	public function update_generated_payroll($data = array()) {
		return $this->save($data);
	}
	public function find_existing_review_and_finalize_by_id_or_code($generated_payroll_id = null) {
		if(is_numeric($generated_payroll_id)) {
			$default_conditions = array(
				'GeneratedPayroll.id' => $generated_payroll_id
			);
		}
		else {
			$default_conditions = array(
				'GeneratedPayroll.code' => $generated_payroll_id
			);
		}
		
		$generated_payroll = $this->find('first', array(
			'fields' => array(
				'GeneratedPayroll.id',
				'GeneratedPayroll.reference_number',
				'GeneratedPayroll.employee_name',
				'GeneratedPayroll.employee_monthly_salary',
				'GeneratedPayroll.employee_gross_income',
				'GeneratedPayroll.employee_net_pay',
				'GeneratedPayroll.employee_monthly_first_half_net_pay',
				'GeneratedPayroll.employee_monthly_second_half_net_pay',
				'GeneratedPayroll.employee_monthly_third_half_net_pay',
				'GeneratedPayroll.employee_monthly_fourth_half_net_pay',
				'GeneratedPayroll.employee_hazard_pay',
				'GeneratedPayroll.hazard_pay_coop_loan',
				'GeneratedPayroll.hazard_pay_gross_amount',
				'GeneratedPayroll.employee_net_subsistence_allowance',
				'GeneratedPayroll.employee_net_laundry_allowance',
				'GeneratedPayroll.total_de_minimis_allowance',
				'GeneratedPayroll.employee_rata',
				'GeneratedPayroll.total_income_and_benefits',
				'GeneratedPayroll.total_tardiness_amount',
				'GeneratedPayroll.total_undertime_amount',
				'GeneratedPayroll.total_absenses_without_pay_amount',
				'GeneratedPayroll.total_deductions_amount',
				'GeneratedPayroll.total_loans_and_payments_amount',
				'GeneratedPayroll.gsis_employee_share',
				'GeneratedPayroll.phic_employee_share',
				'GeneratedPayroll.pagibig_employee_share',
				'GeneratedPayroll.withholding_tax',
				'GeneratedPayroll.total_overtime_amount',
				'GeneratedPayroll.total_night_differential_amount',
				'GeneratedPayroll.night_differential_tax_1',
				'GeneratedPayroll.night_differential_tax_2',
				'GeneratedPayroll.total_night_differential_tax',
				'GeneratedPayroll.night_differential_net_pay',
				'GeneratedPayroll.employee_pera',
				'GeneratedPayroll.gsis_employer_share',
				'GeneratedPayroll.gsis_ecip_employer_share',
				'GeneratedPayroll.phic_employer_share',
				'GeneratedPayroll.pagibig_employer_share',
				'GeneratedPayroll.remarks',
				'GeneratedPayroll.status',
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $generated_payroll;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['GeneratedPayroll']['reference_number'])) {
			$this->data['GeneratedPayroll']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['GeneratedPayroll']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['GeneratedPayroll']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'GLP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['GeneratedPayroll']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,9,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['GeneratedPayroll']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>