<?php
App::uses('AppModel', 'Model');

class GeneratedPayrollNightDifferential extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'payroll_';
	public $primaryKey = 'reference_number';
	// public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.'
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	  
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			)
		),
		'PayrollNightDifferentialPeriod' => array(
			'className' => 'PayrollNightDifferentialPeriod',
			'foreignKey' => 'payroll_night_differential_code',
			'conditions' => array(
				'PayrollNightDifferentialPeriod.status' => 'Active'
			)
		),
	); 
	
	public function find_existing_employee_night_differential_by_id_and_code($code = null, $id = null) { 
	
		$default_conditions = array(
			'GeneratedPayrollNightDifferential.status' => 'Active',
			'GeneratedPayrollNightDifferential.payroll_night_differential_code' => $code,
			'GeneratedPayrollNightDifferential.id' => $id
		);
		
		$employee_payroll_night_differential = $this->find('first', array(  
			'fields' => array(
				'GeneratedPayrollNightDifferential.id',
				'GeneratedPayrollNightDifferential.reference_number',
				'GeneratedPayrollNightDifferential.payroll_night_differential_code',
				'GeneratedPayrollNightDifferential.employee_code',
				'GeneratedPayrollNightDifferential.employee_name',
				'GeneratedPayrollNightDifferential.salary_grade_name',
				'GeneratedPayrollNightDifferential.salary_grade_code',
				'GeneratedPayrollNightDifferential.job_title_code',
				'GeneratedPayrollNightDifferential.division_code',
				'GeneratedPayrollNightDifferential.section_code',
				'GeneratedPayrollNightDifferential.job_title_name',
				'GeneratedPayrollNightDifferential.division_name',
				'GeneratedPayrollNightDifferential.section_name',
				'GeneratedPayrollNightDifferential.monthly_rate',
				'GeneratedPayrollNightDifferential.hourly_rate',
				'GeneratedPayrollNightDifferential.night_differential_hour',
				'GeneratedPayrollNightDifferential.night_differential_amount',
				'GeneratedPayrollNightDifferential.date_hired'
			),
			// 'contain' => 'Employee',
			'conditions' => $default_conditions,
			'recursive' => -1,
		));
	 
		return $employee_payroll_night_differential;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['GeneratedPayrollNightDifferential']['id'])) {
			$this->data['GeneratedPayrollNightDifferential']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['GeneratedPayrollNightDifferential']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['GeneratedPayrollNightDifferential']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'GPND';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			
			$this->data['GeneratedPayrollNightDifferential']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,9,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['GeneratedPayrollNightDifferential']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>