<?php
App::uses('AppModel', 'Model');

class GovernmentOfficialPosition extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
				
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public $hasMany = array(
	);
	
	public function add_government_official_position($data = array()) {		
		$existing_government_official_position = $this->find_existing_government_official_position_by_name($data['GovernmentOfficialPosition']['name']);
		
		if(isset($existing_government_official_position) && count($existing_government_official_position) > 0) {
			$existing_government_official_position['GovernmentOfficialPosition']['status'] = 'Active';
			$data = $existing_government_official_position;
			
		}

		return $this->save($data);
	}
	
	public function update_government_official_position($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($government_official_position_id = null, $government_official_position = null) {
		$existing_government_official_position = $this->find_existing_government_official_position_by_id_or_code($government_official_position_id);
		
		if(isset($existing_government_official_position) && count($existing_government_official_position) > 0) {
			$existing_government_official_position['GovernmentOfficialPosition']['status'] = $government_official_position;
			$data = $existing_government_official_position;
		}

		return $this->save($data);
	}
	
	public function find_existing_government_official_position_by_name($application_name = null) {
		if(isset($application_name)) {
			$default_conditions = array(
				'UPPER(GovernmentOfficialPosition.name)' => strtoupper($application_name)
			);
		}
		
		$government_official_position = $this->find('first', array(
			'fields' => array(
				'GovernmentOfficialPosition.id',
				'GovernmentOfficialPosition.code',
				'GovernmentOfficialPosition.name',
				'GovernmentOfficialPosition.status',
				'GovernmentOfficialPosition.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $government_official_position;
	}
	
	public function find_existing_government_official_position_by_id_or_code($government_official_position_id = null) {
		if(is_numeric($government_official_position_id)) {
			$default_conditions = array(
				'GovernmentOfficialPosition.id' => $government_official_position_id
			);
		}
		else {
			$default_conditions = array(
				'GovernmentOfficialPosition.code' => $government_official_position_id
			);
		}
		
		$government_official_position = $this->find('first', array(
			'fields' => array(
				'GovernmentOfficialPosition.id',
				'GovernmentOfficialPosition.code',
				'GovernmentOfficialPosition.name',
				'GovernmentOfficialPosition.status',
				'GovernmentOfficialPosition.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $government_official_position;
	}
	public function beforeSave($options = array()) {
		if(!isset($this->data['GovernmentOfficialPosition']['id'])) {
			$this->data['GovernmentOfficialPosition']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['GovernmentOfficialPosition']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['GovernmentOfficialPosition']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'GVTPOS';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['GovernmentOfficialPosition']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['GovernmentOfficialPosition']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>