<?php
App::uses('AppModel', 'Model');

class HolidayType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		'multiplier'=>array(
			'multiplier logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Multiplier is required.',
			),
			'multiplier logic 2' => array(
				'rule'		=> 'numeric',
				'message'	=> 'Multiplier is should be number.',
			),
			
		
		)
	);
	public function add_holiday_type($data = array()) {		

		$existing_holiday_type = $this->find_existing_holiday_type_by_name($data['HolidayType']['name']);
		
		if(isset($existing_holiday_type) && count($existing_holiday_type) > 0) {
			$existing_holiday_type['HolidayType']['status'] = 'Active';
			$data = $existing_holiday_type;
			
		}
		return $this->save($data);
	}
	
	public function update_holiday_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($holiday_type_id = null, $holiday_type = null) {
		$existing_holiday_type = $this->find_existing_holiday_type_by_id_or_code($holiday_type_id);
		
		if(isset($existing_holiday_type) && count($existing_holiday_type) > 0) {
			$existing_holiday_type['HolidayType']['status'] = $holiday_type;
			$data = $existing_holiday_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_holiday_type_by_name($holiday_type_name = null) {
		if(isset($holiday_type_name)) {
			$default_conditions = array(
				'HolidayType.name' => $holiday_type_name
			);
		}
		
		$holiday_type = $this->find('first', array(
			'fields' => array(
				'HolidayType.id',
				'HolidayType.code',
				'HolidayType.name',
				'HolidayType.multiplier',
				'HolidayType.status',
				'HolidayType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $holiday_type;
	}
	
	public function find_existing_holiday_type_by_id_or_code($holiday_type_id = null) {
		if(is_numeric($holiday_type_id)) {
			$default_conditions = array(
				'HolidayType.id' => $holiday_type_id
			);
		}
		else {
			$default_conditions = array(
				'HolidayType.code' => $holiday_type_id
			);
		}
		
		$holiday_type = $this->find('first', array(
			'fields' => array(
				'HolidayType.id',
				'HolidayType.code',
				'HolidayType.name',
				'HolidayType.multiplier',
				'HolidayType.status',
				'HolidayType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $holiday_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['HolidayType']['code'])) {
			$this->data['HolidayType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['HolidayType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['HolidayType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'HTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];

			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['HolidayType']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['HolidayType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>