<?php
App::uses('AppModel', 'Model');

class HospitalPersonnelOrderSubmissionForDtr extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active',
			),
		),		
		'HospitalPersonnelOrderType' => array(
			'className' => 'HospitalPersonnelOrderType',
			'foreignKey' => 'hospital_personnel_order_type_code',
			'conditions' => array(
				'HospitalPersonnelOrderType.status' => 'Active',
			),
		),
	);
	
	public $hasMany = array(
		'HospitalPersonnelOrderSubmissionForDtrDate' => array(
			'className' => 'HospitalPersonnelOrderSubmissionForDtrDate',
			'foreignKey' => 'hospital_personnel_order_submission_for_dtr_id',
			'conditions' => array(
				'HospitalPersonnelOrderSubmissionForDtrDate.status' => 'Active',
			),
		),		
	);

	public $validate = array(
		'employee_code' => array(
            'employee_code logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Employee is required.'
            ),
        ),
        'description' => array(
            'description logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Description is required.'
            ),
        ),
        'date_from' => array(
            'date_from logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Date From is required.'
            ),
        ),
		'date_to' => array(
            'date_to logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Date To is required.'
            ),
        ),
        'hospital_personnel_order_type_code' => array(
            'hospital_personnel_order_type_code logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Hospital Personnel Order Type is required.'
            ),
        ),
        'hazard_pay_identifier' => array(
            'hazard_pay_identifier logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Hazard Pay Identifier is required.'
            ),
        ),
        'attachment' => array(
            'attachment logic 1' => array(
				'on' => 'create',
                'rule' => array('notEmpty'),
                'message' => 'Attachment is required.'
            ),
        ),
    );
	
	public function beforeValidate($options = array()) {
		if (isset($this->data['HospitalPersonnelOrderSubmissionForDtr']['date_from']) && validate_datetime($this->data['HospitalPersonnelOrderSubmissionForDtr']['date_from'], 'm/d/Y')) {
			$this->data['HospitalPersonnelOrderSubmissionForDtr']['date_from'] = convert_datetime($this->data['HospitalPersonnelOrderSubmissionForDtr']['date_from'], 'Y-m-d');
		}	
		
		if (isset($this->data['HospitalPersonnelOrderSubmissionForDtr']['date_to']) && validate_datetime($this->data['HospitalPersonnelOrderSubmissionForDtr']['date_to'], 'm/d/Y')) {
			$this->data['HospitalPersonnelOrderSubmissionForDtr']['date_to'] = convert_datetime($this->data['HospitalPersonnelOrderSubmissionForDtr']['date_to'], 'Y-m-d');
		}	
		
		return true;
	}
	
	public function beforeSave($options = array()) {
		if (!isset($this->data['HospitalPersonnelOrderSubmissionForDtr']['id'])) {
			$this->data['HospitalPersonnelOrderSubmissionForDtr']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['HospitalPersonnelOrderSubmissionForDtr']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['HospitalPersonnelOrderSubmissionForDtr']['status'] = 'Active';
		}
		else {
			$this->data['HospitalPersonnelOrderSubmissionForDtr']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false) {
		foreach($results as $x => $result){
			if (isset($result['HospitalPersonnelOrderSubmissionForDtr']['date_from'])) {
				$results[$x]['HospitalPersonnelOrderSubmissionForDtr']['date_from'] = date('m/d/Y',strtotime($results[$x]['HospitalPersonnelOrderSubmissionForDtr']['date_from']));
			}
			
			if (isset($result['HospitalPersonnelOrderSubmissionForDtr']['date_to'])) {
				$results[$x]['HospitalPersonnelOrderSubmissionForDtr']['date_to'] = date('m/d/Y',strtotime($results[$x]['HospitalPersonnelOrderSubmissionForDtr']['date_to']));
			}			
		}

		return $results;
	}
}
?>