<?php
App::uses('AppModel', 'Model');

class HourlyAttendance extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'filing_';
	public $primaryKey = 'reference_number';
	    public $validate = array(
        'date_from' => array(
            'date_from logic 2' => array(
                'rule'        => 'notEmpty',
                'message'    => 'Date from is required.'
            ),
        ),
        'date_to' => array(
            'date_to logic 2' => array(
                'rule'        => 'notEmpty',
                'message'    => 'Date to is required.'
            ),
        ),
        'total_attendances' => array(
            'total_attendances logic 2' => array(
                'rule'        => 'notEmpty',
                'message'    => 'Total days rendered is required.'
            ),
        ),
        'total_attendances_in_hours' => array(
            'total_attendances_in_hours logic 2' => array(
                'rule'        => 'notEmpty',
                'message'    => 'Total attendance hours is required.'
            ),
        ),
    );
    

	
	public $belongsTo = array(
		// 'LeaveType' => array(
			// 'className' => 'LeaveType',
			// 'foreignKey' => 'leave_type_code',
			// 'fields' => array(
				// 'LeaveType.name',
			// ),
			// 'conditions' => array(
				// 'LeaveType.status' => 'Active'
			// )
		// ),
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'ApprovedByUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_unit',
			'conditions' => array(
				'ApprovedByUnit.status' => 'Active'
			)
		),
		'ApprovedBySubUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_sub_unit',
			'conditions' => array(
				'ApprovedBySubUnit.status' => 'Active'
			)
		),
		'ApprovedBySection' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_section',
			'conditions' => array(
				'ApprovedBySection.status' => 'Active'
			)
		),
		'ApprovedByAdminOfficer' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_admin_officer',
			'conditions' => array(
				'ApprovedByAdminOfficer.status' => 'Active'
			)
		),
		'ApprovedByHRAdmin' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_hr_admin',
			'conditions' => array(
				'ApprovedByHRAdmin.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
		
		
	);
	public $hasMany = array (
		'FilingHourlyAttendanceAttachment' => array(
			'className' => 'FilingHourlyAttendanceAttachment',
			'foreignKey' => 'hourly_attendance_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
	);
	public function beforeValidate($options = array()) {
		if(isset($this->data['HourlyAttendance']['date_from']) && validate_datetime($this->data['HourlyAttendance']['date_from'], 'm/d/Y')) {
			$this->data['HourlyAttendance']['date_from'] = convert_datetime($this->data['HourlyAttendance']['date_from'], 'Y-m-d');
		}	
		
		if(isset($this->data['HourlyAttendance']['date_to']) && validate_datetime($this->data['HourlyAttendance']['date_to'], 'm/d/Y')) {
			$this->data['HourlyAttendance']['date_to'] = convert_datetime($this->data['HourlyAttendance']['date_to'], 'Y-m-d');
		}	
		if(isset($this->data['HourlyAttendance']['filing_date']) && validate_datetime($this->data['HourlyAttendance']['filing_date'], 'm/d/Y')) {
			$this->data['HourlyAttendance']['filing_date'] = convert_datetime($this->data['HourlyAttendance']['filing_date'], 'Y-m-d');
		}	
		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['HourlyAttendance']['id'])) {
			$this->data['HourlyAttendance']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['HourlyAttendance']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['HourlyAttendance']['status'] = 'Active';
		
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'HA';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['HourlyAttendance']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['HourlyAttendance']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['HourlyAttendance']['date_from'])){
				$results[$x]['HourlyAttendance']['date_from'] = date('m/d/Y',strtotime($results[$x]['HourlyAttendance']['date_from']));
			}
			
			if(isset($result['HourlyAttendance']['date_to'])){
				$results[$x]['HourlyAttendance']['date_to'] = date('m/d/Y',strtotime($results[$x]['HourlyAttendance']['date_to']));
			}
			
			if(isset($result['HourlyAttendance']['day_of_the_week'])){
					$dow = json_decode($result['HourlyAttendance']['day_of_the_week'],true);
					foreach($dow as $day) $results[$x]['HourlyAttendance'][$day]=1;
					// debug($dow);
					// exit();
			}
		}

		return $results;
	}
}
?>