<?php
App::uses('AppModel', 'Model');

class IncomeAndBenefitType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			// 'name logic 1' => array(
				// 'rule'		=> 'isUnique',
				// 'message'	=> 'Name is already used.',
				// 'on' => 'create',
			// ),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		'taxable' => array(
			'taxable logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Taxable is required.'
			),
        ),
		'accounting_code' => array(
			'accounting_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Accounting Code is required.'
			),
        ),
	);
	
	public function add_income_and_benefit_type($data = array()) {		
		$existing_income_and_benefit_type = $this->find_existing_income_and_benefit_type_by_name($data['IncomeAndBenefitType']['name']);
		
		if(isset($existing_income_and_benefit_type) && count($existing_income_and_benefit_type) > 0) {
			$existing_income_and_benefit_type['IncomeAndBenefitType']['taxable'] =$data['IncomeAndBenefitType']['taxable'];
			$existing_income_and_benefit_type['IncomeAndBenefitType']['accounting_code'] =$data['IncomeAndBenefitType']['accounting_code'];
			$existing_income_and_benefit_type['IncomeAndBenefitType']['status'] = 'Active';
			$data = $existing_income_and_benefit_type;
			
		}
		
		return $this->save($data);	
	}
	
	public function update_income_and_benefit_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($income_and_benefit_type_id = null, $income_and_benefit_type = null) {
		$existing_income_and_benefit_type = $this->find_existing_income_and_benefit_type_by_id_or_code($income_and_benefit_type_id);
		
		if(isset($existing_income_and_benefit_type) && count($existing_income_and_benefit_type) > 0) {
			$existing_income_and_benefit_type['IncomeAndBenefitType']['status'] = $income_and_benefit_type;
			$data = $existing_income_and_benefit_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_income_and_benefit_type_by_name($income_and_benefit_type_name = null) {
		if(isset($income_and_benefit_type_name)) {
			$default_conditions = array(
				'IncomeAndBenefitType.name' => $income_and_benefit_type_name,
			);
		}
		
		$income_and_benefit_type = $this->find('first', array(
			'fields' => array(
				'IncomeAndBenefitType.id',
				'IncomeAndBenefitType.code',
				'IncomeAndBenefitType.name',
				'IncomeAndBenefitType.taxable',
				'IncomeAndBenefitType.accounting_code',
				'IncomeAndBenefitType.status',
				'IncomeAndBenefitType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $income_and_benefit_type;
	}
	
	public function find_existing_income_and_benefit_type_by_id_or_code($income_and_benefit_type_id = null) {
		if(is_numeric($income_and_benefit_type_id)) {
			$default_conditions = array(
				'IncomeAndBenefitType.id' => $income_and_benefit_type_id,
				// 'IncomeAndBenefitType.status' => 'Active'
			);
		}
		else {
			$default_conditions = array(
				'IncomeAndBenefitType.code' => $income_and_benefit_type_id,
				// 'IncomeAndBenefitType.status' => 'Active'
			);
		}
		
		$income_and_benefit_type = $this->find('first', array(
			'fields' => array(
				'IncomeAndBenefitType.id',
				'IncomeAndBenefitType.code',
				'IncomeAndBenefitType.name',
				'IncomeAndBenefitType.taxable',
				'IncomeAndBenefitType.accounting_code',
				'IncomeAndBenefitType.status',
				'IncomeAndBenefitType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $income_and_benefit_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['IncomeAndBenefitType']['id'])) {
			$this->data['IncomeAndBenefitType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['IncomeAndBenefitType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['IncomeAndBenefitType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'IABTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['IncomeAndBenefitType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['IncomeAndBenefitType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>