<?php
App::uses('AppModel', 'Model');

class IndigenousGroup extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
	);
	
	public function add_indigenous_group($data = array()) {		
		$existing_indigenous_group = $this->find_existing_indigenous_group_by_name($data['IndigenousGroup']['name']);
		
		if(isset($existing_indigenous_group) && count($existing_indigenous_group) > 0) {
			$existing_indigenous_group['IndigenousGroup']['status'] = 'Active';
			$data = $existing_indigenous_group;
			
		}

		return $this->save($data);
	}
	
	public function update_indigenous_group($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($indigenous_group_id = null, $indigenous_group = null) {
		$existing_indigenous_group = $this->find_existing_indigenous_group_by_id_or_code($indigenous_group_id);
		
		if(isset($existing_indigenous_group) && count($existing_indigenous_group) > 0) {
			$existing_indigenous_group['IndigenousGroup']['status'] = $indigenous_group;
			$data = $existing_indigenous_group;
		}

		return $this->save($data);
	}
	
	public function find_existing_indigenous_group_by_name($indigenous_group_name = null) {
		if(isset($indigenous_group_name)) {
			$default_conditions = array(
				'IndigenousGroup.name' => $indigenous_group_name
			);
		}
		
		$indigenous_group = $this->find('first', array(
			'fields' => array(
				'IndigenousGroup.id',
				'IndigenousGroup.code',
				'IndigenousGroup.name',
				'IndigenousGroup.status',
				'IndigenousGroup.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $indigenous_group;
	}
	
	public function find_existing_indigenous_group_by_id_or_code($indigenous_group_id = null) {
		if(is_numeric($indigenous_group_id)) {
			$default_conditions = array(
				'IndigenousGroup.id' => $indigenous_group_id
			);
		}
		else {
			$default_conditions = array(
				'IndigenousGroup.code' => $indigenous_group_id
			);
		}
		
		$indigenous_group = $this->find('first', array(
			'fields' => array(
				'IndigenousGroup.id',
				'IndigenousGroup.code',
				'IndigenousGroup.name',
				'IndigenousGroup.status',
				'IndigenousGroup.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $indigenous_group;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['IndigenousGroup']['id'])) {
			$this->data['IndigenousGroup']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['IndigenousGroup']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['IndigenousGroup']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'INDGRP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['IndigenousGroup']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['IndigenousGroup']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>