<?php
App::uses('AppModel', 'Model');

class JobLevel extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_job_level($data = array()) {		
		$existing_job_level = $this->find_existing_job_level_by_name($data['JobLevel']['name']);
		
		if(isset($existing_job_level) && count($existing_job_level) > 0) {
			$existing_job_level['JobLevel']['status'] = 'Active';
			$data = $existing_job_level;
			
		}

		return $this->save($data);
	}
	
	public function update_job_level($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($job_level_id = null, $job_level = null) {
		$existing_job_level = $this->find_existing_job_level_by_id_or_code($job_level_id);
		
		if(isset($existing_job_level) && count($existing_job_level) > 0) {
			$existing_job_level['JobLevel']['status'] = $job_level;
			$data = $existing_job_level;
		}

		return $this->save($data);
	}
	
	public function find_existing_job_level_by_name($job_level_name = null) {
		if(isset($job_level_name)) {
			$default_conditions = array(
				'JobLevel.name' => $job_level_name
			);
		}
		
		$job_level = $this->find('first', array(
			'fields' => array(
				'JobLevel.id',
				'JobLevel.code',
				'JobLevel.name',
				'JobLevel.status',
				'JobLevel.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $job_level;
	}
	
	public function find_existing_job_level_by_id_or_code($job_level_id = null) {
		if(is_numeric($job_level_id)) {
			$default_conditions = array(
				'JobLevel.id' => $job_level_id
			);
		}
		else {
			$default_conditions = array(
				'JobLevel.code' => $job_level_id
			);
		}
		
		$job_level = $this->find('first', array(
			'fields' => array(
				'JobLevel.id',
				'JobLevel.code',
				'JobLevel.name',
				'JobLevel.status',
				'JobLevel.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $job_level;
	}
	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['JobLevel']['id'])) {
			$this->data['JobLevel']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['JobLevel']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['JobLevel']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'JL';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['JobLevel']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['JobLevel']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>