<?php
App::uses('AppModel', 'Model');

class JobTitle extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public $belongsTo = array(
		'SalaryGrade' => array(
			'className' => 'SalaryGrade',
			'foreignKey' => 'salary_grade_code',
			'conditions' => array(
				'SalaryGrade.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division',
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array(
		'JobTitleItemNumber' => array(
			'className' => 'JobTitleItemNumber',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitleItemNumber.status' => 'Active'
			)
		),
	);
	public function add_job_title($data = array()) {		
		$existing_job_title = $this->find_existing_job_title_by_name($data['JobTitle']['name']);
		
		if(isset($existing_job_title) && count($existing_job_title) > 0) {
			$existing_job_title['JobTitle']['status'] = 'Active';
			$data = $existing_job_title;
			
		}
		return $this->save($data);
	}
	public function update_job_title($data = array()) {
		return $this->save($data);
	}
	public function find_existing_job_title_by_name($job_title_name = null) {
		if(isset($job_title_name)) {
			$default_conditions = array(
				'JobTitle.name' => $job_title_name
			);
		}
		
		$job_title = $this->find('first', array(
			'fields' => array(
				'JobTitle.id',
				'JobTitle.code',
				'JobTitle.name',
				'JobTitle.status',
				'JobTitle.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $job_title;
	}
	public function update_status($job_title_id = null, $job_title = null) {
		$existing_job_title = $this->find_existing_job_title_by_id_or_code($job_title_id);
		
		if(isset($existing_job_title) && count($existing_job_title) > 0) {
			$existing_job_title['JobTitle']['status'] = $job_title;
			$data = $existing_job_title;
		}

		return $this->save($data);
	}
	public function find_existing_job_title_by_id_or_code($job_title_id = null) {
		if(is_numeric($job_title_id)) {
			$default_conditions = array(
				'JobTitle.id' => $job_title_id
			);
		}
		else {
			$default_conditions = array(
				'JobTitle.code' => $job_title_id
			);
		}
		
		$job_title = $this->find('first', array(
			'fields' => array(
				'JobTitle.id',
				'JobTitle.code',
				'JobTitle.name',
				'JobTitle.status',
				'JobTitle.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $job_title;
	}
	public function beforeSave($options = array()) {
		if(!isset($this->data['JobTitle']['code'])) {
			
			$this->data['JobTitle']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['JobTitle']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['JobTitle']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'JBT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['JobTitle']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['JobTitle']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>