<?php
App::uses('AppModel', 'Model');

class JobTitleItemNumber extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	
	public $validate = array(
        'item_number' => array(
			// 'item_number logic 1' => array(
				// 'rule'		=> 'isUnique',
				// 'message'	=> 'Item Number is already used.',
			// ),
			'item_number logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Item Number is required.'
			),
        ),
	);
	
	public $belongsTo = array(
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			)
		),
	);
	
	public function add_job_title_item_number($data = array()) {		
		$existing_job_title_item_number = $this->find('first',array(
			'conditions'=>array(
				'JobTitleItemNumber.item_number'=>$data['JobTitleItemNumber']['item_number'],
				'JobTitleItemNumber.status'=>'Active'
			)
		));
		
		if(isset($existing_job_title_item_number) && count($existing_job_title_item_number) > 0) {
			// $existing_job_title_item_number['JobTitleItemNumber']['status'] = 'Active';
			// $data = $existing_job_title_item_number;
			return false;
		}

		return $this->saveAll($data);
	}
	
	public function update_job_title_item_number($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($job_title_item_number_id = null, $job_title_item_number = null) {
		$existing_job_title_item_number = $this->find_existing_job_title_item_number_by_id_or_code($job_title_item_number_id);
		
		if(isset($existing_job_title_item_number) && count($existing_job_title_item_number) > 0) {
			$existing_job_title_item_number['JobTitleItemNumber']['status'] = $job_title_item_number;
			$data = $existing_job_title_item_number;
		}

		return $this->save($data);
	}
	
	public function find_existing_job_title_item_number_by_name($job_title_item_number_item_number = null) {
		if(isset($job_title_item_number_item_number)) {
			$default_conditions = array(
				'JobTitleItemNumber.item_number' => $job_title_item_number_item_number
			);
		}
		$job_title_item_number = $this->find('first', array(
			'fields' => array(
				'JobTitleItemNumber.id',
				'JobTitleItemNumber.code',
				'JobTitleItemNumber.item_number',
				'JobTitleItemNumber.status',
				'JobTitleItemNumber.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $job_title_item_number;
	}
	
	public function find_existing_job_title_item_number_by_id_or_code($job_title_item_number_id = null) {
		if(is_numeric($job_title_item_number_id)) {
			$default_conditions = array(
				'JobTitleItemNumber.id' => $job_title_item_number_id
			);
		}
		else {
			$default_conditions = array(
				'JobTitleItemNumber.code' => $job_title_item_number_id
			);
		}
		
		$job_title_item_number = $this->find('first', array(
			'fields' => array(
				'JobTitleItemNumber.id',
				'JobTitleItemNumber.code',
				'JobTitleItemNumber.job_title_code',
				'JobTitleItemNumber.item_number',
				'JobTitleItemNumber.is_filled',
				'JobTitleItemNumber.date_from',
				'JobTitleItemNumber.date_to',
				'JobTitleItemNumber.status',
				'JobTitleItemNumber.lock_flag',
				'JobTitle.name',
				'JobTitle.salary_grade_code',
			),
			'contain'=>array(
				'JobTitle'=>array(
					'SalaryGrade'=>array(
						'fields'=>array(
							'SalaryGrade.basic_salary',
							'SalaryGrade.salary_grade_number'
						)
					)
				)
			),
			'conditions' => $default_conditions
		));		
		return $job_title_item_number;
	}
	
	public function beforeSave($options = array()) {
		
		if(isset($this->data['JobTitleItemNumber']['date_published']) && $this->data['JobTitleItemNumber']['date_published']!="") {
			$this->data['JobTitleItemNumber']['date_published']= date('Y-m-d',strtotime($this->data['JobTitleItemNumber']['date_published']));
		}
		if(isset($this->data['JobTitleItemNumber']['date_from']) && $this->data['JobTitleItemNumber']['date_from']!="") {
			$this->data['JobTitleItemNumber']['date_from']= date('Y-m-d',strtotime($this->data['JobTitleItemNumber']['date_from']));
		}
		if(isset($this->data['JobTitleItemNumber']['date_to']) && $this->data['JobTitleItemNumber']['date_to']!="") {
			$this->data['JobTitleItemNumber']['date_to']= date('Y-m-d',strtotime($this->data['JobTitleItemNumber']['date_to']));
		}
		if(!isset($this->data['JobTitleItemNumber']['code'])) {
			$this->data['JobTitleItemNumber']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['JobTitleItemNumber']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['JobTitleItemNumber']['status'] = 'Active';
			
			// $ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			// $code_char = 'ITMNO';
			// $reference = $ReferenceCode->findByPrefixCode($code_char);
			// $code_number = $reference['ReferenceCode']['number'] + 1;
			// $this->data['JobTitleItemNumber']['code'] = $code_char . '-' . $code_number;
		
			// $ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		
		
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'ITMNO';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
		
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['JobTitleItemNumber']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['JobTitleItemNumber']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['JobTitleItemNumber']['date_from'])){
				$results[$x]['JobTitleItemNumber']['date_from'] = date('m/d/Y',strtotime($results[$x]['JobTitleItemNumber']['date_from']));
			}
			
			if(isset($result['JobTitleItemNumber']['date_to'])){
				$results[$x]['JobTitleItemNumber']['date_to'] = date('m/d/Y',strtotime($results[$x]['JobTitleItemNumber']['date_to']));
			}
			
		}
		
		return $results;
	}
}
?>