<?php
App::uses('AppModel', 'Model');

class LearningAndDevelopmentAssessmentTool extends AppModel {

	public $actsAs = array('AuditLog.Auditable');
	
	public $primaryKey = 'code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
	);
	
	public function find_existing_assessment_tool_by_id_or_code($assessment_tools_id = null) {
		if(is_numeric($assessment_tools_id)) {
			$default_conditions = array(
				'LearningAndDevelopmentAssessmentTool.id' => $assessment_tools_id
			);
		}
		else {
			$default_conditions = array(
				'LearningAndDevelopmentAssessmentTool.code' => $assessment_tools_id
			);
		}
		
		$assessment_tool = $this->find('first', array(
			'fields' => array(
				'LearningAndDevelopmentAssessmentTool.id',
				'LearningAndDevelopmentAssessmentTool.code',
				'LearningAndDevelopmentAssessmentTool.name_of_attachment',
				'LearningAndDevelopmentAssessmentTool.status',
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $assessment_tool;
	}

	public function beforeValidate($options = array()) {
		
		if(isset($this->data['LearningAndDevelopmentAssessmentTool']['date_of_attachment']) && validate_datetime($this->data['LearningAndDevelopmentAssessmentTool']['date_of_attachment'], 'm/d/Y')) {
			$this->data['LearningAndDevelopmentAssessmentTool']['date_of_attachment'] = convert_datetime($this->data['LearningAndDevelopmentAssessmentTool']['date_of_attachment'], 'Y-m-d');
		}
	}
	

	
	public function beforeSave($options = array()) {
		// debug($this->data);
		// exit();
		if(!isset($this->data['LearningAndDevelopmentAssessmentTool']['code']) || empty($this->data['LearningAndDevelopmentAssessmentTool']['code'])) {
		$this->data['LearningAndDevelopmentAssessmentTool']['created_by'] = $_SESSION['Auth']['User']['id'];
		$this->data['LearningAndDevelopmentAssessmentTool']['modified_by'] = $_SESSION['Auth']['User']['id'];
		$this->data['LearningAndDevelopmentAssessmentTool']['status'] = 'Active';
		$ReferenceCode = ClassRegistry::init('ReferenceCode');
		
		$code_char = 'LDAT';
		$reference = $ReferenceCode->findByPrefixCode($code_char);
		$code_number = $reference['ReferenceCode']['number'] + 1;
		$year = $reference['ReferenceCode']['year_code'];
		// debug($year);
		
		if($year != date('Y')){
			$year= date('Y');
			$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
			$code_number=1;
		}
		$this->data['LearningAndDevelopmentAssessmentTool']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
	// debug($this->data);
		$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['LearningAndDevelopmentAssessmentTool']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
	return true;
	}
	

	public function afterFind($results, $primary = false){
		foreach($results as $x => $result){
				if(isset($result['LearningAndDevelopmentAssessmentTool']['date_of_attachment'])){
						$results[$x]['LearningAndDevelopmentAssessmentTool']['date_of_attachment'] = date('m/d/Y',strtotime($results[$x]['LearningAndDevelopmentAssessmentTool']['date_of_attachment']));
				}
		}
		
		return $results;
    }
	
}
?>