<?php
App::uses('AppModel', 'Model');

class LearningAndDevelopmentDocumentType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
	);
	
	public function add_learning_and_development_document_type($data = array()) {		
		$existing_learning_and_development_type = $this->find_existing_learning_and_development_type_by_name($data['LearningAndDevelopmentDocumentType']['name']);
		
		if(isset($existing_learning_and_development_type) && count($existing_learning_and_development_type) > 0) {
			$existing_learning_and_development_type['LearningAndDevelopmentDocumentType']['status'] = 'Active';
			$data = $existing_learning_and_development_type;
			
		}

		return $this->save($data);
	}
	
	public function update_learning_and_development_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($learning_and_development_document_type_id = null, $learning_and_development_document_type = null) {
		$existing_learning_and_development_type = $this->find_existing_learning_and_development_document_type_by_id_or_code($learning_and_development_document_type_id);
		
		if(isset($existing_learning_and_development_type) && count($existing_learning_and_development_type) > 0) {
			$existing_learning_and_development_type['LearningAndDevelopmentDocumentType']['status'] = $learning_and_development_document_type;
			$data = $existing_learning_and_development_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_learning_and_development_type_by_name($learning_and_development_type_name = null) {
		if(isset($learning_and_development_type_name)) {
			$default_conditions = array(
				'UPPER(LearningAndDevelopmentDocumentType.name)' => strtoupper($learning_and_development_type_name)
			);
		}
		
		$learning_and_development_document_type = $this->find('first', array(
			'fields' => array(
				'LearningAndDevelopmentDocumentType.id',
				'LearningAndDevelopmentDocumentType.code',
				'LearningAndDevelopmentDocumentType.name',
				'LearningAndDevelopmentDocumentType.status',
				'LearningAndDevelopmentDocumentType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $learning_and_development_document_type;
	}
	
	public function find_existing_learning_and_development_document_type_by_id_or_code($learning_and_development_document_type_id = null) {
		if(is_numeric($learning_and_development_document_type_id)) {
			$default_conditions = array(
				'LearningAndDevelopmentDocumentType.id' => $learning_and_development_document_type_id
			);
		}
		else {
			$default_conditions = array(
				'LearningAndDevelopmentDocumentType.code' => $learning_and_development_document_type_id
			);
		}
		
		$learning_and_development_document_type = $this->find('first', array(
			'fields' => array(
				'LearningAndDevelopmentDocumentType.id',
				'LearningAndDevelopmentDocumentType.code',
				'LearningAndDevelopmentDocumentType.name',
				'LearningAndDevelopmentDocumentType.status',
				'LearningAndDevelopmentDocumentType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $learning_and_development_document_type;
	}
	public function beforeValidate($options = array()) {
		if(isset($this->data['LearningAndDevelopmentDocumentType']['date_attachment']) && validate_datetime($this->data['LearningAndDevelopmentDocumentType']['date_attachment'], 'm/d/Y')) {
			$this->data['LearningAndDevelopmentDocumentType']['date_attachment'] = convert_datetime($this->data['LearningAndDevelopmentDocumentType']['date_attachment'], 'Y-m-d');
		}	
		
		// if(isset($this->data['LearningAndDevelopment']['to']) && validate_datetime($this->data['LearningAndDevelopment']['to'], 'm/d/Y')) {
			// $this->data['LearningAndDevelopment']['to'] = convert_datetime($this->data['LearningAndDevelopment']['to'], 'Y-m-d');
		// }
	}
	public function beforeSave($options = array()) {
		if(!isset($this->data['LearningAndDevelopmentDocumentType']['id'])) {
			$this->data['LearningAndDevelopmentDocumentType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LearningAndDevelopmentDocumentType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LearningAndDevelopmentDocumentType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'LDDT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['LearningAndDevelopmentDocumentType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['LearningAndDevelopmentDocumentType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['LearningAndDevelopmentDocumentType']['date_attachment'])){
				$results[$x]['LearningAndDevelopmentDocumentType']['date_attachment'] = date('m/d/Y',strtotime($results[$x]['LearningAndDevelopmentDocumentType']['date_attachment']));
			}
			
			
		}

		return $results;
	}
}
?>