<?php
App::uses('AppModel', 'Model');

class LearningAndDevelopmentHeader extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_hospital_';
	public $primaryKey = 'code';
	// public $displayField = 'name';
	
	public $validate = array(
        'service_years' => array(
			'service_years logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Service Year is required.'
			),
        ),
		'employeer_name' => array(
			'employeer_name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Employeer Name is required.'
			),
        ),
		'industry_code' => array(
			'industry_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Industry is required.'
			),
        ),
		'address' => array(
			'address logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Address is required.'
			),
        ),
		'position_code' => array(
			'position_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Position is required.'
			),
        ),
		'title_of_learning_and_development' => array(
			'title_of_learning_and_development logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Title of learning and development is required.',
			),
        ),
		'from' => array(
			'from logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Date is required.',
			),
        ),
		'to' => array(
			'to logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Date is required.',
			),
        ),
		'number_of_hours' => array(
			'number_of_hours logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Number of hours is required.',
			),
        ),
		'type_of_ld' => array(
			'type_of_ld logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Type of LD is required.',
			),
        ),
		'conducted_sponsored_by' => array(
			'conducted_sponsored_by logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Conducted/Sponsored by is required.',
			),
        ),
	);
	
	
	public $hasMany = array(
		'LearningAndDevelopmentDetail' => array(
			'className' => 'LearningAndDevelopmentDetail',
			'foreignKey' => 'learning_and_development_code',
			'conditions'=>array(
				'status'=>'Active'
			)
		),
		'LearningAndDevelopmentHeaderAttachment' => array(
			'className' => 'LearningAndDevelopmentHeaderAttachment',
			'foreignKey' => 'learning_development_header_code',
			'conditions'=>array(
				'status'=>'Active'
			)
		),
	);
	
	public $belongsTo = array(
		'LearningAndDevelopmentType' => array(
			'className' => 'LearningAndDevelopmentType',
			'foreignKey' => 'type_of_ld',
			'conditions' => array(
				'LearningAndDevelopmentType.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['LearningAndDevelopmentHeader']['from']) && validate_datetime($this->data['LearningAndDevelopmentHeader']['from'], 'm/d/Y')) {
			$this->data['LearningAndDevelopmentHeader']['from'] = convert_datetime($this->data['LearningAndDevelopmentHeader']['from'], 'Y-m-d');
		}	
		
		if(isset($this->data['LearningAndDevelopmentHeader']['to']) && validate_datetime($this->data['LearningAndDevelopmentHeader']['to'], 'm/d/Y')) {
			$this->data['LearningAndDevelopmentHeader']['to'] = convert_datetime($this->data['LearningAndDevelopmentHeader']['to'], 'Y-m-d');
		}
	}
	
	public function beforeSave($options = array()) {
		$this->data['LearningAndDevelopmentHeader'] = AppModel::fix_date_format(
			$this->data['LearningAndDevelopmentHeader'],
			array('date_filled')
		);
		if(!isset($this->data['LearningAndDevelopmentHeader']['id'])) {
			$this->data['LearningAndDevelopmentHeader']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LearningAndDevelopmentHeader']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LearningAndDevelopmentHeader']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'NOTI';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['LearningAndDevelopmentHeader']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		
		}
		else {
			$this->data['LearningAndDevelopmentHeader']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['LearningAndDevelopmentHeader']['from'])){
				$results[$x]['LearningAndDevelopmentHeader']['from'] = date('m/d/Y',strtotime($results[$x]['LearningAndDevelopmentHeader']['from']));
			}
			
			if(isset($result['LearningAndDevelopmentHeader']['to'])){
				$results[$x]['LearningAndDevelopmentHeader']['to'] = date('m/d/Y',strtotime($results[$x]['LearningAndDevelopmentHeader']['to']));
			}
		}

		return $results;
	}
}
?>