<?php
App::uses('AppModel', 'Model');

class LearningAndDevelopmentType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
	);
	
	public function add_learning_and_development_type($data = array()) {		
		$existing_learning_and_development_type = $this->find_existing_learning_and_development_type_by_name($data['LearningAndDevelopmentType']['name']);
		
		if(isset($existing_learning_and_development_type) && count($existing_learning_and_development_type) > 0) {
			$existing_learning_and_development_type['LearningAndDevelopmentType']['status'] = 'Active';
			$data = $existing_learning_and_development_type;
			
		}

		return $this->save($data);
	}
	
	public function update_learning_and_development_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($learning_and_development_type_id = null, $learning_and_development_type = null) {
		$existing_learning_and_development_type = $this->find_existing_learning_and_development_type_by_id_or_code($learning_and_development_type_id);
		
		if(isset($existing_learning_and_development_type) && count($existing_learning_and_development_type) > 0) {
			$existing_learning_and_development_type['LearningAndDevelopmentType']['status'] = $learning_and_development_type;
			$data = $existing_learning_and_development_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_learning_and_development_type_by_name($learning_and_development_type_name = null) {
		if(isset($learning_and_development_type_name)) {
			$default_conditions = array(
				'UPPER(LearningAndDevelopmentType.name)' => strtoupper($learning_and_development_type_name)
			);
		}
		
		$learning_and_development_type = $this->find('first', array(
			'fields' => array(
				'LearningAndDevelopmentType.id',
				'LearningAndDevelopmentType.code',
				'LearningAndDevelopmentType.name',
				'LearningAndDevelopmentType.status',
				'LearningAndDevelopmentType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $learning_and_development_type;
	}
	
	public function find_existing_learning_and_development_type_by_id_or_code($learning_and_development_type_id = null) {
		if(is_numeric($learning_and_development_type_id)) {
			$default_conditions = array(
				'LearningAndDevelopmentType.id' => $learning_and_development_type_id
			);
		}
		else {
			$default_conditions = array(
				'LearningAndDevelopmentType.code' => $learning_and_development_type_id
			);
		}
		
		$learning_and_development_type = $this->find('first', array(
			'fields' => array(
				'LearningAndDevelopmentType.id',
				'LearningAndDevelopmentType.code',
				'LearningAndDevelopmentType.name',
				'LearningAndDevelopmentType.status',
				'LearningAndDevelopmentType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $learning_and_development_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['LearningAndDevelopmentType']['id'])) {
			$this->data['LearningAndDevelopmentType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LearningAndDevelopmentType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LearningAndDevelopmentType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'LDT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['LearningAndDevelopmentType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['LearningAndDevelopmentType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>