<?php
App::uses('AppModel', 'Model');

class LeaveClassification extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $hasMany = array(
		'LeaveClassificationEligibleEmployee' => array(
			'className' => 'LeaveClassificationEligibleEmployee',
			'foreignKey' => 'leave_classification_code',
			'conditions' => array(
				'LeaveClassificationEligibleEmployee.status' => 'Active'
			)
		),
		'EmployeeLeaveCard' => array(
			'className' => 'EmployeeLeaveCard',
			'foreignKey' => 'leave_classification_code',
			'conditions' => array(
				'EmployeeLeaveCard.status' => 'Active'
			)
		),
	);
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'validate_leave_classification_by_id_and_name_and_code',
				'message'	=> 'Leave Classification Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Leave Classification Name is required.'
			)
        ),
		 'code' => array(
			'code logic 1' => array(
				'rule'		=> 'validate_leave_classification_by_id_and_name_and_code',
				'message'	=> 'Leave Classification Code is already used.',
			),
			'code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Leave Classification Code is required.'
			)
        ),
		'leave_per_year' => array(
			'leave_per_year logic 1' => array(
				'rule' => 'numeric',
				'message' => 'Numbers only.',
				'allowEmpty' => true,
			),
		),
	);
	public function validate_leave_classification_by_id_and_name_and_code($validation_fields = array()) {
		$id = null;
		$leave_classification_name = $this->data['LeaveClassification']['name'];
		$leave_classification_code = $this->data['LeaveClassification']['code'];
	
		if(isset($this->data['LeaveClassification']['id'])) {
			$id = $this->data['LeaveClassification']['id'];
		}
		
		$exsisting_leave_classification = $this->find_existing_leave_classification_by_id_and_name_and_code($id, $leave_classification_name, $leave_classification_code);
		
		if(isset($exsisting_leave_classification) && count($exsisting_leave_classification) > 0) {
			return false;
		}
		else {
			return true;
		}
	
	}
	
	public function find_existing_leave_classification_by_id_and_name_and_code($id = null , $leave_classification_name = null , $leave_classification_code = null) {
		
		if(isset($leave_classification_name)) {
			$default_conditions = array(
				'LeaveClassification.name' => $leave_classification_name
			);
		}
		
		if(isset($id)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'LeaveClassification.id NOT' => $id
				)
			);
		}
		
		if(isset($leave_classification_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'LeaveClassification.code' => $leave_classification_code
				)
			);
		}
		
		$leave_classification = $this->find('first', array(
			'fields' => array(
				'LeaveClassification.id',
				'LeaveClassification.code',
				'LeaveClassification.name',
				'LeaveClassification.leave_per_year',
				'LeaveClassification.description_for_approver',
				'LeaveClassification.description_for_employee',
				'LeaveClassification.leave_classification_is',
				'LeaveClassification.auto_replenish',
				'LeaveClassification.auto_replenish_selected_date',
				'LeaveClassification.remarks',
				'LeaveClassification.status',
				'LeaveClassification.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $leave_classification;
	
	}
	
	
	
	public function add_leave_classification($data = array()) {		
		$existing_leave_classification = $this->find_existing_leave_classification_by_name_and_code($data['LeaveClassification']['name'] , $data['LeaveClassification']['code']);
		if(isset($existing_leave_classification) && count($existing_leave_classification) > 0) {
			
			$existing_leave_classification['LeaveClassification']['name'] = $data['LeaveClassification']['name'];
			$existing_leave_classification['LeaveClassification']['code'] = $data['LeaveClassification']['code'];
			$existing_leave_classification['LeaveClassification']['description_for_approver'] = $data['LeaveClassification']['description_for_approver'];
			$existing_leave_classification['LeaveClassification']['description_for_employee'] = $data['LeaveClassification']['description_for_employee'];
			$existing_leave_classification['LeaveClassification']['description_for_employee'] = $data['LeaveClassification']['description_for_employee'];
			$existing_leave_classification['LeaveClassification']['leave_per_year'] = $data['LeaveClassification']['leave_per_year'];
			$existing_leave_classification['LeaveClassification']['leave_classification_is'] = $data['LeaveClassification']['leave_classification_is'];
			$existing_leave_classification['LeaveClassification']['auto_replenish'] = $data['LeaveClassification']['auto_replenish'];
			$existing_leave_classification['LeaveClassification']['auto_replenish_selected_date'] = $data['LeaveClassification']['auto_replenish_selected_date'];
			$existing_leave_classification['LeaveClassification']['remarks'] = $data['LeaveClassification']['remarks'];
			$existing_leave_classification['LeaveClassification']['status'] = 'Active';
			$data = $existing_leave_classification;
		}
		
		if($data['LeaveClassification']['auto_replenish'] != 'on_selected_date'){
			unset($data['LeaveClassification']['auto_replenish_selected_date']);
		}

		return $this->save($data);
	}
	
	public function update_leave_classification($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($leave_classification_id = null, $leave_classification = null) {
		$existing_leave_classification = $this->find_existing_leave_classification_by_id_or_code($leave_classification_id);
		
		if(isset($existing_leave_classification) && count($existing_leave_classification) > 0) {
			$existing_leave_classification['LeaveClassification']['status'] = $leave_classification;
			$data = $existing_leave_classification;
		}

		return $this->save($data);
	}
	
	public function find_existing_leave_classification_by_name_and_code($leave_classification_name = null , $leave_classification_code) {
		if(isset($leave_classification_name)) {
			$default_conditions = array(
				'LeaveClassification.name' => $leave_classification_name
			);
		}
		if(isset($leave_classification_code)) {
			$default_conditions = array_merge($default_conditions, array(
				'LeaveClassification.code' => $leave_classification_code
			));

		}
		
		$leave_classification = $this->find('first', array(
			'fields' => array(
				'LeaveClassification.id',
				'LeaveClassification.code',
				'LeaveClassification.name',
				'LeaveClassification.leave_per_year',
				'LeaveClassification.description_for_approver',
				'LeaveClassification.description_for_employee',
				'LeaveClassification.leave_classification_is',
				'LeaveClassification.auto_replenish',
				'LeaveClassification.auto_replenish_selected_date',
				'LeaveClassification.remarks',
				'LeaveClassification.status',
				'LeaveClassification.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		return $leave_classification;
	}
	
	public function find_existing_leave_classification_by_id_or_code($leave_classification_id = null) {
		if(is_numeric($leave_classification_id)) {
			$default_conditions = array(
				'LeaveClassification.id' => $leave_classification_id,
				'LeaveClassification.status' => 'Active',
			);
		}
		else {
			$default_conditions = array(
				'LeaveClassification.code' => $leave_classification_id,
				'LeaveClassification.status' => 'Active',
			);
		}
		
		$leave_classification = $this->find('first', array(
			'fields' => array(
				'LeaveClassification.id',
				'LeaveClassification.code',
				'LeaveClassification.name',
				'LeaveClassification.leave_per_year',
				'LeaveClassification.description_for_approver',
				'LeaveClassification.description_for_employee',
				'LeaveClassification.leave_classification_is',
				'LeaveClassification.auto_replenish',
				'LeaveClassification.auto_replenish_selected_date',
				'LeaveClassification.remarks',
				'LeaveClassification.status',
				'LeaveClassification.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $leave_classification;
	}
	
	public $belongsTo = array(
		
	);
	
	public function beforeValidate($options = array()) {

		if(isset($this->data['LeaveClassification']['auto_replenish_selected_date']) && validate_datetime($this->data['LeaveClassification']['auto_replenish_selected_date'], 'm/d/Y')) {
			$this->data['LeaveClassification']['auto_replenish_selected_date'] = convert_datetime($this->data['LeaveClassification']['auto_replenish_selected_date'], 'Y-m-d');
		}	

		return true;
	}	
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['LeaveClassification']['auto_replenish_selected_date'])){
				$results[$x]['LeaveClassification']['auto_replenish_selected_date'] = date('m/d/Y',strtotime($results[$x]['LeaveClassification']['auto_replenish_selected_date']));
			}
		}

		return $results;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['LeaveClassification']['id'])) {
			$this->data['LeaveClassification']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LeaveClassification']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LeaveClassification']['status'] = 'Active';
			
		}
		else {
			$this->data['LeaveClassification']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>