<?php
App::uses('AppModel', 'Model');

class LeaveEntry extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'filing_';
	public $primaryKey = 'reference_number';
	// public $displayField = 'name';
	public $validate = array(
        'no_of_days' => array(
			'no_of_days logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'No Of Days is required.'
			),
			'no_of_days logic 1' => array(
				'rule'		=> array('validate_no_of_days'),
				'message'	=> 'No Of Days should not be less than zero (0).'
			),
        ),
		'from_date' => array(
			'from_date logic 1' => array(
				'rule'		=> array('validate_date_for_classification_code'),
				'message'	=> ' Leave Date  From is required.'
			),
        ),
		'to_date' => array(
			'to_date logic 1' => array(
				'rule'		=> array('validate_date_for_classification_code'),
				'message'	=> 'Leave Date To is required.'
			),
        ),

		'leave_classification_code' => array(
			'leave_classification_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Leave Classification is required.'
			),
        ),
		
	);
	public $belongsTo = array(
		'LeaveType' => array(
			'className' => 'LeaveType',
			'foreignKey' => 'leave_type_code',
			'fields' => array(
				'LeaveType.name',
				
			),
			'conditions' => array(
				'LeaveType.status' => 'Active'
			)
		),
		'LeaveClassification' => array(
			'className' => 'LeaveClassification',
			'foreignKey' => 'leave_classification_code',
			'fields' => array(
				'LeaveClassification.name',
				
			),
			'conditions' => array(
				'LeaveClassification.status' => 'Active'
			)
		),
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
		'ApprovedByUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_unit',
			'conditions' => array(
				'ApprovedByUnit.status' => 'Active'
			)
		),
		'ApprovedBySubUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_sub_unit',
			'conditions' => array(
				'ApprovedBySubUnit.status' => 'Active'
			)
		),
		'ApprovedBySection' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_section',
			'conditions' => array(
				'ApprovedBySection.status' => 'Active'
			)
		),
		'ApprovedByDivision' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_division',
			'conditions' => array(
				'ApprovedByDivision.status' => 'Active'
			)
		),
		'ApprovedByAdminOfficer' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_admin_officer',
			'conditions' => array(
				'ApprovedByAdminOfficer.status' => 'Active'
			)
		),
		'ApprovedByHRAdmin' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_hr_admin',
			'conditions' => array(
				'ApprovedByHRAdmin.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
		// 'SystemApprover' => array(
			// 'className' => 'SystemApprover',
			// 'foreignKey' => 'sub_unit_code',
			// 'conditions' => array(
				// 'SystemApprover.status' => 'Active'
			// )
		// ),
	);
	
	public $hasMany = array (
		'FilingLeaveEntryAttachment' => array(
			'className' => 'FilingLeaveEntryAttachment',
			'foreignKey' => 'leave_entry_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
		'EmployeeLeaveCard' => array(
			'className' => 'EmployeeLeaveCard',
			'foreignKey' => 'leave_entry_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
		'ApprovalNotification' => array(
			'className' => 'ApprovalNotification',
			'foreignKey' => 'alert_code',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
	);
	public function validate_no_of_days($validation_fields = array()) {
		$no_of_days = $this->data['LeaveEntry']['no_of_days'];
		
		if($no_of_days < 0){
			return false;
		}
		else{
			return true;
		}
		
	}
	
	public function validate_date_for_classification_code($validation_fields = array()) {
		
		$classification_code = $this->data['LeaveEntry']['leave_classification_code'];
		
		if(isset($this->data['LeaveEntry']['from_date'])){
			$from_date = $this->data['LeaveEntry']['from_date'];	
		}
		else{
			$from_date = '';
		}
		
		if(isset($this->data['LeaveEntry']['to_date'])){
			$to_date =$this->data['LeaveEntry']['to_date'];	
		}
		else{
			$to_date = '';
		}

		if($classification_code != 'LM') {

			if($from_date == null || $from_date == ''){
				return false;
			}
			else{
				return true;
			}
			
			if($to_date == null || $to_date == ''){
				return false;
			}
			else{
				return true;
			}
		}
		return true;
	}
	
	// public function check_validate_date_for_classification_code($from_date = null, $to_date = null) {
		
		
	// }
	
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['LeaveEntry']['from_date']) && validate_datetime($this->data['LeaveEntry']['from_date'], 'm/d/Y')) {
			$this->data['LeaveEntry']['from_date'] = convert_datetime($this->data['LeaveEntry']['from_date'], 'Y-m-d');
		}	
			// return true;		
		if(isset($this->data['LeaveEntry']['to_date']) && validate_datetime($this->data['LeaveEntry']['to_date'], 'm/d/Y')) {
			$this->data['LeaveEntry']['to_date'] = convert_datetime($this->data['LeaveEntry']['to_date'], 'Y-m-d');
		}
		
		if(isset($this->data['LeaveEntry']['filing_date']) && validate_datetime($this->data['LeaveEntry']['filing_date'], 'm/d/Y')) {
			$this->data['LeaveEntry']['filing_date'] = convert_datetime($this->data['LeaveEntry']['filing_date'], 'Y-m-d');
		}
		return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['LeaveEntry']['reference_number'])) {
			$this->data['LeaveEntry']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LeaveEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LeaveEntry']['status'] = 'Active';
			

			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'FLV';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['LeaveEntry']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			// debug($this->data['LaboratoryLogBook']['laboratory_case_number']);
			// exit();
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
			

		}
		else {
			$this->data['LeaveEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['LeaveEntry']['from_date'])){
				$results[$x]['LeaveEntry']['from_date'] = date('m/d/Y',strtotime($results[$x]['LeaveEntry']['from_date']));
			}
			
			if(isset($result['LeaveEntry']['to_date'])){
				$results[$x]['LeaveEntry']['to_date'] = date('m/d/Y',strtotime($results[$x]['LeaveEntry']['to_date']));
			}
			if(isset($result['LeaveEntry']['filing_date'])){
				$results[$x]['LeaveEntry']['filing_date'] = date('m/d/Y',strtotime($results[$x]['LeaveEntry']['filing_date']));
			}
			if(isset($result['LeaveEntry']['created'])){
				$results[$x]['LeaveEntry']['created'] = date('m/d/Y',strtotime($results[$x]['LeaveEntry']['created']));
			}
		}

		return $results;
	}
}
?>