<?php
App::uses('AppModel', 'Model');

class LeaveType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
				'on' => 'create'
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),
	);
	
	public function add_leave_type($data = array()) {		
		$existing_leave_type_status = $this->find_existing_leave_type_by_name($data['LeaveType']['name']);
		
		if(isset($existing_leave_type_status) && count($existing_leave_type_status) > 0) {
			$existing_leave_type_status['LeaveType']['status'] = 'Active';
			$data = $existing_leave_type_status;
			
			// return false;
		}

		return $this->save($data);
	}
	
	public function update_leave_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($leave_type_id = null, $leave_type_status = null) {
		$existing_leave_type_status = $this->find_existing_leave_type_by_id_or_code($leave_type_id);
		
		if(isset($existing_leave_type_status) && count($existing_leave_type_status) > 0) {
			$existing_leave_type_status['LeaveType']['status'] = $leave_type_status;
			$data = $existing_leave_type_status;
		}
		return $this->save($data);
	}
	
	public function find_existing_leave_type_by_name($leave_type_name = null) {
		if(isset($leave_type_name)) {
			$default_conditions = array(
				'LeaveType.name' => $leave_type_name
			);
		}
		
		$leave_type_status = $this->find('first', array(
			'fields' => array(
				'LeaveType.id',
				'LeaveType.code',
				'LeaveType.name',
				'LeaveType.status',
				'LeaveType.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions,
		));
		
		return $leave_type_status;
	}
	
	public function find_existing_leave_type_by_id_or_code($leave_type_id = null) {
		if(is_numeric($leave_type_id)) {
			$default_conditions = array(
				'LeaveType.id' => $leave_type_id
			);
		}
		else {
			$default_conditions = array(
				'LeaveType.code' => $leave_type_id
			);
		}
		
		$leave_type = $this->find('first', array(
			'fields' => array(
				'LeaveType.id',
				'LeaveType.code',
				'LeaveType.name',
				'LeaveType.status',
				'LeaveType.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions
		));
		
		return $leave_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['LeaveType']['id'])) {
			$this->data['LeaveType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LeaveType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LeaveType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'LVTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['LeaveType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['LeaveType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>