<?php
App::uses('AppModel', 'Model');

class Level extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_level($data = array()) {		
		$existing_level = $this->find_existing_level_by_name($data['Level']['name']);
		
		if(isset($existing_level) && count($existing_level) > 0) {
			$existing_level['Level']['status'] = 'Active';
			$data = $existing_level;
			
		}

		return $this->save($data);
	}
	
	public function update_level($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($level_id = null, $level = null) {
		$existing_level = $this->find_existing_level_by_id_or_code($level_id);
		
		if(isset($existing_level) && count($existing_level) > 0) {
			$existing_level['Level']['status'] = $level;
			$data = $existing_level;
		}

		return $this->save($data);
	}
	public function find_existing_level_by_name($level_name = null) {
		if(isset($level_name)) {
			$default_conditions = array(
				'Level.name' => $level_name
			);
		}
		
		$level = $this->find('first', array(
			'fields' => array(
				'Level.id',
				'Level.code',
				'Level.name',
				'Level.status',
				'Level.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $level;
	}
	public function find_existing_level_by_id_or_code($level_id = null) {
		if(is_numeric($level_id)) {
			$default_conditions = array(
				'Level.id' => $level_id
			);
		}
		else {
			$default_conditions = array(
				'Level.code' => $level_id
			);
		}
		
		$level = $this->find('first', array(
			'fields' => array(
				'Level.id',
				'Level.code',
				'Level.name',
				'Level.status',
				'Level.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $level;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Level']['id'])) {
			$this->data['Level']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Level']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Level']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'LVL';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Level']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Level']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>