<?php
App::uses('AppModel', 'Model');

class LoyaltyIncentivePayDetail extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'payroll_';
	// public $primaryKey = 'code';
	// public $displayField = 'loyalty_incentive_pay';

	public $validate = array(
        'loyalty_incentive_pay_name' => array(
			'loyalty_incentive_pay_name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Loyalty Incentive Pay Name is already used.',
				'required' => true
			),
        ),
		 'year' => array(
			'year logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Loyalty Incentive Pay Year is already used.',
				'required' => true
			),
			'year logic 2' => array(
				'rule'		=>  array('maxLength', 4),
				'message'	=> 'Please Input Valid Year',
			),
        ),
	);
	
	public $hasMany = array(
		'LoyaltyIncentivePayEmployee' => array(
			'className' => 'LoyaltyIncentivePayEmployee',
			'foreignKey' => 'loyalty_incentive_pay_id',
			'conditions'=>array(
				'status'=>'Active'
			)
		),
		'LoyaltyIncentivePayEmploymentStatus' => array(
			'className' => 'LoyaltyIncentivePayEmploymentStatus',
			'foreignKey' => 'loyalty_incentive_pay_id',
			'conditions'=>array(
				'status'=>'Active'
			)
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['LoyaltyIncentivePayDetail']['assumption_date']) && validate_datetime($this->data['LoyaltyIncentivePayDetail']['assumption_date'], 'm/d/Y')) {
			$this->data['LoyaltyIncentivePayDetail']['assumption_date'] = convert_datetime($this->data['LoyaltyIncentivePayDetail']['assumption_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['LoyaltyIncentivePayDetail']['loyalty_incentive_pay_date']) && validate_datetime($this->data['LoyaltyIncentivePayDetail']['loyalty_incentive_pay_date'], 'm/d/Y')) {
			$this->data['LoyaltyIncentivePayDetail']['loyalty_incentive_pay_date'] = convert_datetime($this->data['LoyaltyIncentivePayDetail']['loyalty_incentive_pay_date'], 'Y-m-d');
		}
		
		return true;
	}

	
	public function beforeSave($options = array()) {
		if(!isset($this->data['LoyaltyIncentivePayDetail']['id'])) {
			$this->data['LoyaltyIncentivePayDetail']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LoyaltyIncentivePayDetail']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['LoyaltyIncentivePayDetail']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'LIP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['LoyaltyIncentivePayDetail']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['LoyaltyIncentivePayDetail']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['LoyaltyIncentivePayDetail']['assumption_date'])){
				$results[$x]['LoyaltyIncentivePayDetail']['assumption_date'] = date('m/d/Y',strtotime($results[$x]['LoyaltyIncentivePayDetail']['assumption_date']));
			}
		}
		
		foreach($results as $x => $result){
			if(isset($result['LoyaltyIncentivePayDetail']['loyalty_incentive_pay_date'])){
				$results[$x]['LoyaltyIncentivePayDetail']['loyalty_incentive_pay_date'] = date('m/d/Y',strtotime($results[$x]['LoyaltyIncentivePayDetail']['loyalty_incentive_pay_date']));
			}
		}

		return $results;
	}
	
}
?>