<?php
App::uses('AppModel', 'Model');

class MedicareShare extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'payroll_';
	public $primaryKey = 'code';
	// public $displayField = 'number_of_day';
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
        'year' => array(
			'year logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Year is required.'
			)
        ),
        'month' => array(
			'month logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Month is required.'
			)
        ),
        'date_from' => array(
			'date_from logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Date From is required.'
			)
        ),
        'date_to' => array(
			'date_to logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Date To is required.'
			)
        ),
        'batch' => array(
			'batch logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Batch is required'
			),
			'batch logic 2' => array(
				'rule' 		=> array('inList', array('1st Batch', '2nd Batch')),
				'message'	=> 'Please select the proper value from the dropdown list'
			)
        ),
        'medicare_share_amount' => array(
			'medicare_share_amount logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Medicare Share Amount is required.'
			)
        ),
        'no_of_days' => array(
			'no_of_days logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'No of Days is required.'
			)
        ),
        'rate_per_day' => array(
			'rate_per_day logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Rate per Day is required.'
			)
        ),
	);
	
	public $hasMany = array(
		'EmployeeMedicareShare' => array(
			'className' => 'EmployeeMedicareShare',
			'foreignKey' => 'medicare_share_code',
			'conditions'=>array(
				'status'=>'Active'
			)
		),
		'EmploymentStatusMedicareShare' => array(
			'className' => 'EmploymentStatusMedicareShare',
			'foreignKey' => 'medicare_share_code',
			'conditions'=>array(
				'status'=>'Active'
			)
		),
	);
	
	public function beforeValidate($options = array()) {	
		if(isset($this->data['MedicareShare']['date_from']) && validate_datetime($this->data['MedicareShare']['date_from'], 'm/d/Y')) {
			$this->data['MedicareShare']['date_from'] = convert_datetime($this->data['MedicareShare']['date_from'], 'Y-m-d');
		}
		
		if(isset($this->data['MedicareShare']['date_to']) && validate_datetime($this->data['MedicareShare']['date_to'], 'm/d/Y')) {
			$this->data['MedicareShare']['date_to'] = convert_datetime($this->data['MedicareShare']['date_to'], 'Y-m-d');
		}
		
		return true;	
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['MedicareShare']['id'])) {
			$this->data['MedicareShare']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['MedicareShare']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['MedicareShare']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'MDS';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['MedicareShare']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['MedicareShare']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>