<?php
App::uses('AppModel', 'Model');

class ModeOfPayment extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),	
	);
	
	public function add_mode_of_payment($data = array()) {		
		$existing_mode_of_payment = $this->find_existing_mode_of_payment_by_name($data['ModeOfPayment']['name']);
		
		if(isset($existing_mode_of_payment) && count($existing_mode_of_payment) > 0) {
			$existing_mode_of_payment['ModeOfPayment']['status'] = 'Active';
			$data = $existing_mode_of_payment;

		}

		return $this->save($data);
	}
	
	public function update_mode_of_payment($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($mode_of_payment_id = null, $mode_of_payment = null) {
		$existing_mode_of_payment = $this->find_existing_mode_of_payment_by_id_or_code($mode_of_payment_id);
		
		if(isset($existing_mode_of_payment) && count($existing_mode_of_payment) > 0) {
			$existing_mode_of_payment['ModeOfPayment']['status'] = $mode_of_payment;
			$data = $existing_mode_of_payment;
		}
		return $this->save($data);
	}
	
	public function find_existing_mode_of_payment_by_name($mode_of_payment_name = null) {
		if(isset($mode_of_payment_name)) {
			$default_conditions = array(
				'ModeOfPayment.name' => $mode_of_payment_name
			);
		}
		
		$mode_of_payment = $this->find('first', array(
			'fields' => array(
				'ModeOfPayment.id',
				'ModeOfPayment.code',
				'ModeOfPayment.name',
				'ModeOfPayment.status',
				'ModeOfPayment.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions
		));
		
		return $mode_of_payment;
	}
	
	public function find_existing_mode_of_payment_by_id_or_code($mode_of_payment_id = null) {
		if(is_numeric($mode_of_payment_id)) {
			$default_conditions = array(
				'ModeOfPayment.id' => $mode_of_payment_id
			);
		}
		else {
			$default_conditions = array(
				'ModeOfPayment.code' => $mode_of_payment_id
			);
		}
		
		$mode_of_payment = $this->find('first', array(
			'fields' => array(
				'ModeOfPayment.id',
				'ModeOfPayment.code',
				'ModeOfPayment.name',
				'ModeOfPayment.status',
				'ModeOfPayment.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions
		));
		
		return $mode_of_payment;
	}
	

	public function beforeSave($options = array()) {
		if(!isset($this->data['ModeOfPayment']['id'])) {
			$this->data['ModeOfPayment']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ModeOfPayment']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ModeOfPayment']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'MOP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ModeOfPayment']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ModeOfPayment']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>