<?php
App::uses('AppModel', 'Model');

class NatureOfAppointment extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_nature_of_appointment($data = array()) {		
		$existing_nature_of_appointment = $this->find_existing_nature_of_appointment_by_name($data['NatureOfAppointment']['name']);
		
		if(isset($existing_nature_of_appointment) && count($existing_nature_of_appointment) > 0) {
			$existing_nature_of_appointment['NatureOfAppointment']['status'] = 'Active';
			$data = $existing_nature_of_appointment;

		}

		return $this->save($data);
	}
	
	public function update_nature_of_appointment($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($nature_of_appointment_id = null, $nature_of_appointment = null) {
		$existing_nature_of_appointment = $this->find_existing_nature_of_appointment_by_id_or_code($nature_of_appointment_id);
		
		if(isset($existing_nature_of_appointment) && count($existing_nature_of_appointment) > 0) {
			$existing_nature_of_appointment['NatureOfAppointment']['status'] = $nature_of_appointment;
			$data = $existing_nature_of_appointment;
		}
		return $this->save($data);
	}
	
	public function find_existing_nature_of_appointment_by_name($nature_of_appointment_name = null) {
		if(isset($nature_of_appointment_name)) {
			$default_conditions = array(
				'NatureOfAppointment.name' => $nature_of_appointment_name
			);
		}
		
		$nature_of_appointment = $this->find('first', array(
			'fields' => array(
				'NatureOfAppointment.id',
				'NatureOfAppointment.code',
				'NatureOfAppointment.name',
				'NatureOfAppointment.status',
				'NatureOfAppointment.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions
		));
		
		return $nature_of_appointment;
	}
	
	public function find_existing_nature_of_appointment_by_id_or_code($nature_of_appointment_id = null) {
		if(is_numeric($nature_of_appointment_id)) {
			$default_conditions = array(
				'NatureOfAppointment.id' => $nature_of_appointment_id
			);
		}
		else {
			$default_conditions = array(
				'NatureOfAppointment.code' => $nature_of_appointment_id
			);
		}
		
		$nature_of_appointment = $this->find('first', array(
			'fields' => array(
				'NatureOfAppointment.id',
				'NatureOfAppointment.code',
				'NatureOfAppointment.name',
				'NatureOfAppointment.status',
				'NatureOfAppointment.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions
		));
		
		return $nature_of_appointment;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['NatureOfAppointment']['id'])) {
			$this->data['NatureOfAppointment']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['NatureOfAppointment']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['NatureOfAppointment']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'NOA';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['NatureOfAppointment']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['NatureOfAppointment']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>