<?php
App::uses('AppModel', 'Model');

class NumberOfOffense extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		
	);
	public $hasMany = array(
		'EmployeeAdministrativeOffense' => array(
			'className' => 'EmployeeAdministrativeOffense',
			'foreignKey' => 'administrative_case_code',
		),
	);
	
	public function add_number_of_offense($data = array()) {		
		$existing_number_of_offense = $this->find_existing_number_of_offense_by_name($data['NumberOfOffense']['name']);
		
		if(isset($existing_number_of_offense) && count($existing_number_of_offense) > 0) {
			$existing_number_of_offense['NumberOfOffense']['status'] = 'Active';
			$data = $existing_number_of_offense;			
		}
		return $this->saveAll($data);
	}
	
	public function update_number_of_offense($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($number_of_offense_id = null, $number_of_offense = null) {
		$existing_number_of_offense = $this->find_existing_number_of_offense_by_id_or_code($number_of_offense_id);
		
		if(isset($existing_number_of_offense) && count($existing_number_of_offense) > 0) {
			$existing_number_of_offense['NumberOfOffense']['status'] = $number_of_offense;
			$data = $existing_number_of_offense;
		}

		return $this->save($data);
	}
	
	public function find_existing_number_of_offense_by_name($number_of_offense_name = null) {
		if(isset($number_of_offense_name)) {
			$default_conditions = array(
				'UPPER(NumberOfOffense.name)' => strtoupper($number_of_offense_name)
			);
		}
		
		$number_of_offense = $this->find('first', array(
			'fields' => array(
				'NumberOfOffense.id',
				'NumberOfOffense.code',
				'NumberOfOffense.name',
				'NumberOfOffense.status',
				'NumberOfOffense.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions
		));
		
		return $number_of_offense;
	}
	
	public function find_existing_number_of_offense_by_id_or_code($number_of_offense_id = null) {
		if(is_numeric($number_of_offense_id)) {
			$default_conditions = array(
				'NumberOfOffense.id' => $number_of_offense_id
			);
		}
		else {
			$default_conditions = array(
				'NumberOfOffense.code' => $number_of_offense_id
			);
		}
		
		$number_of_offense = $this->find('first', array(
			'fields' => array(
				'NumberOfOffense.id',
				'NumberOfOffense.code',
				'NumberOfOffense.name',
				'NumberOfOffense.status',
				'NumberOfOffense.lock_flag'
			),
			'recursive' => -1,
			'conditions' => $default_conditions
		));
		
		return $number_of_offense;
	}
	
	public function beforeSave($options = array()) {

		if(!isset($this->data['NumberOfOffense']['id'])) {
			$this->data['NumberOfOffense']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['NumberOfOffense']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['NumberOfOffense']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'OFFS';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['NumberOfOffense']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['NumberOfOffense']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>