<?php
App::uses('AppModel', 'Model');

class OtherPersonnelActionType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_other_personnel_action_type($data = array()) {		
		$existing_other_personnel_action_type = $this->find_existing_other_personnel_action_type_by_name($data['OtherPersonnelActionType']['name']);
		
		if(isset($existing_other_personnel_action_type) && count($existing_other_personnel_action_type) > 0) {
			$existing_other_personnel_action_type['OtherPersonnelActionType']['status'] = 'Active';
			$data = $existing_other_personnel_action_type;
			
		}

		return $this->save($data);
	}
	
	public function update_other_personnel_action_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($other_personnel_action_type_id = null, $other_personnel_action_type = null) {
		$existing_other_personnel_action_type = $this->find_existing_other_personnel_action_type_by_id_or_code($other_personnel_action_type_id);
		
		if(isset($existing_other_personnel_action_type) && count($existing_other_personnel_action_type) > 0) {
			$existing_other_personnel_action_type['OtherPersonnelActionType']['status'] = $other_personnel_action_type;
			$data = $existing_other_personnel_action_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_other_personnel_action_type_by_name($other_personnel_action_type_name = null) {
		if(isset($other_personnel_action_type_name)) {
			$default_conditions = array(
				'OtherPersonnelActionType.name' => $other_personnel_action_type_name
			);
		}
		
		$other_personnel_action_type = $this->find('first', array(
			'fields' => array(
				'OtherPersonnelActionType.id',
				'OtherPersonnelActionType.code',
				'OtherPersonnelActionType.name',
				'OtherPersonnelActionType.status',
				'OtherPersonnelActionType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $other_personnel_action_type;
	}
	
	public function find_existing_other_personnel_action_type_by_id_or_code($other_personnel_action_type_id = null) {
		if(is_numeric($other_personnel_action_type_id)) {
			$default_conditions = array(
				'OtherPersonnelActionType.id' => $other_personnel_action_type_id
			);
		}
		else {
			$default_conditions = array(
				'OtherPersonnelActionType.code' => $other_personnel_action_type_id
			);
		}
		
		$other_personnel_action_type = $this->find('first', array(
			'fields' => array(
				'OtherPersonnelActionType.id',
				'OtherPersonnelActionType.code',
				'OtherPersonnelActionType.name',
				'OtherPersonnelActionType.status',
				'OtherPersonnelActionType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $other_personnel_action_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['OtherPersonnelActionType']['id'])) {
			$this->data['OtherPersonnelActionType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['OtherPersonnelActionType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['OtherPersonnelActionType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'OPA';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['OtherPersonnelActionType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['OtherPersonnelActionType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>