<?php
App::uses('AppModel', 'Model');

class OvertimeAuthorityEntry extends AppModel {
	
	// public $tablePrefix = 'filing_';
	public $actsAs = array('AuditLog.Auditable');
	public $primaryKey = 'reference_number';
	
	public $hasMany= array(
		'OvertimeAuthorityEntryList' => array(
			'className' => 'OvertimeAuthorityEntryList',
			'foreignKey' => 'overtime_authority_entry_reference_number',
			// 'fields' => array(
				// 'OvertimeAuthorityEntryList.id',
				// 'OvertimeAuthorityEntryList.item_master_list_item_code',
				// 'ConsignmentOrderRequestEntryItem.quantity',
				// 'OvertimeAuthorityEntryList.original_quantity',
				// 'ConsignmentOrderRequestEntryItem.landed_cost',
				// 'ConsignmentOrderRequestEntryItem.remarks',
				// 'ConsignmentOrderRequestEntryItem.department_code'
			// ),
			'conditions' => array(
				'OvertimeAuthorityEntryList.status' => 'Active'
			)
		),
	);
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'officer_employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'RequestedBy' => array(
			'className' => 'Employee',
			'foreignKey' => 'requested_by',

			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'RecommendingApproval' => array(
			'className' => 'Employee',
			'foreignKey' => 'recommending_approval',
			'conditions' => array(
				'RecommendingApproval.status' => 'Active'
			),
		),
		'ApprovedBy' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by',
			'conditions' => array(
				'ApprovedBy.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['OvertimeAuthorityEntry']['filing_date']) && validate_datetime($this->data['OvertimeAuthorityEntry']['filing_date'], 'm/d/Y')) {
			$this->data['OvertimeAuthorityEntry']['filing_date'] = convert_datetime($this->data['OvertimeAuthorityEntry']['filing_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['OvertimeAuthorityEntry']['period_covered']) && validate_datetime($this->data['OvertimeAuthorityEntry']['period_covered'], 'm/d/Y')) {
			$this->data['OvertimeAuthorityEntry']['period_covered'] = convert_datetime($this->data['OvertimeAuthorityEntry']['period_covered'], 'Y-m-d');
		}	
		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['OvertimeAuthorityEntry']['id'])) {
			$this->data['OvertimeAuthorityEntry']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['OvertimeAuthorityEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['OvertimeAuthorityEntry']['status'] = 'Active';
		
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'OTA';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['OvertimeAuthorityEntry']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['OvertimeAuthorityEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['OvertimeAuthorityEntry']['filing_date'])){
				$results[$x]['OvertimeAuthorityEntry']['filing_date'] = date('m/d/Y',strtotime($results[$x]['OvertimeAuthorityEntry']['filing_date']));
			}
			
			if(isset($result['OvertimeAuthorityEntry']['period_covered'])){
				$results[$x]['OvertimeAuthorityEntry']['period_covered'] = date('m/d/Y',strtotime($results[$x]['OvertimeAuthorityEntry']['period_covered']));
			}
		}

		return $results;
	}
}
?>