<?php
App::uses('AppModel', 'Model');

class PayrollDetail extends AppModel {
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	
	public $validate = array(
        // 'payroll_type_code' => array(
			// 'payroll_type_code logic 1' => array(
				// 'rule'		=> 'notEmpty',
				// 'message'	=> 'Type Code is required'
			// )
        // ),
        // 'payroll_behavior' => array(
			// 'payroll_behavior logic 1' => array(
				// 'rule'		=> 'notEmpty',
				// 'message'	=> 'Behavior is required'
			// )
        // ),
		'rice_allowance' => array(
			'rice_allowance logic 1' => array(
				'rule'		=> array('comparison','>=',0),
				'message'	=> 'Value cannot be negative',
				 'allowEmpty' => true,
			)
        )
	);
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			)
		),
		'PayrollType' => array(
			'className' => 'PayrollType',
			'foreignKey' => 'payroll_type_code',
			'fields' => array(
				'PayrollType.code',
				'PayrollType.name',
			),
			'conditions' => array(
				'PayrollType.status' => 'Active'
			)
		),
		'TaxStatus' => array(
			'className' => 'TaxStatus',
			'foreignKey' => 'tax_status_code',
			'fields' => array(
				'TaxStatus.code',
				'TaxStatus.name',
			),
			'conditions' => array(
				'TaxStatus.status' => 'Active'
			)
		),
		'SalaryGrade' => array(
			'className' => 'SalaryGrade',
			'foreignKey' => 'salary_grade_code',
			'conditions' => array(
				'SalaryGrade.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'position_detail_id',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array(
		'PayrollDetailHistoryLog' => array(
			'className' => 'PayrollDetailHistoryLog',
			'foreignKey' => 'payroll_detail_id',
			'fields' => array(
				'PayrollDetailHistoryLog.payroll_detail_id',
				'PayrollDetailHistoryLog.employee_code',
				'PayrollDetailHistoryLog.monthly_rate',
				'PayrollDetailHistoryLog.semi_monthly_rate',
				'PayrollDetailHistoryLog.daily_rate',
				'PayrollDetailHistoryLog.hourly_rate',
				'PayrollDetailHistoryLog.food_allowance',
				'PayrollDetailHistoryLog.cola',
				'PayrollDetailHistoryLog.tax_shield',
				'PayrollDetailHistoryLog.transportation_allowance',
				'PayrollDetailHistoryLog.payroll_type_code',
				'PayrollDetailHistoryLog.payroll_behavior',
				'PayrollDetailHistoryLog.has_holiday_pay',
				'PayrollDetailHistoryLog.has_night_differential_pay',
				'PayrollDetailHistoryLog.tax_status_code',
				'PayrollDetailHistoryLog.phic_employee_share',
				'PayrollDetailHistoryLog.phic_employer_share',
				'PayrollDetailHistoryLog.pagibig_employee_share',
				'PayrollDetailHistoryLog.pagibig_employer_share',
				'PayrollDetailHistoryLog.gsis_employee_share',
				'PayrollDetailHistoryLog.gsis_employer_share',
				'PayrollDetailHistoryLog.sss_employee_share',
				'PayrollDetailHistoryLog.sss_employer_share',
			),
			'conditions' => array(
				'PayrollDetailHistoryLog.status' => 'Active'
			)
		),
		'SalaryAdjustment' => array(
			'className' => 'SalaryAdjustment',
			'foreignKey' => 'payroll_detail_id',
			'conditions' => array(
				'SalaryAdjustment.status' => 'Active'
			)
		),
	);
	
	public function add_many_payroll_details_from_phic_contribution_table($data = array()){
		
		if(!empty($data)){
			return $this->saveMany($data);
		}
		return false;
	}
	
	public function beforeValidate($options = array()) {	
		if(isset($this->data['PayrollDetail']['salary_increase_date']) && validate_datetime($this->data['PayrollDetail']['salary_increase_date'], 'm/d/Y')) {
			$this->data['PayrollDetail']['salary_increase_date'] = convert_datetime($this->data['PayrollDetail']['salary_increase_date'], 'Y-m-d');
		}
		
		if(isset($this->data['PayrollDetail']['promotion_increase_date']) && validate_datetime($this->data['PayrollDetail']['promotion_increase_date'], 'm/d/Y')) {
			$this->data['PayrollDetail']['promotion_increase_date'] = convert_datetime($this->data['PayrollDetail']['promotion_increase_date'], 'Y-m-d');
		}
		
		if(isset($this->data['PayrollDetail']['step_increment_increase_date']) && validate_datetime($this->data['PayrollDetail']['step_increment_increase_date'], 'm/d/Y')) {
			$this->data['PayrollDetail']['step_increment_increase_date'] = convert_datetime($this->data['PayrollDetail']['step_increment_increase_date'], 'Y-m-d');
		}
		
		return true;	
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['PayrollDetail']['id'])) {
			$this->data['PayrollDetail']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollDetail']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollDetail']['status'] = 'Active';
		}
		else {
			$this->data['PayrollDetail']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PayrollDetail']['salary_increase_date'])){
				$results[$x]['PayrollDetail']['salary_increase_date'] = date('m/d/Y',strtotime($results[$x]['PayrollDetail']['salary_increase_date']));
			}
			
			if(isset($result['PayrollDetail']['promotion_increase_date'])){
				$results[$x]['PayrollDetail']['promotion_increase_date'] = date('m/d/Y',strtotime($results[$x]['PayrollDetail']['promotion_increase_date']));
			}
			
			if(isset($result['PayrollDetail']['step_increment_increase_date'])){
				$results[$x]['PayrollDetail']['step_increment_increase_date'] = date('m/d/Y',strtotime($results[$x]['PayrollDetail']['step_increment_increase_date']));
			}
		}
		 // debug($results);		
		// exit();
		return $results;
	}
	
}
?>