<?php
App::uses('AppModel', 'Model');

class PayrollLongevityPay extends AppModel {
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'payroll_';
	public $primaryKey = 'reference_number';
	
	
	public $belongsTo = array(
		'EmploymentStatus' => array(
			'className' => 'EmploymentStatus',
			'foreignKey' => 'employment_status_code',
		),
		'PayrollPeriod' => array(
			'className' => 'PayrollPeriod',
			'foreignKey' => 'payroll_period',
		),
	);
	
	public $hasMany = array(
		'GeneratedLongevityPay' => array(
			'className' => 'GeneratedLongevityPay',
			'foreignKey' => 'longevity_pay_reference_number',
			'conditions' => array(
				'GeneratedLongevityPay.status' => 'Active'
			)
		),
		'PayrollLongevityPayEmploymentStatus' => array(
			'className' => 'PayrollLongevityPayEmploymentStatus',
			'foreignKey' => 'payroll_longevity_pay_code',
			'fields' => array(
				'employment_status_code',
				'employment_status_name',
			),
			'conditions' => array(
				'PayrollLongevityPayEmploymentStatus.status' => 'Active'
			),
		),
	);
	public function beforeValidate($options = array()) {
		if(isset($this->data['PayrollLongevityPay']['longevity_pay_date']) && validate_datetime($this->data['PayrollLongevityPay']['longevity_pay_date'], 'm/d/Y')) {
			$this->data['PayrollLongevityPay']['longevity_pay_date'] = convert_datetime($this->data['PayrollLongevityPay']['longevity_pay_date'], 'Y-m-d');
		}	
		
		return true;
	}

	public function beforeSave($options = array()) {
		if(!isset($this->data['PayrollLongevityPay']['reference_number'])) {
			$this->data['PayrollLongevityPay']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollLongevityPay']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollLongevityPay']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'PLP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			
			$this->data['PayrollLongevityPay']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PayrollLongevityPay']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PayrollLongevityPay']['longevity_pay_date'])){
				$results[$x]['PayrollLongevityPay']['longevity_pay_date'] = date('m/d/Y',strtotime($results[$x]['PayrollLongevityPay']['longevity_pay_date']));
			}
		}

		return $results;
	}
	
}
?>