<?php
App::uses('AppModel', 'Model');

class PayrollNightDifferentialPeriod extends AppModel { 
	public $actsAs = array('AuditLog.Auditable'); 
	public $primaryKey = 'code';
	public $displayField = 'payroll_type';
	public $validate = array(
	
        'night_differential_payroll_name' => array(
			'night_differential_payroll_name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Night Differential Payroll Name is already used.',
			),
			'night_differential_payroll_name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Night Differential Payroll Name is required.'
			)
        ),
		'payroll_code' => array(
			'payroll_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Payroll Period is required.'
			)
        ), 
	);
	
	public $belongsTo = array(
		'PayrollType' => array(
			'className' => 'PayrollType',
			'foreignKey' => 'payroll_type',
		),
		'PayrollPeriod' => array(
			'className' => 'PayrollPeriod',
			'foreignKey' => 'payroll_code',
		),
		'PayrollCycle' => array(
			'className' => 'PayrollCycle',
			'foreignKey' => 'payroll_cycle',
		),
		'EmploymentStatus' => array(
			'className' => 'EmploymentStatus',
			'foreignKey' => 'employment_status_code',
		),
	);
	
	public $hasMany = array(
		'GeneratedPayrollNightDifferential' => array(
			'className' => 'GeneratedPayrollNightDifferential',
			'foreignKey' => 'payroll_night_differential_code',
			'conditions' => array(
				'GeneratedPayrollNightDifferential.status' => 'Active'
			)
		),
	);
	
	public $virtualFields= array(
		'PayrollNightDifferentialPeriodFromTo'=> 'CONCAT(PayrollNightDifferentialPeriod.from, " to ", PayrollNightDifferentialPeriod.to)',
	);
	
	public function beforeValidate($options = array()) {
		
		if(isset($this->data['PayrollNightDifferentialPeriod']['payroll_date']) && validate_datetime($this->data['PayrollNightDifferentialPeriod']['payroll_date'], 'm/d/Y')) {
			$this->data['PayrollNightDifferentialPeriod']['payroll_date'] = convert_datetime($this->data['PayrollNightDifferentialPeriod']['payroll_date'], 'Y-m-d');
		}	
		if(isset($this->data['PayrollNightDifferentialPeriod']['pay_date']) && validate_datetime($this->data['PayrollNightDifferentialPeriod']['pay_date'], 'm/d/Y')) {
			$this->data['PayrollNightDifferentialPeriod']['pay_date'] = convert_datetime($this->data['PayrollNightDifferentialPeriod']['pay_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['PayrollNightDifferentialPeriod']['from']) && validate_datetime($this->data['PayrollNightDifferentialPeriod']['from'], 'm/d/Y')) {
			$this->data['PayrollNightDifferentialPeriod']['from'] = convert_datetime($this->data['PayrollNightDifferentialPeriod']['from'], 'Y-m-d');
		}
		
		if(isset($this->data['PayrollNightDifferentialPeriod']['to']) && validate_datetime($this->data['PayrollNightDifferentialPeriod']['to'], 'm/d/Y')) {
			$this->data['PayrollNightDifferentialPeriod']['to'] = convert_datetime($this->data['PayrollNightDifferentialPeriod']['to'], 'Y-m-d');
		}
		
		if(isset($this->data['PayrollNightDifferentialPeriod']['assumption_date']) && validate_datetime($this->data['PayrollNightDifferentialPeriod']['assumption_date'], 'm/d/Y')) {
			$this->data['PayrollNightDifferentialPeriod']['assumption_date'] = convert_datetime($this->data['PayrollNightDifferentialPeriod']['assumption_date'], 'Y-m-d');
		}
		return true;
	}	
	
	public function beforeSave($options = array()) {
		$this->data['PayrollNightDifferentialPeriod'] = AppModel::fix_date_format(
			$this->data['PayrollNightDifferentialPeriod'],
			array('payroll_date','from','to','pay_date')
		);
		if(!isset($this->data['PayrollNightDifferentialPeriod']['code'])) {
			$this->data['PayrollNightDifferentialPeriod']['generated'] = 1;
			$this->data['PayrollNightDifferentialPeriod']['generated_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollNightDifferentialPeriod']['generated_date'] = date("Y-m-d H;i:s");
			$this->data['PayrollNightDifferentialPeriod']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollNightDifferentialPeriod']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollNightDifferentialPeriod']['status'] = 'Active';
	 
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'PNDP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['PayrollNightDifferentialPeriod']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PayrollNightDifferentialPeriod']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PayrollNightDifferentialPeriod']['payroll_date'])){
				$results[$x]['PayrollNightDifferentialPeriod']['payroll_date'] = date('m/d/Y',strtotime($results[$x]['PayrollNightDifferentialPeriod']['payroll_date']));
			}
			if(isset($result['PayrollNightDifferentialPeriod']['pay_date'])){
				$results[$x]['PayrollNightDifferentialPeriod']['pay_date'] = date('m/d/Y',strtotime($results[$x]['PayrollNightDifferentialPeriod']['pay_date']));
			}
			if(isset($result['PayrollNightDifferentialPeriod']['from'])){
				$results[$x]['PayrollNightDifferentialPeriod']['from'] = date('m/d/Y',strtotime($results[$x]['PayrollNightDifferentialPeriod']['from']));
			}
			if(isset($result['PayrollNightDifferentialPeriod']['to'])){
				$results[$x]['PayrollNightDifferentialPeriod']['to'] = date('m/d/Y',strtotime($results[$x]['PayrollNightDifferentialPeriod']['to']));
			}	
			if(isset($result['PayrollNightDifferentialPeriod']['assumption_date'])){
				$results[$x]['PayrollNightDifferentialPeriod']['assumption_date'] = date('m/d/Y',strtotime($results[$x]['PayrollNightDifferentialPeriod']['assumption_date']));
			}	
		}
		return $results;
	}
}
?>