<?php
App::uses('AppModel', 'Model');

class PayrollOvertimePeriod extends AppModel {
	
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'payroll_type';
	
	public $belongsTo = array(
		'PayrollType' => array(
			'className' => 'PayrollType',
			'foreignKey' => 'payroll_type',
		),
		'PayrollCycle' => array(
			'className' => 'PayrollCycle',
			'foreignKey' => 'payroll_cycle',
		),
		'EmploymentStatus' => array(
			'className' => 'EmploymentStatus',
			'foreignKey' => 'employment_status_code',
		),
	);
	
	public $hasMany = array(
		'GeneratedPayrollOvertime' => array(
			'className' => 'GeneratedPayrollOvertime',
			'foreignKey' => 'payroll_overtime_code',
		),
	);
	
	public $virtualFields= array(
		'PayrollOvertimePeriodFromTo'=> 'CONCAT(PayrollOvertimePeriod.from, " to ", PayrollOvertimePeriod.to)',
	);
	

	public function beforeValidate($options = array()) {
		if(isset($this->data['PayrollOvertimePeriod']['payroll_date']) && validate_datetime($this->data['PayrollOvertimePeriod']['payroll_date'], 'm/d/Y')) {
			$this->data['PayrollOvertimePeriod']['payroll_date'] = convert_datetime($this->data['PayrollOvertimePeriod']['payroll_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['PayrollOvertimePeriod']['from']) && validate_datetime($this->data['PayrollOvertimePeriod']['from'], 'm/d/Y')) {
			$this->data['PayrollOvertimePeriod']['from'] = convert_datetime($this->data['PayrollOvertimePeriod']['from'], 'Y-m-d');
		}
		
		if(isset($this->data['PayrollOvertimePeriod']['to']) && validate_datetime($this->data['PayrollOvertimePeriod']['to'], 'm/d/Y')) {
			$this->data['PayrollOvertimePeriod']['to'] = convert_datetime($this->data['PayrollOvertimePeriod']['to'], 'Y-m-d');
		}
		return true;
	}		
	
	public function beforeSave($options = array()) {
		$this->data['PayrollOvertimePeriod'] = AppModel::fix_date_format(
			$this->data['PayrollOvertimePeriod'],
			array('payroll_date','from','to','pay_date')
		);
		if(!isset($this->data['PayrollOvertimePeriod']['code'])) {
			$this->data['PayrollOvertimePeriod']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollOvertimePeriod']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollOvertimePeriod']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'POP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['PayrollOvertimePeriod']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PayrollOvertimePeriod']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PayrollOvertimePeriod']['payroll_date'])){
				$results[$x]['PayrollOvertimePeriod']['payroll_date'] = date('m/d/Y',strtotime($results[$x]['PayrollOvertimePeriod']['payroll_date']));
			}
			if(isset($result['PayrollOvertimePeriod']['from'])){
				$results[$x]['PayrollOvertimePeriod']['from'] = date('m/d/Y',strtotime($results[$x]['PayrollOvertimePeriod']['from']));
			}
			if(isset($result['PayrollOvertimePeriod']['to'])){
				$results[$x]['PayrollOvertimePeriod']['to'] = date('m/d/Y',strtotime($results[$x]['PayrollOvertimePeriod']['to']));
			}	
		}
		return $results;
	}
	
}
?>