<?php
App::uses('AppModel', 'Model');

class PayrollPeriod extends AppModel {
	
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'payroll_type';
	
	public $belongsTo = array(
		'PayrollType' => array(
			'className' => 'PayrollType',
			'foreignKey' => false,
			'conditions'=>array(
				'PayrollType.code = PayrollPeriod.payroll_type'
			)
		),
		'PayrollCycle' => array(
			'className' => 'PayrollCycle',
			'foreignKey' => 'payroll_cycle',
		),
		'EmploymentStatus' => array(
			'className' => 'EmploymentStatus',
			'foreignKey' => 'employment_status_code',
		),
	);
	
	public $hasMany = array(
		'GeneratedPayroll' => array(
			'className' => 'GeneratedPayroll',
			'foreignKey' => 'payroll_period_code',
		),
		'GeneratedPayrollDeductionAndLoanPayment' => array(
			'className' => 'GeneratedPayrollDeductionAndLoanPayment',
			'foreignKey' => 'payroll_period_code',
		),
		'GeneratedPayrollIncomeAndBenefit' => array(
			'className' => 'GeneratedPayrollIncomeAndBenefit',
			'foreignKey' => 'payroll_period_code',
		),
	);
	
	public $virtualFields= array(
		'PayrollPeriodFromTo'=> 'CONCAT(PayrollPeriod.from, " to ", PayrollPeriod.to)',
		'PayrollPeriodDateFromTo'=> 'CONCAT(DATE_FORMAT(PayrollPeriod.payroll_date, "%m/%d/%Y"), " - ",DATE_FORMAT(PayrollPeriod.from, "%m/%d/%Y"), "-", DATE_FORMAT(PayrollPeriod.to, "%m/%d/%Y"))',
	);
	
	// public function beforeValidate($options = array()) {
		// if(isset($this->data['PayrollPeriod']['from']) && validate_datetime($this->data['PayrollPeriod']['from'], 'm/d/Y')) {
			// $this->data['PayrollPeriod']['from'] = convert_datetime($this->data['PayrollPeriod']['from'], 'Y-m-d');
		// }	
		
		// if(isset($this->data['PayrollPeriod']['to']) && validate_datetime($this->data['PayrollPeriod']['to'], 'm/d/Y')) {
			// $this->data['PayrollPeriod']['to'] = convert_datetime($this->data['PayrollPeriod']['to'], 'Y-m-d');
		// }
		// return true;
	// }	
	
	public function beforeSave($options = array()) {
		$this->data['PayrollPeriod'] = AppModel::fix_date_format(
			$this->data['PayrollPeriod'],
			array('payroll_date','from','to','pay_date')
		);
		if(!isset($this->data['PayrollPeriod']['code'])) {
			$this->data['PayrollPeriod']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollPeriod']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollPeriod']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'PP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['PayrollPeriod']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PayrollPeriod']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
		public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PayrollPeriod']['payroll_date'])){
				$results[$x]['PayrollPeriod']['payroll_date'] = date('m/d/Y',strtotime($results[$x]['PayrollPeriod']['payroll_date']));
			}
			if(isset($result['PayrollPeriod']['to'])){
				$results[$x]['PayrollPeriod']['to'] = date('m/d/Y',strtotime($results[$x]['PayrollPeriod']['to']));
			}
			if(isset($result['PayrollPeriod']['from'])){
				$results[$x]['PayrollPeriod']['from'] = date('m/d/Y',strtotime($results[$x]['PayrollPeriod']['from']));
			}
			
			
		}
		 // debug($results);		
		// exit();
		return $results;
	}
}
?>