<?php
App::uses('AppModel', 'Model');

class PayrollType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_payroll_type($data = array()) {		
		$existing_payroll_type = $this->find_existing_payroll_type_by_name($data['PayrollType']['name']);
		
		if(isset($existing_payroll_type) && count($existing_payroll_type) > 0) {
			$existing_payroll_type['PayrollType']['status'] = 'Active';
			$data = $existing_payroll_type;
			
		}

		return $this->save($data);
	}
	
	public function update_payroll_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($payroll_type_id = null, $payroll_type = null) {
		$existing_payroll_type = $this->find_existing_payroll_type_by_id_or_code($payroll_type_id);
		
		if(isset($existing_payroll_type) && count($existing_payroll_type) > 0) {
			$existing_payroll_type['PayrollType']['status'] = $payroll_type;
			$data = $existing_payroll_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_payroll_type_by_name($payroll_type_name = null) {
		if(isset($payroll_type_name)) {
			$default_conditions = array(
				'PayrollType.name' => $payroll_type_name
			);
		}
		
		$payroll_type = $this->find('first', array(
			'fields' => array(
				'PayrollType.id',
				'PayrollType.code',
				'PayrollType.name',
				'PayrollType.status',
				'PayrollType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $payroll_type;
	}
	
	public function find_existing_payroll_type_by_id_or_code($payroll_type_id = null) {
		if(is_numeric($payroll_type_id)) {
			$default_conditions = array(
				'PayrollType.id' => $payroll_type_id
			);
		}
		else {
			$default_conditions = array(
				'PayrollType.code' => $payroll_type_id
			);
		}
		
		$payroll_type = $this->find('first', array(
			'fields' => array(
				'PayrollType.id',
				'PayrollType.code',
				'PayrollType.name',
				'PayrollType.status',
				'PayrollType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $payroll_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['PayrollType']['id'])) {
			$this->data['PayrollType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PayrollType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'PAYTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['PayrollType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PayrollType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>