<?php
App::uses('AppModel', 'Model');

class PermissionToLeave extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'filing_';
	public $primaryKey = 'reference_number';
	public $displayField = 'activity_title';
	
	public $validate = array(
        'no_of_hours' => array(
			'no_of_hours logic 1' => array(
				'rule' => 'notEmpty',
				'message'	=> 'No. of hours is required.'
			),
        ),
		// 'activity_title' => array(
			// 'activity_title logic 1' => array(
				// 'rule' => 'notEmpty',
				// 'message'	=> 'Purpose is required.'
			// ),
        // ),
		
		'date' => array(
			'date_from logic 1' => array(
				'rule' => 'notEmpty',
				'message'	=> 'Date From is required.'
			),
        ),
		'date_from' => array(
			'date_from logic 1' => array(
				'rule' => 'notEmpty',
				'message'	=> 'Date From is required.'
			),
        ),
		'date_to' => array(
			'date_to logic 1' => array(
				'rule' => 'notEmpty',
				'message'	=> 'Date To is required.'
			),
        ),
		'time_from' => array(
			'time_from logic 1' => array(
				'rule' => 'notEmpty',
				'message'	=> 'Time of Departure is required.'
			),
        ),
		'time_to' => array(
			'time_to logic 1' => array(
				'rule' => 'notEmpty',
				'message'	=> 'Expected time of Return is required.'
			),
        ),
	);
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		
		// 'Section' => array(
			// 'className' => 'Section',
			// 'foreignKey' => 'section_code',
			// 'conditions' => array(
				// 'Section.status' => 'Active'
			// ),
		// ),
		// 'PositionDetail' => array(
			// 'className' => 'PositionDetail',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'PositionDetail.status' => 'Active'
			// ),
		// ),
		// 'Unit' => array(
			// 'className' => 'Unit',
			// 'foreignKey' => 'unit_code',
			// 'conditions' => array(
				// 'Unit.status' => 'Active'
			// ),
		// ),
		
		'ApprovedByUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_unit',
			'conditions' => array(
				'ApprovedByUnit.status' => 'Active'
			)
		),
		'ApprovedBySubUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_sub_unit',
			'conditions' => array(
				'ApprovedBySubUnit.status' => 'Active'
			)
		),
		'ApprovedBySection' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_section',
			'conditions' => array(
				'ApprovedBySection.status' => 'Active'
			)
		),
		'ApprovedByDivision' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_division',
			'conditions' => array(
				'ApprovedByDivision.status' => 'Active'
			)
		),
		'ApprovedByAdminOfficer' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_admin_officer',
			'conditions' => array(
				'ApprovedByAdminOfficer.status' => 'Active'
			)
		),
		'ApprovedByHRAdmin' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_hr_admin',
			'conditions' => array(
				'ApprovedByHRAdmin.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array (
		'FilingPermissionToLeaveAttachment' => array(
			'className' => 'FilingPermissionToLeaveAttachment',
			'foreignKey' => 'permission_to_leave_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
		'FilingPermissionToLeaveAttachmentProvider' => array(
			'className' => 'FilingPermissionToLeaveAttachmentProvider',
			'foreignKey' => 'permission_to_leave_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
	);
	public function beforeValidate($options = array()) {
		if(isset($this->data['PermissionToLeave']['date']) && validate_datetime($this->data['PermissionToLeave']['date'], 'm/d/Y')) {
			$this->data['PermissionToLeave']['date'] = convert_datetime($this->data['PermissionToLeave']['date'], 'Y-m-d');
		}	
		
		if(isset($this->data['PermissionToLeave']['date_from']) && validate_datetime($this->data['PermissionToLeave']['date_from'], 'm/d/Y')) {
			$this->data['PermissionToLeave']['date_from'] = convert_datetime($this->data['PermissionToLeave']['date_from'], 'Y-m-d');
		}	
		
		if(isset($this->data['PermissionToLeave']['date_to']) && validate_datetime($this->data['PermissionToLeave']['date_to'], 'm/d/Y')) {
			$this->data['PermissionToLeave']['date_to'] = convert_datetime($this->data['PermissionToLeave']['date_to'], 'Y-m-d');
		}	
		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['PermissionToLeave']['reference_number'])) {
			$this->data['PermissionToLeave']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PermissionToLeave']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PermissionToLeave']['status'] = 'Active';
		
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'PRMTLV';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['PermissionToLeave']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PermissionToLeave']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PermissionToLeave']['date'])){
				$results[$x]['PermissionToLeave']['date'] = date('m/d/Y',strtotime($results[$x]['PermissionToLeave']['date']));
			}
			if(isset($result['PermissionToLeave']['date_from'])){
				$results[$x]['PermissionToLeave']['date_from'] = date('m/d/Y',strtotime($results[$x]['PermissionToLeave']['date_from']));
			}
			
			if(isset($result['PermissionToLeave']['date_to'])){
				$results[$x]['PermissionToLeave']['date_to'] = date('m/d/Y',strtotime($results[$x]['PermissionToLeave']['date_to']));
			}
		}

		return $results;
	}
}
?>