<?php
App::uses('AppModel', 'Model');

class PersonnelType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),	
	);
	
	public function add_personnel_type($data = array()) {		
		$existing_personnel_type = $this->find_existing_personnel_type_by_name($data['PersonnelType']['name']);
		
		if(isset($existing_personnel_type) && count($existing_personnel_type) > 0) {
			$existing_personnel_type['PersonnelType']['status'] = 'Active';
			$data = $existing_personnel_type;
			
		}

		return $this->save($data);
	}
	
	public function update_personnel_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($personnel_type_id = null, $personnel_type = null) {
		$existing_personnel_type = $this->find_existing_personnel_type_by_id_or_code($personnel_type_id);
		
		if(isset($existing_personnel_type) && count($existing_personnel_type) > 0) {
			$existing_personnel_type['PersonnelType']['status'] = $personnel_type;
			$data = $existing_personnel_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_personnel_type_by_name($personnel_type_name = null) {
		if(isset($personnel_type_name)) {
			$default_conditions = array(
				'PersonnelType.name' => $personnel_type_name
			);
		}
		
		$personnel_type = $this->find('first', array(
			'fields' => array(
				'PersonnelType.id',
				'PersonnelType.code',
				'PersonnelType.name',
				'PersonnelType.status',
				'PersonnelType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $personnel_type;
	}
	
	public function find_existing_personnel_type_by_id_or_code($personnel_type_id = null) {
		if(is_numeric($personnel_type_id)) {
			$default_conditions = array(
				'PersonnelType.id' => $personnel_type_id
			);
		}
		else {
			$default_conditions = array(
				'PersonnelType.code' => $personnel_type_id
			);
		}
		
		$personnel_type = $this->find('first', array(
			'fields' => array(
				'PersonnelType.id',
				'PersonnelType.code',
				'PersonnelType.name',
				'PersonnelType.status',
				'PersonnelType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $personnel_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['PersonnelType']['id'])) {
			$this->data['PersonnelType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PersonnelType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PersonnelType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'PERTYP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['PersonnelType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PersonnelType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>