<?php
App::uses('AppModel', 'Model');

class PhicContributionTable extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public function add_phic_contribution_table($data = array()) {		
		
		return $this->save($data);
	}
	public function add_many_phic_contribution_table($data = array()) {		
		return $this->saveAll($data);
	}
	public function update_phic_contribution_table($data = array()) {
		return $this->save($data);
	}
	public function update_status($phic_contribution_table_id = null, $phic_contribution_table = null) {
		$existing_phic_contribution_table = $this->find_existing_phic_contribution_table_by_id_or_code($phic_contribution_table_id);
		
		if(isset($existing_phic_contribution_table) && count($existing_phic_contribution_table) > 0) {
			$existing_phic_contribution_table['PhicContributionTable']['status'] = $phic_contribution_table;
			$data = $existing_phic_contribution_table;
		}

		return $this->save($data);
	}
	
	public function find_existing_phic_contribution_table_by_id_or_code($phic_contribution_tables_id = null) {
		if(is_numeric($phic_contribution_tables_id)) {
			$default_conditions = array(
				'PhicContributionTable.id' => $phic_contribution_tables_id
			);
		}
		$phic_contribution_table = $this->find('first', array(
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $phic_contribution_table;
	}
	
	public function find_currently_applied_phic(){
		
		$currently_applied = $this->find('first', array(
			'recursive'=>-1,
			'conditions' => array(
				'PhicContributionTable.current_and_latest_applied_status' => 'Currently Applied',
			),
		));
		
		return $currently_applied;
	}
	
	public function beforeValidate($options = array()) {

		if(isset($this->data['PhicContributionTable']['to_be_applied_on'])) {
			$this->data['PhicContributionTable']['to_be_applied_on'] = convert_datetime($this->data['PhicContributionTable']['to_be_applied_on'], 'Y-m-d');
		}		
		if(isset($this->data['PhicContributionTable']['actual_date_applied'])) {
			$this->data['PhicContributionTable']['actual_date_applied'] = convert_datetime($this->data['PhicContributionTable']['actual_date_applied'], 'Y-m-d');
		}		
		return true;
	}
	public function beforeSave($options = array()) {
		if(!isset($this->data['PhicContributionTable']['id'])) {
			$this->data['PhicContributionTable']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PhicContributionTable']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PhicContributionTable']['status'] = 'Active';
			
		}
		else {
			$this->data['PhicContributionTable']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PhicContributionTable']['to_be_applied_on'])){
				$results[$x]['PhicContributionTable']['to_be_applied_on'] = date('m/d/Y',strtotime($results[$x]['PhicContributionTable']['to_be_applied_on']));
			}
			if(isset($result['PhicContributionTable']['actual_date_applied'])){
				$results[$x]['PhicContributionTable']['actual_date_applied'] = date('m/d/Y',strtotime($results[$x]['PhicContributionTable']['actual_date_applied']));
			}
		}
		return $results;
	}
}
?>