<?php
App::uses('AppModel', 'Model');

class PlantillaVacancy extends AppModel {
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'recruitment_';
	public $primaryKey = 'reference_number';
	// public $displayField='job_title';
	
	public $validate = array(
		'date_posted' => array(
            'date_posted_logic 1' => array(
				'rule' => 'date',
				'message' => 'Please enter a valid date',
				'allowEmpty' => true
			)
        ),
		'deadline' => array(
            'deadline_logic 1' => array(
				'rule' => 'date',
				'message' => 'Please enter a valid date',
				'allowEmpty' => true
			)
        ),
		'date' => array(
            'date_logic 1' => array(
				'rule' => 'date',
				'message' => 'Please enter a valid date',
				'allowEmpty' => true
			)
        )
	);
	
	public $belongsTo = array(
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'fields' => array(
				'code',
				'name',
				'salary_grade_code',
				
			),
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		),
		
		'ApplicationStatus' => array(
			'className' => 'ApplicationStatus',
			'foreignKey' => 'application_status_code',
			'fields' => array(
				'code',
				'name',
			),
			'conditions' => array(
				'ApplicationStatus.status' => 'Active'
			),
		),
		
		'JobTitleItemNumber' => array(
			'className' => 'JobTitleItemNumber',
			'foreignKey' => 'job_title_item_number_code',
			'conditions' => array(
				'JobTitleItemNumber.status' => 'Active'
			),
		),
		
		
		
	);
	
	public $hasMany = array(
		
		'RecruitmentApplicantAttachment' => array(
			'className' => 'RecruitmentApplicantAttachment',
			'foreignKey' => 'recruitment_plantilla_vacancy_code',
			'conditions' => array(
				'RecruitmentApplicantAttachment.status' => 'Active'
			)
		),
		
		
		
		
		
	);
	
	public $hasOne = array(
		'VacancyDetail' => array(
			'className' => 'VacancyDetail',
			'foreignKey' => 'recruitment_plantilla_vacancy_code',
			'conditions' => array(
				'VacancyDetail.status' => 'Active'
			)
		),
	
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['PlantillaVacancy']['date_posted']) && validate_datetime($this->data['PlantillaVacancy']['date_posted'], 'm/d/Y')) {
			$this->data['PlantillaVacancy']['date_posted'] = convert_datetime($this->data['PlantillaVacancy']['date_posted'], 'Y-m-d');
		}
		
		if(isset($this->data['PlantillaVacancy']['deadline']) && validate_datetime($this->data['PlantillaVacancy']['deadline'], 'm/d/Y')) {
			$this->data['PlantillaVacancy']['deadline'] = convert_datetime($this->data['PlantillaVacancy']['deadline'], 'Y-m-d');
		}

		if(isset($this->data['PlantillaVacancy']['date']) && validate_datetime($this->data['PlantillaVacancy']['date'], 'm/d/Y')) {
			$this->data['PlantillaVacancy']['date'] = convert_datetime($this->data['PlantillaVacancy']['date'], 'Y-m-d');
		}	
		
	}
	
	public function beforeSave($options = array()) {
		// debug($this->data);
		// exit();
		if(!isset($this->data['PlantillaVacancy']['reference_number'])) {
			$this->data['PlantillaVacancy']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PlantillaVacancy']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PlantillaVacancy']['status'] = 'Active';
			
			
		
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'RPVC';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			
			$this->data['PlantillaVacancy']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['PlantillaVacancy']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PlantillaVacancy']['date_posted'])){
				$results[$x]['PlantillaVacancy']['date_posted'] = date('m/d/Y',strtotime($results[$x]['PlantillaVacancy']['date_posted']));
			}
			if(isset($result['PlantillaVacancy']['deadline'])){
				$results[$x]['PlantillaVacancy']['deadline'] = date('m/d/Y',strtotime($results[$x]['PlantillaVacancy']['deadline']));
			}
			
			if(isset($result['PlantillaVacancy']['date'])){
				$results[$x]['PlantillaVacancy']['date'] = date('m/d/Y',strtotime($results[$x]['PlantillaVacancy']['date']));
			}
			
			
		}

		return $results;
	}
}
?>