<?php
App::uses('AppModel', 'Model');

class PositionDetail extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	public $virtualFields=array(
		'vl_earn' => "PERIOD_DIFF( DATE_FORMAT(CURDATE(), '%Y%m') , DATE_FORMAT(PositionDetail.date_employed, '%Y%m') ) * 1.25",
		'sl_earn' => "PERIOD_DIFF( DATE_FORMAT(CURDATE(), '%Y%m') , DATE_FORMAT(PositionDetail.date_employed, '%Y%m') ) * 1.25" 
	);
	
	public $validate = array(
		'professional_non_professional' => array(
			'professional_non_professional logic 1' => array(
				'rule' => 'notEmpty',
				'message' => 'This field is required'
			)
		),
		'work_type' => array(
			'work_type logic 1' => array(
				'rule' => 'notEmpty',
				'message' => 'This field is required'
			)
		),
		'professional_non_professional' => array(
			'professional_non_professional logic 1' => array(
				'rule' => 'notEmpty',
				'message' => 'This field is required'
			)
		),
	);
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				// 'Employee.status' => 'Active'
			)
		),
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'fields' => array(
				'JobTitle.code',
				'JobTitle.name',
			),
			'conditions' => array(
				'JobTitle.status' => 'Active'
			)
		),
		'JobLevel' => array(
			'className' => 'JobLevel',
			'foreignKey' => 'job_level_code',
			'fields' => array(
				'JobLevel.code',
				'JobLevel.name',
			),
			'conditions' => array(
				'JobLevel.status' => 'Active'
			)
		),
		'JobTitleItemNumber' => array(
			'className' => 'JobTitleItemNumber',
			'foreignKey' => 'job_title_item_number_code',
			'fields' => array(
				'JobTitleItemNumber.code',
				'JobTitleItemNumber.job_title_code',
				'JobTitleItemNumber.item_number',
				'JobTitleItemNumber.is_filled',
			),
			'conditions' => array(
				'JobTitleItemNumber.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'fields' => array(
				'Section.code',
				'Section.name',
			),
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'fields' => array(
				'Division.code',
				'Division.name',
				// 'Division.division_type_code',
			),
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'fields' => array(
				'Unit.code',
				'Unit.name',
			),
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'fields' => array(
				'SubUnit.code',
				'SubUnit.name',
			),
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
		'SubSpecialty' => array(
			'className' => 'SubSpecialty',
			'foreignKey' => 'sub_specialty_code',
			'fields' => array(
				'SubSpecialty.code',
				'SubSpecialty.name',
			),
			'conditions' => array(
				'SubSpecialty.status' => 'Active'
			)
		),
		'EmploymentStatus' => array(
			'className' => 'EmploymentStatus',
			'foreignKey' => 'employment_status_code',
			'fields' => array(
				'EmploymentStatus.code',
				'EmploymentStatus.name',
			),
			'conditions' => array(
				'EmploymentStatus.status' => 'Active'
			)
		),
		'SalaryGrade' => array(
			'className' => 'SalaryGrade',
			'foreignKey' => 'salary_grade_code',
			'fields' => array(
				'SalaryGrade.code',
				'SalaryGrade.name',
				'SalaryGrade.salary_grade_number',
			),
			'conditions' => array(
				'SalaryGrade.status' => 'Active'
			)
		),
		// 'EmployeeType' => array(
		// 	'className' => 'EmployeeType',
		// 	'foreignKey' => 'employee_type_code',
		// 	'fields' => array(
		// 		'EmployeeType.code',
		// 		'EmployeeType.name',
		// 	),
		// 	'conditions' => array(
		// 		'EmployeeType.status' => 'Active'
		// 	)
		// ),
		'PersonnelType' => array(
			'className' => 'PersonnelType',
			'foreignKey' => 'personnel_type_code',
			'fields' => array(
				'PersonnelType.code',
				'PersonnelType.name',
			),
			'conditions' => array(
				'PersonnelType.status' => 'Active'
			)
		),
		'NatureOfAppointment' => array(
			'className' => 'NatureOfAppointment',
			'foreignKey' => 'nature_of_appointment_code',
			'fields' => array(
				'NatureOfAppointment.code',
				'NatureOfAppointment.name',
			),
			'conditions' => array(
				'NatureOfAppointment.status' => 'Active'
			)
		),
		'SeparationStatus' => array(
			'className' => 'SeparationStatus',
			'foreignKey' => 'separation_status_code',
			'conditions' => array(
				'SeparationStatus.status' => 'Active'
			)
		),
		'OtherPersonnelActionType' => array(
			'className' => 'OtherPersonnelActionType',
			'foreignKey' => 'other_personnel_action_type_code',
			'conditions' => array(
				'OtherPersonnelActionType.status' => 'Active'
			)
		),
	);
	
	public $hasOne = array(
		'PayrollDetail' => array(
			'className' => 'PayrollDetail',
			'foreignKey' => 'position_detail_id',
			'conditions' => array(
				'PayrollDetail.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array(
		'PositionDetailHistoryLog' => array(
			'className' => 'PositionDetailHistoryLog',
			'foreignKey' => 'position_detail_id',
			'fields' => array(
				'PositionDetailHistoryLog.position_detail_id',
				'PositionDetailHistoryLog.employee_code',
				'PositionDetailHistoryLog.job_title_code',
				'PositionDetailHistoryLog.job_title_item_number_code',
				'PositionDetailHistoryLog.salary_grade_code',
				'PositionDetailHistoryLog.section_code',
				'PositionDetailHistoryLog.unit_code',
				'PositionDetailHistoryLog.sub_unit_code',
				'PositionDetailHistoryLog.date_employed',
				'PositionDetailHistoryLog.end_of_contract',
				'PositionDetailHistoryLog.employment_status_code',
				'PositionDetailHistoryLog.personnel_type_code',
			),
			'conditions' => array(
				'PositionDetailHistoryLog.status' => 'Active'
			)
		),
		'PayrollDetailHistoryLog' => array(
			'className' => 'PayrollDetailHistoryLog',
			'foreignKey' => 'position_detail_id',
			'conditions' => array(
				'PayrollDetailHistoryLog.status' => 'Active'
			)
		),
	);
	
	public function beforeValidate($options = array()) {
		// if(isset($this->data['PositionDetail']['date_employed']) && validate_datetime($this->data['PositionDetail']['date_employed'], 'm/d/Y')) {
			// $this->data['PositionDetail']['date_employed'] = convert_datetime($this->data['PositionDetail']['date_employed'], 'Y-m-d');
		// }

		if(isset($this->data['PositionDetail']['end_of_contract']) && validate_datetime($this->data['PositionDetail']['end_of_contract'], 'm/d/Y')) {
			$this->data['PositionDetail']['end_of_contract'] = convert_datetime($this->data['PositionDetail']['end_of_contract'], 'Y-m-d');
		}
		// data[PositionDetail][appointment_date_from_agency]
		if(isset($this->data['PositionDetail']['appointment_date']) && validate_datetime($this->data['PositionDetail']['appointment_date'], 'm/d/Y')) {
			$this->data['PositionDetail']['appointment_date'] = convert_datetime($this->data['PositionDetail']['appointment_date'], 'Y-m-d');
		}
		if(isset($this->data['PositionDetail']['other_personnel_action_type_date']) && validate_datetime($this->data['PositionDetail']['other_personnel_action_type_date'], 'm/d/Y')) {
			$this->data['PositionDetail']['other_personnel_action_type_date'] = convert_datetime($this->data['PositionDetail']['other_personnel_action_type_date'], 'Y-m-d');
		}
		
		if(isset($this->data['PositionDetail']['appointment_date_from_agency']) && validate_datetime($this->data['PositionDetail']['appointment_date_from_agency'], 'm/d/Y')) {
			$this->data['PositionDetail']['appointment_date_from_agency'] = convert_datetime($this->data['PositionDetail']['appointment_date_from_agency'], 'Y-m-d');
		}
		return true;
	}
		
	public function beforeSave($options = array()) {
		if(!isset($this->data['PositionDetail']['id'])) {
			$this->data['PositionDetail']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PositionDetail']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['PositionDetail']['status'] = 'Active';
		}
		else {
			$this->data['PositionDetail']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}

	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['PositionDetail']['appointment_date'])){
				$results[$x]['PositionDetail']['appointment_date'] = date('m/d/Y',strtotime($results[$x]['PositionDetail']['appointment_date']));
			}
			if(isset($result['PositionDetail']['end_of_contract'])){
				$results[$x]['PositionDetail']['end_of_contract'] = date('m/d/Y',strtotime($results[$x]['PositionDetail']['end_of_contract']));
			}
			if(isset($result['PositionDetail']['other_personnel_action_type_date'])){
				$results[$x]['PositionDetail']['other_personnel_action_type_date'] = date('m/d/Y',strtotime($results[$x]['PositionDetail']['other_personnel_action_type_date']));
			}
			
			if(isset($result['PositionDetail']['appointment_date_from_agency'])){
				$results[$x]['PositionDetail']['appointment_date_from_agency'] = date('m/d/Y',strtotime($results[$x]['PositionDetail']['appointment_date_from_agency']));
			}
		}
		 // debug($results);		
		// exit();
		return $results;
	}
}
?>