<?php
App::uses('AppModel', 'Model');

class ProfessionalFee extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'payroll_';
	// public $primaryKey = 'code';
	// public $displayField = 'or_no';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'doctor_employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			)
		)
	);
	
	public $hasMany = array(
		'ProfessionalFeeDetail' => array(
			'className' => 'ProfessionalFeeDetail',
			'foreignKey' => 'professional_fee_id',
			'conditions' => array(
				'ProfessionalFeeDetail.status' => 'Active'
			)
		)
	);
	
	public $validate = array(
		'patient_name' => array(
            'patient_name' => array(
                'rule' => array('notEmpty'),
                'message' => 'Patient name is required.'
            ),
        ),
		'sub_total_amount_1' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('sub_total_amount_1')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'pf_share' => array(
			'logic 1' => array(
				'rule' => array('validate_negative_numbers', array('pf_share')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'sub_total_amount_2' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('sub_total_amount_2')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'less_share' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('less_share')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'sub_total_amount_3' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('sub_total_amount_3')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'additional' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('additional')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'sub_total_amount_4' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('sub_total_amount_4')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'withholding_tax' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('withholding_tax')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'professional_fee_tax_amount' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('professional_fee_tax_amount')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'percentage_vat' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('percentage_vat')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'vat_amount' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('vat_amount')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'administrative_fee' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('administrative_fee')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'administrative_fee_tax_amount' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('administrative_fee_tax_amount')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
		'total_professional_fee' => array(
			'checkPositive' => array(
				'rule' => array('validate_negative_numbers', array('total_professional_fee')),
				'allowEmpty' => true,
				'message' => 'Negative numbers are not allowed.'
			)
		),
	);
		
	function validate_negative_numbers($value, $fields) {
		if ($value[$fields[0]] >= 0) {
			return true;
		}
		else {
			return false;
		}
	}
	
	public function beforeValidate($options = array()) {
		if (isset($this->data['ProfessionalFee']['or_date']) && validate_datetime($this->data['ProfessionalFee']['or_date'], 'm/d/Y')) {
			$this->data['ProfessionalFee']['or_date'] = convert_datetime($this->data['ProfessionalFee']['or_date'], 'Y-m-d');
		}	
		
		if (isset($this->data['ProfessionalFee']['date_prepared']) && validate_datetime($this->data['ProfessionalFee']['date_prepared'], 'm/d/Y')) {
			$this->data['ProfessionalFee']['date_prepared'] = convert_datetime($this->data['ProfessionalFee']['date_prepared'], 'Y-m-d');
		}
		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if (!isset($this->data['ProfessionalFee']['id'])) {
			$this->data['ProfessionalFee']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ProfessionalFee']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ProfessionalFee']['status'] = 'Active';
		}
		else {
			$this->data['ProfessionalFee']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false) {
		foreach ($results as $x => $result) {
			if (isset($result['ProfessionalFee']['or_date'])) {
				$results[$x]['ProfessionalFee']['or_date'] = date('m/d/Y',strtotime($results[$x]['ProfessionalFee']['or_date']));
			}
			
			if (isset($result['ProfessionalFee']['date_prepared'])) {
				$results[$x]['ProfessionalFee']['date_prepared'] = date('m/d/Y',strtotime($results[$x]['ProfessionalFee']['date_prepared']));
			}
		}

		return $results;
	}
}
?>