<?php
App::uses('AppModel', 'Model');

class Province extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
			'name logic 1' => array(
				'rule'		=> array('validate_province_by_id_and_name_and_region_code'),
				'message'	=> 'The data that you inserted is already exist.'
			),
        ),
	);
	public $hasMany = array(
		'Address' => array(
			'className' => 'Address',
			'foreignKey' => 'province_code'
		),
		'Province' => array(
			'className' =>  'Province',
			'foreignKey' => 'province_code',
				'fields' => array(
					'Province.code',
					'Province.name',
				)
		)
	);
	public $belongsTo = array(
		'Region' => array(
			'className' => 'Region',
			'foreignKey' => 'region_code'
		),
	);
	public function validate_province_by_id_and_name_and_region_code($validation_fields = array()) {
		$id = null;
		$province_name = $this->data['Province']['name'];
		$region_code = $this->data['Province']['region_code'];
		
		if(isset($this->data['Province']['id'])) {
			$id = $this->data['Province']['id'];
		}
		
		$existing_province = $this->find_existing_province_by_id_and_name_and_region_code($id, $province_name, $region_code);
		
		if(isset($existing_province) && count($existing_province) > 0) {
			return false;
		}
		else {
			return true;
		}
	}
	
	public function find_existing_province_by_id_and_name_and_region_code($id = null, $province_name = null, $region_code = null) {
		if(isset($province_name)) {
			$default_conditions = array(
				'Province.name' => $province_name
			);
		}
		
		if(isset($id)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'Province.id NOT' => $id
				)
			);
		}
		
		if(isset($region_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'Province.region_code' => $region_code
				)
			);
		}
		
		$province = $this->find('first', array(
			'fields' => array(
				'Province.id',
				'Province.code',
				'Province.name',
				'Province.region_code',
				'Province.status',
				'Province.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $province;
	}
	
	public function add_province($data = array()) {		
		return $this->save($data);
	}
	
	public function update_province($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($province_id = null, $province = null) {
		$existing_province = $this->find_existing_province_by_id_or_code($province_id);
		
		if(isset($existing_province) && count($existing_province) > 0) {
			$existing_province['Province']['status'] = $province;
			$data = $existing_province;
		}

		return $this->save($data);
	}
	
	public function find_existing_province_by_name($province_name = null) {
		if(isset($province_name)) {
			$default_conditions = array(
				'Province.name' => $province_name
			);
		}
		
		$province = $this->find('first', array(
			'fields' => array(
				'Province.id',
				'Province.code',
				'Province.name',
				'Province.status',
				'Province.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $province;
	}
	
	public function find_existing_province_by_id_or_code($province_id = null) {
		if(is_numeric($province_id)) {
			$default_conditions = array(
				'Province.id' => $province_id
			);
		}
		else {
			$default_conditions = array(
				'Province.code' => $province_id
			);
		}
		
		$province = $this->find('first', array(
			'fields' => array(
				'Province.id',
				'Province.code',
				'Province.name',
				'Province.region_code',
				'Region.code',
				'Region.name',
				'Province.status',
				'Province.lock_flag'
			),
			'recursive' => 0,
			'conditions' => $default_conditions
		));
		
		return $province;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Province']['id'])) {
			$this->data['Province']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Province']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Province']['status'] = 'Active';
			$this->data['Province']['province_status'] = 'A';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'PROV';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Province']['code'] = $code_char . '-' . $code_number;

			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
			
		}
		else {
			$this->data['Province']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>