<?php
App::uses('AppModel', 'Model');

class ReAppointment extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	public $primaryKey = 'code';
	public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
	);

	public $hasMany = array(
		'ReAppointmentHistoryLog' => array(
			'className' => 'ReAppointmentHistoryLog',
			'foreignKey' => 're_appointment_code',
			'fields' => array(
				'ReAppointmentHistoryLog.id',
				'ReAppointmentHistoryLog.re_appointment_code',
				'ReAppointmentHistoryLog.employee_code',
				'ReAppointmentHistoryLog.re_appointment_date',
				'ReAppointmentHistoryLog.remarks',
			),
			'conditions' => array(
				'ReAppointmentHistoryLog.status' => 'Active'
			)
		),
	);
	public $validate = array(
        'employee_code' => array(
            'employee_code logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Employee is required.'
            ),
			
        ), 
	);
	public function beforeValidate($options = array()) {		
		if(isset($this->data['ReAppointment']['re_appointment_date']) && validate_datetime($this->data['ReAppointment']['re_appointment_date'], 'm/d/Y')) {
			$this->data['ReAppointment']['re_appointment_date'] = convert_datetime($this->data['ReAppointment']['re_appointment_date'], 'Y-m-d');
		}
			return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ReAppointment']['id'])) {
			$this->data['ReAppointment']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ReAppointment']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ReAppointment']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'REAPPMNT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ReAppointment']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ReAppointment']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['ReAppointment']['re_appointment_date'])){
				$results[$x]['ReAppointment']['re_appointment_date'] = date('m/d/Y',strtotime($results[$x]['ReAppointment']['re_appointment_date']));
			}
		}

		return $results;
	}
}
?>