<?php
App::uses('AppModel', 'Model');

class Region extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public $hasMany = array(
		'Address' => array(
			'className' => 'Address',
			'foreignKey' => 'region_code'
		),
		 'Province' => array(
			'className' =>  'Province',
			'foreignKey' => 'region_code',
				'fields' => array(
					'Province.code',
					'Province.name',
				)
		)
	);
	
	public function add_region($data = array()) {		
		$existing_region = $this->find_existing_region_by_name($data['Region']['name']);
		
		if(isset($existing_region) && count($existing_region) > 0) {
			$existing_region['Region']['status'] = 'Active';
			$data = $existing_region;
			
		}

		return $this->save($data);
	}
	
	public function update_region($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($region_id = null, $region = null) {
		$existing_region = $this->find_existing_region_by_id_or_code($region_id);
		
		if(isset($existing_region) && count($existing_region) > 0) {
			$existing_region['Region']['status'] = $region;
			$data = $existing_region;
		}

		return $this->save($data);
	}
	
	public function find_existing_region_by_name($region_name = null) {
		if(isset($region_name)) {
			$default_conditions = array(
				'Region.name' => $region_name
			);
		}
		
		$region = $this->find('first', array(
			'fields' => array(
				'Region.id',
				'Region.code',
				'Region.name',
				'Region.status',
				'Region.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $region;
	}
	
	public function find_existing_region_by_id_or_code($region_id = null) {
		if(is_numeric($region_id)) {
			$default_conditions = array(
				'Region.id' => $region_id
			);
		}
		else {
			$default_conditions = array(
				'Region.code' => $region_id
			);
		}
		
		$region = $this->find('first', array(
			'fields' => array(
				'Region.id',
				'Region.code',
				'Region.name',
				'Region.status',
				'Region.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $region;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Region']['id'])) {
			$this->data['Region']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Region']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Region']['status'] = 'Active';
			$this->data['Region']['region_status'] = 'A';
			
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'REG';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Region']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Region']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>