<?php
App::uses('AppModel', 'Model');

class Reinstatement extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	public $primaryKey = 'code';
	public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
	);

	public function beforeValidate($options = array()) {		
		if(isset($this->data['Reinstatement']['reinstatement_date']) && validate_datetime($this->data['Reinstatement']['reinstatement_date'], 'm/d/Y')) {
			$this->data['Reinstatement']['reinstatement_date'] = convert_datetime($this->data['Reinstatement']['reinstatement_date'], 'Y-m-d');
		}
			return true;
	}
	
	public $hasMany = array(
		'ReinstatementHistoryLog' => array(
			'className' => 'ReinstatementHistoryLog',
			'foreignKey' => 'reinstatement_code',
			'fields' => array(
				'ReinstatementHistoryLog.reinstatement_code',
				'ReinstatementHistoryLog.employee_code',
				'ReinstatementHistoryLog.reinstatement_date',
				'ReinstatementHistoryLog.remarks',
			),
			'conditions' => array(
				'ReinstatementHistoryLog.status' => 'Active'
			)
		),
	);



	public function beforeSave($options = array()) {
		if(!isset($this->data['Reinstatement']['id'])) {
			$this->data['Reinstatement']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Reinstatement']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Reinstatement']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'REINSTMNT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Reinstatement']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Reinstatement']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Reinstatement']['reinstatement_date'])){
				$results[$x]['Reinstatement']['reinstatement_date'] = date('m/d/Y',strtotime($results[$x]['Reinstatement']['reinstatement_date']));
			}
		}

		return $results;
	}
}
?>