<?php
App::uses('AppModel', 'Model');

class Relation extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),
		
		// 'degree' => array(
			// 'degree logic 1' => array(
				// 'rule'		=> 'notEmpty',
				// 'message'	=> 'degree is required.'
			// )
        // ),	
	);
	
	public function add_relation($data = array()) {		
		$existing_relation = $this->find_existing_relation_by_name($data['Relation']['name']);
		
		if(isset($existing_relation) && count($existing_relation) > 0) {
			$existing_relation['Relation']['status'] = 'Active';
			$data = $existing_relation;
			
		}

		return $this->save($data);
	}
	
	public function update_relation($data = array()) {
		

		return $this->save($data);
	}
	
	public function update_status($relation_id = null, $relation = null) {
		$existing_relation = $this->find_existing_relation_by_id_or_code($relation_id);
		
		if(isset($existing_relation) && count($existing_relation) > 0) {
			$existing_relation['Relation']['status'] = $relation;
			$data = $existing_relation;
		}

		return $this->save($data);
	}
	
	public function find_existing_relation_by_name($relation_name = null) {
		if(isset($relation_name)) {
			$default_conditions = array(
				'Relation.name' => $relation_name
			);
		}
		
		$relation = $this->find('first', array(
			'fields' => array(
				'Relation.id',
				'Relation.code',
				'Relation.name',
				'Relation.status',
				'Relation.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $relation;
	}
	
	public function find_existing_relation_by_id_or_code($relation_id = null) {
		if(is_numeric($relation_id)) {
			$default_conditions = array(
				'Relation.id' => $relation_id
			);
		}
		else {
			$default_conditions = array(
				'Relation.code' => $relation_id
			);
		}
		
		$relation = $this->find('first', array(
			'fields' => array(
				'Relation.id',
				'Relation.code',
				'Relation.name',
				'Relation.degree',
				'Relation.status',
				'Relation.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $relation;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Relation']['code'])) {
			$this->data['Relation']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Relation']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Relation']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'RLTN';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Relation']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
			}
			else {
				$this->data['Relation']['modified_by'] = $_SESSION['Auth']['User']['id'];
			}
		
		return true;
	}
}
?>