<?php
App::uses('AppModel', 'Model');

class Religion extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'religion_code';
	public $displayField = 'description';
	
	public $validate = array(
        'description' => array(
			'description logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'description logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		
	);
	
	public function add_religion($data = array()) {		
		$existing_religion = $this->find_existing_religion_by_name($data['Religion']['description']);
		
		if(isset($existing_religion) && count($existing_religion) > 0) {
			$existing_religion['Religion']['status'] = 'Active';
			$data = $existing_religion;
			
		}

		return $this->save($data);
	}
	
	public function update_religion($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($religion_id = null, $religion = null) {
		$existing_religion = $this->find_existing_religion_by_id_or_code($religion_id);
		
		if(isset($existing_religion) && count($existing_religion) > 0) {
			$existing_religion['Religion']['status'] = $religion;
			$data = $existing_religion;
		}

		return $this->save($data);
	}
	
	public function find_existing_religion_by_name($religion_name = null) {
		if(isset($religion_name)) {
			$default_conditions = array(
				'Religion.description' => $religion_name
			);
		}
		
		$religion = $this->find('first', array(
			'fields' => array(
				'Religion.id',
				'Religion.religion_code',
				'Religion.description',
				'Religion.status',
				'Religion.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $religion;
	}
	
	public function find_existing_religion_by_id_or_code($religion_id = null) {
		if(is_numeric($religion_id)) {
			$default_conditions = array(
				'Religion.id' => $religion_id
			);
		}
		else {
			$default_conditions = array(
				'Religion.religion_code' => $religion_id
			);
		}
		
		$religion = $this->find('first', array(
			'fields' => array(
				'Religion.id',
				'Religion.religion_code',
				'Religion.description',
				'Religion.status',
				'Religion.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $religion;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Religion']['id'])) {
			$this->data['Religion']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Religion']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Religion']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'REL';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Religion']['religion_code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Religion']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>