<?php
App::uses('AppModel', 'Model');

class Retirement extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'separation_';
	public $primaryKey = 'reference_number';
	public $displayField = 'employee_code';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'Employee.first_name',
				// 'Employee.middle_name',
				// 'Employee.last_name',
				// 'Employee.combination_whole_name',
				// 'Employee.standard_name',
			// ),
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),	
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
		// 'ApprovedByUnit' => array(
			// 'className' => 'Employee',
			// 'foreignKey' => 'approved_by_unit',
			// 'conditions' => array(
				// 'ApprovedByUnit.status' => 'Active'
			// )
		// ),
		// 'ApprovedBySubUnit' => array(
			// 'className' => 'Employee',
			// 'foreignKey' => 'approved_by_sub_unit',
			// 'conditions' => array(
				// 'ApprovedBySubUnit.status' => 'Active'
			// )
		// ),
		// 'ApprovedBySection' => array(
			// 'className' => 'Employee',
			// 'foreignKey' => 'approved_by_section',
			// 'conditions' => array(
				// 'ApprovedBySection.status' => 'Active'
			// )
		// ),
		'ApprovedByAdminOfficer' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_admin_officer',
			'conditions' => array(
				'ApprovedByAdminOfficer.status' => 'Active'
			)
		),
		'ApprovedByHRAdmin' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_hr_admin',
			'conditions' => array(
				'ApprovedByHRAdmin.status' => 'Active'
			)
		),
		// 'Section' => array(
			// 'className' => 'Section',
			// 'foreignKey' => 'section_code',
			// 'conditions' => array(
				// 'Section.status' => 'Active'
			// )
		// ),
		// 'Unit' => array(
			// 'className' => 'Unit',
			// 'foreignKey' => 'unit_code',
			// 'conditions' => array(
				// 'Unit.status' => 'Active'
			// )
		// ),
		// 'SubUnit' => array(
			// 'className' => 'SubUnit',
			// 'foreignKey' => 'sub_unit_code',
			// 'conditions' => array(
				// 'SubUnit.status' => 'Active'
			// )
		// ),
	);
	public $hasMany = array (
		'FilingRetirementAttachment' => array(
			'className' => 'FilingRetirementAttachment',
			'foreignKey' => 'retirement_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
	);
	public function beforeValidate($options = array()) {
		if(isset($this->data['Retirement']['filing_date']) && validate_datetime($this->data['Retirement']['filing_date'], 'm/d/Y')) {
			$this->data['Retirement']['filing_date'] = convert_datetime($this->data['Retirement']['filing_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['Retirement']['retirement_date']) && validate_datetime($this->data['Retirement']['retirement_date'], 'm/d/Y')) {
			$this->data['Retirement']['retirement_date'] = convert_datetime($this->data['Retirement']['retirement_date'], 'Y-m-d');
		}
		
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Retirement']['id'])) {
			$this->data['Retirement']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Retirement']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Retirement']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'RTR';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			
			$this->data['Retirement']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Retirement']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Retirement']['filing_date'])){
				$results[$x]['Retirement']['filing_date'] = date('m/d/Y',strtotime($results[$x]['Retirement']['filing_date']));
			}
			
			if(isset($result['Retirement']['retirement_date'])){
				$results[$x]['Retirement']['retirement_date'] = date('m/d/Y',strtotime($results[$x]['Retirement']['retirement_date']));
			}
		}

		return $results;
	}
}
?>