<?php
App::uses('AppModel', 'Model');

class SalaryGrade extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	// public $displayField = 'name';
	
	public $validate = array(
        'salary_grade_number' => array(
			'salary_grade_number logic 1' => array(
				'rule'		=> array('validate_salary_grade_group_code','salary_grade_number'),
				'message'	=> 'The data that you inserted is already exist.'
			),
			'salary_grade_number logic 2' => array(
				'rule' => 'numeric',
				'message' => 'Salary Grade Number must be numeric.',
			)
        ),
		
		 'hazard_pay_percentage' => array(
			'hazard_pay_percentage logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Hazard Pay Percentage is required.'
			),
			'hazard_pay_percentage logic 2' => array(
				'rule' => 'numeric',
				'message' => 'Hazard Pay Percentage is Numbers only'
			),
			'hazard_pay_percentage logic 3' => array(
				'rule' => 'numeric',
				'message' => 'Hazard Pay Percentage must be numeric.'
			)
		),

        'employee_code' => array(
			'employee_code logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Employee Name is already used.',
			),
			'employee_code logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Employee Name is required.'
			),
        ),
	);
	
	public $hasMany = array(
		'SalaryGradeStepNumber' => array(
			'className' => 'SalaryGradeStepNumber',
			'foreignKey' => 'salary_grade_code',
			'conditions' => array(
				'SalaryGradeStepNumber.status' => 'Active'
			)
		),
	);
	
	public $belongsTo = array(
		'SalaryGradeGroup' => array(
			'className' => 'SalaryGradeGroup',
			'foreignKey' => 'salary_grade_group_code',
			'conditions' => array(
				'SalaryGradeGroup.status' => 'Active'
			)
		),
	);
	public function validate_salary_grade_group_code($validation_fields = array(),$compare) {
		$salary_grade_group_code = isset($this->data['SalaryGrade']['salary_grade_group_code']) ? $this->data['SalaryGrade']['salary_grade_group_code']:'';
	
		$existing_salary_grade = $this->find_existing_salary_grade_group_code($salary_grade_group_code,$validation_fields[$compare]);
 
		if (isset($existing_salary_grade) && count($existing_salary_grade) > 0) {
			
			if ($this->data['SalaryGrade']['code'] == $existing_salary_grade['SalaryGrade']['code']) {
				return true;
			}
			return false;
		}
		else {
			return true;
		}
	}
	
	public function find_existing_salary_grade_group_code($salary_grade_group_code = null,$salary_grade_number=null) {
		$default_conditions=array();
		
		if(isset($salary_grade_group_code)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'SalaryGrade.salary_grade_group_code' => $salary_grade_group_code
				)
			);
		}
		if(isset($salary_grade_number)) {
			$default_conditions = array_merge(
				$default_conditions,
				array(
					'SalaryGrade.salary_grade_number' => $salary_grade_number
				)
			);
		}
		$salary_grade = $this->find('first', array(
			// 'fields' => array(
				// 'SalaryGrade.id',
				// 'SalaryGrade.code',
				// 'SalaryGrade.name',
				// 'SalaryGrade.salary_grade_number',
				// 'SalaryGrade.basic_salary',
				// 'SalaryGrade.hazard_pay_percentage',
				// 'SalaryGrade.status',
				// 'SalaryGrade.lock_flag'
			// ),
			'conditions' => $default_conditions
		));
		
		return $salary_grade;
	}
	
	public function add_salary_grade($data = array()) {		
	
		$existing_salary_grade = $this->find_existing_salary_grade_by_name($data['SalaryGrade']['name'],$data['SalaryGrade']['salary_grade_group_code']);
		
		if(isset($existing_salary_grade) && count($existing_salary_grade) > 0) {
			$existing_salary_grade['SalaryGrade']['status'] = 'Active';
			$data = $existing_salary_grade;
			
		}
		return $this->save($data);
	}
	
	public function update_salary_grade($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($salary_grade_id = null, $salary_grade = null) {
		$existing_salary_grade = $this->find_existing_salary_grade_by_id_or_code($salary_grade_id);
		
		if(isset($existing_salary_grade) && count($existing_salary_grade) > 0) {
			$existing_salary_grade['SalaryGrade']['status'] = $salary_grade;
			$data = $existing_salary_grade;
		}

		return $this->save($data);
	}
	
	public function find_existing_salary_grade_by_name($salary_grade_name = null) {
		if(isset($salary_grade_name)) {
			$default_conditions = array(
				'SalaryGrade.name' => $salary_grade_name,
				'SalaryGrade.salary_grade_group_code' => $salary_grade_group_code
			);
		}
		
		$salary_grade = $this->find('first', array(
			'fields' => array(
				'SalaryGrade.id',
				'SalaryGrade.code',
				'SalaryGrade.name',
				'SalaryGrade.salary_grade_number',
				'SalaryGrade.basic_salary',
				'SalaryGrade.hazard_pay_percentage',
				'SalaryGrade.status',
				'SalaryGrade.lock_flag'
			),
			'contain' => 'SalaryGradeStepNumber',
			'conditions' => $default_conditions
		));
		
		return $salary_grade;
	}
	
	public function find_existing_salary_grade_by_id_or_code($salary_grade_id = null) {
		if(is_numeric($salary_grade_id)) {
			$default_conditions = array(
				'SalaryGrade.id' => $salary_grade_id
			);
		}
		else {
			$default_conditions = array(
				'SalaryGrade.code' => $salary_grade_id
			);
		}
		
		$salary_grade = $this->find('first', array(
			// 'fields' => array(
				// 'SalaryGrade.id',
				// 'SalaryGrade.code',
				// 'SalaryGrade.name',
				// 'SalaryGrade.salary_grade_number',
				// 'SalaryGrade.basic_salary',
				// 'SalaryGrade.hazard_pay_percentage',
				// 'SalaryGrade.status',
				// 'SalaryGrade.lock_flag'
			// ),
			'contain' => array(
				'SalaryGradeStepNumber',
				'SalaryGradeGroup',
			),
			'conditions' => $default_conditions
		));
		
		return $salary_grade;
	}
	
	
		
	public function beforeSave($options = array()) {
		// debug('asd');
		// exit();
		if(!isset($this->data['SalaryGrade']['code'])) {
			$this->data['SalaryGrade']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SalaryGrade']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SalaryGrade']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SGR';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['SalaryGrade']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['SalaryGrade']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>