<?php
App::uses('AppModel', 'Model');

class SalaryGradeGroup extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				"on" => "create",
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	
	public $hasMany = array(
		'SalaryGrade' => array(
			'className' => 'SalaryGrade',
			'foreignKey' => 'salary_grade_group_code',
			'conditions' => array(
				'SalaryGrade.status' => 'Active'
			)
		),
	);
	public function add_salary_grade_group($data = array()) {		
		$existing_salary_grade_groups = $this->find_existing_salary_grade_group_by_name($data['SalaryGradeGroup']['name']);
		
		if(isset($existing_salary_grade_groups) && count($existing_salary_grade_groups) > 0) {
			$existing_salary_grade_groups['SalaryGradeGroup']['status'] = 'Active';
			$data = $existing_salary_grade_groups;
		}

		return $this->save($data);
	}
	public function update_salary_grade_group($data = array()) {
		return $this->save($data);
	}
	public function update_status($salary_grade_group_id = null, $salary_grade_group = null) {
		$existing_salary_grade_group = $this->find_existing_salary_grade_group_by_id_or_code($salary_grade_group_id);
		
		if(isset($existing_salary_grade_group) && count($existing_salary_grade_group) > 0) {
			$existing_salary_grade_group['SalaryGradeGroup']['status'] = $salary_grade_group;
			$data = $existing_salary_grade_group;
		}

		return $this->save($data);
	}
	public function find_existing_salary_grade_group_by_name($salary_grade_group_name = null) {
		if(isset($salary_grade_group_name)) {
			$default_conditions = array(
				'SalaryGradeGroup.name' => $salary_grade_group_name
			);
		}
		
		$salary_grade_groups = $this->find('first', array(
			'fields' => array(
				
				'SalaryGradeGroup.id',
				'SalaryGradeGroup.code',
				'SalaryGradeGroup.name',
				'SalaryGradeGroup.year',
				'SalaryGradeGroup.to_be_applied_on',
				'SalaryGradeGroup.applied_on',
				'SalaryGradeGroup.status',
				// 'SalaryGradeGroup.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $salary_grade_groups;
	}
	
	public function find_existing_salary_grade_group_by_id_or_code($salary_grade_groups_id = null) {
		if(is_numeric($salary_grade_groups_id)) {
			$default_conditions = array(
				'SalaryGradeGroup.id' => $salary_grade_groups_id
			);
		}
		else {
			$default_conditions = array(
				'SalaryGradeGroup.code' => $salary_grade_groups_id
			);
		}
		
		$salary_grade_group = $this->find('first', array(
			'fields' => array(
				'SalaryGradeGroup.id',
				'SalaryGradeGroup.code',
				'SalaryGradeGroup.name',
				'SalaryGradeGroup.year',
				'SalaryGradeGroup.to_be_applied_on',
				'SalaryGradeGroup.applied_on',
				'SalaryGradeGroup.status',
				'SalaryGradeGroup.copy_salary_grade_group_code',
				// 'SalaryGradeGroup.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $salary_grade_group;
	}
	
	public function beforeSave($options = array()) {
		if(isset($this->data['SalaryGradeGroup']['to_be_applied_on']) && $this->data['SalaryGradeGroup']['to_be_applied_on']!='') {
			$this->data['SalaryGradeGroup']['to_be_applied_on'] = date('Y-m-d',strtotime($this->data['SalaryGradeGroup']['to_be_applied_on']));
		}
		if(isset($this->data['SalaryGradeGroup']['applied_on']) && $this->data['SalaryGradeGroup']['applied_on']!='') {
			$this->data['SalaryGradeGroup']['applied_on'] = date('Y-m-d',strtotime($this->data['SalaryGradeGroup']['applied_on']));
		}
		if(!isset($this->data['SalaryGradeGroup']['code'])) {
			$this->data['SalaryGradeGroup']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SalaryGradeGroup']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SalaryGradeGroup']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SGG';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['SalaryGradeGroup']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['SalaryGradeGroup']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['SalaryGradeGroup']['to_be_applied_on']) && $result['SalaryGradeGroup']['to_be_applied_on']!=''){
				$results[$x]['SalaryGradeGroup']['to_be_applied_on'] = date('m/d/Y',strtotime($results[$x]['SalaryGradeGroup']['to_be_applied_on']));
			}
			
			if(isset($result['SalaryGradeGroup']['applied_on']) && $result['SalaryGradeGroup']['applied_on']!=''){
				$results[$x]['SalaryGradeGroup']['applied_on'] = date('m/d/Y',strtotime($results[$x]['SalaryGradeGroup']['applied_on']));
			}
			
		}

		return $results;
	}
}
?>