<?php
App::uses('AppModel', 'Model');

class SalaryGradeStepNumber extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	
	public $validate = array(
        'step_number' => array(
			'step_number logic 1' => array(	
				'rule' => 'numeric',
				'message' => 'Step Number Must be numeric.'
			),
			'step_number logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Step Number Name is required.'
			),
        ),
		'basic_salary' => array(
			'basic_salary logic 1' => array(
				'rule' => 'numeric',
				'message' => 'Basic Salary Must be numeric.'
			),
			'basic_salary logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Basic Salary is required.'
			),
        ),
	);
	
	public $hasOne = array(
		'SalaryGradeGroupDetail' => array(
			'className' => 'SalaryGradeGroupDetail',
			'foreignKey' => 'salary_grade_step_number_code',
			'conditions' => array(
				'SalaryGradeGroupDetail.status' => 'Active'
			)
		),
	
	);
	public $belongsTo = array(
		'SalaryGrade' => array(
			'className' => 'SalaryGrade',
			'foreignKey' => 'salary_grade_code',
			'conditions' => array(
				'SalaryGradeStepNumber.status' => 'Active'
			)
		),
	);
	
	public function add_salary_grade_step_number($data = array()) {		
		$existing_salary_grade_step_number = $this->find_existing_salary_grade_step_number_by_name($data['SalaryGradeStepNumber']['step_number']);
		// debug($existing_salary_grade_step_number);exit();
		if(isset($existing_salary_grade_step_number) && count($existing_salary_grade_step_number) > 0) {
			$existing_salary_grade_step_number['SalaryGradeStepNumber']['status'] = 'Active';
			$data = $existing_salary_grade_step_number;
			
		}
		// debug($data);exit();
		return $this->saveAll($data);
	}
	
	public function update_salary_grade_step_number($data = array()) {
		return $this->saveAll($data);
	}
	
	public function update_status($salary_grade_step_number_id = null, $salary_grade_step_number = null) {
		$existing_salary_grade_step_number = $this->find_existing_salary_grade_step_number_by_id_or_code($salary_grade_step_number_id);
		
		if(isset($existing_salary_grade_step_number) && count($existing_salary_grade_step_number) > 0) {
			$existing_salary_grade_step_number['SalaryGradeStepNumber']['status'] = $salary_grade_step_number;
			$data = $existing_salary_grade_step_number;
		}
		return $this->save($data);
	}
	
	public function find_existing_salary_grade_step_number_by_name($salary_grade_step_number_name = null) {
		if(isset($salary_grade_step_number_name)) {
			$default_conditions = array(
				'SalaryGradeStepNumber.step_number' => $salary_grade_step_number_name
			);
		}
		
		$salary_grade_step_number = $this->find('first', array(
			'fields' => array(
				'SalaryGrade.id',
				'SalaryGrade.code',
				'SalaryGradeStepNumber.id',
				'SalaryGradeStepNumber.salary_grade_code',
				'SalaryGradeStepNumber.code',
				'SalaryGradeStepNumber.name',
				'SalaryGradeStepNumber.step_number',
				'SalaryGradeStepNumber.basic_salary',
				'SalaryGradeStepNumber.status',		
			),
			'recursive'=>0,
			'conditions' => $default_conditions
		));
		
		return $salary_grade_step_number;
	}
	
	public function find_existing_salary_grade_step_number_by_id_or_code($salary_grade_step_number_id = null) {
		if(is_numeric($salary_grade_step_number_id)) {
			$default_conditions = array(
				'SalaryGradeStepNumber.id' => $salary_grade_step_number_id
			);
		}
		else {
			$default_conditions = array(
				'SalaryGradeStepNumber.code' => $salary_grade_step_number_id
			);
		}

		$salary_grade_step_number = $this->find('first', array(
			'fields' => array(
				'SalaryGrade.id',
				'SalaryGrade.code',
				'SalaryGrade.name',
				'SalaryGradeStepNumber.id',
				'SalaryGradeStepNumber.salary_grade_code',
				'SalaryGradeStepNumber.code',
				'SalaryGradeStepNumber.name',
				'SalaryGradeStepNumber.step_number',
				'SalaryGradeStepNumber.basic_salary',
				'SalaryGradeStepNumber.status',		
			),
			'contain' => array(
				'SalaryGrade' => array(
					'fields'	=> array(
						'SalaryGrade.id',
						'SalaryGrade.code',
						'SalaryGrade.name',
					),
				)
			),
			'conditions' => array(
				'SalaryGradeStepNumber.id' => $salary_grade_step_number_id,
			),
		));
		
		return $salary_grade_step_number;
	}
		
	public function beforeSave($options = array()) {
		if(!isset($this->data['SalaryGradeStepNumber']['id'])) {
			$this->data['SalaryGradeStepNumber']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SalaryGradeStepNumber']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SalaryGradeStepNumber']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'STN';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['SalaryGradeStepNumber']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['SalaryGradeStepNumber']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>