<?php
App::uses('AppModel', 'Model');

class Sanction extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
		
	);
	public $hasMany = array(
		'EmployeeAdministrativeOffense' => array(
			'className' => 'EmployeeAdministrativeOffense',
			'foreignKey' => 'administrative_case_code',
		),
	);
	
	public function add_sanction($data = array()) {		
		$existing_sanction = $this->find_existing_sanction_by_name($data['Sanction']['name']);
		
		if(isset($existing_sanction) && count($existing_sanction) > 0) {
			$existing_sanction['Sanction']['status'] = 'Active';
			$data = $existing_sanction;
			
		}

		return $this->save($data);
	}
	
	public function update_sanction($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($sanction_id = null, $sanction = null) {
		$existing_sanction = $this->find_existing_sanction_by_id_or_code($sanction_id);
		
		if(isset($existing_sanction) && count($existing_sanction) > 0) {
			$existing_sanction['Sanction']['status'] = $sanction;
			$data = $existing_sanction;
		}

		return $this->save($data);
	}
	
	public function find_existing_sanction_by_name($sanction_name = null) {
		if(isset($sanction_name)) {
			$default_conditions = array(
				'UPPER(Sanction.name)' => strtoupper($sanction_name)
			);
		}
		
		$sanction = $this->find('first', array(
			'fields' => array(
				'Sanction.id',
				'Sanction.code',
				'Sanction.name',
				'Sanction.status',
				'Sanction.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $sanction;
	}
	
	public function find_existing_sanction_by_id_or_code($sanction_id = null) {
		if(is_numeric($sanction_id)) {
			$default_conditions = array(
				'Sanction.id' => $sanction_id
			);
		}
		else {
			$default_conditions = array(
				'Sanction.code' => $sanction_id
			);
		}
		
		$sanction = $this->find('first', array(
			'fields' => array(
				'Sanction.id',
				'Sanction.code',
				'Sanction.name',
				'Sanction.status',
				'Sanction.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $sanction;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Sanction']['id'])) {
			$this->data['Sanction']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Sanction']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Sanction']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'STNS';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Sanction']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Sanction']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>