<?php
App::uses('AppModel', 'Model');

class Section extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
        
	);
	public $belongsTo= array(
		'SectionHead' => array(
			'className' => 'Employee',
			'foreignKey' => 'section_head',
			'fields' => array(
				'SectionHead.combination_whole_name',
				
			),
			'conditions' => array(
				'SectionHead.status' => 'Active'
			)
		),
		'SectionAssistantHead' => array(
			'className' => 'Employee',
			'foreignKey' => 'assistant_section_head',
			'fields' => array(
				'SectionAssistantHead.combination_whole_name',
				
			),
			'conditions' => array(
				'SectionAssistantHead.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'fields' => array(
				'Division.name',
				'Division.code',
				'Division.division_head',
				'Division.assistant_division_head',
			),
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),

	);
	
	public $hasMany = array(
		'SectionHistoryLog' => array(
			'className' => 'SectionHistoryLog',
			'foreignKey' => 'section_code',
			'fields' => array(
				'SectionHistoryLog.section_code',
				'SectionHistoryLog.name',
				'SectionHistoryLog.section_head',
				'SectionHistoryLog.assistant_section_head',
			),
			'conditions' => array(
				'SectionHistoryLog.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
	);
	
	public function add_section($data = array()) {		
		$existing_section = $this->find_existing_section_by_name($data['Section']['name']);
		
		if(isset($existing_section) && count($existing_section) > 0) {
			$existing_section['Section']['status'] = 'Active';
			$existing_section['Section']['division_code'] = $data['Section']['division_code'];
			$existing_section['Section']['section_head'] = $data['Section']['section_head'];
			$existing_section['Section']['assistant_section_head'] = $data['Section']['assistant_section_head'];
						
			$data = $existing_section;
		}
		return $this->saveAssociated($data);
	}
	
	public function update_section($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($section_id = null, $section = null) {
		$existing_section = $this->find_existing_section_by_id_or_code($section_id);
		
		if(isset($existing_section) && count($existing_section) > 0) {
			$existing_section['Section']['status'] = $section;
			$data = $existing_section;
		}

		return $this->save($data);
	}
	
	public function find_existing_section_by_name($section_name = null) {
		if(isset($section_name)) {
			$default_conditions = array(
				'Section.name' => $section_name
			);
		}
		
		$section = $this->find('first', array(
			'fields' => array(
				'Section.id',
				'Section.code',
				'Section.name',
				'Section.status',
				'Section.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $section;
	}
	
	public function find_existing_section_by_id_or_code($section_id = null) {
		if(is_numeric($section_id)) {
			$default_conditions = array(
				'Section.id' => $section_id
			);
		}
		else {
			$default_conditions = array(
				'Section.code' => $section_id
			);
		}
		
		$section = $this->find('first', array(
			// 'fields' => array(
				// 'Section.id',
				// 'Section.code',
				// 'Section.name',
				// 'Section.status',
				// 'Section.lock_flag',
				// 'SectionHead.combination_whole_name',
				// 'SectionAssistantHead.combination_whole_name',
			// ),
			'contain' => array(
				'SectionHead',
				'SectionAssistantHead',
				'SectionHistoryLog',
			),
			'recursive'=>1,
			'conditions' => $default_conditions
		));
		
		return $section;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Section']['id'])) {
			$this->data['Section']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Section']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Section']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SEC';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Section']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Section']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>