<?php
App::uses('AppModel', 'Model');

class SeparationStatus extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			// 'name logic 1' => array(
				// 'rule'		=> 'isUnique',
				// 'message'	=> 'Name is already used.',
			// ),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public $belongsTo = array(
		'DocumentType' => array(
			'className' => 'DocumentType',
			'foreignKey' => 'document_type_code',
			'conditions' => array(
				'DocumentType.status' => 'Active'
			)
		),
	);
	
	public function add_separation_status($data = array()) {		
		$existing_separation_status = $this->find_existing_separation_status_by_name($data['SeparationStatus']['name']);
		
		if(isset($existing_separation_status) && count($existing_separation_status) > 0) {
			$existing_separation_status['SeparationStatus']['status'] = 'Active';
			$data = $existing_separation_status;
			
		}else{
			return $this->save($data);
			
		}

		
	}
	
	public function update_separation_status($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($separation_status_id = null, $separation_status = null) {
		$existing_separation_status = $this->find_existing_separation_status_by_id_or_code($separation_status_id);
		
		if(isset($existing_separation_status) && count($existing_separation_status) > 0) {
			$existing_separation_status['SeparationStatus']['status'] = $separation_status;
			$data = $existing_separation_status;
		}

		return $this->save($data);
	}
	
	public function find_existing_separation_status_by_name($separation_status_name = null) {
		if(isset($separation_status_name)) {
			$default_conditions = array(
				'SeparationStatus.name' => $separation_status_name,
				'SeparationStatus.status' => 'Active'
			);
		}
		
		$separation_status = $this->find('first', array(
			'fields' => array(
			'SeparationStatus.id',
			'SeparationStatus.code',
			'SeparationStatus.name',
			'SeparationStatus.document_type_code',
			'DocumentType.name',
			'SeparationStatus.status',
			), 
			'conditions' => array(
				'SeparationStatus.status' => 'Active'
			), 
			'order' => 'SeparationStatus.name ASC', 
			'limit' => 20, 
			'recursive' => 1,
			'conditions' => $default_conditions
		));
		
		return $separation_status;
	}
	
	public function find_existing_separation_status_by_id_or_code($separation_status_id = null) {
		if(is_numeric($separation_status_id)) {
			$default_conditions = array(
				'SeparationStatus.id' => $separation_status_id,
				// 'SeparationStatus.status' => 'Active'
			);
		}
		else {
			$default_conditions = array(
				'SeparationStatus.code' => $separation_status_id,
				// 'SeparationStatus.status' => 'Active'
			);
		}
		
		$separation_status = $this->find('first', array(
			'fields' => array(
			'SeparationStatus.id',
			'SeparationStatus.name',
			'SeparationStatus.code',
			'SeparationStatus.document_type_code',
			'DocumentType.name',
			'SeparationStatus.status',
			), 
			'conditions' => array(
				'SeparationStatus.status' => 'Active'
			), 
			'order' => 'SeparationStatus.name ASC', 
			'limit' => 20, 
			'recursive' => 1,
			'conditions' => $default_conditions
		));
		
		return $separation_status;
	}

	
	public function beforeSave($options = array()) {
		if(!isset($this->data['SeparationStatus']['id'])) {
			$this->data['SeparationStatus']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SeparationStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SeparationStatus']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'EMPSTAT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['SeparationStatus']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['SeparationStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>