<?php
App::uses('AppModel', 'Model');

class ShiftType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_shift_type($data = array()) {		
		$existing_shift_type = $this->find_existing_shift_type_by_name($data['ShiftType']['name']);
		
		if(isset($existing_shift_type) && count($existing_shift_type) > 0) {
			$existing_shift_type['ShiftType']['status'] = 'Active';
			$data = $existing_shift_type;
			
		}

		return $this->save($data);
	}
	
	public function update_shift_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($shift_type_id = null, $shift_type = null) {
		$existing_shift_type = $this->find_existing_shift_type_by_id_or_code($shift_type_id);
		
		if(isset($existing_shift_type) && count($existing_shift_type) > 0) {
			$existing_shift_type['ShiftType']['status'] = $shift_type;
			$data = $existing_shift_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_shift_type_by_name($shift_type_name = null) {
		if(isset($shift_type_name)) {
			$default_conditions = array(
				'ShiftType.name' => $shift_type_name
			);
		}
		
		$shift_type = $this->find('first', array(
			'fields' => array(
				'ShiftType.id',
				'ShiftType.code',
				'ShiftType.name',
				'ShiftType.status',
				'ShiftType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $shift_type;
	}
	
	public function find_existing_shift_type_by_id_or_code($shift_type_id = null) {
		if(is_numeric($shift_type_id)) {
			$default_conditions = array(
				'ShiftType.id' => $shift_type_id
			);
		}
		else {
			$default_conditions = array(
				'ShiftType.code' => $shift_type_id
			);
		}
		
		$shift_type = $this->find('first', array(
			'fields' => array(
				'ShiftType.id',
				'ShiftType.code',
				'ShiftType.name',
				'ShiftType.status',
				'ShiftType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $shift_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['ShiftType']['id'])) {
			$this->data['ShiftType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ShiftType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['ShiftType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SHTY';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['ShiftType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['ShiftType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>