<?php
App::uses('AppModel', 'Model');

class Signatory extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	 
	public function add_signatory($data = array()) {		
		$existing_signatory = $this->find_existing_signatory_by_name($data['Signatory']['name']);
		
		if(isset($existing_signatory) && count($existing_signatory) > 0) {
			
			$existing_signatory['Signatory']['status'] = 'Active';
			
			$data = $existing_signatory;		

		
			return $this->save($data);
		}

		return $this->saveAssociated($data);
	}
	
	public function update_signatory($data = array()) {
		return $this->saveAssociated($data);
	}
	
	public function update_status($signatory_id = null, $signatory = null) {
		$existing_signatory = $this->find_existing_signatory_by_id_or_code($signatory_id);
		
		if(isset($existing_signatory) && count($existing_signatory) > 0) {
			$existing_signatory['Signatory']['status'] = $signatory;
			$data = $existing_signatory;
		}

		return $this->save($data);
	}
	
	public function find_existing_signatory_by_name($signatory_name = null) {
		if(isset($signatory_name)) {
			$default_conditions = array(
				'Signatory.name' => $signatory_name
			);
		}
		
		$signatory = $this->find('first', array(
			'recursive'=>1,
			'conditions' => $default_conditions
		));

		return $signatory;
	}
	
	public function find_existing_signatory_by_id_or_code($signatory_id = null) {
		if(is_numeric($signatory_id)) {
			$default_conditions = array(
				'Signatory.id' => $signatory_id
			);
		}
		else {
			$default_conditions = array(
				'Signatory.code' => $signatory_id
			);
		}
		
		$signatory = $this->find('first', array(

			'recursive'=>1,
			'conditions' => $default_conditions
		));
		
		return $signatory;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Signatory']['code'])) {
			$this->data['Signatory']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Signatory']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Signatory']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SIG';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Signatory']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Signatory']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>