<?php
App::uses('AppModel', 'Model');

class Specialization extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public function add_specialization($data = array()) {
		
		$existing_specializations = $this->find_existing_specialization_by_name($data['Specialization']['name']);
		
		if(isset($existing_specializations) && count($existing_specializations) > 0) {
			$existing_specializations['Specialization']['status'] = 'Active';
			$data = $existing_specializations;
		}

		return $this->save($data);
	}
	public function update_specialization($data = array()) {
		return $this->save($data);
	}
	public function update_status($specialization_id = null, $specialization = null) {
		$existing_specializations = $this->find_existing_specialization_by_id_or_code($specialization_id);
		
		if(isset($existing_specializations) && count($existing_specializations) > 0) {
			$existing_specializations['Specialization']['status'] = $specialization;
			$data = $existing_specializations;
		}

		return $this->save($data);
	}
	public function find_existing_specialization_by_name($specialization_name = null) {
		if(isset($specialization_name)) {
			$default_conditions = array(
				'Specialization.name' => $specialization_name
			);
		}
		
		$specialization = $this->find('first', array(
			'fields' => array(
				'Specialization.id',
				'Specialization.code',
				'Specialization.name',
				'Specialization.status',
				'Specialization.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $specialization;
	}
	
	public function find_existing_specialization_by_id_or_code($specialization_id = null) {
		if(is_numeric($specialization_id)) {
			$default_conditions = array(
				'Specialization.id' => $specialization_id
			);
		}
		else {
			$default_conditions = array(
				'Specialization.code' => $specialization_id
			);
		}
		
		$specialization = $this->find('first', array(
			'fields' => array(
				'Specialization.id',
				'Specialization.code',
				'Specialization.name',
				'Specialization.status',
				'Specialization.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $specialization;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Specialization']['code'])) {
			$this->data['Specialization']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Specialization']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Specialization']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SPL';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Specialization']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Specialization']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>