<?php
App::uses('AppModel', 'Model');

class StatusOfAppointment extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
				'on' => 'create',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	public function add_status_of_appointment($data = array()) {		
		$existing_status_of_appointment = $this->find_existing_status_of_appointment_by_name($data['StatusOfAppointment']['name']);
		
		if(isset($existing_status_of_appointment) && count($existing_status_of_appointment) > 0) {
			$existing_status_of_appointment['StatusOfAppointment']['status'] = 'Active';
			$data = $existing_status_of_appointment;
			
		}

		return $this->save($data);
	}
	
	public function update_status_of_appointment($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($status_of_appointment_id = null, $status_of_appointment = null) {
		$existing_status_of_appointment = $this->find_existing_status_of_appointment_by_id_or_code($status_of_appointment_id);
		
		if(isset($existing_status_of_appointment) && count($existing_status_of_appointment) > 0) {
			$existing_status_of_appointment['StatusOfAppointment']['status'] = $status_of_appointment;
			$data = $existing_status_of_appointment;
		}

		return $this->save($data);
	}
	
	public function find_existing_status_of_appointment_by_name($status_of_appointment_name = null) {
		if(isset($status_of_appointment_name)) {
			$default_conditions = array(
				'StatusOfAppointment.name' => $status_of_appointment_name
			);
		}
		
		$status_of_appointment = $this->find('first', array(
			'fields' => array(
				'StatusOfAppointment.id',
				'StatusOfAppointment.code',
				'StatusOfAppointment.name',
				'StatusOfAppointment.status',
				'StatusOfAppointment.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $status_of_appointment;
	}
	
	public function find_existing_status_of_appointment_by_id_or_code($status_of_appointment_id = null) {
		if(is_numeric($status_of_appointment_id)) {
			$default_conditions = array(
				'StatusOfAppointment.id' => $status_of_appointment_id
			);
		}
		else {
			$default_conditions = array(
				'StatusOfAppointment.code' => $status_of_appointment_id
			);
		}
		
		$status_of_appointment = $this->find('first', array(
			'fields' => array(
				'StatusOfAppointment.id',
				'StatusOfAppointment.code',
				'StatusOfAppointment.name',
				'StatusOfAppointment.status',
				'StatusOfAppointment.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $status_of_appointment;
	}
	public function beforeSave($options = array()) {
		if(!isset($this->data['StatusOfAppointment']['id'])) {
			$this->data['StatusOfAppointment']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['StatusOfAppointment']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['StatusOfAppointment']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'STATAPP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['StatusOfAppointment']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['StatusOfAppointment']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>