<?php
App::uses('AppModel', 'Model');

class StepIncrement extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	// public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	
	
	public $belongsTo = array(
		'SalaryGrade' => array(
			'className' => 'SalaryGrade',
			'foreignKey' => 'salary_grade_code',
		),
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			)
		),
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'fields' => array(
				'JobTitle.code',
				'JobTitle.name',
			),
			'conditions' => array(
				'JobTitle.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'fields' => array(
				'Section.code',
				'Section.name',
			),
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'fields' => array(
				'Unit.code',
				'Unit.name',
			),
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'fields' => array(
				'SubUnit.code',
				'SubUnit.name',
			),
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
		'EmployeeType' => array(
			'className' => 'EmployeeType',
			'foreignKey' => 'employee_type_code',
			'fields' => array(
				'EmployeeType.code',
				'EmployeeType.name',
			),
			'conditions' => array(
				'EmployeeType.status' => 'Active'
			)
		),
		'PersonnelType' => array(
			'className' => 'PersonnelType',
			'foreignKey' => 'personnel_type_code',
			'fields' => array(
				'PersonnelType.code',
				'PersonnelType.name',
			),
			'conditions' => array(
				'PersonnelType.status' => 'Active'
			)
		),
	);
	
	
	public function beforeSave($options = array()) {
		if(isset($this->data['StepIncrement']['date_hired']) && validate_datetime($this->data['StepIncrement']['date_hired'], 'm/d/Y')) {
			$this->data['StepIncrement']['date_hired'] = convert_datetime($this->data['StepIncrement']['date_hired'], 'Y-m-d');
		}
		if(isset($this->data['StepIncrement']['step_increment_date']) && validate_datetime($this->data['StepIncrement']['step_increment_date'], 'm/d/Y')) {
			$this->data['StepIncrement']['step_increment_date'] = convert_datetime($this->data['StepIncrement']['step_increment_date'], 'Y-m-d');
		}
		
		if(!isset($this->data['StepIncrement']['id'])) {
			$this->data['StepIncrement']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['StepIncrement']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['StepIncrement']['status'] = 'Active';
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'STEINC';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}
			$this->data['StepIncrement']['code'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['StepIncrement']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>