<?php
App::uses('AppModel', 'Model');

class SubSpecialty extends AppModel {

	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_sub_specialty($data = array()) {		
		$existing_sub_specialties = $this->find_existing_sub_specialty_by_name($data['SubSpecialty']['name']);
		
		if(isset($existing_sub_specialties) && count($existing_sub_specialties) > 0) {
			$existing_sub_specialties['SubSpecialty']['status'] = 'Active';
			$data = $existing_sub_specialties;
		}

		return $this->save($data);
	}
	
	public function update_sub_specialty($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($sub_specialty_id = null, $sub_specialty = null) {
		$existing_sub_specialtiy = $this->find_existing_sub_specialty_by_id_or_code($sub_specialty_id);
		
		if(isset($existing_sub_specialtiy) && count($existing_sub_specialtiy) > 0) {
			$existing_sub_specialtiy['SubSpecialty']['status'] = $sub_specialty;
			$data = $existing_sub_specialtiy;
		}

		return $this->save($data);
	}
	
	public function find_existing_sub_specialty_by_name($sub_specialty_name = null) {
		if(isset($sub_specialty_name)) {
			$default_conditions = array(
				'SubSpecialty.name' => $sub_specialty_name
			);
		}
		
		$sub_specialties = $this->find('first', array(
			'fields' => array(
				'SubSpecialty.id',
				'SubSpecialty.code',
				'SubSpecialty.name',
				'SubSpecialty.status',
				// 'SubSpecialty.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $sub_specialties;
	}
	
	public function find_existing_sub_specialty_by_id_or_code($sub_specialties_id = null) {
		if(is_numeric($sub_specialties_id)) {
			$default_conditions = array(
				'SubSpecialty.id' => $sub_specialties_id
			);
		}
		else {
			$default_conditions = array(
				'SubSpecialty.code' => $sub_specialties_id
			);
		}
		
		$sub_specialty = $this->find('first', array(
			'fields' => array(
				'SubSpecialty.id',
				'SubSpecialty.code',
				'SubSpecialty.name',
				'SubSpecialty.status',
				// 'SubSpecialty.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $sub_specialty;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['SubSpecialty']['code'])) {
			$this->data['SubSpecialty']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SubSpecialty']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SubSpecialty']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SSP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['SubSpecialty']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['SubSpecialty']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>