<?php
App::uses('AppModel', 'Model');

class SubUnit extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public function add_sub_unit($data = array()) {		
		$existing_sub_unit = $this->find_existing_sub_unit_by_name($data['SubUnit']['name']);
		
		if(isset($existing_sub_unit) && count($existing_sub_unit) > 0) {
			$existing_sub_unit['SubUnit']['status'] = 'Active';
			$data = $existing_sub_unit;
			return $this->save($data);
			
		}

		return $this->saveAssociated($data);
	}
	
	public function update_sub_unit($data = array()) {
		return $this->saveAssociated($data);
	}
	
	public function update_status($sub_unit_id = null, $sub_unit = null) {
		$existing_sub_unit = $this->find_existing_sub_unit_by_id_or_code($sub_unit_id);
		
		if(isset($existing_sub_unit) && count($existing_sub_unit) > 0) {
			$existing_sub_unit['SubUnit']['status'] = $sub_unit;
			$data = $existing_sub_unit;
		}

		return $this->save($data);
	}
	
	public function find_existing_sub_unit_by_name($sub_unit_name = null) {
		if(isset($sub_unit_name)) {
			$default_conditions = array(
				'SubUnit.name' => $sub_unit_name
			);
		}
		
		$sub_unit = $this->find('first', array(
			'contain' => array(
				'Division',
				'Section',
				'SubUnitHead',
				'SubUnitHeadAssistant',
				'SubUnitHistoryLog'
			),
			'recursive'=>1,
			'conditions' => $default_conditions
		));
		
		return $sub_unit;
	}
	
	public function find_existing_sub_unit_by_id_or_code($sub_unit_id = null) {
		if(is_numeric($sub_unit_id)) {
			$default_conditions = array(
				'SubUnit.id' => $sub_unit_id
			);
		}
		else {
			$default_conditions = array(
				'SubUnit.code' => $sub_unit_id
			);
		}
		
		$sub_unit = $this->find('first', array(
			'contain' => array(
				'Division',
				'Section',
				'Unit',
				'SubUnitHead',
				'SubUnitHeadAssistant',
				'SubUnitHistoryLog'
			),
			'conditions' => $default_conditions
		));
		
		return $sub_unit;
	}
	
	
	public $belongsTo = array(
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'fields' => array(
				'Unit.code',
				'Unit.name',
				
			),
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'fields' => array(
				'Section.code',
				'Section.name',
				
			),
			'conditions' => array(
				'Section.status' => 'Active'
			),
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'fields' => array(
				'Division.code',
				'Division.name',
				
			),
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		
		'SubUnitHead' => array(
			'className' => 'Employee',
			'foreignKey' => 'sub_unit_head',
			'fields' => array(
				'SubUnitHead.combination_whole_name',
				
			),
			'conditions' => array(
				'SubUnitHead.status' => 'Active'
			)
		),
		'SubUnitHeadAssistant' => array(
			'className' => 'Employee',
			'foreignKey' => 'sub_unit_head_assistant',
			'fields' => array(
				'SubUnitHeadAssistant.combination_whole_name',
				
			),
			'conditions' => array(
				'SubUnitHeadAssistant.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array(
		'SubUnitHistoryLog' => array(
			'className' => 'SubUnitHistoryLog',
			'foreignKey' => 'sub_unit_code',
			'fields' => array(
				'SubUnitHistoryLog.unit_code',
				'SubUnitHistoryLog.sub_unit_code',
				'SubUnitHistoryLog.name',
				'SubUnitHistoryLog.sub_unit_head',
				'SubUnitHistoryLog.sub_unit_head_assistant',
			),
			'conditions' => array(
				'SubUnitHistoryLog.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
	);		

	public function beforeSave($options = array()) {
		if(!isset($this->data['SubUnit']['id'])) {
			$this->data['SubUnit']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SubUnit']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SubUnit']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'SUNT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['SubUnit']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['SubUnit']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>