<?php
App::uses('AppModel', 'Model');

class SuggestedSchedule extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'recruitment_';
	
	public $validate = array(
        'job_title_code' => array(
			'job_title_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Position Title is required.'
			),
        ),
		'job_title_item_number_code' => array(
			'job_title_item_number_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Item Number is required.'
			),
        ),
		
	);
	
	public $belongsTo = array(
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		),
		'JobTitleItemNumber' => array(
			'className' => 'JobTitleItemNumber',
			'foreignKey' => 'job_title_item_number_code',
			'conditions' => array(
				'JobTitleItemNumber.status' => 'Active'
			),
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			),
		),
	);

	
	public function beforeValidate($options = array()) {
		
		
		if(isset($this->data['SuggestedSchedule']['date_vacancy'])) {
			$this->data['SuggestedSchedule']['date_vacancy'] = convert_datetime($this->data['SuggestedSchedule']['date_vacancy'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['date_posted_from'])) {
			$this->data['SuggestedSchedule']['date_posted_from'] = convert_datetime($this->data['SuggestedSchedule']['date_posted_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['date_posted_to'])) {
			$this->data['SuggestedSchedule']['date_posted_to'] = convert_datetime($this->data['SuggestedSchedule']['date_posted_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['deadline_of_acceptance_of_application'])) {
			$this->data['SuggestedSchedule']['deadline_of_acceptance_of_application'] = convert_datetime($this->data['SuggestedSchedule']['deadline_of_acceptance_of_application'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['notification_from'])) {
			$this->data['SuggestedSchedule']['notification_from'] = convert_datetime($this->data['SuggestedSchedule']['notification_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['notification_to'])) {
			$this->data['SuggestedSchedule']['notification_to'] = convert_datetime($this->data['SuggestedSchedule']['notification_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['examination_date'])) {
			$this->data['SuggestedSchedule']['examination_date'] = convert_datetime($this->data['SuggestedSchedule']['examination_date'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['checking_from'])) {
			$this->data['SuggestedSchedule']['checking_from'] = convert_datetime($this->data['SuggestedSchedule']['checking_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['checking_to'])) {
			$this->data['SuggestedSchedule']['checking_to'] = convert_datetime($this->data['SuggestedSchedule']['checking_to'], 'Y-m-d');
		}	
		
		if(isset($this->data['SuggestedSchedule']['interview_from'])) {
			$this->data['SuggestedSchedule']['interview_from'] = convert_datetime($this->data['SuggestedSchedule']['interview_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['interview_to'])) {
			$this->data['SuggestedSchedule']['interview_to'] = convert_datetime($this->data['SuggestedSchedule']['interview_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['preparation_of_reports_from'])) {
			$this->data['SuggestedSchedule']['preparation_of_reports_from'] = convert_datetime($this->data['SuggestedSchedule']['preparation_of_reports_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['preparation_of_reports_to'])) {
			$this->data['SuggestedSchedule']['preparation_of_reports_to'] = convert_datetime($this->data['SuggestedSchedule']['preparation_of_reports_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['deliberation'])) {
			$this->data['SuggestedSchedule']['deliberation'] = convert_datetime($this->data['SuggestedSchedule']['deliberation'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['background_investigation_from'])) {
			$this->data['SuggestedSchedule']['background_investigation_from'] = convert_datetime($this->data['SuggestedSchedule']['background_investigation_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['background_investigation_to'])) {
			$this->data['SuggestedSchedule']['background_investigation_to'] = convert_datetime($this->data['SuggestedSchedule']['background_investigation_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['review_by_psb_from'])) {
			$this->data['SuggestedSchedule']['review_by_psb_from'] = convert_datetime($this->data['SuggestedSchedule']['review_by_psb_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['review_by_psb_to'])) {
			$this->data['SuggestedSchedule']['review_by_psb_to'] = convert_datetime($this->data['SuggestedSchedule']['review_by_psb_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['approval_of_appointment_from'])) {
			$this->data['SuggestedSchedule']['approval_of_appointment_from'] = convert_datetime($this->data['SuggestedSchedule']['approval_of_appointment_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['approval_of_appointment_to'])) {
			$this->data['SuggestedSchedule']['approval_of_appointment_to'] = convert_datetime($this->data['SuggestedSchedule']['approval_of_appointment_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['preparation_of_reports_2nd_from'])) {
			$this->data['SuggestedSchedule']['preparation_of_reports_2nd_from'] = convert_datetime($this->data['SuggestedSchedule']['preparation_of_reports_2nd_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['preparation_of_reports_2nd_to'])) {
			$this->data['SuggestedSchedule']['preparation_of_reports_2nd_to'] = convert_datetime($this->data['SuggestedSchedule']['preparation_of_reports_2nd_to'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['notification_2nd_from'])) {
			$this->data['SuggestedSchedule']['notification_2nd_from'] = convert_datetime($this->data['SuggestedSchedule']['notification_2nd_from'], 'Y-m-d');
		}
		
		if(isset($this->data['SuggestedSchedule']['notification_2nd_to'])) {
			$this->data['SuggestedSchedule']['notification_2nd_to'] = convert_datetime($this->data['SuggestedSchedule']['notification_2nd_to'], 'Y-m-d');
		}
		return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['SuggestedSchedule']['id'])) {
			$this->data['SuggestedSchedule']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SuggestedSchedule']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['SuggestedSchedule']['status'] = 'Active';
		}
		else {
			$this->data['SuggestedSchedule']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false) {
		foreach($results as $x => $result){
			if(isset($result['SuggestedSchedule']['date_vacancy'])){
				$results[$x]['SuggestedSchedule']['date_vacancy'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['date_vacancy']));
			}
			
			if(isset($result['SuggestedSchedule']['date_posted_from'])){
				$results[$x]['SuggestedSchedule']['date_posted_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['date_posted_from']));
			}
			
			if(isset($result['SuggestedSchedule']['date_posted_to'])){
				$results[$x]['SuggestedSchedule']['date_posted_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['date_posted_to']));
			}
			
			if(isset($result['SuggestedSchedule']['deadline_of_acceptance_of_application'])){
				$results[$x]['SuggestedSchedule']['deadline_of_acceptance_of_application'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['deadline_of_acceptance_of_application']));
			}
			
			if(isset($result['SuggestedSchedule']['notification_from'])){
				$results[$x]['SuggestedSchedule']['notification_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['notification_from']));
			}
			
			if(isset($result['SuggestedSchedule']['notification_to'])){
				$results[$x]['SuggestedSchedule']['notification_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['notification_to']));
			}
			
			if(isset($result['SuggestedSchedule']['examination_date'])){
				$results[$x]['SuggestedSchedule']['examination_date'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['examination_date']));
			}
			
			if(isset($result['SuggestedSchedule']['checking_from'])){
				$results[$x]['SuggestedSchedule']['checking_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['checking_from']));
			}
			
			if(isset($result['SuggestedSchedule']['checking_to'])){
				$results[$x]['SuggestedSchedule']['checking_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['checking_to']));
			}
			
			if(isset($result['SuggestedSchedule']['interview_from'])){
				$results[$x]['SuggestedSchedule']['interview_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['interview_from']));
			}
			
			if(isset($result['SuggestedSchedule']['interview_to'])){
				$results[$x]['SuggestedSchedule']['interview_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['interview_to']));
			}
			
			if(isset($result['SuggestedSchedule']['preparation_of_reports_from'])){
				$results[$x]['SuggestedSchedule']['preparation_of_reports_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['preparation_of_reports_from']));
			}
			
			if(isset($result['SuggestedSchedule']['preparation_of_reports_to'])){
				$results[$x]['SuggestedSchedule']['preparation_of_reports_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['preparation_of_reports_to']));
			}
			
			if(isset($result['SuggestedSchedule']['deliberation'])){
				$results[$x]['SuggestedSchedule']['deliberation'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['deliberation']));
			}
			
			if(isset($result['SuggestedSchedule']['background_investigation_from'])){
				$results[$x]['SuggestedSchedule']['background_investigation_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['background_investigation_from']));
			}
			
			if(isset($result['SuggestedSchedule']['background_investigation_to'])){
				$results[$x]['SuggestedSchedule']['background_investigation_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['background_investigation_to']));
			}
			
			if(isset($result['SuggestedSchedule']['review_by_psb_from'])){
				$results[$x]['SuggestedSchedule']['review_by_psb_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['review_by_psb_from']));
			}
			
			if(isset($result['SuggestedSchedule']['review_by_psb_to'])){
				$results[$x]['SuggestedSchedule']['review_by_psb_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['review_by_psb_to']));
			}
			
			if(isset($result['SuggestedSchedule']['approval_of_appointment_from'])){
				$results[$x]['SuggestedSchedule']['approval_of_appointment_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['approval_of_appointment_from']));
			}
			
			if(isset($result['SuggestedSchedule']['approval_of_appointment_to'])){
				$results[$x]['SuggestedSchedule']['approval_of_appointment_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['approval_of_appointment_to']));
			}
			
			if(isset($result['SuggestedSchedule']['preparation_of_reports_2nd_from'])){
				$results[$x]['SuggestedSchedule']['preparation_of_reports_2nd_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['preparation_of_reports_2nd_from']));
			}
			
			if(isset($result['SuggestedSchedule']['preparation_of_reports_2nd_to'])){
				$results[$x]['SuggestedSchedule']['preparation_of_reports_2nd_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['preparation_of_reports_2nd_to']));
			}
			
			if(isset($result['SuggestedSchedule']['notification_2nd_from'])){
				$results[$x]['SuggestedSchedule']['notification_2nd_from'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['notification_2nd_from']));
			}
			if(isset($result['SuggestedSchedule']['notification_2nd_to'])){
				$results[$x]['SuggestedSchedule']['notification_2nd_to'] = date('m/d/Y',strtotime($results[$x]['SuggestedSchedule']['notification_2nd_to']));
			}
			
			
		}

		return $results;
	}
}
?>