<?php
App::uses('AppModel', 'Model');

class TaxStatus extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),
	);
	
	public function add_tax_status($data = array()) {		
		$existing_tax_status = $this->find_existing_tax_status_by_name($data['TaxStatus']['name']);
		
		if(isset($existing_tax_status) && count($existing_tax_status) > 0) {
			$existing_tax_status['TaxStatus']['status'] = 'Active';
			$data = $existing_tax_status;
			
		}

		return $this->save($data);
	}
	
	public function update_tax_status($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($tax_status_id = null, $tax_status = null) {
		$existing_tax_status = $this->find_existing_tax_status_by_id_or_code($tax_status_id);
		
		if(isset($existing_tax_status) && count($existing_tax_status) > 0) {
			$existing_tax_status['TaxStatus']['status'] = $tax_status;
			$data = $existing_tax_status;
		}

		return $this->save($data);
	}
	
	public function find_existing_tax_status_by_name($tax_status_name = null) {
		if(isset($tax_status_name)) {
			$default_conditions = array(
				'TaxStatus.name' => $tax_status_name
			);
		}
		
		$tax_status = $this->find('first', array(
			'fields' => array(
				'TaxStatus.id',
				'TaxStatus.code',
				'TaxStatus.name',
				'TaxStatus.status',
				'TaxStatus.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $tax_status;
	}
	
	public function find_existing_tax_status_by_id_or_code($tax_status_id = null) {
		if(is_numeric($tax_status_id)) {
			$default_conditions = array(
				'TaxStatus.id' => $tax_status_id
			);
		}
		else {
			$default_conditions = array(
				'TaxStatus.code' => $tax_status_id
			);
		}
		
		$tax_status = $this->find('first', array(
			'fields' => array(
				'TaxStatus.id',
				'TaxStatus.code',
				'TaxStatus.name',
				'TaxStatus.status',
				'TaxStatus.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $tax_status;
	}
	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['TaxStatus']['id'])) {
			$this->data['TaxStatus']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TaxStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TaxStatus']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'TAX';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['TaxStatus']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['TaxStatus']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>