<?php
App::uses('AppModel', 'Model');

class TempEmployee extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	// public $primaryKey = "employee_code";
	public $displayField = 'employee_number';

	public $virtualFields=array(
		'age' => "TIMESTAMPDIFF(YEAR,TempEmployee.birth_date, CURDATE())",
	);
	
	public function __construct($id = false, $table = null, $ds = null) {
		parent::__construct($id, $table, $ds);
		$this->virtualFields['combination_whole_name'] = sprintf(
			'CONCAT(%s.last_name, ", ", %s.first_name, " ", %s.middle_name)', $this->alias, $this->alias, $this->alias
		);
		
		$this->virtualFields['standard_name'] = sprintf(
			'CONCAT(%s.first_name, " ", SUBSTR(%s.middle_name, 1, 1), ". ", %s.last_name)', $this->alias, $this->alias, $this->alias
		);
	}
	
	public $belongsTo = array(
	
		'Suffix' => array(
			'className' => 'Suffix',
			'foreignKey' => 'suffix_code',
			'fields' => array(
				'Suffix.code',
				'Suffix.name',
			),
			'conditions' => array(
				'Suffix.status' => 'Active'
			)
		),
		'PrefixList' => array(
			'className' => 'PrefixList',
			'foreignKey' => 'prefix_code',
			'fields' => array(
				'PrefixList.code',
				'PrefixList.name',
			),
			'conditions' => array(
				'PrefixList.status' => 'Active'
			)
		),
		'Gender' => array(
			'className' => 'Gender',
			'foreignKey' => 'gender_code',
			'fields' => array(
				'Gender.code',
				'Gender.name',
			),
			'conditions' => array(
				'Gender.status' => 'Active'
			)
		),
		'CivilStatus' => array(
			'className' => 'CivilStatus',
			'foreignKey' => 'civil_status_code',
			'fields' => array(
				'CivilStatus.code',
				'CivilStatus.name',
			),
			'conditions' => array(
				'CivilStatus.status' => 'Active'
			)
		),
		'Nationality' => array(
			'className' => 'Nationality',
			'foreignKey' => 'nationality_code',
			'fields' => array(
				'Nationality.code',
				'Nationality.name',
			),
			'conditions' => array(
				'Nationality.status' => 'Active'
			)
		),
		'SeparationStatus' => array(
			'className' => 'SeparationStatus',
			'foreignKey' => 'separation_status_code',
			'fields' => array(
				'SeparationStatus.code',
				'SeparationStatus.name',
			),
			'conditions' => array(
				'SeparationStatus.status' => 'Active'
			)
		),
		'DocumentType' => array(
			'className' => 'DocumentType',
			'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'SeparationStatus.code',
				// 'SeparationStatus.name',
			// ),
			'conditions' => array(
				'DocumentType.status' => 'Active'
			)
		),
		'BloodType' => array(
			'className' => 'BloodType',
			'foreignKey' => 'blood_type_code',
			'fields' => array(
				'BloodType.code',
				'BloodType.name',
			),
			'conditions' => array(
				'BloodType.status' => 'Active'
			)
		),
		'IndigenousGroup' => array(
			'className' => 'IndigenousGroup',
			'foreignKey' => 'indigenous_group_code',
			'fields' => array(
				'IndigenousGroup.code',
				'IndigenousGroup.name',
			),
			'conditions' => array(
				'IndigenousGroup.status' => 'Active'
			)
		),
		'Disability' => array(
			'className' => 'Disability',
			'foreignKey' => 'disability_code',
			'fields' => array(
				'Disability.code',
				'Disability.name',
			),
			'conditions' => array(
				'Disability.status' => 'Active'
			)
		),
		'CitizenshipCountry' => array(
			'className' => 'CountryList',
			'foreignKey' => 'citizenship_country_code',
			'conditions' => array(
				'CitizenshipCountry.status' => 'Active'
			)
		),
		// 'Applicant' => array(
			// 'className' => 'Applicant',
			// 'foreignKey' => 'applicant_code',
			// 'conditions' => array(
				// 'Applicant.status' => 'Active'
			// )
		// ),

		// 'OtherPersonnelActionType' => array(
			// 'className' => 'OtherPersonnelActionType',
			// 'foreignKey' => 'other_personnel_action_type_code',
			// 'fields' => array(
				// 'OtherPersonnelActionType.code',
				// 'OtherPersonnelActionType.name'
			// ),
			// 'conditions' => array(
				// 'OtherPersonnelActionType.status' => 'Active'
			// )
		// )
		
		
	);

	public $hasMany = array(
		'TempEmployeeEmailAddress' => array(
			'className' => 'TempEmployeeEmailAddress',
			'foreignKey' => 'temp_employee_id',
			'conditions' => array(
				'TempEmployeeEmailAddress.status' => 'Active'
			),
		),
		
		'TempEmployeeMobileNumber' => array(
			'className' => 'TempEmployeeMobileNumber',
			'foreignKey' => 'temp_employee_id',
			'conditions' => array(
				'TempEmployeeMobileNumber.status' => 'Active'
			),
		),
		'EmployeeLoanEntry' => array(
			'className' => 'EmployeeLoanEntry',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'EmployeeLoanEntry.id',
				'EmployeeLoanEntry.code',
				'EmployeeLoanEntry.employee_code',
				'EmployeeLoanEntry.loan_type_code',
				'EmployeeLoanEntry.date_filed',
				'EmployeeLoanEntry.reference_no',
				'EmployeeLoanEntry.loan_amount',
				'EmployeeLoanEntry.loan_with_interest',
				'EmployeeLoanEntry.monthly_amortization',
				'EmployeeLoanEntry.payment_start',
				'EmployeeLoanEntry.payment_end',
				'EmployeeLoanEntry.remarks',
				'EmployeeLoanEntry.pnno',
				'EmployeeLoanEntry.pn_date',
				'EmployeeLoanEntry.payroll_cycle',
				'EmployeeLoanEntry.deduct_loan',
			),
			'conditions' => array(
				'EmployeeLoanEntry.status' => 'Active'
			),
			 'order' => 'EmployeeLoanEntry.created ASC',
		),
		// 'EmployeeLeaveCard' => array(
			// 'className' => 'EmployeeLeaveCard',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
			// 	'EmployeeLeaveCard.id',
			// 	'EmployeeLeaveCard.code',
			// 	'EmployeeLeaveCard.employee_code',
			// 	'EmployeeLeaveCard.particulars',
			// 	'EmployeeLeaveCard.period',
			// 	'EmployeeLeaveCard.vacation_leave_earned',
			// 	'EmployeeLeaveCard.vacation_absence_with_pay',
			// 	'EmployeeLeaveCard.vacation_balance_incl',
			// 	'EmployeeLeaveCard.vacation_balance_excl',
			// 	'EmployeeLeaveCard.vacation_absence_without_pay',
			// 	'EmployeeLeaveCard.sick_leave_earned',
			// 	'EmployeeLeaveCard.sick_absence_with_pay',
			// 	'EmployeeLeaveCard.sick_balance_incl',
			// 	'EmployeeLeaveCard.sick_balance_excl',
			// 	'EmployeeLeaveCard.sick_absence_without_pay',
			// 	'EmployeeLeaveCard.excess_vacation',
			// 	'EmployeeLeaveCard.excess_sick',
			// 	'EmployeeLeaveCard.remarks',
				
			// ),
			// 'conditions' => array(
				// 'EmployeeLeaveCard.status' => 'Active'
			// )
		// ),
		// 'EmployeeServiceRecord' =>array(
			// 'className' => 'EmployeeServiceRecord',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'EmployeeServiceRecord.id',
				// 'EmployeeServiceRecord.employee_code',
				// 'EmployeeServiceRecord.designation',
				// 'EmployeeServiceRecord.date_from',
				// 'EmployeeServiceRecord.date_to',
				// 'EmployeeServiceRecord.salary',
				// 'EmployeeServiceRecord.service_status',
				// 'EmployeeServiceRecord.place_of_assignment',
				// 'EmployeeServiceRecord.branch',
				// 'EmployeeServiceRecord.wop',
				// 'EmployeeServiceRecord.cause_remarks',
			// ),
			// 'conditions' => array(
				// 'EmployeeServiceRecord.status' => 'Active'
			// )			
		// ),
		// 'EmployeeHistoryLog' =>array(
			// 'className' => 'EmployeeHistoryLog',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeHistoryLog.status' => 'Active'
			// )
		// ),
		// 'UnderTimeEntry' => array(
			// 'className' => 'UnderTimeEntry',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'UnderTimeEntry.status' => 'Active'
			// )
		// ),
		// 'Overtime' => array(
			// 'className' => 'Overtime',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'Overtime.status' => 'Active'
			// )
		// ),
		// 'EmployeeDeduction' => array(
			// 'className' => 'EmployeeDeduction',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeDeduction.status' => 'Active'
			// )
		// ),
		// 'EmployeeLoanEntry' => array(
			// 'className' => 'EmployeeLoanEntry',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeLoanEntry.status' => 'Active'
			// )
		// ),
		'Education' => array(
			'className' => 'Education',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'Education.id',
				'Education.employee_code',
				'Education.degree_level',
				'Education.from',
				'Education.to',
				'Education.highest_level_units_earned',
				'Education.year_graduated',
				'Education.scholarship',
				'Education.remarks',
				'Education.school',
				'Education.course_degree ',
			),
			'conditions' => array(
				'Education.status' => 'Active'
			),
		),
		
		// 'EmployeeSchedule' =>array(
			// 'className' => 'EmployeeSchedule',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeSchedule.status' => 'Active'
			// )
		// ),
		'ServiceRecord' => array(
			'className' => 'ServiceRecord',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'ServiceRecord.id',
				'ServiceRecord.employee_code',
				'ServiceRecord.designation',
				'ServiceRecord.date_from',
				'ServiceRecord.date_to',
				'ServiceRecord.salary',
				'ServiceRecord.service_status',
				'ServiceRecord.place_of_assignment',
				'ServiceRecord.branch',
				'ServiceRecord.wop',
				'ServiceRecord.cause_remarks',
			),
			'conditions' => array(
				'ServiceRecord.status' => 'Active'
			),
		),		
		'TrainingsSeminar' => array(
			'className' => 'TrainingsSeminar',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'TrainingsSeminar.id',
				'TrainingsSeminar.employee_code',
				'TrainingsSeminar.date_from',
				'TrainingsSeminar.date_to',
				'TrainingsSeminar.activity_title',
				'TrainingsSeminar.provider',
				'TrainingsSeminar.remarks',
			),
			'conditions' => array(
				'TrainingsSeminar.status' => 'Active'
			),
		),
		'WorkHistory' => array(
			'className' => 'WorkHistory',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'WorkHistory.id',
				'WorkHistory.employee_code',
				'WorkHistory.from',
				'WorkHistory.to',
				'WorkHistory.position_title',
				'WorkHistory.department_office_company',
				'WorkHistory.monthly_salary',
				'WorkHistory.salary_job_grade',
				'WorkHistory.status_of_appointment_code',
				'WorkHistory.gov_service',
			),
			'conditions' => array(
				'WorkHistory.status' => 'Active'
			),
		),
		// 'TimeEntry' => array(
			// 'className' => 'TimeEntry',
			// 'foreignKey' => 'employee_code',
		// ),
		
		// 'EmployeeFormalCharge' => array(
			// 'className' => 'EmployeeFormalCharge',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeFormalCharge.status' => 'Active'
			// ),
		// ),
		// 'EmployeeAdministrativeOffense' => array(
			// 'className' => 'EmployeeAdministrativeOffense',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeAdministrativeOffense.status' => 'Active'
			// ),
		// ),
		// 'EmployeeRanForPublicOffice' => array(
			// 'className' => 'EmployeeRanForPublicOffice',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeRanForPublicOffice.status' => 'Active'
			// ),
		// ),
		
		// 'EmployeeIncomeAndBenefit' => array(
			// 'className' => 'EmployeeIncomeAndBenefit',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeIncomeAndBenefit.status' => 'Active'
			// ),
		// ),
		'CivilService' => array(
			'className' => 'CivilService',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'CivilService.id',
				'CivilService.employee_code',
				'CivilService.career_service_code',
				'CivilService.rating',
				'CivilService.date_of_examination',
				'CivilService.place_of_examination',
				'CivilService.number',
				'CivilService.date_of_validity',
				'CivilService.date_passed',
				'CivilService.title',
				'CivilService.remarks',
				'CivilService.attachment',
				'CivilService.status',
				'CivilService.career_type',
				
			),
			'conditions' => array(
				'CivilService.status' => 'Active'
			),
		),
		'VoluntaryWork' => array(
			'className' => 'VoluntaryWork',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'VoluntaryWork.id',
				'VoluntaryWork.employee_code',
				'VoluntaryWork.name_address_of_organization',
				'VoluntaryWork.from',
				'VoluntaryWork.to',
				'VoluntaryWork.number_of_hours',
				'VoluntaryWork.position_nature_of_work',
				'VoluntaryWork.status',
				
			),
			'conditions' => array(
				'VoluntaryWork.status' => 'Active'
			),
		),
		
		'LearningAndDevelopment' => array(
			'className' => 'LearningAndDevelopment',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'LearningAndDevelopment.id',
				'LearningAndDevelopment.employee_code',
				'LearningAndDevelopment.title_of_learning_and_development',
				'LearningAndDevelopment.from',
				'LearningAndDevelopment.to',
				'LearningAndDevelopment.number_of_hours',
				'LearningAndDevelopment.type_of_ld',
				'LearningAndDevelopment.conducted_sponsored_by',
				'LearningAndDevelopment.status',
				
			),
			'conditions' => array(
				'LearningAndDevelopment.status' => 'Active'
			),
		),
		
		'OtherInformation' => array(
			'className' => 'OtherInformation',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'OtherInformation.id',
				'OtherInformation.employee_code',
				'OtherInformation.special_skill_and_hobby',
				'OtherInformation.non_academic_distinction_or_recognition',
				'OtherInformation.membership_in_association_or_organization',
				'OtherInformation.status',
				
			),
			'conditions' => array(
				'OtherInformation.status' => 'Active'
			),
		),
		
		// 'Reference' => array(
			// 'className' => 'Reference',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'Reference.id',
				// 'Reference.employee_code',
				// 'Reference.name',
				// 'Reference.address',
				// 'Reference.telephone_no',
				// 'Reference.status',
				
			// ),
			// 'conditions' => array(
				// 'Reference.status' => 'Active'
			// ),
		// ),
		
		// 'Dependent' => array(
			// 'className' => 'Dependent',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'Dependent.status' => 'Active'
			// ),
		// ),
		
		// 'Contact' => array(
			// 'className' => 'Contact',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'Contact.status' => 'Active'
			// ),
		// ),
		
		// 'RelativesInGovernment' => array(
			// 'className' => 'RelativesInGovernment',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'RelativesInGovernment.status' => 'Active'
			// ),
		// ),
		
		// 'Document' => array(
			// 'className' => 'Document',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'Document.status' => 'Active'
			// ),
		// ),
		
		// 'EmployeeAdministrativeOffense' => array(
			// 'className' => 'EmployeeAdministrativeOffense',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeAdministrativeOffense.status' => 'Active'
			// ),
		// ),
		// 'EmployeeRanForPublicOffice' => array(
			// 'className' => 'EmployeeRanForPublicOffice',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeRanForPublicOffice.status' => 'Active'
			// ),
		// ),
		// 'EmployeeFormalCharge' => array(
			// 'className' => 'EmployeeFormalCharge',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeFormalCharge.status' => 'Active'
			// ),
		// ),
		// 'EmployeeFormalCharge' => array(
			// 'className' => 'EmployeeFormalCharge',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeFormalCharge.status' => 'Active'
			// ),
		// ),
		// 'StepIncrement' => array(
			// 'className' => 'StepIncrement',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'StepIncrement.status' => 'Active'
			// ),
		// ),
		// 'LeaveEarned' => array(
			// 'className' => 'LeaveEarned',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'LeaveEarned.status' => 'Active'
			// ),
		// ),
		
	);
	
	public $hasOne = array(
		'User' => array(
			'className' => 'User',
			'foreignKey' => 'employee_code',
			'dependent' => true
		),

		// 'LeaveUsedAndRemaining' => array(
			// 'className' => 'LeaveUsedAndRemaining',
			// 'foreignKey' => 'employee_code',
			// 'dependent' => true
		// ),
		// 'EmployeeRanForPublicOfficeForSearch' => array(
			// 'className' => 'EmployeeRanForPublicOffice',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeRanForPublicOfficeForSearch.status' => 'Active'
			// ),
		// ),
		// 'EmployeeAdministrativeOffenseForSearch' => array(
			// 'className' => 'EmployeeAdministrativeOffense',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeAdministrativeOffenseForSearch.status' => 'Active'
			// ),
		// ),
		// 'EmployeeFormalChargeForSearch' => array(
			// 'className' => 'EmployeeFormalCharge',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeFormalChargeForSearch.status' => 'Active'
			// ),
		// ),
		// 'RelativesInGovernmentForSearch' => array(
			// 'className' => 'RelativesInGovernment',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'RelativesInGovernmentForSearch.status' => 'Active'
			// ),
		// ),
		// 'EmployeeAdressForSearch' => array(
			// 'className' => 'EmployeeAddress',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeAdressForSearch.status' => 'Active'
			// ),
		// ),
		// 'EmployeeTempFamilyMemberForSearch' => array(
			// 'className' => 'EmployeeTempFamilyMember',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeTempFamilyMemberForSearch.relation_code' => array('DAUGH','SON'),
				// 'EmployeeTempFamilyMemberForSearch.status' => 'Active'
				
			// ),
		// ),
		// 'EmployeeTrainingsSeminarForSearch' => array(
			// 'className' => 'TrainingsSeminar',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeTrainingsSeminarForSearch.status' => 'Active'
				
			// ),
		// ),
		// 'EmployeeTrainingsSeminarForSearch' => array(
			// 'className' => 'TrainingsSeminar',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeTrainingsSeminarForSearch.status' => 'Active'
				
			// ),
		// ),
		// 'EmployeeWorkHistoryForSearch' => array(
			// 'className' => 'WorkHistory',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeWorkHistoryForSearch.status' => 'Active'
				
			// ),
		// ),
		// 'EmployeeCityForSearch' => array(
			// 'className' => 'City',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'EmployeeCityForSearch.status' => 'Active'
			// ),
		// ),
		
		'TempAddress' => array(
			'className' => 'TempAddress',
			'foreignKey' => 'temp_employee_id',
			// 'fields' => array(
				// 'TempAddress.id',
				// 'TempAddress.house_block_lot_no',
				// 'TempAddress.street',
				// 'TempAddress.subdivision_village',
				// 'TempAddress.barangay_code',
				// 'TempAddress.city_code',
				// 'TempAddress.province_code',
				// 'TempAddress.postal_zip_code',
				// 'TempAddress.country_code',
				// 'TempAddress.pa_house_block_lot_no',
				// 'TempAddress.pa_street',
				// 'TempAddress.pa_subdivision_village',
				// 'TempAddress.pa_barangay_code',
				// 'TempAddress.pa_city_code',
				// 'TempAddress.pa_province_code',
				// 'TempAddress.pa_region_code',
				// 'TempAddress.pa_postal_zip_code',
				// 'TempAddress.pa_country_code',
			// ),
			'conditions' => array(
				'TempAddress.status' => 'Active'
			)
		),
		'TempSeparationStatus' => array(
			'className' => 'TempSeparationStatus',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'TempSeparationStatus.status' => 'Active'
			)
		),
		// 'PositionDetail' => array(
			// 'className' => 'PositionDetail',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'PositionDetail.id',
				// 'PositionDetail.job_title_code',
				// 'PositionDetail.job_title_item_number_code',
				// 'PositionDetail.section_code',
				// 'PositionDetail.unit_code',
				// 'PositionDetail.sub_unit_code',
				// 'PositionDetail.date_employed',
				// 'PositionDetail.end_of_contract',
				// 'PositionDetail.employment_status_code',
				// 'PositionDetail.nature_of_appointment_code',
				// 'PositionDetail.personnel_type_code',
				// 'PositionDetail.appointment_date',
			// ),
			// 'conditions' => array(
				// 'PositionDetail.status' => 'Active'
			// )
		// ),
		// 'PayrollDetail' => array(
			// 'className' => 'PayrollDetail',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'PayrollDetail.id',
				// 'PayrollDetail.salary_grade_code',
				// 'PayrollDetail.monthly_rate',
				// 'PayrollDetail.semi_monthly_rate',
				// 'PayrollDetail.daily_rate',
				// 'PayrollDetail.hourly_rate',
				// 'PayrollDetail.food_allowance',
				// 'PayrollDetail.cola',
				// 'PayrollDetail.tax_shield',
				// 'PayrollDetail.transportation_allowance',
				// 'PayrollDetail.payroll_type_code',
				// 'PayrollDetail.has_holiday_pay',
				// 'PayrollDetail.has_night_differential_pay',
				// 'PayrollDetail.tax_status_code',
				// 'PayrollDetail.phic_employee_share',
				// 'PayrollDetail.phic_employer_share',
				// 'PayrollDetail.pagibig_employee_share',
				// 'PayrollDetail.pagibig_employer_share',
				// 'PayrollDetail.gsis_employee_share',
				// 'PayrollDetail.gsis_employer_share',
				// 'PayrollDetail.sss_employee_share',
				// 'PayrollDetail.sss_employer_share',
			// ),
			// 'conditions' => array(
				// 'PayrollDetail.status' => 'Active'
			// )
		// ),
		// 'BankAccountDetail' => array(
			// 'className' => 'BankAccountDetail',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
				// 'BankAccountDetail.id',
				// 'BankAccountDetail.bank_code',
				// 'BankAccountDetail.account_number',
			// ),
			// 'conditions' => array(
				// 'BankAccountDetail.status' => 'Active'
			// )
		// ),
		// 'SectionHead' => array(
			// 'className' => 'Section',
			// 'foreignKey' => 'section_head',
			// 'conditions' => array(
				// 'SectionHead.status' => 'Active'
			// )
		// ),
		// 'SectionAssistantHead' => array(
			// 'className' => 'Section',
			// 'foreignKey' => 'assistant_section_head',
			// 'conditions' => array(
				// 'SectionAssistantHead.status' => 'Active'
			// )
		// ),
		// 'UnitHead' => array(
			// 'className' => 'Unit',
			// 'foreignKey' => 'unit_head',
			// 'conditions' => array(
				// 'UnitHead.status' => 'Active'
			// )
		// ),
		// 'UnitHeadAssistant' => array(
			// 'className' => 'Unit',
			// 'foreignKey' => 'unit_head_assistant',
			// 'conditions' => array(
				// 'UnitHeadAssistant.status' => 'Active'
			// )
		// ),
		// 'SubUnitHead' => array(
			// 'className' => 'SubUnit',
			// 'foreignKey' => 'sub_unit_head',
			// 'conditions' => array(
				// 'SubUnitHead.status' => 'Active'
			// )
		// ),
		// 'SubUnitHeadAssistant' => array(
			// 'className' => 'SubUnit',
			// 'foreignKey' => 'sub_unit_head_assistant',
			// 'conditions' => array(
				// 'SubUnitHeadAssistant.status' => 'Active'
			// )
		// ),
		// 'EmployeePayrollDetail' => array(
			// 'className' => 'EmployeePayrollDetail',
			// 'foreignKey' => 'employee_code',
			// 'fields' => array(
					// 'EmployeePayrollDetail.id',
					// 'EmployeePayrollDetail.reference_code',
					// 'EmployeePayrollDetail.employee_code',
					// 'EmployeePayrollDetail.monthly_rate',
					// 'EmployeePayrollDetail.semi_monthly_rate',
					// 'EmployeePayrollDetail.daily_rate',
					// 'EmployeePayrollDetail.hourly_rate',
					// 'EmployeePayrollDetail.food_allowance',
					// 'EmployeePayrollDetail.cola',
					// 'EmployeePayrollDetail.tax_shield',
					// 'EmployeePayrollDetail.transportation_allowance',
					// 'EmployeePayrollDetail.payroll_type_code',
					// 'EmployeePayrollDetail.has_holiday_pay',
					// 'EmployeePayrollDetail.has_night_differential_pay',
					// 'EmployeePayrollDetail.pagibig_employee_share',
					// 'EmployeePayrollDetail.pagibig_employer_share',
					// 'EmployeePayrollDetail.gsis_employee_share',
					// 'EmployeePayrollDetail.gsis_employer_share',
			// ),
			// 'conditions' => array(
				// 'EmployeePayrollDetail.status' => 'Active'
			// )
		// )
		
		'OtherInformationQuestion' => array(
			'className' => 'OtherInformationQuestion',
			'foreignKey' => 'employee_code',
			
			'conditions' => array(
				'OtherInformationQuestion.status' => 'Active'
			),
		),
		
		'TempFamilyMember' => array(
			'className' => 'TempFamilyMember',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'TempFamilyMember.id',
				'TempFamilyMember.employee_code',
				'TempFamilyMember.spouse_surname',
				'TempFamilyMember.spouse_first_name',
				'TempFamilyMember.spouse_middle_name',
				'TempFamilyMember.spouse_name_extension',
				'TempFamilyMember.spouse_maiden_middle_name',
				'TempFamilyMember.spouse_occupation',
				'TempFamilyMember.spouse_employeer_business_name',
				'TempFamilyMember.spouse_employment_status',
				'TempFamilyMember.spouse_tin',
				'TempFamilyMember.spouse_business_address',
				'TempFamilyMember.spouse_telephone',
				'TempFamilyMember.spouse_combination_whole_name',
				'TempFamilyMember.spouse_standard_name',
				'TempFamilyMember.father_surname',
				'TempFamilyMember.father_first_name',
				'TempFamilyMember.father_middle_name',
				'TempFamilyMember.father_name_extension',
				'TempFamilyMember.mother_maiden_name',
				'TempFamilyMember.mother_surname',
				'TempFamilyMember.mother_first_name',
				'TempFamilyMember.mother_middle_name',
				'TempFamilyMember.status',
			),
			'conditions' => array(
				'TempFamilyMember.approval_status' => 'Pending'
			),
		),
		
		'GovernmentIssuedId' => array(
			'className' => 'GovernmentIssuedId',
			'foreignKey' => 'employee_code',
			'fields' => array(
				'GovernmentIssuedId.id',
				'GovernmentIssuedId.employee_code',
				'GovernmentIssuedId.government_issued_id_no',
				'GovernmentIssuedId.id_license_passport_no',
				'GovernmentIssuedId.date_place_of_issuance',
				'GovernmentIssuedId.status',
				
			),
			'conditions' => array(
				'GovernmentIssuedId.status' => 'Active'
			),
		),
		
		// 'StatementOfAssetsLiabilityAndNetworth' => array(
			// 'className' => 'StatementOfAssetsLiabilityAndNetworth',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'StatementOfAssetsLiabilityAndNetworth.status' => 'Active'
			// ),
		// ),
		
		// 'LoyaltyIncentivePay' => array(
			// 'className' => 'LoyaltyIncentivePay',
			// 'foreignKey' => 'employee_code',
			// 'conditions' => array(
				// 'LoyaltyIncentivePay.status' => 'Active'
			// ),
		// ),
		
	);
	
	function validate_gsis_if_exist() {
		
		$Employee = ClassRegistry::init('Employee');
		$count_record = $Employee->find('count', array(
			'conditions' => array(
				'Employee.gsis' => $this->data['TempEmployee']['gsis'],
				'Employee.employee_code !=' => $_SESSION['Auth']['User']['Employee']['employee_code'],
			)
		));		
		
		if ($count_record > 0) {
			return false;
		}
		else {
			return true;
		}
	}
	
	function validate_pagibig_if_exist() {
		
		$Employee = ClassRegistry::init('Employee');
		$count_record = $Employee->find('count', array(
			'conditions' => array(
				'Employee.pagibig' => $this->data['TempEmployee']['pagibig'],
				'Employee.employee_code !=' => $_SESSION['Auth']['User']['Employee']['employee_code'],
			)
		));		
		
		if ($count_record > 0) {
			return false;
		}
		else {
			return true;
		}
	}
	
	function validate_philhealth_if_exist() {
		
		$Employee = ClassRegistry::init('Employee');
		$count_record = $Employee->find('count', array(
			'conditions' => array(
				'Employee.philhealth' => $this->data['TempEmployee']['philhealth'],
				'Employee.employee_code !=' => $_SESSION['Auth']['User']['Employee']['employee_code'],
			)
		));		
		
		if ($count_record > 0) {
			return false;
		}
		else {
			return true;
		}
	}
	
	function validate_tin_if_exist() {
		
		$Employee = ClassRegistry::init('Employee');
		$count_record = $Employee->find('count', array(
			'conditions' => array(
				'Employee.tin' => $this->data['TempEmployee']['tin'],
				'Employee.employee_code !=' => $_SESSION['Auth']['User']['Employee']['employee_code'],
			)
		));		
		
		if ($count_record > 0) {
			return false;
		}
		else {
			return true;
		}
	}
	
	public $validate = array(
		'employee_id_number' => array(
            'employee_id_number logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Employee ID Number is required.'
            ),
        ), 
		
        'gsis' => array(
            'gsis logic 1' => array(
                'rule' => array('validate_gsis_if_exist'),
                'message' => 'GSIS No. is already used.'
            ),
			'gsis logic 2' => array(
                'rule' => array('notEmpty'),
                'message' => 'GSIS No. is required.'
            ),
        ),
		
		'pagibig' => array(
            'pagibig logic 1' => array(
                'rule' => array('validate_pagibig_if_exist'),
                'message' => 'PAGIBIG No. is already used.'
            ),
			'pagibig logic 2' => array(
                'rule' => array('notEmpty'),
                'message' => 'PAGIBIG No. is required.'
            ),
        ),
		
		'philhealth' => array(
            'philhealth logic 1' => array(
                'rule' => array('validate_philhealth_if_exist'),
                'message' => 'PHIC No. is already used.'
            ),
			'philhealth logic 2' => array(
                'rule' => array('notEmpty'),
                'message' => 'PHIC No. is required.'
            ),
        ),
		
		'tin' => array(
            'tin logic 1' => array(
                'rule' => array('validate_tin_if_exist'),
                'message' => 'TIN No. is already used.'
            ),
			'tin logic 2' => array(
                'rule' => array('notEmpty'),
                'message' => 'TIN No. is required.'
            ),
        ),
		
		'last_name' => array(
            'last_name logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'First name is required.'
            ),
			'last_name logic 2' => array(
                'rule'    => array('maxLength', 50),
                'message' => 'Last name must be no longer than 100 characters.'
            )
        ),      
        'status' => array(
            'status logic 1' => array(
                'rule' => array('inList', array('Active', 'Disabled')),
                'message' => 'Please select a status.',
                'allowEmpty' => false
            )
        ),
		
		
    );	
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['TempEmployee']['birth_date']) && validate_datetime($this->data['TempEmployee']['birth_date'], 'm/d/Y')) {
			$this->data['TempEmployee']['birth_date'] = convert_datetime($this->data['TempEmployee']['birth_date'], 'Y-m-d');
		}	
		if(isset($this->data['TempEmployee']['date_hired']) && validate_datetime($this->data['TempEmployee']['date_hired'], 'm/d/Y')) {
			$this->data['TempEmployee']['date_hired'] = convert_datetime($this->data['TempEmployee']['date_hired'], 'Y-m-d');
		}
		if(isset($this->data['TempEmployee']['step_increment_date']) && validate_datetime($this->data['TempEmployee']['step_increment_date'], 'm/d/Y')) {
			$this->data['TempEmployee']['step_increment_date'] = convert_datetime($this->data['TempEmployee']['step_increment_date'], 'Y-m-d');
		}
		
		if(isset($this->data['TempEmployee']['effectivity_date']) && validate_datetime($this->data['TempEmployee']['effectivity_date'], 'm/d/Y')) {
			$this->data['TempEmployee']['effectivity_date'] = convert_datetime($this->data['TempEmployee']['effectivity_date'], 'Y-m-d');
		}
		
		if(isset($this->data['TempEmployee']['since_date']) && validate_datetime($this->data['TempEmployee']['since_date'], 'm/d/Y')) {
			$this->data['TempEmployee']['since_date'] = convert_datetime($this->data['TempEmployee']['since_date'], 'Y-m-d');
		}
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['TempEmployee']['employee_code'])) {
			$this->data['TempEmployee']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TempEmployee']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TempEmployee']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'EMP';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['TempEmployee']['employee_code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			// $this->data['Employee']['status'] = 'Active';
			$this->data['TempEmployee']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TempEmployee']['date_last_modified'] = date("Y-m-d");
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['TempEmployee']['birth_date'])){
				$results[$x]['TempEmployee']['birth_date'] = date('m/d/Y',strtotime($results[$x]['TempEmployee']['birth_date']));
			}
			if(isset($result['TempEmployee']['date_hired'])){
				$results[$x]['TempEmployee']['date_hired'] = date('m/d/Y',strtotime($results[$x]['TempEmployee']['date_hired']));
			}
			if(isset($result['TempEmployee']['step_increment_date'])){
				$results[$x]['TempEmployee']['step_increment_date'] = date('m/d/Y',strtotime($results[$x]['TempEmployee']['step_increment_date']));
			}
			
			if(isset($result['TempEmployee']['effectivity_date'])){
				$results[$x]['TempEmployee']['effectivity_date'] = date('m/d/Y',strtotime($results[$x]['TempEmployee']['effectivity_date']));
			}
			
			if(isset($result['TempEmployee']['since_date'])){
				$results[$x]['TempEmployee']['since_date'] = date('m/d/Y',strtotime($results[$x]['TempEmployee']['since_date']));
			}
		}
		 // debug($results);		
		// exit();
		return $results;
	}
}
?>