<?php
App::uses('AppModel', 'Model');

class TempOtherInformationQuestion extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';

	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
	);
	
	public $validate = array(
		'within_3rd_degree' => array(
			 'within_3rd_degree logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 34 A is required.'
			),
		),
         'within_4th_degree' => array(
			'within_4th_degree logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 34 B is required.'
			),
			 'within_4th_degree logic 2' => array(
				'rule'		=> array('validate_details', array('within_4th_degree', 'within_4th_degree_desc')),
				'message'	=> 'Please give details.'
			),
         ),
		 'found_guilty_administrative_offense' => array(
			'found_guilty_administrative_offense logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 35 A is required.'
			),
			 'found_guilty_administrative_offense logic 2' => array(
				'rule'		=> array('validate_details' , array('found_guilty_administrative_offense', 'found_guilty_administrative_offense_details')),
				'message'	=> 'Please give details.'
			),
         ),
		 'criminally_charged' => array(
			'criminally_charged logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 35 B is required.'
			),
			 'criminally_charged logic 2' => array(
				'rule'		=> array('validate_addtional_details' , array('criminally_charged', 'criminally_charged_status_of_case','criminally_charged_date_filed')),
				'message'	=> 'Please give details.'
			),
         ),
		 'convicted_any_crime' => array(
			'convicted_any_crime logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 36 is required.'
			),
			 'convicted_any_crime logic 2' => array(
				'rule'		=> array('validate_details' , array('convicted_any_crime', 'convicted_any_crime_details')),
				'message'	=> 'Please give details.'
			),
         ),
		  'criminally_charged_date_filed' => array(
			'criminally_charged_date_filed logic 1' => array(
				'rule' => 'date',
				'message' => 'Enter a valid date',
				'allowEmpty' => true
			),
        ),
		 'seperated_from_the_service' => array(
			'seperated_from_the_service logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 37 is required.'
			),
			 'seperated_from_the_service logic 2' => array(
				'rule'		=> array('validate_details' , array('seperated_from_the_service', 'seperated_from_the_service_details')),
				'message'	=> 'Please give details.'
			),
         ),
		 'candidate_national_local_election' => array(
			'candidate_national_local_election logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 38 A is required.'
			),
			 'candidate_national_local_election logic 2' => array(
				'rule'		=> array('validate_details' , array('candidate_national_local_election', 'candidate_national_local_election_details')),
				'message'	=> 'Please give details.'
			),
         ),
		 'resigned_government_service' => array(
			'resigned_government_service logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 38 B is required.'
			),
			 'resigned_government_service logic 2' => array(
				'rule'		=> array('validate_details' , array('resigned_government_service', 'resigned_government_service_details')),
				'message'	=> 'Please give details.'
			),
         ),
		 'status_of_an_immigrant' => array(
			'status_of_an_immigrant logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 39 is required.'
			),
			 'status_of_an_immigrant logic 2' => array(
				'rule'		=> array('validate_details' , array('status_of_an_immigrant', 'status_of_an_immigrant_details')),
				'message'	=> 'Please give details.'
			),
         ),
		 'indigenous_group' => array(
			'indigenous_group logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 40 A is required.'
			),
			 'indigenous_group logic 2' => array(
				'rule'		=> array('validate_details' , array('indigenous_group', 'indigenous_group_details')),
				'message'	=> 'Please give details.'
			),
         ),
		  'person_with_disability' => array(
			'person_with_disability logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 40 B is required.'
			),
			 'person_with_disability logic 1' => array(
				'rule'		=> array('validate_addtional_details' , array('person_with_disability', 'person_with_disability_id_no','person_with_disability_attachment')),
				'message'	=> 'Please give details or attached a file.'
			),
         ),
		 'solo_parent' => array(
			'solo_parent logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Question 40 B is required.'
			),
			 'solo_parent logic 1' => array(
				'rule'		=> array('validate_addtional_details' , array('solo_parent', 'solo_parent_id_no', 'solo_parent_attachment')),
				'message'	=> 'Please give details or attached a file.'
			),
         ),
	);
	
	public function validate_details($validation_fields = array(), $fields_and_details = array()) {
		$details_field=null;
		$field_name = $this->data['TempOtherInformationQuestion'][$fields_and_details[0]];
		
		if(isset($this->data['TempOtherInformationQuestion'][$fields_and_details[1]])){
			$details_field = $this->data['TempOtherInformationQuestion'][$fields_and_details[1]];
		}
		
		
		if($field_name == 'YES'){
			if($details_field== null || $details_field==''){
				return false;
			}
			else{
				return true;
			}
		}
		else{
			$this->data['TempOtherInformationQuestion'][$fields_and_details[1]] = '';
			return true;
		}
	}
	
	public function validate_addtional_details($validation_fields = array(), $fields_and_details = array()) {
		$details_field=null;
		$date_field_data=null;
		$field_name = $this->data['TempOtherInformationQuestion'][$fields_and_details[0]];
		if(isset($this->data['TempOtherInformationQuestion'][$fields_and_details[1]])){
			$details_field = $this->data['TempOtherInformationQuestion'][$fields_and_details[1]];
		}
		if(isset($this->data['TempOtherInformationQuestion'][$fields_and_details[2]])){
			$date_field_data = $this->data['TempOtherInformationQuestion'][$fields_and_details[2]];
		}
		
		if($field_name == 'YES'){
			if($details_field== null || $details_field==''){
				if($date_field_data == null || $date_field_data == ''){
					return false;
				}
				else{
					return false;
				}
			}
			else{
				if($date_field_data == null || $date_field_data == ''){
					return false;
				}
				else{
					return true;
				}
			}
		}
		else{
			 $this->data['TempOtherInformationQuestion'][$fields_and_details[1]] = '';
			 $this->data['TempOtherInformationQuestion'][$fields_and_details[2]] = '';
			return true;
		}
	}
	
		public function validate_solo_parent_attachment($validation_fields = array()) {
		$answer_solo_parent = $this->data['TempOtherInformationQuestion']['solo_parent'];
		
		
		if($answer_solo_parent == 'YES'){
				
			if(isset($this->data['TempOtherInformationQuestion']['solo_parent_attachment']['error']) && $this->data['TempOtherInformationQuestion']['solo_parent_attachment']['error'] > 0 ){
				return false;
			}
			else{
				return true;
			}
		}
		return true;
	}
	
	public function validate_person_with_disability_attachment($validation_fields = array()) {
		$answer_person_with_disability = $this->data['TempOtherInformationQuestion']['person_with_disability'];
		
		
		if($answer_person_with_disability == 'YES'){
				
			if(isset($this->data['TempOtherInformationQuestion']['person_with_disability_attachment']['error']) && $this->data['TempOtherInformationQuestion']['person_with_disability_attachment']['error'] > 0 ){
				return false;
			}
			else{
				return true;
			}
		}
		return true;
	}
	
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['TempOtherInformationQuestion']['criminally_charged_date_filed']) && validate_datetime($this->data['TempOtherInformationQuestion']['criminally_charged_date_filed'], 'm/d/Y')) {
			$this->data['TempOtherInformationQuestion']['criminally_charged_date_filed'] = convert_datetime($this->data['TempOtherInformationQuestion']['criminally_charged_date_filed'], 'Y-m-d');
		}	
		return true;
	}	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['TempOtherInformationQuestion']['id'])) {
			$this->data['TempOtherInformationQuestion']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TempOtherInformationQuestion']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TempOtherInformationQuestion']['status'] = 'Active';
		}
		else {
			$this->data['TempOtherInformationQuestion']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['TempOtherInformationQuestion']['criminally_charged_date_filed'])){
				$results[$x]['TempOtherInformationQuestion']['criminally_charged_date_filed'] = date('m/d/Y',strtotime($results[$x]['TempOtherInformationQuestion']['criminally_charged_date_filed']));
			}
		}

		return $results;
	}
}
?>