<?php
App::uses('AppModel', 'Model');

class TimeEntry extends AppModel {
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	public $primaryKey = 'id';

	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
		),
		'Shift' => array(
			'className' => 'Shift',
			'foreignKey' => 'shift_code',
		),
		'EmployeeSchedule' => array(
			'className' => 'EmployeeSchedule',
			'foreignKey' => 'schedule_code',
		),
		'Holiday' => array(
			'className' => 'Holiday',
			'foreignKey' => 'holiday_code',
		),
	);
	
	public $validate = array(
	   // 'employee_code' => array(
			// 'required' => array(
				// 'rule' => array('notEmpty'),
				// 'message' => 'Employee doesn`t exists!'
			// )
		// ),
	);
	
	public function beforeSave($options = array()) {
		$is_disputed =false;
		$has_schedule =false;
		$has_break=false;
		$total_hours_rendered =0;
		$total_hours_late =0;
		$total_hours_overtime =0;
		$total_posible_overtime_hours=0;
		$total_hours_undertime = 0;
		$total_hours_night_diff =0;
		$total_hours_holiday =0;
		$holiday_code =null;
		$holiday_date =null;
		$employee_total_hours_break =0;
		$max_allowable_break_hours = 3600; //1hr allowable break
		$total_shift_hours = 28800; // default 8hrs
		$shift_date_time_in =null;
		$grace_period =null;
		$shift_date_time_out =null;
		$schedule_type = '';
		$night_diff_start = (count($this->get_night_differential_hours())>=1 ? $this->get_night_differential_hours()['NightDifferential']['time_from'] : 0); 
		$night_diff_end = (count($this->get_night_differential_hours())>=1 ? $this->get_night_differential_hours()['NightDifferential']['time_to'] : 0); 
		
		$this->data['TimeEntry']['has_break'] = (isset($this->data['TimeEntry']['has_break']) ? $this->data['TimeEntry']['has_break'] : false);
		
		// debug($this->get_night_differential_hours());
		// exit();
		$total_payable_regular_hours_rendered = 0;
		$this->data['TimeEntry'] = AppModel::fix_date_format(
			$this->data['TimeEntry'],
			array('time_in','break_out','break_in','time_out')
		);
		if (!isset($this->data['TimeEntry']['id']) || empty($this->data['TimeEntry']['id'])) unset($this->data['TimeEntry']['id']);
		if(isset($this->data['TimeEntry']['time_entry_status']) && trim($this->data['TimeEntry']['time_entry_status'])=='R'){
			$is_disputed=true;
			$this->data['TimeEntry']['resolved']=1;
			$this->data['TimeEntry']['undertime'] = 0;
		}
		
		// debug($this->data['TimeEntry']['undertime']);
		// debug($total_hours_undertime);
		// exit();
		// debug($this->data);
		// exit();
		//check if has schedule and calculate shift
		if(isset($this->data['TimeEntry']['schedule_code']) && !empty($this->data['TimeEntry']['schedule_code'])){
			$has_schedule=true;
			$schedule_type = $this->data['TimeEntry']['schedule_type'];
			$shift_date_time_in = $this->data['TimeEntry']['shift_date_time_in'];
			$shift_date_time_out = $this->data['TimeEntry']['shift_date_time_out'];
			$total_shift_hours = (isset($this->data['TimeEntry']['total_hours_of_shift']) ? (intval($this->data['TimeEntry']['total_hours_of_shift']) *3600) : 28800);
			
			// debug($total_shift_hours);
			// exit();
			
			//overide flexible for time dispute
			if($schedule_type==='flexible' && isset($this->data['TimeEntry']['dispute']) && $this->data['TimeEntry']['dispute']==='Yes'){
				$total_shift_hours = 8;
				$shift_date_time_in = $this->data['TimeEntry']['time_in'];
				$shift_date_time_out = date('Y-m-d H:i:s',strtotime($shift_date_time_in . '+'.$total_shift_hours.' hours'));
				$this->data['TimeEntry']['shift_date_time_in'] =$shift_date_time_in;
				$this->data['TimeEntry']['shift_date_time_out'] =$shift_date_time_out;
			}
			
			// debug($shift_date_time_in);
			// debug($shift_date_time_out);
			// exit();
			
			//check if has break time and calculate break and undertime break
			if (isset($this->data['TimeEntry']['has_break']) && $this->data['TimeEntry']['has_break']===true && $schedule_type!=='shifting'){
				
				$shift_break_out = convert_time_to_seconds($this->data['TimeEntry']['shift_break_out']);
				$shift_break_in = convert_time_to_seconds($this->data['TimeEntry']['shift_break_in']);
				$break_out = convert_time_to_seconds(date('H:i:s',strtotime($this->data['TimeEntry']['break_out'])));
				
				$break_in = convert_time_to_seconds(date('H:i:s',strtotime($this->data['TimeEntry']['break_in'])));
				$has_break=true;
				
				//overiden
				if($schedule_type==='semi_flexible'){
					if($break_out >= $shift_break_out && $break_out <= $shift_break_in){
						$shift_break_out = $break_out;
					}else{
						$shift_break_out = $shift_break_out;
					}
					
					if(($break_out + 3600) >= $shift_break_out && ($break_out + 3600) <= $shift_break_in){
						$shift_break_in = ($break_out + 3600);
					}else{
						$shift_break_in = $shift_break_in;
					}
					
					$this->data['TimeEntry']['shift_date_time_break_out'] = date('Y-m-d',strtotime($this->data['TimeEntry']['shift_date_time_break_out'])) . ' '. convert_seconds_to_time($shift_break_out);
					
					$this->data['TimeEntry']['shift_date_time_break_in'] = date('Y-m-d',strtotime($this->data['TimeEntry']['shift_date_time_break_in'])) . ' '. convert_seconds_to_time($shift_break_in);
					
					$this->data['TimeEntry']['shift_break_out'] = convert_seconds_to_time($shift_break_out);
					$this->data['TimeEntry']['shift_break_in'] = convert_seconds_to_time($shift_break_in);
				}
				
				
				if(!empty($this->data['TimeEntry']['break_in']) && !empty($this->data['TimeEntry']['break_out'])) {
					
					$shift_break_out = ($break_out<=$shift_break_out) ? $shift_break_out : $break_out;
					$remaining_break_hours = abs($shift_break_out - $shift_break_in);
			
					if($remaining_break_hours>=$max_allowable_break_hours){
						$shift_break_in = $shift_break_out + $max_allowable_break_hours;
					}

					if($break_out <= $shift_break_out){
						$total_hours_undertime = abs($shift_break_out - $break_out);					
					}

					if($break_in > $shift_break_in){
						$total_hours_late = abs($break_in - $shift_break_in);
					}
					
					$employee_total_hours_break =($break_in - $break_out);
					
					
				}elseif(!empty($this->data['TimeEntry']['break_out']) && empty($this->data['TimeEntry']['break_in'])){
					if ($break_out>=$shift_break_out && $break_out<=$shift_break_in){
						
					}elseif($break_out<$shift_break_out){
						$total_hours_undertime = abs($shift_break_out - $break_out);
						
					}elseif($break_out>$shift_break_in){
						$total_hours_late = abs($break_out - $shift_break_in);
					}
				}elseif(empty($this->data['TimeEntry']['break_out']) && !empty($this->data['TimeEntry']['break_in'])){
					if($break_in>$shift_break_in){
						$total_hours_late = abs($break_in - $shift_break_in);
					}
				}
				
				//if has break automatically deduct the break hrs to total shift hours
				// $total_shift_hours -= $max_allowable_break_hours;
			}else{
				$has_break=false;
			}
		}else{
			//no schedule
			if (isset($this->data['TimeEntry']['time_in'])){
				$shift_date_time_out = strtotime($this->data['TimeEntry']['time_in']);
				$shift_date_time_out += $total_shift_hours;
				$shift_date_time_out =date('Y-m-d H:i:s',$shift_date_time_out);
			}
		}
		
		if(!empty($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['time_out'])){
			//has time in and time out
			$total_hours_rendered = $this->get_time_hours_rendered($has_schedule,$has_break,$max_allowable_break_hours,$shift_date_time_in,$this->data['TimeEntry']['time_in'],$this->data['TimeEntry']['time_out']);
			$total_hours_late += $this->get_time_late($shift_date_time_in,$this->data['TimeEntry']['time_in'],$grace_period);
			$total_hours_overtime = $this->get_time_overtime($shift_date_time_out,$this->data['TimeEntry']['time_out']);
			// debug($total_hours_late);
			//posible overtime 
			$min_overtime_threshold_start = 1800; //equivalent to 30mins threshold after shift to start overtime
			$min_overtime_threshold_hrs = 3600; //equivalent to 1hr min allowable hours of overtime
			$max_allowable_hrs_for_working_days = 7200; //default equivalent to 2hrs for weekdays
			$max_allowable_hrs_for_non_working_days = 28800; //default equivalent to 8hrs for weekends and holidays

			//condition to check if overtime is within the allowable time
			if($has_schedule==false && $total_hours_rendered>=($min_overtime_threshold_start + $min_overtime_threshold_hrs)){
				
				//condition to check days to get max allowable hrs of overtime
				$is_holiday = (boolean) $this->get_holiday_code($this->data['TimeEntry']['time_in']);
				if($is_holiday){ //check if holiday
					$max_allowable_overtime_hrs = $max_allowable_hrs_for_non_working_days;
				}elseif(date("N",strtotime($this->data['TimeEntry']['time_in'])) ==6 || date("N",strtotime($this->data['TimeEntry']['time_in']))==7){ //check if weekends 
					$max_allowable_overtime_hrs = $max_allowable_hrs_for_non_working_days;
				}else{	// weekdays
					$max_allowable_overtime_hrs = $max_allowable_hrs_for_working_days;
				}
				
				if(($total_hours_rendered - $min_overtime_threshold_start)>=$max_allowable_overtime_hrs){
					$total_posible_overtime_hours=$max_allowable_overtime_hrs;
				}else{
					$total_posible_overtime_hours = ($total_hours_rendered - $min_overtime_threshold_start);
				}
				
			}
			
			// debug($total_hours_rendered);
			// debug($total_hours_overtime);
			// debug($total_hours_late);
			// debug($total_hours_undertime);
			// debug($max_allowable_break_hours);
			// exit();
			
		
			
			$total_payable_regular_hours_rendered = $this->get_payable_regular_hours_rendered($total_hours_rendered,$total_hours_overtime,$total_hours_late,$total_hours_undertime,$max_allowable_break_hours);
			
			$total_hours_undertime += $this->get_time_undertime($shift_date_time_out,$this->data['TimeEntry']['time_out']);
			
			$total_hours_night_diff = $this->get_night_differential_and_holiday($night_diff_start,$night_diff_end,$this->data['TimeEntry']['time_in'],$this->data['TimeEntry']['time_out']);
			
			//get holiday code,time,date
			$holiday_data = $this->get_holiday_code($this->data['TimeEntry']['time_in'],$this->data['TimeEntry']['time_out']);
			if (count($holiday_data)>=1){
				$holiday_code = ((count($holiday_data)>=1) ? $holiday_data['Holiday']['code'] : null);
				$total_hours_holiday = $this->get_night_differential_and_holiday('00:00:00','24:00:00',$this->data['TimeEntry']['time_in'],$this->data['TimeEntry']['time_out']);
			}
			
		}elseif(!empty($this->data['TimeEntry']['time_in']) && empty($this->data['TimeEntry']['time_out'])){
			//has time in and no time out
			$total_hours_late += $this->get_time_late($shift_date_time_in,$this->data['TimeEntry']['time_in'],$grace_period);
			
			$holiday_data = $this->get_holiday_code($this->data['TimeEntry']['time_in']);
			if (count($holiday_data)>=1){
				$holiday_code = ((count($holiday_data)>=1) ? $holiday_data['Holiday']['code'] : null);
			}
		}
		
		elseif(empty($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['time_out'])){	
			//no time in and has time out
			$total_hours_undertime += $this->get_time_undertime($shift_date_time_out,$this->data['TimeEntry']['time_out']);
			// debug($shift_date_time_out);
			// debug($total_hours_undertime);
			// exit();
			$holiday_data = $this->get_holiday_code($this->data['TimeEntry']['time_out']);
			if (count($holiday_data)>=1){
				$holiday_code = ((count($holiday_data)>=1) ? $holiday_data['Holiday']['code'] : null);
			}
		}
		
		if(!isset($this->data['TimeEntry']['id'])) {
			if(isset($_SESSION['Auth']['User']['id'])){
				$this->data['TimeEntry']['created_by'] = $_SESSION['Auth']['User']['id'];
				$this->data['TimeEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
			}
			$this->data['TimeEntry']['status'] = 'Active';
			
			if($is_disputed==true){
				$this->data['TimeEntry']['resolved_by']=$_SESSION['Auth']['User']['id'];
			}
			
		}else {
			if(isset($_SESSION['Auth']['User']['id'])){
				$this->data['TimeEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
				
				if($is_disputed==true){
					$this->data['TimeEntry']['resolved_by']=$_SESSION['Auth']['User']['id'];
				}

				
			}
		}
		
		//WVMC SPECIAL COMPUTATION FOR WVMC
		$overwrite_status =false;
		$total_shift_divided = $total_shift_hours / 2;
		// debug($total_shift_hours);
		
		if($schedule_type==='fixed' || $schedule_type==='semi_flexible'){
			
			if(empty($this->data['TimeEntry']['time_in']) || (empty($this->data['TimeEntry']['break_out']) && (isset($this->data['TimeEntry']['has_break']) &&  $this->data['TimeEntry']['has_break']===true))){
				$total_hours_late += $total_shift_divided; //4hrs
				$overwrite_status=true;
			}
			
			if((empty($this->data['TimeEntry']['break_in']) && (isset($this->data['TimeEntry']['has_break']) &&  $this->data['TimeEntry']['has_break']===true) ) || empty($this->data['TimeEntry']['time_out'])){
				$old_total_hours_undertime_holder = $total_hours_undertime;
				$total_hours_undertime = $total_shift_divided + $old_total_hours_undertime_holder; //4hrs
				if(($total_hours_late + $total_hours_undertime)>$total_shift_hours){
					$total_hours_undertime = (($total_shift_hours - $total_hours_late)>=0 ? ($total_shift_hours - $total_hours_late) : 0);
				}
				
				$overwrite_status=true;
			}
			
			// dito ka bumalik
			if(empty($this->data['TimeEntry']['time_in']) && empty($this->data['TimeEntry']['break_out']) && !empty($this->data['TimeEntry']['break_in']) && !empty($this->data['TimeEntry']['time_out']))
			{
				
				$time_difference = get_datetime_diff($this->data['TimeEntry']['break_in'],$this->data['TimeEntry']['time_out']);
				$convert_to_time = convert_time_to_seconds($time_difference);
				if ($convert_to_time >= 14400)
				{
					$total_hours_undertime = 0;
				}
				else 
				{
					$total_hours_undertime = $total_shift_divided - $convert_to_time;
				}
					
			}
			
			
		}
		else if($schedule_type==='shifting') {

			if(!empty($this->data['TimeEntry']['time_in']) && empty($this->data['TimeEntry']['time_out'])) {
			
				$total_hours_undertime = $total_shift_hours; //8hrs
				$overwrite_status=true;

			}
			elseif(empty($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['time_out'])) {
			
				$total_hours_late = $total_shift_divided; //4hrs
				$overwrite_status=true;

			}
			
			if((empty($this->data['TimeEntry']['break_out']) && (isset($this->data['TimeEntry']['has_break']) && $this->data['TimeEntry']['has_break']===true))) {
				$total_hours_late = $total_shift_divided - 1800; //4hrs
				$overwrite_status=true;
			}
			
			if ((empty($this->data['TimeEntry']['break_in']) && (isset($this->data['TimeEntry']['has_break']) && $this->data['TimeEntry']['has_break']===true))) {
				$old_total_hours_undertime_holder = $total_hours_undertime - 1800;
				$total_hours_undertime = $total_shift_divided + $old_total_hours_undertime_holder; //4hrs
				
				if(($total_hours_late + $total_hours_undertime)>$total_shift_hours){
					$total_hours_undertime = (($total_shift_hours - $total_hours_late)>=0 ? ($total_shift_hours - $total_hours_late) : 0);
				}

				$overwrite_status = true;
			}

		}
		
		//ranz= this will overide undertime to halfday if time entry is not complete
		if($schedule_type!=='flexible'){
			$total_entry_missing =0;
			$total_entry_missing += (empty($this->data['TimeEntry']['time_in']) ? 1 : 0);
			$total_entry_missing += (empty($this->data['TimeEntry']['break_out']) ? 1 : 0);
			$total_entry_missing += (empty($this->data['TimeEntry']['break_in']) ? 1 : 0);
			$total_entry_missing += (empty($this->data['TimeEntry']['time_out']) ? 1 : 0);

			if($total_entry_missing==3){
				$total_hours_late=0;
				$total_hours_undertime = (($total_shift_hours));
				$overwrite_status=true;	
			}elseif(isset($this->data['TimeEntry']['has_break']) && $this->data['TimeEntry']['has_break']===true && (empty($this->data['TimeEntry']['time_in']) || empty($this->data['TimeEntry']['break_out']) || empty($this->data['TimeEntry']['break_in']) || empty($this->data['TimeEntry']['time_out'])) ){
				$total_hours_late=0;
				$total_hours_undertime = $total_shift_divided; //halfday
				$overwrite_status=true;
			}elseif((!isset($this->data['TimeEntry']['has_break']) || $this->data['TimeEntry']['has_break']===false) && (empty($this->data['TimeEntry']['time_in']) || empty($this->data['TimeEntry']['time_out']))){
				$total_hours_late=0;
				$total_hours_undertime = $total_shift_divided; //halfday
				$overwrite_status=true;
			}else{
				if($schedule_type==='semi_flexible'){
					$total_hours_undertime =0;
					$total_hours_late =0;
				}
			}
			
			// debug($total_hours_undertime);
			// exit();

			// if($schedule_type==='fixed'){
				// $shift_date_time_in = $this->data['TimeEntry']['shift_date_time_in'];
				// $shift_date_time_out = $this->data['TimeEntry']['shift_date_time_out'];
				
				// if(isset($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['break_out'])){
					// $shift_date_time_in_sec = convert_time_to_seconds(date('H:i:s',strtotime($this->data['TimeEntry']['shift_date_time_in'])));
					// $time_in_sec = convert_time_to_seconds(date('H:i:s',strtotime($this->data['TimeEntry']['time_in'])));
					// if($time_in_sec > $shift_date_time_in_sec){
						// $total_hours_late = abs($time_in_sec - $shift_date_time_in_sec);
						
					// }
				// }
				
				// if(isset($this->data['TimeEntry']['time_out']) && !empty($this->data['TimeEntry']['time_out'])){
					// $shift_date_time_out_sec = convert_time_to_seconds(date('H:i:s',strtotime($this->data['TimeEntry']['shift_date_time_out'])));
					// $time_out_sec = convert_time_to_seconds(date('H:i:s',strtotime($this->data['TimeEntry']['time_out'])));
					// if($time_out_sec < $shift_date_time_out_sec){
						// $total_hours_undertime += abs($time_out_sec - $shift_date_time_out_sec);
					// }
				// }
			// }
			
			
			// exit();
			
			//del edit start get shift
			if($schedule_type==='semi_flexible'){
				$EmployeeSchedule = ClassRegistry::init('EmployeeSchedule');			
				$schedule_code = $this->data['TimeEntry']['schedule_code'];
				$schedule = $EmployeeSchedule->find('first',array(
					'conditions'=>array(
						'EmployeeSchedule.code'=>$schedule_code
					),
					'contain'=>array(
						'Shift'
					)
				));
				// debug($schedule);
				$total_am_undertime_fixed=0;
				$total_am_undertime_can_offset=0;
				$total_hours_undertime_am=0;
				$total_hours_undertime_pm=0;
				$total_am_late=0;
				$total_am_over=0;
				// if am has break and with time in and break_out
				if($this->data['TimeEntry']['has_break']===true && !empty($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['break_out']) )
				{
					
					if($schedule){
						$orginal_schedule_date=date('Y-m-d', strtotime($schedule['EmployeeSchedule']['schedule_date']));
						$orginal_schedule_date_plus_one_day=date('Y-m-d', strtotime("+1 day", strtotime($schedule['EmployeeSchedule']['schedule_date'])));
						$orginal_shift_date_time_in=$schedule['Shift']['time_in'];
						$orginal_shift_date_break_out=$schedule['Shift']['break_out'];
						$orginal_shift_date_break_in=$schedule['Shift']['break_in'];
						$orginal_shift_date_time_out=$schedule['Shift']['time_out'];
						
						if($orginal_shift_date_time_in>$orginal_shift_date_break_out){
							$orginal_shift_date_break_out = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_break_out;
						}
						else{
							$orginal_shift_date_break_out = $orginal_schedule_date.' '.$orginal_shift_date_break_out;
						}
						if($orginal_shift_date_time_in>$orginal_shift_date_break_in){
							$orginal_shift_date_break_in = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_break_in;
						}
						else{
							$orginal_shift_date_break_in = $orginal_schedule_date.' '.$orginal_shift_date_break_in;
						}
						if($orginal_shift_date_time_in>$orginal_shift_date_time_out){
							$orginal_shift_date_time_out = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_time_out;
						}
						else{
							$orginal_shift_date_time_out = $orginal_schedule_date.' '.$orginal_shift_date_time_out;
						}
						$orginal_shift_date_time_in = $orginal_schedule_date.' '.$orginal_shift_date_time_in;
						$break_time = 3600;
						
					
						//get grace period
						$grace_period=abs(strtotime($orginal_shift_date_time_out)-strtotime($orginal_shift_date_time_in)-$break_time-$total_shift_hours);
						$orginal_shift_date_time_in_grace_period=strtotime($orginal_shift_date_time_in)+$grace_period;
						// max grace period for time in
						$orginal_shift_date_time_in_max = (date('Y-m-d H:i:s',($orginal_shift_date_time_in_grace_period)));
						// if in is less than shift time in get the shift time in
						if($this->data['TimeEntry']['time_in']<$orginal_shift_date_time_in){
							$paid_date_time_in = $orginal_shift_date_time_in;
						}else{
							$paid_date_time_in = $this->data['TimeEntry']['time_in'];
						}
						//get late
						$total_am_late = $this->get_time_late($orginal_shift_date_time_in,$this->data['TimeEntry']['time_in'],$orginal_shift_date_time_in_max);
						// get under time if early break
						$total_am_undertime_fixed = $this->get_time_undertime($orginal_shift_date_break_out,$this->data['TimeEntry']['break_out']);
						
						//get hours rendered
						$total_am_rendered = $this->get_total_break_hours($this->data['TimeEntry']['break_out'], $paid_date_time_in);
						
						//if pm has undertime you can offset in am
						$total_am_over = max($total_am_rendered - $total_shift_divided,0);
						
						// get under time if hours rendered is lessthan shift half day hours
						$total_am_undertime_can_offset = max($total_shift_divided - $total_am_rendered -$total_am_undertime_fixed -$total_am_late,0);
						
						$total_hours_undertime_am =$total_am_undertime_fixed+$total_am_undertime_can_offset;
						
						// debug("paid_date_time_in = " .($paid_date_time_in));
						// debug("total_am_rendered = " .convert_seconds_to_time($total_am_rendered));
						// debug("total_am_over = " .convert_seconds_to_time($total_am_over));
						// debug("total_hours_undertime_am = " .convert_seconds_to_time($total_hours_undertime_am));
						// debug("total_am_late = " .convert_seconds_to_time($total_am_late));
						// debug("total_am_undertime_fixed = " .convert_seconds_to_time($total_am_undertime_fixed));
						// debug("total_am_undertime_can_offset = " .convert_seconds_to_time($total_am_undertime_can_offset));
						// debug(($this->data));
					}
				}else{
					
					$total_hours_undertime_am = $total_shift_divided;
				}
				// if pm has break and with break in and time out
				if($this->data['TimeEntry']['has_break']===true && !empty($this->data['TimeEntry']['break_in']) && !empty($this->data['TimeEntry']['time_out']) )
				{
					
					if($schedule){
						$orginal_schedule_date=date('Y-m-d', strtotime($schedule['EmployeeSchedule']['schedule_date']));
						$orginal_schedule_date_plus_one_day=date('Y-m-d', strtotime("+1 day", strtotime($schedule['EmployeeSchedule']['schedule_date'])));
						$orginal_shift_date_time_in=$schedule['Shift']['time_in'];
						$orginal_shift_date_break_out=$schedule['Shift']['break_out'];
						$orginal_shift_date_break_in=$schedule['Shift']['break_in'];
						$orginal_shift_date_time_out=$schedule['Shift']['time_out'];
						if($orginal_shift_date_time_in>$orginal_shift_date_break_out){
							$orginal_shift_date_break_out = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_break_out;
						}
						else{
							$orginal_shift_date_break_out = $orginal_schedule_date.' '.$orginal_shift_date_break_out;
						}
						if($orginal_shift_date_time_in>$orginal_shift_date_break_in){
							$orginal_shift_date_break_in = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_break_in;
						}
						else{
							$orginal_shift_date_break_in = $orginal_schedule_date.' '.$orginal_shift_date_break_in;
						}
						if($orginal_shift_date_time_in>$orginal_shift_date_time_out){
							$orginal_shift_date_time_out = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_time_out;
						}
						else{
							$orginal_shift_date_time_out = $orginal_schedule_date.' '.$orginal_shift_date_time_out;
						}
						$orginal_shift_date_time_in = $orginal_schedule_date.' '.$orginal_shift_date_time_in;
						$break_time = 3600;
						
					
						
						//get grace period
						$grace_period=abs(strtotime($orginal_shift_date_time_out)-strtotime($orginal_shift_date_time_in)-$break_time-$total_shift_hours);
						// minimum time out if you time out lessthan the minumum consider undertime
						$orginal_shift_date_time_out_minimum =strtotime($orginal_shift_date_time_out)-$grace_period;
						$orginal_shift_date_time_out_minimum = (date('Y-m-d H:i:s',($orginal_shift_date_time_out_minimum)));
						// if time out is less than shift time out get the shift time out. if you time out more than the shift time its not payable
						if($this->data['TimeEntry']['time_out']>$orginal_shift_date_time_out){
							$paid_date_time_out = $orginal_shift_date_time_out;
						}else{
							$paid_date_time_out = $this->data['TimeEntry']['time_out'];
						}
						
						//get late if late break in
						$total_pm_late = $this->get_time_undertime($this->data['TimeEntry']['break_in'],$orginal_shift_date_break_in);
						//get early out 
						$total_pm_undertime_fixed = $this->get_time_undertime($orginal_shift_date_time_out_minimum,$this->data['TimeEntry']['time_out']);
						//get hours 
						$total_pm_rendered = $this->get_total_break_hours($this->data['TimeEntry']['break_in'], $paid_date_time_out);					
						// if over break
						if(!empty($this->data['TimeEntry']['break_in']) && !empty($this->data['TimeEntry']['break_out'])){

							$total_pm_break= $this->get_total_break_hours($this->data['TimeEntry']['break_in'], $this->data['TimeEntry']['break_out']);					
							$total_pm_break_over = max(($total_pm_break )-($break_time+$total_pm_late+$total_am_undertime_fixed),0);												
						}else{
							$total_pm_break_over=0;
						}
						// get under time if hours rendered is lessthan shift half day hours
						$total_pm_undertime = max($total_shift_divided - $total_pm_rendered - $total_pm_late - $total_pm_undertime_fixed,0);
						//if am has undertime you can offset in pm
						$total_pm_over = max($total_pm_rendered - $total_shift_divided,0);
						$total_pm_over = max($total_pm_rendered - $total_shift_divided,0);
						
						$total_hours_undertime_pm =max($total_am_undertime_can_offset+$total_pm_undertime -($total_pm_over + $total_am_over +($total_pm_break_over)),0) + $total_am_undertime_fixed + $total_pm_undertime_fixed;	
						// 60 + 0 -(15 + 0 + 5) + 5 + 0
						
						$total_hours_undertime+=$total_hours_undertime_pm;
						$total_hours_late = $total_pm_late+$total_am_late+$total_pm_break_over;
						// debug("total_pm_undertime = " .convert_seconds_to_time($total_pm_undertime));
						// debug("total_pm_break_over = " .convert_seconds_to_time($total_pm_break_over));
						// debug("total_pm_late  = " .convert_seconds_to_time($total_pm_late ));
						// debug("paid_date_time_out = " .($paid_date_time_out));
						// debug("total_am_over = " .convert_seconds_to_time($total_am_over));
						// debug("total_pm_rendered = " .convert_seconds_to_time($total_pm_rendered));
						// debug("total_pm_over = " .convert_seconds_to_time($total_pm_over));
						// debug("total_hours_undertime_pm = " .convert_seconds_to_time($total_hours_undertime_pm));
						// debug("total_pm_late = " .convert_seconds_to_time($total_pm_late));
						// debug("total_pm_undertime = " .convert_seconds_to_time($total_pm_undertime));
						// debug("total_pm_undertime_fixed = " .convert_seconds_to_time($total_pm_undertime_fixed));
						// debug("total_am_undertime_can_offset = " .convert_seconds_to_time($total_am_undertime_can_offset));
						
						// debug(($this->data));
					}
				}else{
					$total_hours_undertime+=$total_hours_undertime_am;
					$total_hours_late = $total_am_late;
				}
			}
			// del edit for fixed schedule
			elseif($schedule_type==='fixed'){
				$EmployeeSchedule = ClassRegistry::init('EmployeeSchedule');			
				$schedule_code = $this->data['TimeEntry']['schedule_code'];
				$schedule = $EmployeeSchedule->find('first',array(
					'conditions'=>array(
						'EmployeeSchedule.code'=>$schedule_code
					),
					'contain'=>array(
						'Shift'
					)
				));
				$orginal_schedule_date=date('Y-m-d', strtotime($schedule['EmployeeSchedule']['schedule_date']));
				$orginal_schedule_date_plus_one_day=date('Y-m-d', strtotime("+1 day", strtotime($schedule['EmployeeSchedule']['schedule_date'])));
				$orginal_shift_date_time_in=$schedule['Shift']['time_in'];
				$orginal_shift_date_break_out=$schedule['Shift']['break_out'];
				$orginal_shift_date_break_in=$schedule['Shift']['break_in'];
				$orginal_shift_date_time_out=$schedule['Shift']['time_out'];
				
				if($orginal_shift_date_time_in>$orginal_shift_date_break_out){
					$orginal_shift_date_break_out = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_break_out;
				}
				else{
					$orginal_shift_date_break_out = $orginal_schedule_date.' '.$orginal_shift_date_break_out;
				}
				if($orginal_shift_date_time_in>$orginal_shift_date_break_in){
					$orginal_shift_date_break_in = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_break_in;
				}
				else{
					$orginal_shift_date_break_in = $orginal_schedule_date.' '.$orginal_shift_date_break_in;
				}
				if($orginal_shift_date_time_in>$orginal_shift_date_time_out){
					$orginal_shift_date_time_out = $orginal_schedule_date_plus_one_day.' '.$orginal_shift_date_time_out;
				}
				else{
					$orginal_shift_date_time_out = $orginal_schedule_date.' '.$orginal_shift_date_time_out;
				}
				$orginal_shift_date_time_in = $orginal_schedule_date.' '.$orginal_shift_date_time_in;
				
				
				
				$total_pm_rendered = 0;
				$total_am_rendered = 0;
				$undertime_render = 0;
				$total_break_late = 0;
				$total_am_undertime_can_offset = 0;
				$total_pm_undertime_can_offset = 0;
				$total_pm_undertime_can_offset = 0;
				$total_pm_over = 0;
				$total_am_over = 0;
				$break_time = 3600;	
				// $hours_to_be_render=$total_shift_hours;
				$hours_to_be_render=0;
				if($this->data['TimeEntry']['has_break']===true){
					if(!empty($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['break_out']) )
					{
						// exit();
						$total_am_late = $this->get_time_late($orginal_shift_date_time_in,$this->data['TimeEntry']['time_in'],$orginal_shift_date_time_in);
						$total_am_undertime = $this->get_time_undertime($orginal_shift_date_break_out,$this->data['TimeEntry']['break_out']);
						if($this->data['TimeEntry']['time_in']<$orginal_shift_date_time_in){
							$paid_date_time_in = $orginal_shift_date_time_in;
						}else{
							$paid_date_time_in = $this->data['TimeEntry']['time_in'];
						}
						$total_am_rendered = $this->get_total_break_hours($this->data['TimeEntry']['break_out'], $paid_date_time_in);
						//if pm has undertime you can offset in am
						$total_am_over = max($total_am_rendered - $total_shift_divided,0);
						$total_am_undertime_can_offset = max($total_shift_divided - $total_am_rendered -$total_am_undertime -$total_am_late,0);
						$hours_to_be_render+=$total_shift_divided;
						// debug('paid_date_time_in = '. $paid_date_time_in);
						// debug('total_am_undertime_can_offset = '. convert_seconds_to_time($total_am_undertime_can_offset));
						// debug('total_am_undertime = '. convert_seconds_to_time($total_am_undertime));
						// debug('total_am_late = '. convert_seconds_to_time($total_am_late));
						// debug('total_am_rendered = '. convert_seconds_to_time($total_am_rendered));
					}
					else{
						$total_am_undertime =$total_shift_divided;
						$total_am_late = 0;
						$is_half_day=true;
					}
					if(!empty($this->data['TimeEntry']['break_in']) && !empty($this->data['TimeEntry']['time_out']) ){
						// $total_pm_late = $this->get_time_late($orginal_shift_date_break_in,$this->data['TimeEntry']['break_in'],$orginal_shift_date_break_in);
						// $total_pm_undertime = $this->get_time_undertime($orginal_shift_date_time_out,$this->data['TimeEntry']['time_out']);
						
						$flexi_break_in = abs(convert_time_to_seconds(date('H:i:s',strtotime($orginal_shift_date_break_out))) - convert_time_to_seconds(date('H:i:s',strtotime($orginal_shift_date_break_in))));
						$flexi_break_in = convert_seconds_to_time(convert_time_to_seconds(date('H:i:s',strtotime($orginal_shift_date_break_in))) - (($flexi_break_in - $max_allowable_break_hours) / 2));

						if($this->data['TimeEntry']['break_in']>$orginal_shift_date_break_in){
							if(empty($this->data['TimeEntry']['break_out'])){
								$paid_date_break_in = date('Y-m-d',strtotime($orginal_shift_date_break_in)).' '.$flexi_break_in;
							}else{
								$paid_date_break_in = $orginal_shift_date_break_in;
							}
							
						}else{
							if(empty($this->data['TimeEntry']['break_out'])){	
								$paid_date_break_in = date('Y-m-d',strtotime($orginal_shift_date_break_in)).' '.$flexi_break_in;
							}else{
								$paid_date_break_in = $this->data['TimeEntry']['break_in'];
							}
						}
						// debug($paid_date_break_in);
						// exit();
						//ranz change
						$total_pm_late = $this->get_time_late($paid_date_break_in,$this->data['TimeEntry']['break_in'],$paid_date_break_in);
						$total_pm_undertime = $this->get_time_undertime($orginal_shift_date_time_out,$this->data['TimeEntry']['time_out']);	
						//end change
						
						if($this->data['TimeEntry']['time_out']>$orginal_shift_date_time_out){
							$paid_date_time_out = $orginal_shift_date_time_out;
						}else{
							$paid_date_time_out = $this->data['TimeEntry']['time_out'];
						}					
						$total_pm_rendered = $this->get_total_break_hours($paid_date_time_out, $paid_date_break_in);
						$total_pm_undertime_can_offset = max($total_shift_divided - $total_am_rendered -$total_am_undertime -$total_am_late,0);
						$total_pm_over = max($total_pm_rendered - $total_shift_divided,0);
						
						$hours_to_be_render+=$total_shift_divided;
						// debug('paid_date_time_out = '. $paid_date_time_out);
						// debug('paid_date_break_in = '. $paid_date_break_in);
						// debug('total_pm_undertime = '. convert_seconds_to_time($total_pm_undertime));
						// debug('total_pm_late = '. convert_seconds_to_time($total_pm_late));
						// debug('total_pm_rendered = '. convert_seconds_to_time($total_pm_rendered));
					
					}
					else{
						$total_pm_undertime =$total_shift_divided;
						$total_pm_late = 0;
					}
					if( !empty($this->data['TimeEntry']['break_in']) && !empty($this->data['TimeEntry']['break_out']) && !empty($this->data['TimeEntry']['time_out']) && !empty($this->data['TimeEntry']['time_in'])){
						$total_break_render = $this->get_total_break_hours($paid_date_break_in, $this->data['TimeEntry']['break_out']);
						$total_break_late = max(($total_break_render - $break_time) -($total_pm_late + $total_am_undertime) ,0) ;
					}else{
						//if half day compute if render the halfday hours;
						$undertime_render =max(($total_am_undertime_can_offset+$total_pm_undertime_can_offset) - ($total_pm_over + $total_am_over),0);
					}
					// debug('paid_date_break_in = '. ($paid_date_break_in));
					// debug('paid_date_break_out = '. ($paid_date_break_out));
					// debug('total_break_render = '. convert_seconds_to_time($total_break_render));
					// debug('break_time = '. convert_seconds_to_time($break_time));
					// debug('total_break_late = '. convert_seconds_to_time($total_break_late));
					// debug('total_break_late = '. convert_seconds_to_time($total_break_late));
					$total_hours_rendered= $total_pm_rendered + $total_am_rendered;
					// get if rendered the half day or whole day hour and add it to under time
					$total_hours_late= $total_pm_late + $total_am_late + $total_break_late;
					$total_hours_undertime= $total_pm_undertime + $total_am_undertime + $undertime_render;
				}
			}
			//end del edit
		}
		// debug("total_hours_undertime = " .convert_seconds_to_time($total_hours_undertime));		
		// debug($this->data['TimeEntry']);
		// exit();
		
		//end overide
		
		$total_payable_regular_hours_rendered = ($total_shift_hours - ($total_hours_late + $total_hours_undertime));
		// debug('undertime_render = '. convert_seconds_to_time($undertime_render));
		// debug($total_shift_hours);
		// debug($total_hours_late);

		$this->data['TimeEntry']['total_break_hours']= convert_seconds_to_time($employee_total_hours_break);
		$this->data['TimeEntry']['hours_rendered']= convert_seconds_to_time($total_hours_rendered);
		$this->data['TimeEntry']['payable_regular_hours_rendered']= convert_seconds_to_time($total_payable_regular_hours_rendered);
		$this->data['TimeEntry']['late']= convert_seconds_to_time($total_hours_late);
		$this->data['TimeEntry']['ot']= convert_seconds_to_time($total_hours_overtime);
		$this->data['TimeEntry']['posible_ot_hrs']= convert_seconds_to_time($total_posible_overtime_hours);
		$this->data['TimeEntry']['undertime']= convert_seconds_to_time($total_hours_undertime);
		$this->data['TimeEntry']['night_differential']= $total_hours_night_diff;
		$this->data['TimeEntry']['holiday_code']= $holiday_code;
		$this->data['TimeEntry']['holiday_time']=$total_hours_holiday;
		
		// debug($this->data);
		// exit();
		
		if(isset($this->data['TimeEntry']['shift_date_time_in'])){
			$this->data['TimeEntry']['time_entry_date'] = date('Y-m-d', strtotime($this->data['TimeEntry']['shift_date_time_in']));
		}else{
			if (isset($this->data['TimeEntry']['bio_date_time'])) {
				$this->data['TimeEntry']['time_entry_date'] = date('Y-m-d', strtotime($this->data['TimeEntry']['bio_date_time']));
			}
			else {
				if (!isset($this->data['TimeEntry']['time_entry_date'])) {
					$this->data['TimeEntry']['time_entry_date'] = date('Y-m-d', strtotime($this->data['TimeEntry']['schedule_date']));
				}
			}
		}
		
		// ranz_edit: Raymart start
		if ($this->data['TimeEntry']['schedule_type'] == "flexible") {
			$this->data['TimeEntry']['undertime']=0;
			$this->data['TimeEntry']['late']=0;
		}
		// Raymart end

		//status Tagging
		if($is_disputed===true){
			$this->data['TimeEntry']['time_entry_status'] = 'R';
		}elseif($has_schedule===false){
			$this->data['TimeEntry']['time_entry_status'] = 'N';
			$this->data['TimeEntry']['undertime']=0;
			$this->data['TimeEntry']['late']=0;
		}elseif($total_hours_undertime>=1){
			if ($overwrite_status===false){
				$this->data['TimeEntry']['time_entry_status'] = 'U';
			}else{
				$this->data['TimeEntry']['time_entry_status'] = 'I'; //SPECIAL COMPUTATION STATUS
			}
		}elseif(!empty($this->data['TimeEntry']['time_in']) && !empty($this->data['TimeEntry']['time_out'])){
			$this->data['TimeEntry']['time_entry_status'] = 'C';
		}else{
			$this->data['TimeEntry']['time_entry_status'] = 'I';
		}

		if (isset($this->data['TimeEntry']['schedule_code']) && trim($this->data['TimeEntry']['schedule_code'])!==''){
			$EmployeeSchedule = ClassRegistry::init('EmployeeSchedule');
			$response = $EmployeeSchedule->query("UPDATE employee_schedules SET has_attendance = 1 WHERE code = '".$this->data['TimeEntry']['schedule_code']."'");

			if($response===false){
				return false;
			}
			
		}

		// debug($this->data);
		// exit();
		return true;
	}
	
	
	
	

	private function get_payable_regular_hours_rendered($total_hours_rendered=0,$total_hours_overtime=0,$total_hours_late=0,$total_hours_undertime=0){
		$payable_regular_hours_rendered =0;
		// $payable_regular_hours_rendered = ($total_hours_rendered - ($total_hours_overtime + $total_hours_late + $total_hours_undertime));
		$payable_regular_hours_rendered = ($total_hours_rendered - $total_hours_overtime);
		return $payable_regular_hours_rendered;
	}
	
	private function get_time_hours_rendered($has_schedule=false,$has_break=false,$shift_total_hours_break,$shift_datetime_in=null,$datetime_in=null,$datetime_out=null){
		$hours_rendered=0;
		if( ($has_schedule===false) || (strtotime($datetime_in) >= strtotime($shift_datetime_in))){
			$hours_rendered= abs(strtotime($datetime_in) - strtotime($datetime_out));
			//if has break automatically deduct the break hrs to total hours rendered
			if(($has_schedule===true) &&  ($has_break===true)) $hours_rendered -= $shift_total_hours_break;
		}else{
			$hours_rendered= abs(strtotime($shift_datetime_in) - strtotime($datetime_out));
			//if has break automatically deduct the break hrs to total hours rendered
			if($has_break===true) $hours_rendered -= $shift_total_hours_break;
		}
		return $hours_rendered;
	}
	
	private function get_time_late($shift_in=null,$time_in=null,$max_in_time=null){
		$time_late=0;
		if(!empty($shift_in)){
			if(!empty($max_in_time)) $shift_in = $max_in_time; //max in time for grace period
			if(strtotime($time_in) > strtotime($shift_in)){
				$time_late=abs(strtotime($time_in)-strtotime($shift_in));
			}
		}
		return $time_late;
	}
	
	private function get_time_overtime($shift_out=null,$time_out=null){
		$time_overtime=0;
		if(strtotime($time_out) > strtotime($shift_out)){
			$time_overtime=abs(strtotime($time_out)-strtotime($shift_out));
		}
		return $time_overtime;
	}
	
	private function get_time_undertime($shift_out_schedule,$current_time_out){
		$time_undertime=0;
		
		if(strtotime($current_time_out) < strtotime($shift_out_schedule)){
			$time_undertime=abs(strtotime($current_time_out)-strtotime($shift_out_schedule));
		}
		return $time_undertime;
	}
	
	private function get_total_break_hours($break_out=null,$break_in=null){
		return abs(strtotime($break_in)-strtotime($break_out));
	}
	
	private function get_holiday_code($start_work=null,$end_work=null){
		$holiday_conditions =array();
		if(!empty($start_work) && !empty($end_work)){
			$holiday_conditions = array(
				'OR'=>array(
					array('Holiday.holiday_date'=>date('Y-m-d',strtotime($start_work))),
					array('Holiday.holiday_date'=>date('Y-m-d',strtotime($end_work)))
				)
			);
		}elseif(!empty($start_work) && empty($end_work)){
			$holiday_conditions = array(
				'Holiday.holiday_date'=>date('Y-m-d',strtotime($start_work))
			);
		}elseif(empty($start_work) && !empty($end_work)){
			$holiday_conditions = array(
				'Holiday.holiday_date'=>date('Y-m-d',strtotime($end_work))
			);
		}else{
			return false;
		}
		
		// debug($start_work);
		// debug($end_work);
		// debug($holiday_conditions);
		// exit();
		
		$Holiday = ClassRegistry::init('Holiday');	
		$Holiday->recursive=-1;
		$holidays = $Holiday->find('first',array(
			'fields'=>array(
				'Holiday.code',
				'Holiday.holiday_date'
			),
			'conditions'=>array(
				$holiday_conditions,
				'Holiday.status'=>'Active'
			),
		));
		
		if (count($holidays)>=1){
			return $holidays;
		}else{
			return array();
		}
	}
	
	private function get_night_differential_hours(){
		$NightDifferential = ClassRegistry::init('NightDifferential');	
		$data=$NightDifferential->find('first',array(
			'fields'=>array(
				'time_from',
				'time_to'
			),
			'conditions'=>array(
				'NightDifferential.status'=>'Active'
			)
		));
		
		if(count($data)<=0){
			return array();
		}else{
			return array(
				'NightDifferential'=>array(
					'time_from' => $data['NightDifferential']['time_from'],
					'time_to' => $data['NightDifferential']['time_to']
				)
			);
		}
	}
	
	function get_night_differential_and_holiday($start_night,$end_night,$start_work,$end_work)
	{
		$start_night =date('Y-m-d',strtotime($start_work)). ' ' . $start_night;
		$end_night = date('Y-m-d',strtotime($start_work)). ' ' . $end_night;
		
		$start_night = strtotime($start_night);
		$end_night = strtotime($end_night);
		
		$start_work = strtotime($start_work);
		$end_work = strtotime($end_work);
		
		if ($start_night > $end_night){
			$end_night +=86400; //add 1day
		}

		if($start_work >= $start_night && $start_work <= $end_night)
		{
			if($end_work >= $end_night)
			{
				return convert_seconds_to_time(($end_night - $start_work));
			}
			else
			{
				return convert_seconds_to_time(($end_work - $start_work));
			}
		}
		elseif($end_work >= $start_night && $end_work <= $end_night)
		{
			
			if($start_work <= $start_night)
			{
				return convert_seconds_to_time(($end_work - $start_night));
			}
			else
			{
				return convert_seconds_to_time(($end_work - $start_work));
			}
		}
		else
		{
			if($start_work < $start_night && $end_work > $end_night)
			{
				return convert_seconds_to_time(($end_night - $start_night));
			}
			return convert_seconds_to_time(strtotime(0));
		}
	}
	
	private function get_night_differential($start_work=null,$end_work=null){
		// $this->autoRender=false;
		$start_work ='23:00:00';
		$end_work = '07:00:00';
		
		$start_work =strtotime(date('H:i:s',strtotime($start_work)));
		$end_work =strtotime(date('H:i:s',strtotime($end_work)));
		$NightDifferential = ClassRegistry::init('NightDifferential');	
		$data=$NightDifferential->find('first',array(
			'fields'=>array(
				'time_from',
				'time_to'
			),
			'conditions'=>array(
				'NightDifferential.status'=>'Active'
			)
		));
		
		if(count($data)<=0){
			return convert_seconds_to_time(strtotime(0));
			exit();
		}
		
		$start_night=strtotime($data['NightDifferential']['time_from']);
		$end_night=strtotime($data['NightDifferential']['time_to']);
		if($start_work>$end_work){
			$start_work = strtotime('+0 day',$start_work);
			$end_work =strtotime('+1 day',$end_work);
		}else{
			$start_work = strtotime('+0 day',$start_work);
			$end_work = strtotime('+0 day',$end_work);
		}
		if((date("Y-m-d",$start_work) == date("Y-m-d",$end_work)) && ($start_work<$end_work)){
			if($start_work>=$start_night && $start_work<=strtotime('23:59:59')){
				if($start_night>$end_night){
					$start_night = strtotime('+0 day',$start_night);
					$end_night = strtotime('+1 day',$end_night);
				}else{
					$start_night = strtotime('+0 day',$start_night);
					$end_night = strtotime('+0 day',$end_night);
				}
				// debug("1.1");
			}else{
				if($start_night>$end_night){
					$start_night = strtotime('-1 day',$start_night);
					$end_night = strtotime('0 day',$end_night);
				}else{
					$start_night = strtotime('+0 day',$start_night);
					$end_night = strtotime('+0 day',$end_night);
				}
				// debug("1.2");
			}
		}
		elseif(date("Y-m-d",$start_work) == date("Y-m-d",$end_work)){
			// debug("2");
				if($start_night>$end_night){
					$start_night = strtotime('-1 day',$start_night);
					$end_night = strtotime('+0 day',$end_night);
				}else{
					$start_night = strtotime('+0 day',$start_night);
					$end_night = strtotime('+0 day',$end_night);
				}
		}else{
			// debug("3");
			if($start_night>$end_night){
				$start_night = strtotime('+0 day',$start_night);
				$end_night = strtotime('+1 day',$end_night);
			}else{
				$start_night = strtotime('+0 day',$start_night);
				$end_night = strtotime('+0 day',$end_night);
			}
			
		}
		
		// debug(date('Y-m-d H:i:s',$start_night));
		// debug(date('Y-m-d H:i:s',$end_night));	
		
		// debug(date('Y-m-d H:i:s',$start_work));
		// debug(date('Y-m-d H:i:s',$end_work));	

		// if(($start_work>=$start_night && $start_work<=$end_night) || ($end_work>=$start_night && (($end_work<=$end_night)||($end_work>=$end_night)))){
			$night_diff_hours_start=null;
			$night_diff_hours_end=null;
			
				if($start_work<=$start_night){
					$night_diff_hours_start=$start_night;
				}else{
					$night_diff_hours_start = $start_work;
				}

				if($end_work>=$end_night){
					$night_diff_hours_end=$end_night;
				}else{
					$night_diff_hours_end=$end_work;
				}
				
			// debug(date('Y-m-d H:i:s',$night_diff_hours_start));
			// debug(date('Y-m-d H:i:s',$night_diff_hours_end));	
			// exit();
			
			$total_hours_diff = abs($night_diff_hours_start-$night_diff_hours_end);
			return $total_hours_diff;
		// }else{
			// return convert_seconds_to_time(strtotime(0));
		// }
		
	}
	
	private function get_holiday_hours($start_work=null,$end_work=null){
		// $this->autoRender=false;
		$start_work =strtotime(date('H:i:s',strtotime($start_work)));
		$end_work =strtotime(date('H:i:s',strtotime($end_work)));
		
		$start_night=strtotime('1:00:00');
		$end_night=strtotime('24:00:00');
	
		if($start_work>$end_work){
			$start_work = strtotime('+0 day',$start_work);
			$end_work =strtotime('+1 day',$end_work);
		}else{
			$start_work = strtotime('+1 day',$start_work);
			$end_work = strtotime('+0 day',$end_work);
		}
		
		if($start_night>$end_night){
			$start_night = strtotime('+0 day',$start_night);
			$end_night = strtotime('+1 day',$end_night);
		}else{
			$start_night = strtotime('+1 day',$start_night);
			$end_night = strtotime('+0 day',$end_night);
		}
		

		if(($start_work>=$start_night && $start_work<=$end_night) || ($end_work>=$start_night && (($end_work<=$end_night)||($end_work>=$end_night)))){
			$night_diff_hours_start=null;
			$night_diff_hours_end=null;
			
			if (date('a',$start_work)=='pm'){
				
				if($start_night<=$start_work){
					$night_diff_hours_start=$start_work;
				}else{
					$night_diff_hours_start=$start_night;
				}
				
				if($end_work<=$end_night){
					$night_diff_hours_end=$end_work;
				}else{
					$night_diff_hours_end=$end_night;
				}
				
			}else{
				if($end_night>=$start_work){
					$night_diff_hours_start=$start_work;
				}

				if($end_night>=$end_work){
					$night_diff_hours_end=$end_night;
				}else{
					$night_diff_hours_end=$end_work;
				}	
			}
			
			$total_hours_diff = abs($night_diff_hours_start-$night_diff_hours_end);
			return convert_seconds_to_time($total_hours_diff);
		}else{
			return convert_seconds_to_time(strtotime(0));
		}
		
	}
	
	
	private function get_time_entry_by_id($id=null){
		$data = $this->find('first',array(
			'fields'=>array(
				'TimeEntry.time_in',
				'TimeEntry.time_out',
				'TimeEntry.shift_code',
				'Shift.time_in',
				'Shift.time_out',
				'Shift.no_of_hours',
				'TimeEntry.time_entry_status'
			),
			'joins'=>array(
				array(
					'table'=>'setting_shifts',
					'alias'=>'Shift',
					'type'=>'left',
					'conditions'=>array(
						'Shift.code=TimeEntry.shift_code',
						'Shift.status'=>'Active',
					)
				),
			),
			'conditions'=>array(
				'TimeEntry.id'=>$id
			),
			'recursive'=>-1
		));	
		return $data;
	}
	
	
	
	
	// public function afterFind($results, $primary = false)
	// {
		// foreach($results as $x => $result){
			// if(isset($result['TimeEntry']['time_in'])){
				// $results[$x]['TimeEntry']['time_in'] = date('m/d/Y - h:iA',strtotime($results[$x]['TimeEntry']['time_in']));
			// }
			
			// if(isset($result['TimeEntry']['break_in'])){
				// $results[$x]['TimeEntry']['break_in'] = date('m/d/Y - h:iA',strtotime($results[$x]['TimeEntry']['break_in']));
			// }
			
			// if(isset($result['TimeEntry']['break_out'])){
				// $results[$x]['TimeEntry']['break_out'] = date('m/d/Y - h:iA',strtotime($results[$x]['TimeEntry']['break_out']));
			// }
			
			// if(isset($result['TimeEntry']['time_out'])){
				// $results[$x]['TimeEntry']['time_out'] = date('m/d/Y - h:iA',strtotime($results[$x]['TimeEntry']['time_out']));
			// }
		// }
		
		// return $results;
	// }
	//new version
}
?>