<?php
App::uses('AppModel', 'Model');

class TrainingSeminarType extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			)
        ),	
	);
	
	public function add_training_seminar_type($data = array()) {		
		$existing_training_seminar_type = $this->find_existing_training_seminar_type_by_name($data['TrainingSeminarType']['name']);
		
		if(isset($existing_training_seminar_type) && count($existing_training_seminar_type) > 0) {
			$existing_training_seminar_type['TrainingSeminarType']['status'] = 'Active';
			$data = $existing_training_seminar_type;
			
		}

		return $this->save($data);
	}
	
	public function update_training_seminar_type($data = array()) {
		return $this->save($data);
	}
	
	public function update_status($training_seminar_type_id = null, $training_seminar_type = null) {
		$existing_training_seminar_type = $this->find_existing_training_seminar_type_by_id_or_code($training_seminar_type_id);
		
		if(isset($existing_training_seminar_type) && count($existing_training_seminar_type) > 0) {
			$existing_training_seminar_type['TrainingSeminarType']['status'] = $training_seminar_type;
			$data = $existing_training_seminar_type;
		}

		return $this->save($data);
	}
	
	public function find_existing_training_seminar_type_by_name($training_seminar_type_name = null) {
		if(isset($training_seminar_type_name)) {
			$default_conditions = array(
				'TrainingSeminarType.name' => $training_seminar_type_name
			);
		}
		
		$training_seminar_type = $this->find('first', array(
			'fields' => array(
				'TrainingSeminarType.id',
				'TrainingSeminarType.code',
				'TrainingSeminarType.name',
				'TrainingSeminarType.status',
				'TrainingSeminarType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $training_seminar_type;
	}
	
	public function find_existing_training_seminar_type_by_id_or_code($training_seminar_type_id = null) {
		if(is_numeric($training_seminar_type_id)) {
			$default_conditions = array(
				'TrainingSeminarType.id' => $training_seminar_type_id
			);
		}
		else {
			$default_conditions = array(
				'TrainingSeminarType.code' => $training_seminar_type_id
			);
		}
		
		$training_seminar_type = $this->find('first', array(
			'fields' => array(
				'TrainingSeminarType.id',
				'TrainingSeminarType.code',
				'TrainingSeminarType.name',
				'TrainingSeminarType.status',
				'TrainingSeminarType.lock_flag'
			),
			'recursive'=>-1,
			'conditions' => $default_conditions
		));
		
		return $training_seminar_type;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['TrainingSeminarType']['id'])) {
			$this->data['TrainingSeminarType']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TrainingSeminarType']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TrainingSeminarType']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'TST';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['TrainingSeminarType']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['TrainingSeminarType']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>