<?php
App::uses('AppModel', 'Model');

class TrainingsSeminar extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	// public $primaryKey = 'code';
	// public $displayField = 'name';
	public $validate = array(
        'date_from' => array(
			'date_from logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Date is required.'
			),
        ),
		'date_to' => array(
			'date_to logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Date is required.'
			),
        ),
		'activity_title' => array(
			'activity_title logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Activity Title is required.'
			),
        ),
		'provider' => array(
			'provider logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Provider is required.'
			),
        ),
	);
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'TrainingSeminarType' => array(
			'className' => 'TrainingSeminarType',
			'foreignKey' => 'training_seminar_type_code',
			'conditions' => array(
				'TrainingSeminarType.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['TrainingsSeminar']['date_from']) && validate_datetime($this->data['TrainingsSeminar']['date_from'], 'm/d/Y')) {
			$this->data['TrainingsSeminar']['date_from'] = convert_datetime($this->data['TrainingsSeminar']['date_from'], 'Y-m-d');
		}	
			
		if(isset($this->data['TrainingsSeminar']['date_to']) && validate_datetime($this->data['TrainingsSeminar']['date_to'], 'm/d/Y')) {
			$this->data['TrainingsSeminar']['date_to'] = convert_datetime($this->data['TrainingsSeminar']['date_to'], 'Y-m-d');
		}
			
		return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['TrainingsSeminar']['id'])) {
			$this->data['TrainingsSeminar']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TrainingsSeminar']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['TrainingsSeminar']['status'] = 'Active';
		}
		else {
			$this->data['TrainingsSeminar']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['TrainingsSeminar']['date_from'])){
				$results[$x]['TrainingsSeminar']['date_from'] = date('m/d/Y',strtotime($results[$x]['TrainingsSeminar']['date_from']));
			}
			
			if(isset($result['TrainingsSeminar']['date_to'])){
				$results[$x]['TrainingsSeminar']['date_to'] = date('m/d/Y',strtotime($results[$x]['TrainingsSeminar']['date_to']));
			}
		}

		return $results;
	}
}
?>