<?php
App::uses('AppModel', 'Model');

class Transfer extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'employee_';
	public $primaryKey = 'code';
	// public $displayField = 'name';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			),
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			),
		),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'Unit.status' => 'Active'
			),
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'SubUnit.status' => 'Active'
			),
		),
		
	);

	public $hasMany = array(
		'TransferHistoryLog' => array(
			'className' => 'TransferHistoryLog',
			'foreignKey' => 'transfer_code',
			'fields' => array(
				'TransferHistoryLog.transfer_code',
				'TransferHistoryLog.employee_code',
				'TransferHistoryLog.transfer_date',
				'TransferHistoryLog.remarks',
			),
			'conditions' => array(
				'TransferHistoryLog.status' => 'Active'
			)
		),
	);
	public $validate = array(
		 
        'employee_code' => array(
            'employee_code logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'Employee is required.'
            ),
			
        ), 
	);
	public function beforeValidate($options = array()) {		
		if(isset($this->data['Transfer']['transfer_date']) && validate_datetime($this->data['Transfer']['transfer_date'], 'm/d/Y')) {
			$this->data['Transfer']['transfer_date'] = convert_datetime($this->data['Transfer']['transfer_date'], 'Y-m-d');
		}
			return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['Transfer']['id'])) {
			$this->data['Transfer']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Transfer']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Transfer']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'TRNFER';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Transfer']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Transfer']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['Transfer']['transfer_date'])){
				$results[$x]['Transfer']['transfer_date'] = date('m/d/Y',strtotime($results[$x]['Transfer']['transfer_date']));
			}
		}

		return $results;
	}
}
?>