<?php
App::uses('AppModel', 'Model');

class UnderTimeEntry extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'filing_';
	public $primaryKey = 'reference_number';
	// public $displayField = 'name';
	
	public $belongsTo = array(
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'Employee.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'employee_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
		'ApprovedByUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_unit',
			'conditions' => array(
				'ApprovedByUnit.status' => 'Active'
			)
		),
		'ApprovedBySubUnit' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_sub_unit',
			'conditions' => array(
				'ApprovedBySubUnit.status' => 'Active'
			)
		),
		'ApprovedBySection' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_section',
			'conditions' => array(
				'ApprovedBySection.status' => 'Active'
			)
		),
		'ApprovedByDivision' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_division',
			'conditions' => array(
				'ApprovedByDivision.status' => 'Active'
			)
		),
		'ApprovedByAdminOfficer' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_admin_officer',
			'conditions' => array(
				'ApprovedByAdminOfficer.status' => 'Active'
			)
		),
		'ApprovedByHRAdmin' => array(
			'className' => 'Employee',
			'foreignKey' => 'approved_by_hr_admin',
			'conditions' => array(
				'ApprovedByHRAdmin.status' => 'Active'
			)
		),
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		'Unit' => array(
			'className' => 'Unit',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'Unit.status' => 'Active'
			)
		),
		'SubUnit' => array(
			'className' => 'SubUnit',
			'foreignKey' => 'sub_unit_code',
			'conditions' => array(
				'SubUnit.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array (
		'FilingUnderTimeEntryAttachment' => array(
			'className' => 'FilingUnderTimeEntryAttachment',
			'foreignKey' => 'under_time_entry_reference_number',
			'conditions'=>array(
				'status'=>'Active'
			),
		),
	);
	public function beforeValidate($options = array()) {
		if(isset($this->data['UnderTimeEntry']['under_time_entry_date']) && validate_datetime($this->data['UnderTimeEntry']['under_time_entry_date'], 'm/d/Y')) {
			$this->data['UnderTimeEntry']['under_time_entry_date'] = convert_datetime($this->data['UnderTimeEntry']['under_time_entry_date'], 'Y-m-d');
		}	
			return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['UnderTimeEntry']['id'])) {
			$this->data['UnderTimeEntry']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['UnderTimeEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['UnderTimeEntry']['status'] = 'Active';

			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			$code_char = 'UTE';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$year = $reference['ReferenceCode']['year_code'];
			// debug($year);
			
			if($year != date('Y')){
				$year= date('Y');
				$ReferenceCode->query("UPDATE reference_codes SET year_code = '$year' WHERE prefix_code = '$code_char'");
				$code_number=1;
			}

			$this->data['UnderTimeEntry']['reference_number'] = (date('y') . '-'.$code_char . (str_pad($code_number,7,"0",STR_PAD_LEFT)));
			// debug($this->data['LaboratoryLogBook']['laboratory_case_number']);
			// exit();
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
			

		}
		else {
			$this->data['UnderTimeEntry']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false)
	{
		foreach($results as $x => $result){
			if(isset($result['UnderTimeEntry']['under_time_entry_date'])){
				$results[$x]['UnderTimeEntry']['under_time_entry_date'] = date('m/d/Y',strtotime($results[$x]['UnderTimeEntry']['under_time_entry_date']));
			}
		}

		return $results;
	}
}
?>