<?php
App::uses('AppModel', 'Model');

class Unit extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'setting_';
	public $primaryKey = 'code';
	public $displayField = 'name';
	
	public $validate = array(
        'name' => array(
			'name logic 1' => array(
				'rule'		=> 'isUnique',
				'message'	=> 'Name is already used.',
			),
			'name logic 2' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Name is required.'
			),
        ),
	);
	
	public $belongsTo = array(
		'Division' => array(
			'className' => 'Division',
			'foreignKey' => 'division_code',
			'fields' => array(
				'Division.name',
				
			),
			'conditions' => array(
				'Division.status' => 'Active'
			)
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'fields' => array(
				'Section.name',
				
			),
			'conditions' => array(
				'Section.status' => 'Active'
			)
		),
		
		'UnitHead' => array(
			'className' => 'Employee',
			'foreignKey' => 'unit_head',
			'fields' => array(
				'UnitHead.combination_whole_name',
				
			),
			'conditions' => array(
				'UnitHead.status' => 'Active'
			)
		),
		'UnitHeadAssistant' => array(
			'className' => 'Employee',
			'foreignKey' => 'unit_head_assistant',
			'fields' => array(
				'UnitHeadAssistant.combination_whole_name',
				
			),
			'conditions' => array(
				'UnitHeadAssistant.status' => 'Active'
			)
		),
	);
	
	public $hasMany = array(
		'UnitHistoryLog' => array(
			'className' => 'UnitHistoryLog',
			'foreignKey' => 'unit_code',
			'fields' => array(
				'UnitHistoryLog.section_code',
				'UnitHistoryLog.unit_code',
				'UnitHistoryLog.name',
				'UnitHistoryLog.unit_head',
				'UnitHistoryLog.unit_head_assistant',
			),
			'conditions' => array(
				'UnitHistoryLog.status' => 'Active'
			)
		),
		'PositionDetail' => array(
			'className' => 'PositionDetail',
			'foreignKey' => 'unit_code',
			'conditions' => array(
				'PositionDetail.status' => 'Active'
			)
		),
	);	
	
	public function add_unit($data = array()) {		
		$existing_unit = $this->find_existing_unit_by_name($data['Unit']['name']);
		
		if(isset($existing_unit) && count($existing_unit) > 0) {
			
			$existing_unit['Unit']['status'] = 'Active';
			
			$data = $existing_unit;			
			return $this->save($data);
		}

		return $this->saveAssociated($data);
	}
	
	public function update_unit($data = array()) {
		return $this->saveAssociated($data);
	}
	
	public function update_status($unit_id = null, $unit = null) {
		$existing_unit = $this->find_existing_unit_by_id_or_code($unit_id);
		
		if(isset($existing_unit) && count($existing_unit) > 0) {
			$existing_unit['Unit']['status'] = $unit;
			$data = $existing_unit;
		}

		return $this->save($data);
	}
	
	public function find_existing_unit_by_name($unit_name = null) {
		if(isset($unit_name)) {
			$default_conditions = array(
				'Unit.name' => $unit_name
			);
		}
		
		$unit = $this->find('first', array(
			'recursive'=>1,
			'conditions' => $default_conditions
		));

		return $unit;
	}
	
	public function find_existing_unit_by_id_or_code($unit_id = null) {
		if(is_numeric($unit_id)) {
			$default_conditions = array(
				'Unit.id' => $unit_id
			);
		}
		else {
			$default_conditions = array(
				'Unit.code' => $unit_id
			);
		}
		
		$unit = $this->find('first', array(

			'recursive'=>1,
			'conditions' => $default_conditions
		));
		
		return $unit;
	}

	public function beforeSave($options = array()) {
		if(!isset($this->data['Unit']['id'])) {
			$this->data['Unit']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Unit']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['Unit']['status'] = 'Active';
			
			$ReferenceCode = ClassRegistry::init('ReferenceCode');
			
			$code_char = 'UNIT';
			$reference = $ReferenceCode->findByPrefixCode($code_char);
			$code_number = $reference['ReferenceCode']['number'] + 1;
			$this->data['Unit']['code'] = $code_char . '-' . $code_number;
		
			$ReferenceCode->query("UPDATE reference_codes SET number = '$code_number' WHERE prefix_code = '$code_char'");
		}
		else {
			$this->data['Unit']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
}
?>