<?php
App::uses('AppModel', 'Model');
App::uses('SimplePasswordHasher', 'Controller/Component/Auth');
App::uses('Folder', 'Utility');
App::uses('File', 'Utility');

class User extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	
	public $belongsTo = array(
	'UserPrivilege' => array(
			'className' => 'UserPrivilege',
			'foreignKey' => 'user_privilege_id',
			'fields' => array(
				'title',
				'page_access'
			),
			'conditions' => array(
				'UserPrivilege.status' => 'Active'
			)
		),
		'Employee' => array(
			'className' => 'Employee',
			'foreignKey' => 'employee_code',
		),
	);

	
	// public $useTable = 'integration_users';

    public $validate = array(
        'username' => array(
            'username logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'A username is required'
            ),
			'username logic 2' => array(
				'rule'		=> 'isUnique',
				// 'on' => 'create',
				'message'	=> 'Username is already used.'
			),
			'username logic 3' => array(
                'rule' => array('alphaNumeric'),
                'message' => 'Username must only contain letters and numbers.'
            )
        ), 
        'password' => array(
			'password logic 1' => array(
                'rule' => array('alphaNumeric'),
                'message' => 'Password must only contain letters and numbers.',
				'allowEmpty' => true
            ),
			'password logic 2' => array(
                'rule' => array('notEmpty'),
                'message' => 'A password is required'
            ),
        ),
		
        'status' => array(
            'status logic 1' => array(
                'rule' => array('inList', array('Active', 'Disabled')),
                'message' => 'Please select a status.',
                'allowEmpty' => false
            )
        ),
		'user_privilege_id' => array(
            'user_privilege_id logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'A User Privilege is required.'
            ),

        ),
		'role' => array(
            'role logic 1' => array(
                'rule' => array('notEmpty'),
                'message' => 'A Role is required.'
            ),

        ),		
    );
	
	
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['User']['id'])) {
			$this->data['User']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['User']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['User']['status'] = 'Active';
		}
		else {
			$this->data['User']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		$passwordHasher = new SimplePasswordHasher();
		
		if (isset($this->data['User']['password'])) {
			$this->data['User']['password'] = $passwordHasher->hash($this->data['User']['password']);
		}
		else {
			unset($this->data['User']['password']);
		}
		
		return true;
	}
}
?>