<?php
App::uses('AppModel', 'Model');

class VacancyJobOrder extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'recruitment_';
	
	public $validate = array(
        'job_title_code' => array(
			'job_title_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Position Title is required.'
			),
        ),		
	);
	
	public $belongsTo = array(
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			),
		),
	);
	
	public $hasOne = array(
		'SuggestedSchedule' => array(
			'className' => 'SuggestedSchedule',
			'foreignKey' => 'vacancy_job_order_id',
			'conditions' => array(
				'SuggestedSchedule.status' => 'Active'
			),
		),
		
		'ActualSchedule' => array(
			'className' => 'ActualSchedule',
			'foreignKey' => 'vacancy_job_order_id',
			'conditions' => array(
				'ActualSchedule.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['VacancyJobOrder']['valid_from_date'])) {
			$this->data['VacancyJobOrder']['valid_from_date'] = convert_datetime($this->data['VacancyJobOrder']['valid_from_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['VacancyJobOrder']['valid_to_date'])) {
			$this->data['VacancyJobOrder']['valid_to_date'] = convert_datetime($this->data['VacancyJobOrder']['valid_to_date'], 'Y-m-d');
		}
		
		if(isset($this->data['VacancyJobOrder']['date_vacancy'])) {
			$this->data['VacancyJobOrder']['date_vacancy'] = convert_datetime($this->data['VacancyJobOrder']['date_vacancy'], 'Y-m-d');
		}	
		
		return true;
	}
	
	public function beforeSave($options = array()) {
		if(!isset($this->data['VacancyJobOrder']['id']) || $this->data['VacancyJobOrder']['id'] == '') {
			$this->data['VacancyJobOrder']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['VacancyJobOrder']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['VacancyJobOrder']['status'] = 'Active';
			$this->data['VacancyJobOrder']['number_of_vacancy'] = '1';
		}
		else {
			$this->data['VacancyJobOrder']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		
		return true;
	}
	
	public function afterFind($results, $primary = false) {
		foreach($results as $x => $result){
			if(isset($result['VacancyJobOrder']['valid_from_date'])){
				$results[$x]['VacancyJobOrder']['valid_from_date'] = date('m/d/Y',strtotime($results[$x]['VacancyJobOrder']['valid_from_date']));
			}
			
			if(isset($result['VacancyJobOrder']['valid_to_date'])){
				$results[$x]['VacancyJobOrder']['valid_to_date'] = date('m/d/Y',strtotime($results[$x]['VacancyJobOrder']['valid_to_date']));
			}
		}

		return $results;
	}
}
?>