<?php
App::uses('AppModel', 'Model');

class VacancyPlantilla extends AppModel {
	
	public $actsAs = array('AuditLog.Auditable');
	public $tablePrefix = 'recruitment_';
	
	public $validate = array(
        'job_title_code' => array(
			'job_title_code logic 1' => array(
				'rule'		=> 'notEmpty',
				'message'	=> 'Position Title is required.'
			),
        ),
		// 'job_title_item_number_code' => array(
			// 'job_title_item_number_code logic 1' => array(
				// 'rule'		=> 'notEmpty',
				// 'message'	=> 'Item Number is required.'
			// ),
        // ),
		
	);
	
	public $belongsTo = array(
		'JobTitle' => array(
			'className' => 'JobTitle',
			'foreignKey' => 'job_title_code',
			'conditions' => array(
				'JobTitle.status' => 'Active'
			),
		),
		'JobTitleItemNumber' => array(
			'className' => 'JobTitleItemNumber',
			'foreignKey' => 'job_title_item_number_code',
			'conditions' => array(
				'JobTitleItemNumber.status' => 'Active'
			),
		),
		'Section' => array(
			'className' => 'Section',
			'foreignKey' => 'section_code',
			'conditions' => array(
				'Section.status' => 'Active'
			),
		),
		
		
	);
	
	public $hasOne = array(
		'SuggestedSchedule' => array(
			'className' => 'SuggestedSchedule',
			'foreignKey' => 'vacancy_plantilla_id',
			'conditions' => array(
				'SuggestedSchedule.status' => 'Active'
			),
		),
		
		'ActualSchedule' => array(
			'className' => 'ActualSchedule',
			'foreignKey' => 'vacancy_plantilla_id',
			'conditions' => array(
				'ActualSchedule.status' => 'Active'
			),
		),
	);
	
	public function beforeValidate($options = array()) {
		if(isset($this->data['VacancyPlantilla']['valid_from_date'])) {
			$this->data['VacancyPlantilla']['valid_from_date'] = convert_datetime($this->data['VacancyPlantilla']['valid_from_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['VacancyPlantilla']['valid_to_date'])) {
			$this->data['VacancyPlantilla']['valid_to_date'] = convert_datetime($this->data['VacancyPlantilla']['valid_to_date'], 'Y-m-d');
		}	
		
		if(isset($this->data['VacancyPlantilla']['date_vacancy'])) {
			$this->data['VacancyPlantilla']['date_vacancy'] = convert_datetime($this->data['VacancyPlantilla']['date_vacancy'], 'Y-m-d');
		}	
		
		return true;
	}
	
	public function beforeSave($options = array()) {
		
		if(!isset($this->data['VacancyPlantilla']['id']) || $this->data['VacancyPlantilla']['id'] == '') {
			$this->data['VacancyPlantilla']['created_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['VacancyPlantilla']['modified_by'] = $_SESSION['Auth']['User']['id'];
			$this->data['VacancyPlantilla']['status'] = 'Active';
			// debug($this->data);
		}
		else {
			$this->data['VacancyPlantilla']['modified_by'] = $_SESSION['Auth']['User']['id'];
		}
		// debug($this->data);
		// exit();
		return true;
	}
	
	public function afterFind($results, $primary = false) {
		foreach($results as $x => $result){
			if(isset($result['VacancyPlantilla']['valid_from_date'])){
				$results[$x]['VacancyPlantilla']['valid_from_date'] = date('m/d/Y',strtotime($results[$x]['VacancyPlantilla']['valid_from_date']));
			}
			
			if(isset($result['VacancyPlantilla']['valid_to_date'])){
				$results[$x]['VacancyPlantilla']['valid_to_date'] = date('m/d/Y',strtotime($results[$x]['VacancyPlantilla']['valid_to_date']));
			}
		}

		return $results;
	}
}
?>